// The Module object: Our interface to the outside world. We import
// and export values on it, and do the work to get that through
// closure compiler if necessary. There are various ways Module can be used:
// 1. Not defined. We create it here
// 2. A function parameter, function(Module) { ..generated code.. }
// 3. pre-run appended it, var Module = {}; ..generated code..
// 4. External script tag defines var Module.
// We need to do an eval in order to handle the closure compiler
// case, where this code here is minified but Module was defined
// elsewhere (e.g. case 4 above). We also need to check if Module
// already exists (e.g. case 3 above).
// Note that if you want to run closure, and also to use Module
// after the generated code, you will need to define   var Module = {};
// before the code. Then that object will be used in the code, and you
// can continue to use Module afterwards as well.
var Module;
if (!Module) Module = (typeof Module !== 'undefined' ? Module : null) || {};

// Sometimes an existing Module object exists with properties
// meant to overwrite the default module functionality. Here
// we collect those properties and reapply _after_ we configure
// the current environment's defaults to avoid having to be so
// defensive during initialization.
var moduleOverrides = {};
for (var key in Module) {
  if (Module.hasOwnProperty(key)) {
    moduleOverrides[key] = Module[key];
  }
}

// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function';
var ENVIRONMENT_IS_WEB = typeof window === 'object';
var ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;

if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  if (!Module['print']) Module['print'] = function print(x) {
    process['stdout'].write(x + '\n');
  };
  if (!Module['printErr']) Module['printErr'] = function printErr(x) {
    process['stderr'].write(x + '\n');
  };

  var nodeFS = require('fs');
  var nodePath = require('path');

  Module['read'] = function read(filename, binary) {
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename);
    // The path is absolute if the normalized version is the same as the resolved.
    if (!ret && filename != nodePath['resolve'](filename)) {
      filename = path.join(__dirname, '..', 'src', filename);
      ret = nodeFS['readFileSync'](filename);
    }
    if (ret && !binary) ret = ret.toString();
    return ret;
  };

  Module['readBinary'] = function readBinary(filename) { return Module['read'](filename, true) };

  Module['load'] = function load(f) {
    globalEval(read(f));
  };

  if (process['argv'].length > 1) {
    Module['thisProgram'] = process['argv'][1].replace(/\\/g, '/');
  } else {
    Module['thisProgram'] = 'unknown-program';
  }

  Module['arguments'] = process['argv'].slice(2);

  if (typeof module !== 'undefined') {
    module['exports'] = Module;
  }

  process['on']('uncaughtException', function(ex) {
    // suppress ExitStatus exceptions from showing an error
    if (!(ex instanceof ExitStatus)) {
      throw ex;
    }
  });
}
else if (ENVIRONMENT_IS_SHELL) {
  if (!Module['print']) Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm

  if (typeof read != 'undefined') {
    Module['read'] = read;
  } else {
    Module['read'] = function read() { throw 'no read() available (jsc?)' };
  }

  Module['readBinary'] = function readBinary(f) {
    if (typeof readbuffer === 'function') {
      return new Uint8Array(readbuffer(f));
    }
    var data = read(f, 'binary');
    assert(typeof data === 'object');
    return data;
  };

  if (typeof scriptArgs != 'undefined') {
    Module['arguments'] = scriptArgs;
  } else if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }

  this['Module'] = Module;

}
else if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function read(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };

  if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }

  if (typeof console !== 'undefined') {
    if (!Module['print']) Module['print'] = function print(x) {
      console.log(x);
    };
    if (!Module['printErr']) Module['printErr'] = function printErr(x) {
      console.log(x);
    };
  } else {
    // Probably a worker, and without console.log. We can do very little here...
    var TRY_USE_DUMP = false;
    if (!Module['print']) Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
  }

  if (ENVIRONMENT_IS_WEB) {
    window['Module'] = Module;
  } else {
    Module['load'] = importScripts;
  }
}
else {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}

function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] && Module['read']) {
  Module['load'] = function load(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
if (!Module['thisProgram']) {
  Module['thisProgram'] = './this.program';
}

// *** Environment setup code ***

// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];

// Callbacks
Module['preRun'] = [];
Module['postRun'] = [];

// Merge back in the overrides
for (var key in moduleOverrides) {
  if (moduleOverrides.hasOwnProperty(key)) {
    Module[key] = moduleOverrides[key];
  }
}



// === Preamble library stuff ===

// Documentation for the public APIs defined in this file must be updated in: 
//    site/source/docs/api_reference/preamble.js.rst
// A prebuilt local version of the documentation is available at: 
//    site/build/text/docs/api_reference/preamble.js.txt
// You can also build docs locally as HTML or other formats in site/
// An online HTML version (which may be of a different version of Emscripten)
//    is up at http://kripken.github.io/emscripten-site/docs/api_reference/preamble.js.html

//========================================
// Runtime code shared with compiler
//========================================

var Runtime = {
  setTempRet0: function (value) {
    tempRet0 = value;
  },
  getTempRet0: function () {
    return tempRet0;
  },
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  getNativeTypeSize: function (type) {
    switch (type) {
      case 'i1': case 'i8': return 1;
      case 'i16': return 2;
      case 'i32': return 4;
      case 'i64': return 8;
      case 'float': return 4;
      case 'double': return 8;
      default: {
        if (type[type.length-1] === '*') {
          return Runtime.QUANTUM_SIZE; // A pointer
        } else if (type[0] === 'i') {
          var bits = parseInt(type.substr(1));
          assert(bits % 8 === 0);
          return bits/8;
        } else {
          return 0;
        }
      }
    }
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  STACK_ALIGN: 16,
  getAlignSize: function (type, size, vararg) {
    // we align i64s and doubles on 64-bit boundaries, unlike x86
    if (!vararg && (type == 'i64' || type == 'double')) return 8;
    if (!type) return Math.min(size, 8); // align structures internally to 64 bits
    return Math.min(size || (type ? Runtime.getNativeFieldSize(type) : 0), Runtime.QUANTUM_SIZE);
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      if (!args.splice) args = Array.prototype.slice.call(args);
      args.splice(0, 0, ptr);
      return Module['dynCall_' + sig].apply(null, args);
    } else {
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  functionPointers: [],
  addFunction: function (func) {
    for (var i = 0; i < Runtime.functionPointers.length; i++) {
      if (!Runtime.functionPointers[i]) {
        Runtime.functionPointers[i] = func;
        return 2*(1 + i);
      }
    }
    throw 'Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS.';
  },
  removeFunction: function (index) {
    Runtime.functionPointers[(index-2)/2] = null;
  },
  getAsmConst: function (code, numArgs) {
    // code is a constant string on the heap, so we can cache these
    if (!Runtime.asmConstCache) Runtime.asmConstCache = {};
    var func = Runtime.asmConstCache[code];
    if (func) return func;
    var args = [];
    for (var i = 0; i < numArgs; i++) {
      args.push(String.fromCharCode(36) + i); // $0, $1 etc
    }
    var source = Pointer_stringify(code);
    if (source[0] === '"') {
      // tolerate EM_ASM("..code..") even though EM_ASM(..code..) is correct
      if (source.indexOf('"', 1) === source.length-1) {
        source = source.substr(1, source.length-2);
      } else {
        // something invalid happened, e.g. EM_ASM("..code($0)..", input)
        abort('invalid EM_ASM input |' + source + '|. Please use EM_ASM(..code..) (no quotes) or EM_ASM({ ..code($0).. }, input) (to input values)');
      }
    }
    try {
      // Module is the only 'upvar', which we provide directly. We also provide FS for legacy support.
      var evalled = eval('(function(Module, FS) { return function(' + args.join(',') + '){ ' + source + ' } })')(Module, typeof FS !== 'undefined' ? FS : null);
    } catch(e) {
      Module.printErr('error in executing inline EM_ASM code: ' + e + ' on: \n\n' + source + '\n\nwith args |' + args + '| (make sure to use the right one out of EM_ASM, EM_ASM_ARGS, etc.)');
      throw e;
    }
    return Runtime.asmConstCache[code] = evalled;
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[sig]) {
      Runtime.funcWrappers[sig] = {};
    }
    var sigCache = Runtime.funcWrappers[sig];
    if (!sigCache[func]) {
      sigCache[func] = function dynCall_wrapper() {
        return Runtime.dynCall(sig, func, arguments);
      };
    }
    return sigCache[func];
  },
  UTF8Processor: function () {
    var buffer = [];
    var needed = 0;
    this.processCChar = function (code) {
      code = code & 0xFF;

      if (buffer.length == 0) {
        if ((code & 0x80) == 0x00) {        // 0xxxxxxx
          return String.fromCharCode(code);
        }
        buffer.push(code);
        if ((code & 0xE0) == 0xC0) {        // 110xxxxx
          needed = 1;
        } else if ((code & 0xF0) == 0xE0) { // 1110xxxx
          needed = 2;
        } else {                            // 11110xxx
          needed = 3;
        }
        return '';
      }

      if (needed) {
        buffer.push(code);
        needed--;
        if (needed > 0) return '';
      }

      var c1 = buffer[0];
      var c2 = buffer[1];
      var c3 = buffer[2];
      var c4 = buffer[3];
      var ret;
      if (buffer.length == 2) {
        ret = String.fromCharCode(((c1 & 0x1F) << 6)  | (c2 & 0x3F));
      } else if (buffer.length == 3) {
        ret = String.fromCharCode(((c1 & 0x0F) << 12) | ((c2 & 0x3F) << 6)  | (c3 & 0x3F));
      } else {
        // http://mathiasbynens.be/notes/javascript-encoding#surrogate-formulae
        var codePoint = ((c1 & 0x07) << 18) | ((c2 & 0x3F) << 12) |
                        ((c3 & 0x3F) << 6)  | (c4 & 0x3F);
        ret = String.fromCharCode(
          (((codePoint - 0x10000) / 0x400)|0) + 0xD800,
          (codePoint - 0x10000) % 0x400 + 0xDC00);
      }
      buffer.length = 0;
      return ret;
    }
    this.processJSString = function processJSString(string) {
      /* TODO: use TextEncoder when present,
        var encoder = new TextEncoder();
        encoder['encoding'] = "utf-8";
        var utf8Array = encoder['encode'](aMsg.data);
      */
      string = unescape(encodeURIComponent(string));
      var ret = [];
      for (var i = 0; i < string.length; i++) {
        ret.push(string.charCodeAt(i));
      }
      return ret;
    }
  },
  getCompilerSetting: function (name) {
    throw 'You must build with -s RETAIN_COMPILER_SETTINGS=1 for Runtime.getCompilerSetting or emscripten_get_compiler_setting to work';
  },
  stackAlloc: function (size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = (((STACKTOP)+15)&-16); return ret; },
  staticAlloc: function (size) { var ret = STATICTOP;STATICTOP = (STATICTOP + size)|0;STATICTOP = (((STATICTOP)+15)&-16); return ret; },
  dynamicAlloc: function (size) { var ret = DYNAMICTOP;DYNAMICTOP = (DYNAMICTOP + size)|0;DYNAMICTOP = (((DYNAMICTOP)+15)&-16); if (DYNAMICTOP >= TOTAL_MEMORY) enlargeMemory();; return ret; },
  alignMemory: function (size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 16))*(quantum ? quantum : 16); return ret; },
  makeBigInt: function (low,high,unsigned) { var ret = (unsigned ? ((+((low>>>0)))+((+((high>>>0)))*4294967296.0)) : ((+((low>>>0)))+((+((high|0)))*4294967296.0))); return ret; },
  GLOBAL_BASE: 8,
  QUANTUM_SIZE: 4,
  __dummy__: 0
}


Module['Runtime'] = Runtime;









//========================================
// Runtime essentials
//========================================

var __THREW__ = 0; // Used in checking for thrown exceptions.

var ABORT = false; // whether we are quitting the application. no code should run after this. set in exit() and abort()
var EXITSTATUS = 0;

var undef = 0;
// tempInt is used for 32-bit signed values or smaller. tempBigInt is used
// for 32-bit unsigned values or more than 32 bits. TODO: audit all uses of tempInt
var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD, tempDouble, tempFloat;
var tempI64, tempI64b;
var tempRet0, tempRet1, tempRet2, tempRet3, tempRet4, tempRet5, tempRet6, tempRet7, tempRet8, tempRet9;

function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}

var globalScope = this;

// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  var func = Module['_' + ident]; // closure exported function
  if (!func) {
    try {
      func = eval('_' + ident); // explicit lookup
    } catch(e) {}
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}

var cwrap, ccall;
(function(){
  var JSfuncs = {
    // Helpers for cwrap -- it can't refer to Runtime directly because it might
    // be renamed by closure, instead it calls JSfuncs['stackSave'].body to find
    // out what the minified function name is.
    'stackSave': function() {
      Runtime.stackSave()
    },
    'stackRestore': function() {
      Runtime.stackRestore()
    },
    // type conversion from js to c
    'arrayToC' : function(arr) {
      var ret = Runtime.stackAlloc(arr.length);
      writeArrayToMemory(arr, ret);
      return ret;
    },
    'stringToC' : function(str) {
      var ret = 0;
      if (str !== null && str !== undefined && str !== 0) { // null string
        // at most 4 bytes per UTF-8 code point, +1 for the trailing '\0'
        ret = Runtime.stackAlloc((str.length << 2) + 1);
        writeStringToMemory(str, ret);
      }
      return ret;
    }
  };
  // For fast lookup of conversion functions
  var toC = {'string' : JSfuncs['stringToC'], 'array' : JSfuncs['arrayToC']};

  // C calling interface. 
  ccall = function ccallFunc(ident, returnType, argTypes, args) {
    var func = getCFunc(ident);
    var cArgs = [];
    var stack = 0;
    if (args) {
      for (var i = 0; i < args.length; i++) {
        var converter = toC[argTypes[i]];
        if (converter) {
          if (stack === 0) stack = Runtime.stackSave();
          cArgs[i] = converter(args[i]);
        } else {
          cArgs[i] = args[i];
        }
      }
    }
    var ret = func.apply(null, cArgs);
    if (returnType === 'string') ret = Pointer_stringify(ret);
    if (stack !== 0) Runtime.stackRestore(stack);
    return ret;
  }

  var sourceRegex = /^function\s*\(([^)]*)\)\s*{\s*([^*]*?)[\s;]*(?:return\s*(.*?)[;\s]*)?}$/;
  function parseJSFunc(jsfunc) {
    // Match the body and the return value of a javascript function source
    var parsed = jsfunc.toString().match(sourceRegex).slice(1);
    return {arguments : parsed[0], body : parsed[1], returnValue: parsed[2]}
  }
  var JSsource = {};
  for (var fun in JSfuncs) {
    if (JSfuncs.hasOwnProperty(fun)) {
      // Elements of toCsource are arrays of three items:
      // the code, and the return value
      JSsource[fun] = parseJSFunc(JSfuncs[fun]);
    }
  }

  
  cwrap = function cwrap(ident, returnType, argTypes) {
    argTypes = argTypes || [];
    var cfunc = getCFunc(ident);
    // When the function takes numbers and returns a number, we can just return
    // the original function
    var numericArgs = argTypes.every(function(type){ return type === 'number'});
    var numericRet = (returnType !== 'string');
    if ( numericRet && numericArgs) {
      return cfunc;
    }
    // Creation of the arguments list (["$1","$2",...,"$nargs"])
    var argNames = argTypes.map(function(x,i){return '$'+i});
    var funcstr = "(function(" + argNames.join(',') + ") {";
    var nargs = argTypes.length;
    if (!numericArgs) {
      // Generate the code needed to convert the arguments from javascript
      // values to pointers
      funcstr += 'var stack = ' + JSsource['stackSave'].body + ';';
      for (var i = 0; i < nargs; i++) {
        var arg = argNames[i], type = argTypes[i];
        if (type === 'number') continue;
        var convertCode = JSsource[type + 'ToC']; // [code, return]
        funcstr += 'var ' + convertCode.arguments + ' = ' + arg + ';';
        funcstr += convertCode.body + ';';
        funcstr += arg + '=' + convertCode.returnValue + ';';
      }
    }

    // When the code is compressed, the name of cfunc is not literally 'cfunc' anymore
    var cfuncname = parseJSFunc(function(){return cfunc}).returnValue;
    // Call the function
    funcstr += 'var ret = ' + cfuncname + '(' + argNames.join(',') + ');';
    if (!numericRet) { // Return type can only by 'string' or 'number'
      // Convert the result to a string
      var strgfy = parseJSFunc(function(){return Pointer_stringify}).returnValue;
      funcstr += 'ret = ' + strgfy + '(ret);';
    }
    if (!numericArgs) {
      // If we had a stack, restore it
      funcstr += JSsource['stackRestore'].body.replace('()', '(stack)') + ';';
    }
    funcstr += 'return ret})';
    return eval(funcstr);
  };
})();
Module["cwrap"] = cwrap;
Module["ccall"] = ccall;


function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[((ptr)>>0)]=value; break;
      case 'i8': HEAP8[((ptr)>>0)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,(tempDouble=value,(+(Math_abs(tempDouble))) >= 1.0 ? (tempDouble > 0.0 ? ((Math_min((+(Math_floor((tempDouble)/4294967296.0))), 4294967295.0))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/4294967296.0)))))>>>0) : 0)],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF64[((ptr)>>3)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module['setValue'] = setValue;


function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[((ptr)>>0)];
      case 'i8': return HEAP8[((ptr)>>0)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF64[((ptr)>>3)];
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module['getValue'] = getValue;

var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_DYNAMIC = 3; // Cannot be freed except through sbrk
var ALLOC_NONE = 4; // Do not allocate
Module['ALLOC_NORMAL'] = ALLOC_NORMAL;
Module['ALLOC_STACK'] = ALLOC_STACK;
Module['ALLOC_STATIC'] = ALLOC_STATIC;
Module['ALLOC_DYNAMIC'] = ALLOC_DYNAMIC;
Module['ALLOC_NONE'] = ALLOC_NONE;

// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }

  var singleType = typeof types === 'string' ? types : null;

  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [_malloc, Runtime.stackAlloc, Runtime.staticAlloc, Runtime.dynamicAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }

  if (zeroinit) {
    var ptr = ret, stop;
    assert((ret & 3) == 0);
    stop = ret + (size & ~3);
    for (; ptr < stop; ptr += 4) {
      HEAP32[((ptr)>>2)]=0;
    }
    stop = ret + size;
    while (ptr < stop) {
      HEAP8[((ptr++)>>0)]=0;
    }
    return ret;
  }

  if (singleType === 'i8') {
    if (slab.subarray || slab.slice) {
      HEAPU8.set(slab, ret);
    } else {
      HEAPU8.set(new Uint8Array(slab), ret);
    }
    return ret;
  }

  var i = 0, type, typeSize, previousType;
  while (i < size) {
    var curr = slab[i];

    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }

    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }

    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later

    setValue(ret+i, curr, type);

    // no need to look up size unless type changes, so cache it
    if (previousType !== type) {
      typeSize = Runtime.getNativeTypeSize(type);
      previousType = type;
    }
    i += typeSize;
  }

  return ret;
}
Module['allocate'] = allocate;

function Pointer_stringify(ptr, /* optional */ length) {
  if (length === 0 || !ptr) return '';
  // TODO: use TextDecoder
  // Find the length, and check for UTF while doing so
  var hasUtf = false;
  var t;
  var i = 0;
  while (1) {
    t = HEAPU8[(((ptr)+(i))>>0)];
    if (t >= 128) hasUtf = true;
    else if (t == 0 && !length) break;
    i++;
    if (length && i == length) break;
  }
  if (!length) length = i;

  var ret = '';

  if (!hasUtf) {
    var MAX_CHUNK = 1024; // split up into chunks, because .apply on a huge string can overflow the stack
    var curr;
    while (length > 0) {
      curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
      ret = ret ? ret + curr : curr;
      ptr += MAX_CHUNK;
      length -= MAX_CHUNK;
    }
    return ret;
  }

  var utf8 = new Runtime.UTF8Processor();
  for (i = 0; i < length; i++) {
    t = HEAPU8[(((ptr)+(i))>>0)];
    ret += utf8.processCChar(t);
  }
  return ret;
}
Module['Pointer_stringify'] = Pointer_stringify;

function UTF16ToString(ptr) {
  var i = 0;

  var str = '';
  while (1) {
    var codeUnit = HEAP16[(((ptr)+(i*2))>>1)];
    if (codeUnit == 0)
      return str;
    ++i;
    // fromCharCode constructs a character from a UTF-16 code unit, so we can pass the UTF16 string right through.
    str += String.fromCharCode(codeUnit);
  }
}
Module['UTF16ToString'] = UTF16ToString;


function stringToUTF16(str, outPtr) {
  for(var i = 0; i < str.length; ++i) {
    // charCodeAt returns a UTF-16 encoded code unit, so it can be directly written to the HEAP.
    var codeUnit = str.charCodeAt(i); // possibly a lead surrogate
    HEAP16[(((outPtr)+(i*2))>>1)]=codeUnit;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP16[(((outPtr)+(str.length*2))>>1)]=0;
}
Module['stringToUTF16'] = stringToUTF16;


function UTF32ToString(ptr) {
  var i = 0;

  var str = '';
  while (1) {
    var utf32 = HEAP32[(((ptr)+(i*4))>>2)];
    if (utf32 == 0)
      return str;
    ++i;
    // Gotcha: fromCharCode constructs a character from a UTF-16 encoded code (pair), not from a Unicode code point! So encode the code point to UTF-16 for constructing.
    if (utf32 >= 0x10000) {
      var ch = utf32 - 0x10000;
      str += String.fromCharCode(0xD800 | (ch >> 10), 0xDC00 | (ch & 0x3FF));
    } else {
      str += String.fromCharCode(utf32);
    }
  }
}
Module['UTF32ToString'] = UTF32ToString;


function stringToUTF32(str, outPtr) {
  var iChar = 0;
  for(var iCodeUnit = 0; iCodeUnit < str.length; ++iCodeUnit) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! We must decode the string to UTF-32 to the heap.
    var codeUnit = str.charCodeAt(iCodeUnit); // possibly a lead surrogate
    if (codeUnit >= 0xD800 && codeUnit <= 0xDFFF) {
      var trailSurrogate = str.charCodeAt(++iCodeUnit);
      codeUnit = 0x10000 + ((codeUnit & 0x3FF) << 10) | (trailSurrogate & 0x3FF);
    }
    HEAP32[(((outPtr)+(iChar*4))>>2)]=codeUnit;
    ++iChar;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP32[(((outPtr)+(iChar*4))>>2)]=0;
}
Module['stringToUTF32'] = stringToUTF32;

function demangle(func) {
  var hasLibcxxabi = !!Module['___cxa_demangle'];
  if (hasLibcxxabi) {
    try {
      var buf = _malloc(func.length);
      writeStringToMemory(func.substr(1), buf);
      var status = _malloc(4);
      var ret = Module['___cxa_demangle'](buf, 0, 0, status);
      if (getValue(status, 'i32') === 0 && ret) {
        return Pointer_stringify(ret);
      }
      // otherwise, libcxxabi failed, we can try ours which may return a partial result
    } catch(e) {
      // failure when using libcxxabi, we can try ours which may return a partial result
    } finally {
      if (buf) _free(buf);
      if (status) _free(status);
      if (ret) _free(ret);
    }
  }
  var i = 3;
  // params, etc.
  var basicTypes = {
    'v': 'void',
    'b': 'bool',
    'c': 'char',
    's': 'short',
    'i': 'int',
    'l': 'long',
    'f': 'float',
    'd': 'double',
    'w': 'wchar_t',
    'a': 'signed char',
    'h': 'unsigned char',
    't': 'unsigned short',
    'j': 'unsigned int',
    'm': 'unsigned long',
    'x': 'long long',
    'y': 'unsigned long long',
    'z': '...'
  };
  var subs = [];
  var first = true;
  function dump(x) {
    //return;
    if (x) Module.print(x);
    Module.print(func);
    var pre = '';
    for (var a = 0; a < i; a++) pre += ' ';
    Module.print (pre + '^');
  }
  function parseNested() {
    i++;
    if (func[i] === 'K') i++; // ignore const
    var parts = [];
    while (func[i] !== 'E') {
      if (func[i] === 'S') { // substitution
        i++;
        var next = func.indexOf('_', i);
        var num = func.substring(i, next) || 0;
        parts.push(subs[num] || '?');
        i = next+1;
        continue;
      }
      if (func[i] === 'C') { // constructor
        parts.push(parts[parts.length-1]);
        i += 2;
        continue;
      }
      var size = parseInt(func.substr(i));
      var pre = size.toString().length;
      if (!size || !pre) { i--; break; } // counter i++ below us
      var curr = func.substr(i + pre, size);
      parts.push(curr);
      subs.push(curr);
      i += pre + size;
    }
    i++; // skip E
    return parts;
  }
  function parse(rawList, limit, allowVoid) { // main parser
    limit = limit || Infinity;
    var ret = '', list = [];
    function flushList() {
      return '(' + list.join(', ') + ')';
    }
    var name;
    if (func[i] === 'N') {
      // namespaced N-E
      name = parseNested().join('::');
      limit--;
      if (limit === 0) return rawList ? [name] : name;
    } else {
      // not namespaced
      if (func[i] === 'K' || (first && func[i] === 'L')) i++; // ignore const and first 'L'
      var size = parseInt(func.substr(i));
      if (size) {
        var pre = size.toString().length;
        name = func.substr(i + pre, size);
        i += pre + size;
      }
    }
    first = false;
    if (func[i] === 'I') {
      i++;
      var iList = parse(true);
      var iRet = parse(true, 1, true);
      ret += iRet[0] + ' ' + name + '<' + iList.join(', ') + '>';
    } else {
      ret = name;
    }
    paramLoop: while (i < func.length && limit-- > 0) {
      //dump('paramLoop');
      var c = func[i++];
      if (c in basicTypes) {
        list.push(basicTypes[c]);
      } else {
        switch (c) {
          case 'P': list.push(parse(true, 1, true)[0] + '*'); break; // pointer
          case 'R': list.push(parse(true, 1, true)[0] + '&'); break; // reference
          case 'L': { // literal
            i++; // skip basic type
            var end = func.indexOf('E', i);
            var size = end - i;
            list.push(func.substr(i, size));
            i += size + 2; // size + 'EE'
            break;
          }
          case 'A': { // array
            var size = parseInt(func.substr(i));
            i += size.toString().length;
            if (func[i] !== '_') throw '?';
            i++; // skip _
            list.push(parse(true, 1, true)[0] + ' [' + size + ']');
            break;
          }
          case 'E': break paramLoop;
          default: ret += '?' + c; break paramLoop;
        }
      }
    }
    if (!allowVoid && list.length === 1 && list[0] === 'void') list = []; // avoid (void)
    if (rawList) {
      if (ret) {
        list.push(ret + '?');
      }
      return list;
    } else {
      return ret + flushList();
    }
  }
  var parsed = func;
  try {
    // Special-case the entry point, since its name differs from other name mangling.
    if (func == 'Object._main' || func == '_main') {
      return 'main()';
    }
    if (typeof func === 'number') func = Pointer_stringify(func);
    if (func[0] !== '_') return func;
    if (func[1] !== '_') return func; // C function
    if (func[2] !== 'Z') return func;
    switch (func[3]) {
      case 'n': return 'operator new()';
      case 'd': return 'operator delete()';
    }
    parsed = parse();
  } catch(e) {
    parsed += '?';
  }
  if (parsed.indexOf('?') >= 0 && !hasLibcxxabi) {
    Runtime.warnOnce('warning: a problem occurred in builtin C++ name demangling; build with  -s DEMANGLE_SUPPORT=1  to link in libcxxabi demangling');
  }
  return parsed;
}

function demangleAll(text) {
  return text.replace(/__Z[\w\d_]+/g, function(x) { var y = demangle(x); return x === y ? x : (x + ' [' + y + ']') });
}

function jsStackTrace() {
  var err = new Error();
  if (!err.stack) {
    // IE10+ special cases: It does have callstack info, but it is only populated if an Error object is thrown,
    // so try that as a special-case.
    try {
      throw new Error(0);
    } catch(e) {
      err = e;
    }
    if (!err.stack) {
      return '(no stack trace available)';
    }
  }
  return err.stack.toString();
}

function stackTrace() {
  return demangleAll(jsStackTrace());
}
Module['stackTrace'] = stackTrace;

// Memory management

var PAGE_SIZE = 4096;
function alignMemoryPage(x) {
  return (x+4095)&-4096;
}

var HEAP;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;

var STATIC_BASE = 0, STATICTOP = 0, staticSealed = false; // static area
var STACK_BASE = 0, STACKTOP = 0, STACK_MAX = 0; // stack area
var DYNAMIC_BASE = 0, DYNAMICTOP = 0; // dynamic area handled by sbrk

function enlargeMemory() {
  abort('Cannot enlarge memory arrays. Either (1) compile with -s TOTAL_MEMORY=X with X higher than the current value ' + TOTAL_MEMORY + ', (2) compile with ALLOW_MEMORY_GROWTH which adjusts the size at runtime but prevents some optimizations, or (3) set Module.TOTAL_MEMORY before the program runs.');
}


var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 33554432;
var FAST_MEMORY = Module['FAST_MEMORY'] || 2097152;

var totalMemory = 64*1024;
while (totalMemory < TOTAL_MEMORY || totalMemory < 2*TOTAL_STACK) {
  if (totalMemory < 16*1024*1024) {
    totalMemory *= 2;
  } else {
    totalMemory += 16*1024*1024
  }
}
if (totalMemory !== TOTAL_MEMORY) {
  Module.printErr('increasing TOTAL_MEMORY to ' + totalMemory + ' to be compliant with the asm.js spec');
  TOTAL_MEMORY = totalMemory;
}

// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(typeof Int32Array !== 'undefined' && typeof Float64Array !== 'undefined' && !!(new Int32Array(1)['subarray']) && !!(new Int32Array(1)['set']),
       'JS engine does not provide full typed array support');

var buffer = new ArrayBuffer(TOTAL_MEMORY);
HEAP8 = new Int8Array(buffer);
HEAP16 = new Int16Array(buffer);
HEAP32 = new Int32Array(buffer);
HEAPU8 = new Uint8Array(buffer);
HEAPU16 = new Uint16Array(buffer);
HEAPU32 = new Uint32Array(buffer);
HEAPF32 = new Float32Array(buffer);
HEAPF64 = new Float64Array(buffer);

// Endianness check (note: assumes compiler arch was little-endian)
HEAP32[0] = 255;
assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, 'Typed arrays 2 must be run on a little-endian system');

Module['HEAP'] = HEAP;
Module['buffer'] = buffer;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;

function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    if (typeof callback == 'function') {
      callback();
      continue;
    }
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Runtime.dynCall('v', func);
      } else {
        Runtime.dynCall('vi', func, [callback.arg]);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}

var __ATPRERUN__  = []; // functions called before the runtime is initialized
var __ATINIT__    = []; // functions called during startup
var __ATMAIN__    = []; // functions called when main() is to be run
var __ATEXIT__    = []; // functions called during shutdown
var __ATPOSTRUN__ = []; // functions called after the runtime has exited

var runtimeInitialized = false;
var runtimeExited = false;

function preRun() {
  // compatibility - merge in anything from Module['preRun'] at this time
  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    while (Module['preRun'].length) {
      addOnPreRun(Module['preRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPRERUN__);
}

function ensureInitRuntime() {
  if (runtimeInitialized) return;
  runtimeInitialized = true;
  callRuntimeCallbacks(__ATINIT__);
}

function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}

function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
  runtimeExited = true;
}

function postRun() {
  // compatibility - merge in anything from Module['postRun'] at this time
  if (Module['postRun']) {
    if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
    while (Module['postRun'].length) {
      addOnPostRun(Module['postRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPOSTRUN__);
}

function addOnPreRun(cb) {
  __ATPRERUN__.unshift(cb);
}
Module['addOnPreRun'] = Module.addOnPreRun = addOnPreRun;

function addOnInit(cb) {
  __ATINIT__.unshift(cb);
}
Module['addOnInit'] = Module.addOnInit = addOnInit;

function addOnPreMain(cb) {
  __ATMAIN__.unshift(cb);
}
Module['addOnPreMain'] = Module.addOnPreMain = addOnPreMain;

function addOnExit(cb) {
  __ATEXIT__.unshift(cb);
}
Module['addOnExit'] = Module.addOnExit = addOnExit;

function addOnPostRun(cb) {
  __ATPOSTRUN__.unshift(cb);
}
Module['addOnPostRun'] = Module.addOnPostRun = addOnPostRun;

// Tools


function intArrayFromString(stringy, dontAddNull, length /* optional */) {
  var ret = (new Runtime.UTF8Processor()).processJSString(stringy);
  if (length) {
    ret.length = length;
  }
  if (!dontAddNull) {
    ret.push(0);
  }
  return ret;
}
Module['intArrayFromString'] = intArrayFromString;

function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module['intArrayToString'] = intArrayToString;

function writeStringToMemory(string, buffer, dontAddNull) {
  var array = intArrayFromString(string, dontAddNull);
  var i = 0;
  while (i < array.length) {
    var chr = array[i];
    HEAP8[(((buffer)+(i))>>0)]=chr;
    i = i + 1;
  }
}
Module['writeStringToMemory'] = writeStringToMemory;

function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[(((buffer)+(i))>>0)]=array[i];
  }
}
Module['writeArrayToMemory'] = writeArrayToMemory;

function writeAsciiToMemory(str, buffer, dontAddNull) {
  for (var i = 0; i < str.length; i++) {
    HEAP8[(((buffer)+(i))>>0)]=str.charCodeAt(i);
  }
  if (!dontAddNull) HEAP8[(((buffer)+(str.length))>>0)]=0;
}
Module['writeAsciiToMemory'] = writeAsciiToMemory;

function unSign(value, bits, ignore) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}

// check for imul support, and also for correctness ( https://bugs.webkit.org/show_bug.cgi?id=126345 )
if (!Math['imul'] || Math['imul'](0xffffffff, 5) !== -5) Math['imul'] = function imul(a, b) {
  var ah  = a >>> 16;
  var al = a & 0xffff;
  var bh  = b >>> 16;
  var bl = b & 0xffff;
  return (al*bl + ((ah*bl + al*bh) << 16))|0;
};
Math.imul = Math['imul'];


var Math_abs = Math.abs;
var Math_cos = Math.cos;
var Math_sin = Math.sin;
var Math_tan = Math.tan;
var Math_acos = Math.acos;
var Math_asin = Math.asin;
var Math_atan = Math.atan;
var Math_atan2 = Math.atan2;
var Math_exp = Math.exp;
var Math_log = Math.log;
var Math_sqrt = Math.sqrt;
var Math_ceil = Math.ceil;
var Math_floor = Math.floor;
var Math_pow = Math.pow;
var Math_imul = Math.imul;
var Math_fround = Math.fround;
var Math_min = Math.min;

// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyWatcher = null;
var dependenciesFulfilled = null; // overridden to take different actions when all run dependencies are fulfilled

function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
}
Module['addRunDependency'] = addRunDependency;
function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    }
    if (dependenciesFulfilled) {
      var callback = dependenciesFulfilled;
      dependenciesFulfilled = null;
      callback(); // can add another dependenciesFulfilled
    }
  }
}
Module['removeRunDependency'] = removeRunDependency;

Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data


var memoryInitializer = null;

// === Body ===





STATIC_BASE = 8;

STATICTOP = STATIC_BASE + 11760;
  /* global initializers */ __ATINIT__.push({ func: function() { __GLOBAL__I_a() } });
  

/* memory initializer */ allocate([0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,116,121,112,101,58,32,37,117,44,10,0,0,0,0,9,9,105,115,108,97,110,100,73,110,100,101,120,58,32,37,117,44,10,0,0,0,0,0,9,9,120,102,58,32,37,117,44,10,0,0,0,0,0,0,9,9,120,102,48,58,32,37,117,44,10,0,0,0,0,0,9,9,115,119,101,101,112,58,32,37,117,44,10,0,0,0,9,9,108,105,110,101,97,114,86,101,108,111,99,105,116,121,58,32,37,117,44,10,0,0,9,9,97,110,103,117,108,97,114,86,101,108,111,99,105,116,121,58,32,37,117,44,10,0,9,9,102,111,114,99,101,58,32,37,117,44,10,0,0,0,9,9,116,111,114,113,117,101,58,32,37,117,44,10,0,0,9,9,119,111,114,108,100,58,32,37,117,44,10,0,0,0,9,9,112,114,101,118,58,32,37,117,44,10,0,0,0,0,9,9,110,101,120,116,58,32,37,117,44,10,0,0,0,0,9,9,102,105,120,116,117,114,101,76,105,115,116,58,32,37,117,44,10,0,0,0,0,0,9,9,102,105,120,116,117,114,101,67,111,117,110,116,58,32,37,117,44,10,0,0,0,0,9,9,106,111,105,110,116,76,105,115,116,58,32,37,117,44,10,0,0,0,0,0,0,0,9,9,99,111,110,116,97,99,116,76,105,115,116,58,32,37,117,44,10,0,0,0,0,0,9,9,109,97,115,115,58,32,37,117,44,10,0,0,0,0,9,9,105,110,118,77,97,115,115,58,32,37,117,44,10,0,9,9,73,58,32,37,117,44,10,0,0,0,0,0,0,0,9,9,105,110,118,73,58,32,37,117,44,10,0,0,0,0,9,9,108,105,110,101,97,114,68,97,109,112,105,110,103,58,32,37,117,44,10,0,0,0,9,9,97,110,103,117,108,97,114,68,97,109,112,105,110,103,58,32,37,117,44,10,0,0,9,9,103,114,97,118,105,116,121,83,99,97,108,101,58,32,37,117,44,10,0,0,0,0,9,9,115,108,101,101,112,84,105,109,101,58,32,37,117,44,10,0,0,0,0,0,0,0,9,9,117,115,101,114,68,97,116,97,58,32,37,117,10,0,9,9,105,110,100,101,120,65,58,32,37,117,44,10,0,0,9,9,105,110,100,101,120,66,58,32,37,117,44,10,0,0,9,9,102,114,105,99,116,105,111,110,58,32,37,117,44,10,0,0,0,0,0,0,0,0,9,9,114,101,115,116,105,116,117,116,105,111,110,58,32,37,117,44,10,0,0,0,0,0,9,9,100,101,110,115,105,116,121,58,32,37,117,44,10,0,9,9,98,111,100,121,58,32,37,117,44,10,0,0,0,0,9,9,115,104,97,112,101,58,32,37,117,44,10,0,0,0,9,9,112,114,111,120,105,101,115,58,32,37,117,44,10,0,9,9,112,114,111,120,121,67,111,117,110,116,58,32,37,117,44,10,0,0,0,0,0,0,9,9,102,105,108,116,101,114,58,32,37,117,44,10,0,0,9,9,105,115,83,101,110,115,111,114,58,32,37,117,44,10,0,0,0,0,0,0,0,0,9,9,115,121,115,116,101,109,58,32,37,117,44,10,0,0,9,9,102,105,114,115,116,73,110,100,101,120,58,32,37,117,44,10,0,0,0,0,0,0,9,9,108,97,115,116,73,110,100,101,120,58,32,37,117,44,10,0,0,0,0,0,0,0,9,9,103,114,111,117,112,70,108,97,103,115,58,32,37,117,44,10,0,0,0,0,0,0,9,9,115,116,114,101,110,103,116,104,58,32,37,117,44,10,0,0,0,0,0,0,0,0,9,9,116,105,109,101,115,116,97,109,112,58,32,37,117,44,10,0,0,0,0,0,0,0,9,9,105,110,101,114,116,105,97,58,32,37,117,44,10,0,9,9,99,101,110,116,101,114,58,32,37,117,44,10,0,0,9,9,116,114,97,110,115,102,111,114,109,58,32,37,117,44,10,0,0,0,0,0,0,0,9,9,98,111,100,121,76,105,115,116,58,32,37,117,10,0,9,9,110,111,114,109,97,108,58,32,37,117,44,10,0,0,9,9,112,111,105,110,116,115,58,32,37,117,44,10,0,0,9,9,115,101,112,97,114,97,116,105,111,110,115,58,32,37,117,10,0,0,0,0,0,0,9,9,119,101,105,103,104,116,58,32,37,117,44,10,0,0,9,9,102,108,97,103,115,58,32,37,117,10,0,0,0,0,9,9,105,110,100,101,120,58,32,37,117,44,10,0,0,0,9,9,102,105,120,116,117,114,101,58,32,37,117,44,10,0,9,9,109,97,115,115,58,32,37,117,10,0,0,0,0,0,0,0,0,0,168,4,0,0,1,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,49,53,82,97,121,67,97,115,116,67,97,108,108,98,97,99,107,0,0,0,0,0,0,0,49,55,98,50,82,97,121,67,97,115,116,67,97,108,108,98,97,99,107,0,0,0,0,0,120,43,0,0,136,4,0,0,160,43,0,0,112,4,0,0,160,4,0,0,0,0,0,0,0,0,0,0,160,4,0,0,1,0,0,0,3,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,48,5,0,0,4,0,0,0,5,0,0,0,2,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,49,55,81,117,101,114,121,65,65,66,66,67,97,108,108,98,97,99,107,0,0,0,0,0,49,53,98,50,81,117,101,114,121,67,97,108,108,98,97,99,107,0,0,0,0,0,0,0,120,43,0,0,16,5,0,0,160,43,0,0,248,4,0,0,40,5,0,0,0,0,0,0,0,0,0,0,40,5,0,0,4,0,0,0,6,0,0,0,1,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,208,5,0,0,7,0,0,0,8,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,50,50,98,50,87,111,114,108,100,67,111,110,116,97,99,116,76,105,115,116,101,110,101,114,0,0,0,0,0,0,0,0,49,55,98,50,67,111,110,116,97,99,116,76,105,115,116,101,110,101,114,0,0,0,0,0,120,43,0,0,176,5,0,0,160,43,0,0,144,5,0,0,200,5,0,0,0,0,0,0,0,0,0,0,200,5,0,0,7,0,0,0,9,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,3,0,0,0,6,0,0,0,4,0,0,0,7,0,0,0,8,0,0,0,0,0,0,0,80,6,0,0,10,0,0,0,11,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,55,98,50,83,104,97,112,101,0,0,0,0,0,0,0,0,120,43,0,0,64,6,0,0,9,98,50,66,111,100,121,58,32,123,0,0,0,0,0,0,9,125,0,0,0,0,0,0,9,98,50,70,105,120,116,117,114,101,58,32,123,0,0,0,9,125,44,0,0,0,0,0,9,98,50,80,97,114,116,105,99,108,101,71,114,111,117,112,58,32,123,0,0,0,0,0,9,125,44,0,0,0,0,0,9,98,50,87,111,114,108,100,58,32,123,0,0,0,0,0,9,125,44,0,0,0,0,0,9,98,50,87,111,114,108,100,77,97,110,105,102,111,108,100,58,32,123,0,0,0,0,0,9,125,44,0,0,0,0,0,9,98,50,80,97,114,116,105,99,108,101,67,111,110,116,97,99,116,58,32,123,0,0,0,9,125,44,0,0,0,0,0,9,98,50,80,97,114,116,105,99,108,101,66,111,100,121,67,111,110,116,97,99,116,58,32,123,0,0,0,0,0,0,0,9,125,44,0,0,0,0,0,123,0,0,0,0,0,0,0,125,59,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,7,0,0,10,0,0,0,12,0,0,0,4,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,5,0,0,0,1,0,0,0,0,0,0,0,49,49,98,50,69,100,103,101,83,104,97,112,101,0,0,0,160,43,0,0,184,7,0,0,80,6,0,0,0,0,0,0,0,0,0,0,32,8,0,0,10,0,0,0,13,0,0,0,5,0,0,0,2,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,6,0,0,0,2,0,0,0,0,0,0,0,49,52,98,50,80,111,108,121,103,111,110,83,104,97,112,101,0,0,0,0,0,0,0,0,160,43,0,0,8,8,0,0,80,6,0,0,0,0,0,0,0,0,0,0,112,8,0,0,10,0,0,0,14,0,0,0,6,0,0,0,3,0,0,0,4,0,0,0,3,0,0,0,3,0,0,0,7,0,0,0,3,0,0,0,0,0,0,0,49,51,98,50,67,105,114,99,108,101,83,104,97,112,101,0,160,43,0,0,96,8,0,0,80,6,0,0,0,0,0,0,0,0,0,0,192,8,0,0,15,0,0,0,16,0,0,0,7,0,0,0,4,0,0,0,5,0,0,0,4,0,0,0,4,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,49,50,98,50,67,104,97,105,110,83,104,97,112,101,0,0,160,43,0,0,176,8,0,0,80,6,0,0,0,0,0,0,0,0,0,0,8,9,0,0,17,0,0,0,18,0,0,0,6,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,49,53,98,50,67,111,110,116,97,99,116,70,105,108,116,101,114,0,0,0,0,0,0,0,120,43,0,0,240,8,0,0,0,0,0,0,112,9,0,0,5,0,0,0,6,0,0,0,5,0,0,0,1,0,0,0,19,0,0,0,7,0,0,0,20,0,0,0,21,0,0,0,8,0,0,0,9,0,0,0,8,0,0,0,0,0,0,0,49,50,98,50,77,111,117,115,101,74,111,105,110,116,0,0,55,98,50,74,111,105,110,116,0,0,0,0,0,0,0,0,120,43,0,0,88,9,0,0,160,43,0,0,72,9,0,0,104,9,0,0,0,0,0,0,77,111,117,115,101,32,106,111,105,110,116,32,100,117,109,112,105,110,103,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,88,11,0,0,10,0,0,0,11,0,0,0,6,0,0,0,2,0,0,0,22,0,0,0,12,0,0,0,20,0,0,0,23,0,0,0,13,0,0,0,14,0,0,0,9,0,0,0,0,0,0,0,32,32,98,50,77,111,116,111,114,74,111,105,110,116,68,101,102,32,106,100,59,10,0,0,32,32,106,100,46,98,111,100,121,65,32,61,32,98,111,100,105,101,115,91,37,100,93,59,10,0,0,0,0,0,0,0,32,32,106,100,46,98,111,100,121,66,32,61,32,98,111,100,105,101,115,91,37,100,93,59,10,0,0,0,0,0,0,0,32,32,106,100,46,99,111,108,108,105,100,101,67,111,110,110,101,99,116,101,100,32,61,32,98,111,111,108,40,37,100,41,59,10,0,0,0,0,0,0,32,32,106,100,46,108,105,110,101,97,114,79,102,102,115,101,116,46,83,101,116,40,37,46,49,53,108,101,102,44,32,37,46,49,53,108,101,102,41,59,10,0,0,0,0,0,0,0,32,32,106,100,46,97,110,103,117,108,97,114,79,102,102,115,101,116,32,61,32,37,46,49,53,108,101,102,59,10,0,0,32,32,106,100,46,109,97,120,70,111,114,99,101,32,61,32,37,46,49,53,108,101,102,59,10,0,0,0,0,0,0,0,32,32,106,100,46,109,97,120,84,111,114,113,117,101,32,61,32,37,46,49,53,108,101,102,59,10,0,0,0,0,0,0,32,32,106,100,46,99,111,114,114,101,99,116,105,111,110,70,97,99,116,111,114,32,61,32,37,46,49,53,108,101,102,59,10,0,0,0,0,0,0,0,32,32,106,111,105,110,116,115,91,37,100,93,32,61,32,109,95,119,111,114,108,100,45,62,67,114,101,97,116,101,74,111,105,110,116,40,38,106,100,41,59,10,0,0,0,0,0,0,49,50,98,50,77,111,116,111,114,74,111,105,110,116,0,0,160,43,0,0,72,11,0,0,104,9,0,0,0,0,0,0,0,0,0,0,40,13,0,0,15,0,0,0,16,0,0,0,7,0,0,0,3,0,0,0,24,0,0,0,12,0,0,0,20,0,0,0,25,0,0,0,17,0,0,0,18,0,0,0,10,0,0,0,0,0,0,0,32,32,98,50,68,105,115,116,97,110,99,101,74,111,105,110,116,68,101,102,32,106,100,59,10,0,0,0,0,0,0,0,32,32,106,100,46,98,111,100,121,65,32,61,32,98,111,100,105,101,115,91,37,100,93,59,10,0,0,0,0,0,0,0,32,32,106,100,46,98,111,100,121,66,32,61,32,98,111,100,105,101,115,91,37,100,93,59,10,0,0,0,0,0,0,0,32,32,106,100,46,99,111,108,108,105,100,101,67,111,110,110,101,99,116,101,100,32,61,32,98,111,111,108,40,37,100,41,59,10,0,0,0,0,0,0,32,32,106,100,46,108,111,99,97,108,65,110,99,104,111,114,65,46,83,101,116,40,37,46,49,53,108,101,102,44,32,37,46,49,53,108,101,102,41,59,10,0,0,0,0,0,0,0,32,32,106,100,46,108,111,99,97,108,65,110,99,104,111,114,66,46,83,101,116,40,37,46,49,53,108,101,102,44,32,37,46,49,53,108,101,102,41,59,10,0,0,0,0,0,0,0,32,32,106,100,46,108,101,110,103,116,104,32,61,32,37,46,49,53,108,101,102,59,10,0,32,32,106,100,46,102,114,101,113,117,101,110,99,121,72,122,32,61,32,37,46,49,53,108,101,102,59,10,0,0,0,0,32,32,106,100,46,100,97,109,112,105,110,103,82,97,116,105,111,32,61,32,37,46,49,53,108,101,102,59,10,0,0,0,32,32,106,111,105,110,116,115,91,37,100,93,32,61,32,109,95,119,111,114,108,100,45,62,67,114,101,97,116,101,74,111,105,110,116,40,38,106,100,41,59,10,0,0,0,0,0,0,49,53,98,50,68,105,115,116,97,110,99,101,74,111,105,110,116,0,0,0,0,0,0,0,160,43,0,0,16,13,0,0,104,9,0,0,0,0,0,0,0,0,0,0,224,14,0,0,19,0,0,0,20,0,0,0,8,0,0,0,4,0,0,0,26,0,0,0,12,0,0,0,20,0,0,0,27,0,0,0,21,0,0,0,22,0,0,0,11,0,0,0,0,0,0,0,32,32,98,50,70,114,105,99,116,105,111,110,74,111,105,110,116,68,101,102,32,106,100,59,10,0,0,0,0,0,0,0,32,32,106,100,46,98,111,100,121,65,32,61,32,98,111,100,105,101,115,91,37,100,93,59,10,0,0,0,0,0,0,0,32,32,106,100,46,98,111,100,121,66,32,61,32,98,111,100,105,101,115,91,37,100,93,59,10,0,0,0,0,0,0,0,32,32,106,100,46,99,111,108,108,105,100,101,67,111,110,110,101,99,116,101,100,32,61,32,98,111,111,108,40,37,100,41,59,10,0,0,0,0,0,0,32,32,106,100,46,108,111,99,97,108,65,110,99,104,111,114,65,46,83,101,116,40,37,46,49,53,108,101,102,44,32,37,46,49,53,108,101,102,41,59,10,0,0,0,0,0,0,0,32,32,106,100,46,108,111,99,97,108,65,110,99,104,111,114,66,46,83,101,116,40,37,46,49,53,108,101,102,44,32,37,46,49,53,108,101,102,41,59,10,0,0,0,0,0,0,0,32,32,106,100,46,109,97,120,70,111,114,99,101,32,61,32,37,46,49,53,108,101,102,59,10,0,0,0,0,0,0,0,32,32,106,100,46,109,97,120,84,111,114,113,117,101,32,61,32,37,46,49,53,108,101,102,59,10,0,0,0,0,0,0,32,32,106,111,105,110,116,115,91,37,100,93,32,61,32,109,95,119,111,114,108,100,45,62,67,114,101,97,116,101,74,111,105,110,116,40,38,106,100,41,59,10,0,0,0,0,0,0,49,53,98,50,70,114,105,99,116,105,111,110,74,111,105,110,116,0,0,0,0,0,0,0,160,43,0,0,200,14,0,0,104,9,0,0,0,0,0,0,0,0,0,0,168,16,0,0,23,0,0,0,24,0,0,0,9,0,0,0,5,0,0,0,28,0,0,0,12,0,0,0,20,0,0,0,29,0,0,0,25,0,0,0,26,0,0,0,12,0,0,0,0,0,0,0,32,32,98,50,87,101,108,100,74,111,105,110,116,68,101,102,32,106,100,59,10,0,0,0,32,32,106,100,46,98,111,100,121,65,32,61,32,98,111,100,105,101,115,91,37,100,93,59,10,0,0,0,0,0,0,0,32,32,106,100,46,98,111,100,121,66,32,61,32,98,111,100,105,101,115,91,37,100,93,59,10,0,0,0,0,0,0,0,32,32,106,100,46,99,111,108,108,105,100,101,67,111,110,110,101,99,116,101,100,32,61,32,98,111,111,108,40,37,100,41,59,10,0,0,0,0,0,0,32,32,106,100,46,108,111,99,97,108,65,110,99,104,111,114,65,46,83,101,116,40,37,46,49,53,108,101,102,44,32,37,46,49,53,108,101,102,41,59,10,0,0,0,0,0,0,0,32,32,106,100,46,108,111,99,97,108,65,110,99,104,111,114,66,46,83,101,116,40,37,46,49,53,108,101,102,44,32,37,46,49,53,108,101,102,41,59,10,0,0,0,0,0,0,0,32,32,106,100,46,114,101,102,101,114,101,110,99,101,65,110,103,108,101,32,61,32,37,46,49,53,108,101,102,59,10,0,32,32,106,100,46,102,114,101,113,117,101,110,99,121,72,122,32,61,32,37,46,49,53,108,101,102,59,10,0,0,0,0,32,32,106,100,46,100,97,109,112,105,110,103,82,97,116,105,111,32,61,32,37,46,49,53,108,101,102,59,10,0,0,0,32,32,106,111,105,110,116,115,91,37,100,93,32,61,32,109,95,119,111,114,108,100,45,62,67,114,101,97,116,101,74,111,105,110,116,40,38,106,100,41,59,10,0,0,0,0,0,0,49,49,98,50,87,101,108,100,74,111,105,110,116,0,0,0,160,43,0,0,152,16,0,0,104,9,0,0,0,0,0,0,0,0,0,0,8,18,0,0,27,0,0,0,28,0,0,0,10,0,0,0,6,0,0,0,30,0,0,0,12,0,0,0,20,0,0,0,31,0,0,0,29,0,0,0,30,0,0,0,13,0,0,0,0,0,0,0,32,32,98,50,71,101,97,114,74,111,105,110,116,68,101,102,32,106,100,59,10,0,0,0,32,32,106,100,46,98,111,100,121,65,32,61,32,98,111,100,105,101,115,91,37,100,93,59,10,0,0,0,0,0,0,0,32,32,106,100,46,98,111,100,121,66,32,61,32,98,111,100,105,101,115,91,37,100,93,59,10,0,0,0,0,0,0,0,32,32,106,100,46,99,111,108,108,105,100,101,67,111,110,110,101,99,116,101,100,32,61,32,98,111,111,108,40,37,100,41,59,10,0,0,0,0,0,0,32,32,106,100,46,106,111,105,110,116,49,32,61,32,106,111,105,110,116,115,91,37,100,93,59,10,0,0,0,0,0,0,32,32,106,100,46,106,111,105,110,116,50,32,61,32,106,111,105,110,116,115,91,37,100,93,59,10,0,0,0,0,0,0,32,32,106,100,46,114,97,116,105,111,32,61,32,37,46,49,53,108,101,102,59,10,0,0,32,32,106,111,105,110,116,115,91,37,100,93,32,61,32,109,95,119,111,114,108,100,45,62,67,114,101,97,116,101,74,111,105,110,116,40,38,106,100,41,59,10,0,0,0,0,0,0,49,49,98,50,71,101,97,114,74,111,105,110,116,0,0,0,160,43,0,0,248,17,0,0,104,9,0,0,0,0,0,0,0,0,0,0,152,20,0,0,31,0,0,0,32,0,0,0,11,0,0,0,7,0,0,0,32,0,0,0,12,0,0,0,20,0,0,0,33,0,0,0,33,0,0,0,34,0,0,0,14,0,0,0,0,0,0,0,32,32,98,50,80,114,105,115,109,97,116,105,99,74,111,105,110,116,68,101,102,32,106,100,59,10,0,0,0,0,0,0,32,32,106,100,46,98,111,100,121,65,32,61,32,98,111,100,105,101,115,91,37,100,93,59,10,0,0,0,0,0,0,0,32,32,106,100,46,98,111,100,121,66,32,61,32,98,111,100,105,101,115,91,37,100,93,59,10,0,0,0,0,0,0,0,32,32,106,100,46,99,111,108,108,105,100,101,67,111,110,110,101,99,116,101,100,32,61,32,98,111,111,108,40,37,100,41,59,10,0,0,0,0,0,0,32,32,106,100,46,108,111,99,97,108,65,110,99,104,111,114,65,46,83,101,116,40,37,46,49,53,108,101,102,44,32,37,46,49,53,108,101,102,41,59,10,0,0,0,0,0,0,0,32,32,106,100,46,108,111,99,97,108,65,110,99,104,111,114,66,46,83,101,116,40,37,46,49,53,108,101,102,44,32,37,46,49,53,108,101,102,41,59,10,0,0,0,0,0,0,0,32,32,106,100,46,108,111,99,97,108,65,120,105,115,65,46,83,101,116,40,37,46,49,53,108,101,102,44,32,37,46,49,53,108,101,102,41,59,10,0,32,32,106,100,46,114,101,102,101,114,101,110,99,101,65,110,103,108,101,32,61,32,37,46,49,53,108,101,102,59,10,0,32,32,106,100,46,101,110,97,98,108,101,76,105,109,105,116,32,61,32,98,111,111,108,40,37,100,41,59,10,0,0,0,32,32,106,100,46,108,111,119,101,114,84,114,97,110,115,108,97,116,105,111,110,32,61,32,37,46,49,53,108,101,102,59,10,0,0,0,0,0,0,0,32,32,106,100,46,117,112,112,101,114,84,114,97,110,115,108,97,116,105,111,110,32,61,32,37,46,49,53,108,101,102,59,10,0,0,0,0,0,0,0,32,32,106,100,46,101,110,97,98,108,101,77,111,116,111,114,32,61,32,98,111,111,108,40,37,100,41,59,10,0,0,0,32,32,106,100,46,109,111,116,111,114,83,112,101,101,100,32,61,32,37,46,49,53,108,101,102,59,10,0,0,0,0,0,32,32,106,100,46,109,97,120,77,111,116,111,114,70,111,114,99,101,32,61,32,37,46,49,53,108,101,102,59,10,0,0,32,32,106,111,105,110,116,115,91,37,100,93,32,61,32,109,95,119,111,114,108,100,45,62,67,114,101,97,116,101,74,111,105,110,116,40,38,106,100,41,59,10,0,0,0,0,0,0,49,54,98,50,80,114,105,115,109,97,116,105,99,74,111,105,110,116,0,0,0,0,0,0,160,43,0,0,128,20,0,0,104,9,0,0,0,0,0,0,0,0,0,0,32,22,0,0,35,0,0,0,36,0,0,0,12,0,0,0,8,0,0,0,34,0,0,0,12,0,0,0,20,0,0,0,35,0,0,0,37,0,0,0,38,0,0,0,15,0,0,0,0,0,0,0,32,32,98,50,82,111,112,101,74,111,105,110,116,68,101,102,32,106,100,59,10,0,0,0,32,32,106,100,46,98,111,100,121,65,32,61,32,98,111,100,105,101,115,91,37,100,93,59,10,0,0,0,0,0,0,0,32,32,106,100,46,98,111,100,121,66,32,61,32,98,111,100,105,101,115,91,37,100,93,59,10,0,0,0,0,0,0,0,32,32,106,100,46,99,111,108,108,105,100,101,67,111,110,110,101,99,116,101,100,32,61,32,98,111,111,108,40,37,100,41,59,10,0,0,0,0,0,0,32,32,106,100,46,108,111,99,97,108,65,110,99,104,111,114,65,46,83,101,116,40,37,46,49,53,108,101,102,44,32,37,46,49,53,108,101,102,41,59,10,0,0,0,0,0,0,0,32,32,106,100,46,108,111,99,97,108,65,110,99,104,111,114,66,46,83,101,116,40,37,46,49,53,108,101,102,44,32,37,46,49,53,108,101,102,41,59,10,0,0,0,0,0,0,0,32,32,106,100,46,109,97,120,76,101,110,103,116,104,32,61,32,37,46,49,53,108,101,102,59,10,0,0,0,0,0,0,32,32,106,111,105,110,116,115,91,37,100,93,32,61,32,109,95,119,111,114,108,100,45,62,67,114,101,97,116,101,74,111,105,110,116,40,38,106,100,41,59,10,0,0,0,0,0,0,49,49,98,50,82,111,112,101,74,111,105,110,116,0,0,0,160,43,0,0,16,22,0,0,104,9,0,0,0,0,0,0,0,0,0,0,104,9,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,36,0,0,0,12,0,0,0,20,0,0,0,37,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,47,47,32,68,117,109,112,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,32,102,111,114,32,116,104,105,115,32,106,111,105,110,116,32,116,121,112,101,46,10,0,0,0,0,0,0,224,24,0,0,39,0,0,0,40,0,0,0,13,0,0,0,9,0,0,0,38,0,0,0,12,0,0,0,20,0,0,0,39,0,0,0,41,0,0,0,42,0,0,0,16,0,0,0,0,0,0,0,32,32,98,50,82,101,118,111,108,117,116,101,74,111,105,110,116,68,101,102,32,106,100,59,10,0,0,0,0,0,0,0,32,32,106,100,46,98,111,100,121,65,32,61,32,98,111,100,105,101,115,91,37,100,93,59,10,0,0,0,0,0,0,0,32,32,106,100,46,98,111,100,121,66,32,61,32,98,111,100,105,101,115,91,37,100,93,59,10,0,0,0,0,0,0,0,32,32,106,100,46,99,111,108,108,105,100,101,67,111,110,110,101,99,116,101,100,32,61,32,98,111,111,108,40,37,100,41,59,10,0,0,0,0,0,0,32,32,106,100,46,108,111,99,97,108,65,110,99,104,111,114,65,46,83,101,116,40,37,46,49,53,108,101,102,44,32,37,46,49,53,108,101,102,41,59,10,0,0,0,0,0,0,0,32,32,106,100,46,108,111,99,97,108,65,110,99,104,111,114,66,46,83,101,116,40,37,46,49,53,108,101,102,44,32,37,46,49,53,108,101,102,41,59,10,0,0,0,0,0,0,0,32,32,106,100,46,114,101,102,101,114,101,110,99,101,65,110,103,108,101,32,61,32,37,46,49,53,108,101,102,59,10,0,32,32,106,100,46,101,110,97,98,108,101,76,105,109,105,116,32,61,32,98,111,111,108,40,37,100,41,59,10,0,0,0,32,32,106,100,46,108,111,119,101,114,65,110,103,108,101,32,61,32,37,46,49,53,108,101,102,59,10,0,0,0,0,0,32,32,106,100,46,117,112,112,101,114,65,110,103,108,101,32,61,32,37,46,49,53,108,101,102,59,10,0,0,0,0,0,32,32,106,100,46,101,110,97,98,108,101,77,111,116,111,114,32,61,32,98,111,111,108,40,37,100,41,59,10,0,0,0,32,32,106,100,46,109,111,116,111,114,83,112,101,101,100,32,61,32,37,46,49,53,108,101,102,59,10,0,0,0,0,0,32,32,106,100,46,109,97,120,77,111,116,111,114,84,111,114,113,117,101,32,61,32,37,46,49,53,108,101,102,59,10,0,32,32,106,111,105,110,116,115,91,37,100,93,32,61,32,109,95,119,111,114,108,100,45,62,67,114,101,97,116,101,74,111,105,110,116,40,38,106,100,41,59,10,0,0,0,0,0,0,49,53,98,50,82,101,118,111,108,117,116,101,74,111,105,110,116,0,0,0,0,0,0,0,160,43,0,0,200,24,0,0,104,9,0,0,0,0,0,0,0,0,0,0,16,27,0,0,43,0,0,0,44,0,0,0,14,0,0,0,10,0,0,0,40,0,0,0,12,0,0,0,20,0,0,0,41,0,0,0,45,0,0,0,46,0,0,0,17,0,0,0,0,0,0,0,32,32,98,50,87,104,101,101,108,74,111,105,110,116,68,101,102,32,106,100,59,10,0,0,32,32,106,100,46,98,111,100,121,65,32,61,32,98,111,100,105,101,115,91,37,100,93,59,10,0,0,0,0,0,0,0,32,32,106,100,46,98,111,100,121,66,32,61,32,98,111,100,105,101,115,91,37,100,93,59,10,0,0,0,0,0,0,0,32,32,106,100,46,99,111,108,108,105,100,101,67,111,110,110,101,99,116,101,100,32,61,32,98,111,111,108,40,37,100,41,59,10,0,0,0,0,0,0,32,32,106,100,46,108,111,99,97,108,65,110,99,104,111,114,65,46,83,101,116,40,37,46,49,53,108,101,102,44,32,37,46,49,53,108,101,102,41,59,10,0,0,0,0,0,0,0,32,32,106,100,46,108,111,99,97,108,65,110,99,104,111,114,66,46,83,101,116,40,37,46,49,53,108,101,102,44,32,37,46,49,53,108,101,102,41,59,10,0,0,0,0,0,0,0,32,32,106,100,46,108,111,99,97,108,65,120,105,115,65,46,83,101,116,40,37,46,49,53,108,101,102,44,32,37,46,49,53,108,101,102,41,59,10,0,32,32,106,100,46,101,110,97,98,108,101,77,111,116,111,114,32,61,32,98,111,111,108,40,37,100,41,59,10,0,0,0,32,32,106,100,46,109,111,116,111,114,83,112,101,101,100,32,61,32,37,46,49,53,108,101,102,59,10,0,0,0,0,0,32,32,106,100,46,109,97,120,77,111,116,111,114,84,111,114,113,117,101,32,61,32,37,46,49,53,108,101,102,59,10,0,32,32,106,100,46,102,114,101,113,117,101,110,99,121,72,122,32,61,32,37,46,49,53,108,101,102,59,10,0,0,0,0,32,32,106,100,46,100,97,109,112,105,110,103,82,97,116,105,111,32,61,32,37,46,49,53,108,101,102,59,10,0,0,0,32,32,106,111,105,110,116,115,91,37,100,93,32,61,32,109,95,119,111,114,108,100,45,62,67,114,101,97,116,101,74,111,105,110,116,40,38,106,100,41,59,10,0,0,0,0,0,0,49,50,98,50,87,104,101,101,108,74,111,105,110,116,0,0,160,43,0,0,0,27,0,0,104,9,0,0,0,0,0,0,0,0,0,0,48,29,0,0,47,0,0,0,48,0,0,0,15,0,0,0,11,0,0,0,42,0,0,0,49,0,0,0,20,0,0,0,43,0,0,0,50,0,0,0,51,0,0,0,18,0,0,0,0,0,0,0,32,32,98,50,80,117,108,108,101,121,74,111,105,110,116,68,101,102,32,106,100,59,10,0,32,32,106,100,46,98,111,100,121,65,32,61,32,98,111,100,105,101,115,91,37,100,93,59,10,0,0,0,0,0,0,0,32,32,106,100,46,98,111,100,121,66,32,61,32,98,111,100,105,101,115,91,37,100,93,59,10,0,0,0,0,0,0,0,32,32,106,100,46,99,111,108,108,105,100,101,67,111,110,110,101,99,116,101,100,32,61,32,98,111,111,108,40,37,100,41,59,10,0,0,0,0,0,0,32,32,106,100,46,103,114,111,117,110,100,65,110,99,104,111,114,65,46,83,101,116,40,37,46,49,53,108,101,102,44,32,37,46,49,53,108,101,102,41,59,10,0,0,0,0,0,0,32,32,106,100,46,103,114,111,117,110,100,65,110,99,104,111,114,66,46,83,101,116,40,37,46,49,53,108,101,102,44,32,37,46,49,53,108,101,102,41,59,10,0,0,0,0,0,0,32,32,106,100,46,108,111,99,97,108,65,110,99,104,111,114,65,46,83,101,116,40,37,46,49,53,108,101,102,44,32,37,46,49,53,108,101,102,41,59,10,0,0,0,0,0,0,0,32,32,106,100,46,108,111,99,97,108,65,110,99,104,111,114,66,46,83,101,116,40,37,46,49,53,108,101,102,44,32,37,46,49,53,108,101,102,41,59,10,0,0,0,0,0,0,0,32,32,106,100,46,108,101,110,103,116,104,65,32,61,32,37,46,49,53,108,101,102,59,10,0,0,0,0,0,0,0,0,32,32,106,100,46,108,101,110,103,116,104,66,32,61,32,37,46,49,53,108,101,102,59,10,0,0,0,0,0,0,0,0,32,32,106,100,46,114,97,116,105,111,32,61,32,37,46,49,53,108,101,102,59,10,0,0,32,32,106,111,105,110,116,115,91,37,100,93,32,61,32,109,95,119,111,114,108,100,45,62,67,114,101,97,116,101,74,111,105,110,116,40,38,106,100,41,59,10,0,0,0,0,0,0,49,51,98,50,80,117,108,108,101,121,74,111,105,110,116,0,160,43,0,0,32,29,0,0,104,9,0,0,0,0,0,0,0,0,0,0,144,29,0,0,9,0,0,0,44,0,0,0,45,0,0,0,0,0,0,0,50,52,98,50,67,104,97,105,110,65,110,100,80,111,108,121,103,111,110,67,111,110,116,97,99,116,0,0,0,0,0,0,57,98,50,67,111,110,116,97,99,116,0,0,0,0,0,0,120,43,0,0,120,29,0,0,160,43,0,0,88,29,0,0,136,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,29,0,0,1,0,0,0,44,0,0,0,46,0,0,0,0,0,0,0,0,0,0,0,184,30,0,0,10,0,0,0,44,0,0,0,47,0,0,0,0,0,0,0,50,53,98,50,80,111,108,121,103,111,110,65,110,100,67,105,114,99,108,101,67,111,110,116,97,99,116,0,0,0,0,0,160,43,0,0,152,30,0,0,136,29,0,0,0,0,0,0,0,0,0,0,248,30,0,0,11,0,0,0,44,0,0,0,48,0,0,0,0,0,0,0,49,53,98,50,67,105,114,99,108,101,67,111,110,116,97,99,116,0,0,0,0,0,0,0,160,43,0,0,224,30,0,0,136,29,0,0,0,0,0,0,0,0,0,0,64,31,0,0,12,0,0,0,44,0,0,0,49,0,0,0,0,0,0,0,50,50,98,50,69,100,103,101,65,110,100,67,105,114,99,108,101,67,111,110,116,97,99,116,0,0,0,0,0,0,0,0,160,43,0,0,32,31,0,0,136,29,0,0,0,0,0,0,0,0,0,0,136,31,0,0,13,0,0,0,44,0,0,0,50,0,0,0,0,0,0,0,50,51,98,50,67,104,97,105,110,65,110,100,67,105,114,99,108,101,67,111,110,116,97,99,116,0,0,0,0,0,0,0,160,43,0,0,104,31,0,0,136,29,0,0,0,0,0,0,0,0,0,0,208,31,0,0,14,0,0,0,44,0,0,0,51,0,0,0,0,0,0,0,50,51,98,50,69,100,103,101,65,110,100,80,111,108,121,103,111,110,67,111,110,116,97,99,116,0,0,0,0,0,0,0,160,43,0,0,176,31,0,0,136,29,0,0,0,0,0,0,0,0,0,0,16,32,0,0,15,0,0,0,44,0,0,0,52,0,0,0,0,0,0,0,49,54,98,50,80,111,108,121,103,111,110,67,111,110,116,97,99,116,0,0,0,0,0,0,160,43,0,0,248,31,0,0,136,29,0,0,0,0,0,0,216,8,0,0,0,0,0,0,232,5,0,0,0,0,0,0,0,0,0,0,216,32,0,0,4,0,0,0,53,0,0,0,19,0,0,0,1,0,0,0,20,0,0,0,16,0,0,0,90,78,49,54,98,50,80,97,114,116,105,99,108,101,83,121,115,116,101,109,49,52,83,111,108,118,101,67,111,108,108,105,115,105,111,110,69,82,75,49,48,98,50,84,105,109,101,83,116,101,112,69,50,50,83,111,108,118,101,67,111,108,108,105,115,105,111,110,67,97,108,108,98,97,99,107,0,0,0,0,51,48,98,50,70,105,120,116,117,114,101,80,97,114,116,105,99,108,101,81,117,101,114,121,67,97,108,108,98,97,99,107,0,0,0,0,0,0,0,0,160,43,0,0,160,32,0,0,40,5,0,0,0,0,0,0,160,43,0,0,80,32,0,0,200,32,0,0,0,0,0,0,0,0,0,0,200,32,0,0,4,0,0,0,54,0,0,0,19,0,0,0,1,0,0,0,20,0,0,0,1,0,0,0,0,0,0,0,112,33,0,0,4,0,0,0,55,0,0,0,19,0,0,0,1,0,0,0,20,0,0,0,17,0,0,0,90,78,49,54,98,50,80,97,114,116,105,99,108,101,83,121,115,116,101,109,49,56,85,112,100,97,116,101,66,111,100,121,67,111,110,116,97,99,116,115,69,118,69,50,54,85,112,100,97,116,101,66,111,100,121,67,111,110,116,97,99,116,115,67,97,108,108,98,97,99,107,0,160,43,0,0,40,33,0,0,200,32,0,0,0,0,0,0,0,0,0,0,40,34,0,0,56,0,0,0,57,0,0,0,18,0,0,0,0,0,0,0,90,78,49,54,98,50,80,97,114,116,105,99,108,101,83,121,115,116,101,109,50,48,85,112,100,97,116,101,80,97,105,114,115,65,110,100,84,114,105,97,100,115,69,105,105,82,75,78,83,95,49,54,67,111,110,110,101,99,116,105,111,110,70,105,108,116,101,114,69,69,50,48,85,112,100,97,116,101,84,114,105,97,100,115,67,97,108,108,98,97,99,107,0,0,0,0,78,49,54,98,50,86,111,114,111,110,111,105,68,105,97,103,114,97,109,49,50,78,111,100,101,67,97,108,108,98,97,99,107,69,0,0,0,0,0,0,120,43,0,0,248,33,0,0,160,43,0,0,152,33,0,0,32,34,0,0,0,0,0,0,0,0,0,0,32,34,0,0,56,0,0,0,58,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,248,34,0,0,59,0,0,0,60,0,0,0,21,0,0,0,7,0,0,0,3,0,0,0,0,0,0,0,90,78,49,54,98,50,80,97,114,116,105,99,108,101,83,121,115,116,101,109,52,49,85,112,100,97,116,101,80,97,105,114,115,65,110,100,84,114,105,97,100,115,87,105,116,104,82,101,97,99,116,105,118,101,80,97,114,116,105,99,108,101,115,69,118,69,49,52,82,101,97,99,116,105,118,101,70,105,108,116,101,114,0,0,0,0,0,0,78,49,54,98,50,80,97,114,116,105,99,108,101,83,121,115,116,101,109,49,54,67,111,110,110,101,99,116,105,111,110,70,105,108,116,101,114,69,0,0,120,43,0,0,200,34,0,0,160,43,0,0,112,34,0,0,240,34,0,0,0,0,0,0,0,0,0,0,240,34,0,0,59,0,0,0,61,0,0,0,22,0,0,0,7,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,168,35,0,0,59,0,0,0,62,0,0,0,22,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,90,78,49,54,98,50,80,97,114,116,105,99,108,101,83,121,115,116,101,109,49,56,74,111,105,110,80,97,114,116,105,99,108,101,71,114,111,117,112,115,69,80,49,53,98,50,80,97,114,116,105,99,108,101,71,114,111,117,112,83,49,95,69,50,52,74,111,105,110,80,97,114,116,105,99,108,101,71,114,111,117,112,115,70,105,108,116,101,114,0,0,0,0,0,0,0,160,43,0,0,72,35,0,0,240,34,0,0,0,0,0,0,0,0,0,0,104,36,0,0,10,0,0,0,63,0,0,0,23,0,0,0,5,0,0,0,9,0,0,0,5,0,0,0,5,0,0,0,19,0,0,0,16,0,0,0,0,0,0,0,90,78,49,54,98,50,80,97,114,116,105,99,108,101,83,121,115,116,101,109,51,51,67,114,101,97,116,101,80,97,114,116,105,99,108,101,115,87,105,116,104,83,104,97,112,101,115,70,111,114,71,114,111,117,112,69,80,75,80,75,55,98,50,83,104,97,112,101,105,82,75,49,56,98,50,80,97,114,116,105,99,108,101,71,114,111,117,112,68,101,102,82,75,49,49,98,50,84,114,97,110,115,102,111,114,109,69,49,52,67,111,109,112,111,115,105,116,101,83,104,97,112,101,0,0,0,0,0,160,43,0,0,232,35,0,0,80,6,0,0,0,0,0,0,0,0,0,0,8,37,0,0,4,0,0,0,64,0,0,0,24,0,0,0,10,0,0,0,3,0,0,0,0,0,0,0,90,78,49,54,98,50,80,97,114,116,105,99,108,101,83,121,115,116,101,109,50,51,68,101,115,116,114,111,121,80,97,114,116,105,99,108,101,115,73,110,83,104,97,112,101,69,82,75,55,98,50,83,104,97,112,101,82,75,49,49,98,50,84,114,97,110,115,102,111,114,109,98,69,51,49,68,101,115,116,114,111,121,80,97,114,116,105,99,108,101,115,73,110,83,104,97,112,101,67,97,108,108,98,97,99,107,0,0,0,0,0,0,160,43,0,0,152,36,0,0,40,5,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,32,0,0,0,64,0,0,0,96,0,0,0,128,0,0,0,160,0,0,0,192,0,0,0,224,0,0,0,0,1,0,0,64,1,0,0,128,1,0,0,192,1,0,0,0,2,0,0,128,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE);
/* memory initializer */ allocate([76,105,113,117,105,100,70,117,110,32,49,46,49,46,48,0,8,40,0,0,0,0,0,0,25,0,0,0,0,0,0,0,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,80,40,0,0,0,0,0,0,117,110,99,97,117,103,104,116,0,0,0,0,0,0,0,0,116,101,114,109,105,110,97,116,105,110,103,32,119,105,116,104,32,37,115,32,101,120,99,101,112,116,105,111,110,32,111,102,32,116,121,112,101,32,37,115,58,32,37,115,0,0,0,0,116,101,114,109,105,110,97,116,105,110,103,32,119,105,116,104,32,37,115,32,101,120,99,101,112,116,105,111,110,32,111,102,32,116,121,112,101,32,37,115,0,0,0,0,0,0,0,0,116,101,114,109,105,110,97,116,105,110,103,32,119,105,116,104,32,37,115,32,102,111,114,101,105,103,110,32,101,120,99,101,112,116,105,111,110,0,0,0,116,101,114,109,105,110,97,116,105,110,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,116,104,114,101,97,100,95,111,110,99,101,32,102,97,105,108,117,114,101,32,105,110,32,95,95,99,120,97,95,103,101,116,95,103,108,111,98,97,108,115,95,102,97,115,116,40,41,0,0,0,0,0,0,0,0,99,97,110,110,111,116,32,99,114,101,97,116,101,32,112,116,104,114,101,97,100,32,107,101,121,32,102,111,114,32,95,95,99,120,97,95,103,101,116,95,103,108,111,98,97,108,115,40,41,0,0,0,0,0,0,0,99,97,110,110,111,116,32,122,101,114,111,32,111,117,116,32,116,104,114,101,97,100,32,118,97,108,117,101,32,102,111,114,32,95,95,99,120,97,95,103,101,116,95,103,108,111,98,97,108,115,40,41,0,0,0,0,0,0,0,0,232,41,0,0,65,0,0,0,66,0,0,0,6,0,0,0,0,0,0,0,115,116,100,58,58,98,97,100,95,97,108,108,111,99,0,0,83,116,57,98,97,100,95,97,108,108,111,99,0,0,0,0,160,43,0,0,216,41,0,0,112,42,0,0,0,0,0,0,116,101,114,109,105,110,97,116,101,95,104,97,110,100,108,101,114,32,117,110,101,120,112,101,99,116,101,100,108,121,32,114,101,116,117,114,110,101,100,0,116,101,114,109,105,110,97,116,101,95,104,97,110,100,108,101,114,32,117,110,101,120,112,101,99,116,101,100,108,121,32,116,104,114,101,119,32,97,110,32,101,120,99,101,112,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,116,57,101,120,99,101,112,116,105,111,110,0,0,0,0,120,43,0,0,96,42,0,0,83,116,57,116,121,112,101,95,105,110,102,111,0,0,0,0,120,43,0,0,120,42,0,0,78,49,48,95,95,99,120,120,97,98,105,118,49,49,54,95,95,115,104,105,109,95,116,121,112,101,95,105,110,102,111,69,0,0,0,0,0,0,0,0,160,43,0,0,144,42,0,0,136,42,0,0,0,0,0,0,78,49,48,95,95,99,120,120,97,98,105,118,49,49,55,95,95,99,108,97,115,115,95,116,121,112,101,95,105,110,102,111,69,0,0,0,0,0,0,0,160,43,0,0,200,42,0,0,184,42,0,0,0,0,0,0,78,49,48,95,95,99,120,120,97,98,105,118,49,49,57,95,95,112,111,105,110,116,101,114,95,116,121,112,101,95,105,110,102,111,69,0,0,0,0,0,78,49,48,95,95,99,120,120,97,98,105,118,49,49,55,95,95,112,98,97,115,101,95,116,121,112,101,95,105,110,102,111,69,0,0,0,0,0,0,0,160,43,0,0,40,43,0,0,184,42,0,0,0,0,0,0,160,43,0,0,0,43,0,0,80,43,0,0,0,0,0,0,0,0,0,0,240,42,0,0,67,0,0,0,68,0,0,0,69,0,0,0,70,0,0,0,11,0,0,0,6,0,0,0,1,0,0,0,20,0,0,0,0,0,0,0,232,43,0,0,67,0,0,0,71,0,0,0,69,0,0,0,70,0,0,0,11,0,0,0,7,0,0,0,2,0,0,0,21,0,0,0,78,49,48,95,95,99,120,120,97,98,105,118,49,50,48,95,95,115,105,95,99,108,97,115,115,95,116,121,112,101,95,105,110,102,111,69,0,0,0,0,160,43,0,0,192,43,0,0,240,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+10240);




var tempDoublePtr = Runtime.alignMemory(allocate(12, "i8", ALLOC_STATIC), 8);

assert(tempDoublePtr % 8 == 0);

function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

}

function copyTempDouble(ptr) {

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];

  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];

  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];

  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];

}


  var _cosf=Math_cos;

  var _floorf=Math_floor;

  
  function __ZSt18uncaught_exceptionv() { // std::uncaught_exception()
      return !!__ZSt18uncaught_exceptionv.uncaught_exception;
    }
  
  
  
  var EXCEPTIONS={last:0,caught:[],infos:{},deAdjust:function (adjusted) {
        if (!adjusted || EXCEPTIONS.infos[adjusted]) return adjusted;
        for (var ptr in EXCEPTIONS.infos) {
          var info = EXCEPTIONS.infos[ptr];
          if (info.adjusted === adjusted) {
            return ptr;
          }
        }
        return adjusted;
      },addRef:function (ptr) {
        if (!ptr) return;
        var info = EXCEPTIONS.infos[ptr];
        info.refcount++;
      },decRef:function (ptr) {
        if (!ptr) return;
        var info = EXCEPTIONS.infos[ptr];
        assert(info.refcount > 0);
        info.refcount--;
        if (info.refcount === 0) {
          if (info.destructor) {
            Runtime.dynCall('vi', info.destructor, [ptr]);
          }
          delete EXCEPTIONS.infos[ptr];
          ___cxa_free_exception(ptr);
        }
      },clearRef:function (ptr) {
        if (!ptr) return;
        var info = EXCEPTIONS.infos[ptr];
        info.refcount = 0;
      }};
  function ___resumeException(ptr) {
      if (!EXCEPTIONS.last) { EXCEPTIONS.last = ptr; }
      EXCEPTIONS.clearRef(EXCEPTIONS.deAdjust(ptr)); // exception refcount should be cleared, but don't free it
      throw ptr + " - Exception catching is disabled, this exception cannot be caught. Compile with -s DISABLE_EXCEPTION_CATCHING=0 or DISABLE_EXCEPTION_CATCHING=2 to catch.";
    }function ___cxa_find_matching_catch() {
      var thrown = EXCEPTIONS.last;
      if (!thrown) {
        // just pass through the null ptr
        return ((asm["setTempRet0"](0),0)|0);
      }
      var info = EXCEPTIONS.infos[thrown];
      var throwntype = info.type;
      if (!throwntype) {
        // just pass through the thrown ptr
        return ((asm["setTempRet0"](0),thrown)|0);
      }
      var typeArray = Array.prototype.slice.call(arguments);
  
      var pointer = Module['___cxa_is_pointer_type'](throwntype);
      // can_catch receives a **, add indirection
      if (!___cxa_find_matching_catch.buffer) ___cxa_find_matching_catch.buffer = _malloc(4);
      HEAP32[((___cxa_find_matching_catch.buffer)>>2)]=thrown;
      thrown = ___cxa_find_matching_catch.buffer;
      // The different catch blocks are denoted by different types.
      // Due to inheritance, those types may not precisely match the
      // type of the thrown object. Find one which matches, and
      // return the type of the catch block which should be called.
      for (var i = 0; i < typeArray.length; i++) {
        if (typeArray[i] && Module['___cxa_can_catch'](typeArray[i], throwntype, thrown)) {
          thrown = HEAP32[((thrown)>>2)]; // undo indirection
          info.adjusted = thrown;
          return ((asm["setTempRet0"](typeArray[i]),thrown)|0);
        }
      }
      // Shouldn't happen unless we have bogus data in typeArray
      // or encounter a type for which emscripten doesn't have suitable
      // typeinfo defined. Best-efforts match just in case.
      thrown = HEAP32[((thrown)>>2)]; // undo indirection
      return ((asm["setTempRet0"](throwntype),thrown)|0);
    }function ___cxa_throw(ptr, type, destructor) {
      EXCEPTIONS.infos[ptr] = {
        ptr: ptr,
        adjusted: ptr,
        type: type,
        destructor: destructor,
        refcount: 0
      };
      EXCEPTIONS.last = ptr;
      if (!("uncaught_exception" in __ZSt18uncaught_exceptionv)) {
        __ZSt18uncaught_exceptionv.uncaught_exception = 1;
      } else {
        __ZSt18uncaught_exceptionv.uncaught_exception++;
      }
      throw ptr + " - Exception catching is disabled, this exception cannot be caught. Compile with -s DISABLE_EXCEPTION_CATCHING=0 or DISABLE_EXCEPTION_CATCHING=2 to catch.";
    }

   
  Module["_memset"] = _memset;

  function _b2WorldBeginContactParticle(particleSystemPtr, particleContactPtr) {
      b2World.BeginContactParticle(particleSystemPtr, particleContactPtr);
    }

  function _b2WorldRayCastCallback(fixturePtr, pointX, pointY,
                                     normalX, normalY, fraction) {
      return b2World.RayCast(fixturePtr, pointX, pointY, normalX, normalY, fraction);
    }

  var _FtoIHigh=true;

  function _abort() {
      Module['abort']();
    }

  function _b2WorldBeginContactBody(contactPtr) {
      b2World.BeginContactBody(contactPtr);
    }

  
  
  
  
  var ERRNO_CODES={EPERM:1,ENOENT:2,ESRCH:3,EINTR:4,EIO:5,ENXIO:6,E2BIG:7,ENOEXEC:8,EBADF:9,ECHILD:10,EAGAIN:11,EWOULDBLOCK:11,ENOMEM:12,EACCES:13,EFAULT:14,ENOTBLK:15,EBUSY:16,EEXIST:17,EXDEV:18,ENODEV:19,ENOTDIR:20,EISDIR:21,EINVAL:22,ENFILE:23,EMFILE:24,ENOTTY:25,ETXTBSY:26,EFBIG:27,ENOSPC:28,ESPIPE:29,EROFS:30,EMLINK:31,EPIPE:32,EDOM:33,ERANGE:34,ENOMSG:42,EIDRM:43,ECHRNG:44,EL2NSYNC:45,EL3HLT:46,EL3RST:47,ELNRNG:48,EUNATCH:49,ENOCSI:50,EL2HLT:51,EDEADLK:35,ENOLCK:37,EBADE:52,EBADR:53,EXFULL:54,ENOANO:55,EBADRQC:56,EBADSLT:57,EDEADLOCK:35,EBFONT:59,ENOSTR:60,ENODATA:61,ETIME:62,ENOSR:63,ENONET:64,ENOPKG:65,EREMOTE:66,ENOLINK:67,EADV:68,ESRMNT:69,ECOMM:70,EPROTO:71,EMULTIHOP:72,EDOTDOT:73,EBADMSG:74,ENOTUNIQ:76,EBADFD:77,EREMCHG:78,ELIBACC:79,ELIBBAD:80,ELIBSCN:81,ELIBMAX:82,ELIBEXEC:83,ENOSYS:38,ENOTEMPTY:39,ENAMETOOLONG:36,ELOOP:40,EOPNOTSUPP:95,EPFNOSUPPORT:96,ECONNRESET:104,ENOBUFS:105,EAFNOSUPPORT:97,EPROTOTYPE:91,ENOTSOCK:88,ENOPROTOOPT:92,ESHUTDOWN:108,ECONNREFUSED:111,EADDRINUSE:98,ECONNABORTED:103,ENETUNREACH:101,ENETDOWN:100,ETIMEDOUT:110,EHOSTDOWN:112,EHOSTUNREACH:113,EINPROGRESS:115,EALREADY:114,EDESTADDRREQ:89,EMSGSIZE:90,EPROTONOSUPPORT:93,ESOCKTNOSUPPORT:94,EADDRNOTAVAIL:99,ENETRESET:102,EISCONN:106,ENOTCONN:107,ETOOMANYREFS:109,EUSERS:87,EDQUOT:122,ESTALE:116,ENOTSUP:95,ENOMEDIUM:123,EILSEQ:84,EOVERFLOW:75,ECANCELED:125,ENOTRECOVERABLE:131,EOWNERDEAD:130,ESTRPIPE:86};
  
  var ERRNO_MESSAGES={0:"Success",1:"Not super-user",2:"No such file or directory",3:"No such process",4:"Interrupted system call",5:"I/O error",6:"No such device or address",7:"Arg list too long",8:"Exec format error",9:"Bad file number",10:"No children",11:"No more processes",12:"Not enough core",13:"Permission denied",14:"Bad address",15:"Block device required",16:"Mount device busy",17:"File exists",18:"Cross-device link",19:"No such device",20:"Not a directory",21:"Is a directory",22:"Invalid argument",23:"Too many open files in system",24:"Too many open files",25:"Not a typewriter",26:"Text file busy",27:"File too large",28:"No space left on device",29:"Illegal seek",30:"Read only file system",31:"Too many links",32:"Broken pipe",33:"Math arg out of domain of func",34:"Math result not representable",35:"File locking deadlock error",36:"File or path name too long",37:"No record locks available",38:"Function not implemented",39:"Directory not empty",40:"Too many symbolic links",42:"No message of desired type",43:"Identifier removed",44:"Channel number out of range",45:"Level 2 not synchronized",46:"Level 3 halted",47:"Level 3 reset",48:"Link number out of range",49:"Protocol driver not attached",50:"No CSI structure available",51:"Level 2 halted",52:"Invalid exchange",53:"Invalid request descriptor",54:"Exchange full",55:"No anode",56:"Invalid request code",57:"Invalid slot",59:"Bad font file fmt",60:"Device not a stream",61:"No data (for no delay io)",62:"Timer expired",63:"Out of streams resources",64:"Machine is not on the network",65:"Package not installed",66:"The object is remote",67:"The link has been severed",68:"Advertise error",69:"Srmount error",70:"Communication error on send",71:"Protocol error",72:"Multihop attempted",73:"Cross mount point (not really error)",74:"Trying to read unreadable message",75:"Value too large for defined data type",76:"Given log. name not unique",77:"f.d. invalid for this operation",78:"Remote address changed",79:"Can   access a needed shared lib",80:"Accessing a corrupted shared lib",81:".lib section in a.out corrupted",82:"Attempting to link in too many libs",83:"Attempting to exec a shared library",84:"Illegal byte sequence",86:"Streams pipe error",87:"Too many users",88:"Socket operation on non-socket",89:"Destination address required",90:"Message too long",91:"Protocol wrong type for socket",92:"Protocol not available",93:"Unknown protocol",94:"Socket type not supported",95:"Not supported",96:"Protocol family not supported",97:"Address family not supported by protocol family",98:"Address already in use",99:"Address not available",100:"Network interface is not configured",101:"Network is unreachable",102:"Connection reset by network",103:"Connection aborted",104:"Connection reset by peer",105:"No buffer space available",106:"Socket is already connected",107:"Socket is not connected",108:"Can't send after socket shutdown",109:"Too many references",110:"Connection timed out",111:"Connection refused",112:"Host is down",113:"Host is unreachable",114:"Socket already connected",115:"Connection already in progress",116:"Stale file handle",122:"Quota exceeded",123:"No medium (in tape drive)",125:"Operation canceled",130:"Previous owner died",131:"State not recoverable"};
  
  
  var ___errno_state=0;function ___setErrNo(value) {
      // For convenient setting and returning of errno.
      HEAP32[((___errno_state)>>2)]=value;
      return value;
    }
  
  var PATH={splitPath:function (filename) {
        var splitPathRe = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;
        return splitPathRe.exec(filename).slice(1);
      },normalizeArray:function (parts, allowAboveRoot) {
        // if the path tries to go above the root, `up` ends up > 0
        var up = 0;
        for (var i = parts.length - 1; i >= 0; i--) {
          var last = parts[i];
          if (last === '.') {
            parts.splice(i, 1);
          } else if (last === '..') {
            parts.splice(i, 1);
            up++;
          } else if (up) {
            parts.splice(i, 1);
            up--;
          }
        }
        // if the path is allowed to go above the root, restore leading ..s
        if (allowAboveRoot) {
          for (; up--; up) {
            parts.unshift('..');
          }
        }
        return parts;
      },normalize:function (path) {
        var isAbsolute = path.charAt(0) === '/',
            trailingSlash = path.substr(-1) === '/';
        // Normalize the path
        path = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), !isAbsolute).join('/');
        if (!path && !isAbsolute) {
          path = '.';
        }
        if (path && trailingSlash) {
          path += '/';
        }
        return (isAbsolute ? '/' : '') + path;
      },dirname:function (path) {
        var result = PATH.splitPath(path),
            root = result[0],
            dir = result[1];
        if (!root && !dir) {
          // No dirname whatsoever
          return '.';
        }
        if (dir) {
          // It has a dirname, strip trailing slash
          dir = dir.substr(0, dir.length - 1);
        }
        return root + dir;
      },basename:function (path) {
        // EMSCRIPTEN return '/'' for '/', not an empty string
        if (path === '/') return '/';
        var lastSlash = path.lastIndexOf('/');
        if (lastSlash === -1) return path;
        return path.substr(lastSlash+1);
      },extname:function (path) {
        return PATH.splitPath(path)[3];
      },join:function () {
        var paths = Array.prototype.slice.call(arguments, 0);
        return PATH.normalize(paths.join('/'));
      },join2:function (l, r) {
        return PATH.normalize(l + '/' + r);
      },resolve:function () {
        var resolvedPath = '',
          resolvedAbsolute = false;
        for (var i = arguments.length - 1; i >= -1 && !resolvedAbsolute; i--) {
          var path = (i >= 0) ? arguments[i] : FS.cwd();
          // Skip empty and invalid entries
          if (typeof path !== 'string') {
            throw new TypeError('Arguments to path.resolve must be strings');
          } else if (!path) {
            return ''; // an invalid portion invalidates the whole thing
          }
          resolvedPath = path + '/' + resolvedPath;
          resolvedAbsolute = path.charAt(0) === '/';
        }
        // At this point the path should be resolved to a full absolute path, but
        // handle relative paths to be safe (might happen when process.cwd() fails)
        resolvedPath = PATH.normalizeArray(resolvedPath.split('/').filter(function(p) {
          return !!p;
        }), !resolvedAbsolute).join('/');
        return ((resolvedAbsolute ? '/' : '') + resolvedPath) || '.';
      },relative:function (from, to) {
        from = PATH.resolve(from).substr(1);
        to = PATH.resolve(to).substr(1);
        function trim(arr) {
          var start = 0;
          for (; start < arr.length; start++) {
            if (arr[start] !== '') break;
          }
          var end = arr.length - 1;
          for (; end >= 0; end--) {
            if (arr[end] !== '') break;
          }
          if (start > end) return [];
          return arr.slice(start, end - start + 1);
        }
        var fromParts = trim(from.split('/'));
        var toParts = trim(to.split('/'));
        var length = Math.min(fromParts.length, toParts.length);
        var samePartsLength = length;
        for (var i = 0; i < length; i++) {
          if (fromParts[i] !== toParts[i]) {
            samePartsLength = i;
            break;
          }
        }
        var outputParts = [];
        for (var i = samePartsLength; i < fromParts.length; i++) {
          outputParts.push('..');
        }
        outputParts = outputParts.concat(toParts.slice(samePartsLength));
        return outputParts.join('/');
      }};
  
  var TTY={ttys:[],init:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // currently, FS.init does not distinguish if process.stdin is a file or TTY
        //   // device, it always assumes it's a TTY device. because of this, we're forcing
        //   // process.stdin to UTF8 encoding to at least make stdin reading compatible
        //   // with text files until FS.init can be refactored.
        //   process['stdin']['setEncoding']('utf8');
        // }
      },shutdown:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // inolen: any idea as to why node -e 'process.stdin.read()' wouldn't exit immediately (with process.stdin being a tty)?
        //   // isaacs: because now it's reading from the stream, you've expressed interest in it, so that read() kicks off a _read() which creates a ReadReq operation
        //   // inolen: I thought read() in that case was a synchronous operation that just grabbed some amount of buffered data if it exists?
        //   // isaacs: it is. but it also triggers a _read() call, which calls readStart() on the handle
        //   // isaacs: do process.stdin.pause() and i'd think it'd probably close the pending call
        //   process['stdin']['pause']();
        // }
      },register:function (dev, ops) {
        TTY.ttys[dev] = { input: [], output: [], ops: ops };
        FS.registerDevice(dev, TTY.stream_ops);
      },stream_ops:{open:function (stream) {
          var tty = TTY.ttys[stream.node.rdev];
          if (!tty) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          stream.tty = tty;
          stream.seekable = false;
        },close:function (stream) {
          // flush any pending line data
          stream.tty.ops.flush(stream.tty);
        },flush:function (stream) {
          stream.tty.ops.flush(stream.tty);
        },read:function (stream, buffer, offset, length, pos /* ignored */) {
          if (!stream.tty || !stream.tty.ops.get_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          var bytesRead = 0;
          for (var i = 0; i < length; i++) {
            var result;
            try {
              result = stream.tty.ops.get_char(stream.tty);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            if (result === undefined && bytesRead === 0) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
            if (result === null || result === undefined) break;
            bytesRead++;
            buffer[offset+i] = result;
          }
          if (bytesRead) {
            stream.node.timestamp = Date.now();
          }
          return bytesRead;
        },write:function (stream, buffer, offset, length, pos) {
          if (!stream.tty || !stream.tty.ops.put_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          for (var i = 0; i < length; i++) {
            try {
              stream.tty.ops.put_char(stream.tty, buffer[offset+i]);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
          }
          if (length) {
            stream.node.timestamp = Date.now();
          }
          return i;
        }},default_tty_ops:{get_char:function (tty) {
          if (!tty.input.length) {
            var result = null;
            if (ENVIRONMENT_IS_NODE) {
              result = process['stdin']['read']();
              if (!result) {
                if (process['stdin']['_readableState'] && process['stdin']['_readableState']['ended']) {
                  return null;  // EOF
                }
                return undefined;  // no data available
              }
            } else if (typeof window != 'undefined' &&
              typeof window.prompt == 'function') {
              // Browser.
              result = window.prompt('Input: ');  // returns null on cancel
              if (result !== null) {
                result += '\n';
              }
            } else if (typeof readline == 'function') {
              // Command line.
              result = readline();
              if (result !== null) {
                result += '\n';
              }
            }
            if (!result) {
              return null;
            }
            tty.input = intArrayFromString(result, true);
          }
          return tty.input.shift();
        },flush:function (tty) {
          if (tty.output && tty.output.length > 0) {
            Module['print'](tty.output.join(''));
            tty.output = [];
          }
        },put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['print'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }},default_tty1_ops:{put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['printErr'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        },flush:function (tty) {
          if (tty.output && tty.output.length > 0) {
            Module['printErr'](tty.output.join(''));
            tty.output = [];
          }
        }}};
  
  var MEMFS={ops_table:null,mount:function (mount) {
        return MEMFS.createNode(null, '/', 16384 | 511 /* 0777 */, 0);
      },createNode:function (parent, name, mode, dev) {
        if (FS.isBlkdev(mode) || FS.isFIFO(mode)) {
          // no supported
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (!MEMFS.ops_table) {
          MEMFS.ops_table = {
            dir: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                lookup: MEMFS.node_ops.lookup,
                mknod: MEMFS.node_ops.mknod,
                rename: MEMFS.node_ops.rename,
                unlink: MEMFS.node_ops.unlink,
                rmdir: MEMFS.node_ops.rmdir,
                readdir: MEMFS.node_ops.readdir,
                symlink: MEMFS.node_ops.symlink
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek
              }
            },
            file: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek,
                read: MEMFS.stream_ops.read,
                write: MEMFS.stream_ops.write,
                allocate: MEMFS.stream_ops.allocate,
                mmap: MEMFS.stream_ops.mmap
              }
            },
            link: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                readlink: MEMFS.node_ops.readlink
              },
              stream: {}
            },
            chrdev: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: FS.chrdev_stream_ops
            }
          };
        }
        var node = FS.createNode(parent, name, mode, dev);
        if (FS.isDir(node.mode)) {
          node.node_ops = MEMFS.ops_table.dir.node;
          node.stream_ops = MEMFS.ops_table.dir.stream;
          node.contents = {};
        } else if (FS.isFile(node.mode)) {
          node.node_ops = MEMFS.ops_table.file.node;
          node.stream_ops = MEMFS.ops_table.file.stream;
          node.usedBytes = 0; // The actual number of bytes used in the typed array, as opposed to contents.buffer.byteLength which gives the whole capacity.
          // When the byte data of the file is populated, this will point to either a typed array, or a normal JS array. Typed arrays are preferred
          // for performance, and used by default. However, typed arrays are not resizable like normal JS arrays are, so there is a small disk size
          // penalty involved for appending file writes that continuously grow a file similar to std::vector capacity vs used -scheme.
          node.contents = null; 
        } else if (FS.isLink(node.mode)) {
          node.node_ops = MEMFS.ops_table.link.node;
          node.stream_ops = MEMFS.ops_table.link.stream;
        } else if (FS.isChrdev(node.mode)) {
          node.node_ops = MEMFS.ops_table.chrdev.node;
          node.stream_ops = MEMFS.ops_table.chrdev.stream;
        }
        node.timestamp = Date.now();
        // add the new node to the parent
        if (parent) {
          parent.contents[name] = node;
        }
        return node;
      },getFileDataAsRegularArray:function (node) {
        if (node.contents && node.contents.subarray) {
          var arr = [];
          for (var i = 0; i < node.usedBytes; ++i) arr.push(node.contents[i]);
          return arr; // Returns a copy of the original data.
        }
        return node.contents; // No-op, the file contents are already in a JS array. Return as-is.
      },getFileDataAsTypedArray:function (node) {
        if (!node.contents) return new Uint8Array;
        if (node.contents.subarray) return node.contents.subarray(0, node.usedBytes); // Make sure to not return excess unused bytes.
        return new Uint8Array(node.contents);
      },expandFileStorage:function (node, newCapacity) {
  
        // If we are asked to expand the size of a file that already exists, revert to using a standard JS array to store the file
        // instead of a typed array. This makes resizing the array more flexible because we can just .push() elements at the back to
        // increase the size.
        if (node.contents && node.contents.subarray && newCapacity > node.contents.length) {
          node.contents = MEMFS.getFileDataAsRegularArray(node);
          node.usedBytes = node.contents.length; // We might be writing to a lazy-loaded file which had overridden this property, so force-reset it.
        }
  
        if (!node.contents || node.contents.subarray) { // Keep using a typed array if creating a new storage, or if old one was a typed array as well.
          var prevCapacity = node.contents ? node.contents.buffer.byteLength : 0;
          if (prevCapacity >= newCapacity) return; // No need to expand, the storage was already large enough.
          // Don't expand strictly to the given requested limit if it's only a very small increase, but instead geometrically grow capacity.
          // For small filesizes (<1MB), perform size*2 geometric increase, but for large sizes, do a much more conservative size*1.125 increase to
          // avoid overshooting the allocation cap by a very large margin.
          var CAPACITY_DOUBLING_MAX = 1024 * 1024;
          newCapacity = Math.max(newCapacity, (prevCapacity * (prevCapacity < CAPACITY_DOUBLING_MAX ? 2.0 : 1.125)) | 0);
          if (prevCapacity != 0) newCapacity = Math.max(newCapacity, 256); // At minimum allocate 256b for each file when expanding.
          var oldContents = node.contents;
          node.contents = new Uint8Array(newCapacity); // Allocate new storage.
          if (node.usedBytes > 0) node.contents.set(oldContents.subarray(0, node.usedBytes), 0); // Copy old data over to the new storage.
          return;
        }
        // Not using a typed array to back the file storage. Use a standard JS array instead.
        if (!node.contents && newCapacity > 0) node.contents = [];
        while (node.contents.length < newCapacity) node.contents.push(0);
      },resizeFileStorage:function (node, newSize) {
        if (node.usedBytes == newSize) return;
        if (newSize == 0) {
          node.contents = null; // Fully decommit when requesting a resize to zero.
          node.usedBytes = 0;
          return;
        }
  
        if (!node.contents || node.contents.subarray) { // Resize a typed array if that is being used as the backing store.
          var oldContents = node.contents;
          node.contents = new Uint8Array(new ArrayBuffer(newSize)); // Allocate new storage.
          if (oldContents) {
            node.contents.set(oldContents.subarray(0, Math.min(newSize, node.usedBytes))); // Copy old data over to the new storage.
          }
          node.usedBytes = newSize;
          return;
        }
        // Backing with a JS array.
        if (!node.contents) node.contents = [];
        if (node.contents.length > newSize) node.contents.length = newSize;
        else while (node.contents.length < newSize) node.contents.push(0);
        node.usedBytes = newSize;
      },node_ops:{getattr:function (node) {
          var attr = {};
          // device numbers reuse inode numbers.
          attr.dev = FS.isChrdev(node.mode) ? node.id : 1;
          attr.ino = node.id;
          attr.mode = node.mode;
          attr.nlink = 1;
          attr.uid = 0;
          attr.gid = 0;
          attr.rdev = node.rdev;
          if (FS.isDir(node.mode)) {
            attr.size = 4096;
          } else if (FS.isFile(node.mode)) {
            attr.size = node.usedBytes;
          } else if (FS.isLink(node.mode)) {
            attr.size = node.link.length;
          } else {
            attr.size = 0;
          }
          attr.atime = new Date(node.timestamp);
          attr.mtime = new Date(node.timestamp);
          attr.ctime = new Date(node.timestamp);
          // NOTE: In our implementation, st_blocks = Math.ceil(st_size/st_blksize),
          //       but this is not required by the standard.
          attr.blksize = 4096;
          attr.blocks = Math.ceil(attr.size / attr.blksize);
          return attr;
        },setattr:function (node, attr) {
          if (attr.mode !== undefined) {
            node.mode = attr.mode;
          }
          if (attr.timestamp !== undefined) {
            node.timestamp = attr.timestamp;
          }
          if (attr.size !== undefined) {
            MEMFS.resizeFileStorage(node, attr.size);
          }
        },lookup:function (parent, name) {
          throw FS.genericErrors[ERRNO_CODES.ENOENT];
        },mknod:function (parent, name, mode, dev) {
          return MEMFS.createNode(parent, name, mode, dev);
        },rename:function (old_node, new_dir, new_name) {
          // if we're overwriting a directory at new_name, make sure it's empty.
          if (FS.isDir(old_node.mode)) {
            var new_node;
            try {
              new_node = FS.lookupNode(new_dir, new_name);
            } catch (e) {
            }
            if (new_node) {
              for (var i in new_node.contents) {
                throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
              }
            }
          }
          // do the internal rewiring
          delete old_node.parent.contents[old_node.name];
          old_node.name = new_name;
          new_dir.contents[new_name] = old_node;
          old_node.parent = new_dir;
        },unlink:function (parent, name) {
          delete parent.contents[name];
        },rmdir:function (parent, name) {
          var node = FS.lookupNode(parent, name);
          for (var i in node.contents) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
          }
          delete parent.contents[name];
        },readdir:function (node) {
          var entries = ['.', '..']
          for (var key in node.contents) {
            if (!node.contents.hasOwnProperty(key)) {
              continue;
            }
            entries.push(key);
          }
          return entries;
        },symlink:function (parent, newname, oldpath) {
          var node = MEMFS.createNode(parent, newname, 511 /* 0777 */ | 40960, 0);
          node.link = oldpath;
          return node;
        },readlink:function (node) {
          if (!FS.isLink(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return node.link;
        }},stream_ops:{read:function (stream, buffer, offset, length, position) {
          var contents = stream.node.contents;
          if (position >= stream.node.usedBytes) return 0;
          var size = Math.min(stream.node.usedBytes - position, length);
          assert(size >= 0);
          if (size > 8 && contents.subarray) { // non-trivial, and typed array
            buffer.set(contents.subarray(position, position + size), offset);
          } else
          {
            for (var i = 0; i < size; i++) buffer[offset + i] = contents[position + i];
          }
          return size;
        },write:function (stream, buffer, offset, length, position, canOwn) {
          if (!length) return 0;
          var node = stream.node;
          node.timestamp = Date.now();
  
          if (buffer.subarray && (!node.contents || node.contents.subarray)) { // This write is from a typed array to a typed array?
            if (canOwn) { // Can we just reuse the buffer we are given?
              node.contents = buffer.subarray(offset, offset + length);
              node.usedBytes = length;
              return length;
            } else if (node.usedBytes === 0 && position === 0) { // If this is a simple first write to an empty file, do a fast set since we don't need to care about old data.
              node.contents = new Uint8Array(buffer.subarray(offset, offset + length));
              node.usedBytes = length;
              return length;
            } else if (position + length <= node.usedBytes) { // Writing to an already allocated and used subrange of the file?
              node.contents.set(buffer.subarray(offset, offset + length), position);
              return length;
            }
          }
          // Appending to an existing file and we need to reallocate, or source data did not come as a typed array.
          MEMFS.expandFileStorage(node, position+length);
          if (node.contents.subarray && buffer.subarray) node.contents.set(buffer.subarray(offset, offset + length), position); // Use typed array write if available.
          else
            for (var i = 0; i < length; i++) {
             node.contents[position + i] = buffer[offset + i]; // Or fall back to manual write if not.
            }
          node.usedBytes = Math.max(node.usedBytes, position+length);
          return length;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              position += stream.node.usedBytes;
            }
          }
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return position;
        },allocate:function (stream, offset, length) {
          MEMFS.expandFileStorage(stream.node, offset + length);
          stream.node.usedBytes = Math.max(stream.node.usedBytes, offset + length);
        },mmap:function (stream, buffer, offset, length, position, prot, flags) {
          if (!FS.isFile(stream.node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          var ptr;
          var allocated;
          var contents = stream.node.contents;
          // Only make a new copy when MAP_PRIVATE is specified.
          if ( !(flags & 2) &&
                (contents.buffer === buffer || contents.buffer === buffer.buffer) ) {
            // We can't emulate MAP_SHARED when the file is not backed by the buffer
            // we're mapping to (e.g. the HEAP buffer).
            allocated = false;
            ptr = contents.byteOffset;
          } else {
            // Try to avoid unnecessary slices.
            if (position > 0 || position + length < stream.node.usedBytes) {
              if (contents.subarray) {
                contents = contents.subarray(position, position + length);
              } else {
                contents = Array.prototype.slice.call(contents, position, position + length);
              }
            }
            allocated = true;
            ptr = _malloc(length);
            if (!ptr) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOMEM);
            }
            buffer.set(contents, ptr);
          }
          return { ptr: ptr, allocated: allocated };
        }}};
  
  var IDBFS={dbs:{},indexedDB:function () {
        if (typeof indexedDB !== 'undefined') return indexedDB;
        var ret = null;
        if (typeof window === 'object') ret = window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
        assert(ret, 'IDBFS used, but indexedDB not supported');
        return ret;
      },DB_VERSION:21,DB_STORE_NAME:"FILE_DATA",mount:function (mount) {
        // reuse all of the core MEMFS functionality
        return MEMFS.mount.apply(null, arguments);
      },syncfs:function (mount, populate, callback) {
        IDBFS.getLocalSet(mount, function(err, local) {
          if (err) return callback(err);
  
          IDBFS.getRemoteSet(mount, function(err, remote) {
            if (err) return callback(err);
  
            var src = populate ? remote : local;
            var dst = populate ? local : remote;
  
            IDBFS.reconcile(src, dst, callback);
          });
        });
      },getDB:function (name, callback) {
        // check the cache first
        var db = IDBFS.dbs[name];
        if (db) {
          return callback(null, db);
        }
  
        var req;
        try {
          req = IDBFS.indexedDB().open(name, IDBFS.DB_VERSION);
        } catch (e) {
          return callback(e);
        }
        req.onupgradeneeded = function(e) {
          var db = e.target.result;
          var transaction = e.target.transaction;
  
          var fileStore;
  
          if (db.objectStoreNames.contains(IDBFS.DB_STORE_NAME)) {
            fileStore = transaction.objectStore(IDBFS.DB_STORE_NAME);
          } else {
            fileStore = db.createObjectStore(IDBFS.DB_STORE_NAME);
          }
  
          fileStore.createIndex('timestamp', 'timestamp', { unique: false });
        };
        req.onsuccess = function() {
          db = req.result;
  
          // add to the cache
          IDBFS.dbs[name] = db;
          callback(null, db);
        };
        req.onerror = function() {
          callback(this.error);
        };
      },getLocalSet:function (mount, callback) {
        var entries = {};
  
        function isRealDir(p) {
          return p !== '.' && p !== '..';
        };
        function toAbsolute(root) {
          return function(p) {
            return PATH.join2(root, p);
          }
        };
  
        var check = FS.readdir(mount.mountpoint).filter(isRealDir).map(toAbsolute(mount.mountpoint));
  
        while (check.length) {
          var path = check.pop();
          var stat;
  
          try {
            stat = FS.stat(path);
          } catch (e) {
            return callback(e);
          }
  
          if (FS.isDir(stat.mode)) {
            check.push.apply(check, FS.readdir(path).filter(isRealDir).map(toAbsolute(path)));
          }
  
          entries[path] = { timestamp: stat.mtime };
        }
  
        return callback(null, { type: 'local', entries: entries });
      },getRemoteSet:function (mount, callback) {
        var entries = {};
  
        IDBFS.getDB(mount.mountpoint, function(err, db) {
          if (err) return callback(err);
  
          var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readonly');
          transaction.onerror = function() { callback(this.error); };
  
          var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
          var index = store.index('timestamp');
  
          index.openKeyCursor().onsuccess = function(event) {
            var cursor = event.target.result;
  
            if (!cursor) {
              return callback(null, { type: 'remote', db: db, entries: entries });
            }
  
            entries[cursor.primaryKey] = { timestamp: cursor.key };
  
            cursor.continue();
          };
        });
      },loadLocalEntry:function (path, callback) {
        var stat, node;
  
        try {
          var lookup = FS.lookupPath(path);
          node = lookup.node;
          stat = FS.stat(path);
        } catch (e) {
          return callback(e);
        }
  
        if (FS.isDir(stat.mode)) {
          return callback(null, { timestamp: stat.mtime, mode: stat.mode });
        } else if (FS.isFile(stat.mode)) {
          // Performance consideration: storing a normal JavaScript array to a IndexedDB is much slower than storing a typed array.
          // Therefore always convert the file contents to a typed array first before writing the data to IndexedDB.
          node.contents = MEMFS.getFileDataAsTypedArray(node);
          return callback(null, { timestamp: stat.mtime, mode: stat.mode, contents: node.contents });
        } else {
          return callback(new Error('node type not supported'));
        }
      },storeLocalEntry:function (path, entry, callback) {
        try {
          if (FS.isDir(entry.mode)) {
            FS.mkdir(path, entry.mode);
          } else if (FS.isFile(entry.mode)) {
            FS.writeFile(path, entry.contents, { encoding: 'binary', canOwn: true });
          } else {
            return callback(new Error('node type not supported'));
          }
  
          FS.chmod(path, entry.mode);
          FS.utime(path, entry.timestamp, entry.timestamp);
        } catch (e) {
          return callback(e);
        }
  
        callback(null);
      },removeLocalEntry:function (path, callback) {
        try {
          var lookup = FS.lookupPath(path);
          var stat = FS.stat(path);
  
          if (FS.isDir(stat.mode)) {
            FS.rmdir(path);
          } else if (FS.isFile(stat.mode)) {
            FS.unlink(path);
          }
        } catch (e) {
          return callback(e);
        }
  
        callback(null);
      },loadRemoteEntry:function (store, path, callback) {
        var req = store.get(path);
        req.onsuccess = function(event) { callback(null, event.target.result); };
        req.onerror = function() { callback(this.error); };
      },storeRemoteEntry:function (store, path, entry, callback) {
        var req = store.put(entry, path);
        req.onsuccess = function() { callback(null); };
        req.onerror = function() { callback(this.error); };
      },removeRemoteEntry:function (store, path, callback) {
        var req = store.delete(path);
        req.onsuccess = function() { callback(null); };
        req.onerror = function() { callback(this.error); };
      },reconcile:function (src, dst, callback) {
        var total = 0;
  
        var create = [];
        Object.keys(src.entries).forEach(function (key) {
          var e = src.entries[key];
          var e2 = dst.entries[key];
          if (!e2 || e.timestamp > e2.timestamp) {
            create.push(key);
            total++;
          }
        });
  
        var remove = [];
        Object.keys(dst.entries).forEach(function (key) {
          var e = dst.entries[key];
          var e2 = src.entries[key];
          if (!e2) {
            remove.push(key);
            total++;
          }
        });
  
        if (!total) {
          return callback(null);
        }
  
        var errored = false;
        var completed = 0;
        var db = src.type === 'remote' ? src.db : dst.db;
        var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readwrite');
        var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
  
        function done(err) {
          if (err) {
            if (!done.errored) {
              done.errored = true;
              return callback(err);
            }
            return;
          }
          if (++completed >= total) {
            return callback(null);
          }
        };
  
        transaction.onerror = function() { done(this.error); };
  
        // sort paths in ascending order so directory entries are created
        // before the files inside them
        create.sort().forEach(function (path) {
          if (dst.type === 'local') {
            IDBFS.loadRemoteEntry(store, path, function (err, entry) {
              if (err) return done(err);
              IDBFS.storeLocalEntry(path, entry, done);
            });
          } else {
            IDBFS.loadLocalEntry(path, function (err, entry) {
              if (err) return done(err);
              IDBFS.storeRemoteEntry(store, path, entry, done);
            });
          }
        });
  
        // sort paths in descending order so files are deleted before their
        // parent directories
        remove.sort().reverse().forEach(function(path) {
          if (dst.type === 'local') {
            IDBFS.removeLocalEntry(path, done);
          } else {
            IDBFS.removeRemoteEntry(store, path, done);
          }
        });
      }};
  
  var NODEFS={isWindows:false,staticInit:function () {
        NODEFS.isWindows = !!process.platform.match(/^win/);
      },mount:function (mount) {
        assert(ENVIRONMENT_IS_NODE);
        return NODEFS.createNode(null, '/', NODEFS.getMode(mount.opts.root), 0);
      },createNode:function (parent, name, mode, dev) {
        if (!FS.isDir(mode) && !FS.isFile(mode) && !FS.isLink(mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node = FS.createNode(parent, name, mode);
        node.node_ops = NODEFS.node_ops;
        node.stream_ops = NODEFS.stream_ops;
        return node;
      },getMode:function (path) {
        var stat;
        try {
          stat = fs.lstatSync(path);
          if (NODEFS.isWindows) {
            // On Windows, directories return permission bits 'rw-rw-rw-', even though they have 'rwxrwxrwx', so 
            // propagate write bits to execute bits.
            stat.mode = stat.mode | ((stat.mode & 146) >> 1);
          }
        } catch (e) {
          if (!e.code) throw e;
          throw new FS.ErrnoError(ERRNO_CODES[e.code]);
        }
        return stat.mode;
      },realPath:function (node) {
        var parts = [];
        while (node.parent !== node) {
          parts.push(node.name);
          node = node.parent;
        }
        parts.push(node.mount.opts.root);
        parts.reverse();
        return PATH.join.apply(null, parts);
      },flagsToPermissionStringMap:{0:"r",1:"r+",2:"r+",64:"r",65:"r+",66:"r+",129:"rx+",193:"rx+",514:"w+",577:"w",578:"w+",705:"wx",706:"wx+",1024:"a",1025:"a",1026:"a+",1089:"a",1090:"a+",1153:"ax",1154:"ax+",1217:"ax",1218:"ax+",4096:"rs",4098:"rs+"},flagsToPermissionString:function (flags) {
        if (flags in NODEFS.flagsToPermissionStringMap) {
          return NODEFS.flagsToPermissionStringMap[flags];
        } else {
          return flags;
        }
      },node_ops:{getattr:function (node) {
          var path = NODEFS.realPath(node);
          var stat;
          try {
            stat = fs.lstatSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          // node.js v0.10.20 doesn't report blksize and blocks on Windows. Fake them with default blksize of 4096.
          // See http://support.microsoft.com/kb/140365
          if (NODEFS.isWindows && !stat.blksize) {
            stat.blksize = 4096;
          }
          if (NODEFS.isWindows && !stat.blocks) {
            stat.blocks = (stat.size+stat.blksize-1)/stat.blksize|0;
          }
          return {
            dev: stat.dev,
            ino: stat.ino,
            mode: stat.mode,
            nlink: stat.nlink,
            uid: stat.uid,
            gid: stat.gid,
            rdev: stat.rdev,
            size: stat.size,
            atime: stat.atime,
            mtime: stat.mtime,
            ctime: stat.ctime,
            blksize: stat.blksize,
            blocks: stat.blocks
          };
        },setattr:function (node, attr) {
          var path = NODEFS.realPath(node);
          try {
            if (attr.mode !== undefined) {
              fs.chmodSync(path, attr.mode);
              // update the common node structure mode as well
              node.mode = attr.mode;
            }
            if (attr.timestamp !== undefined) {
              var date = new Date(attr.timestamp);
              fs.utimesSync(path, date, date);
            }
            if (attr.size !== undefined) {
              fs.truncateSync(path, attr.size);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },lookup:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          var mode = NODEFS.getMode(path);
          return NODEFS.createNode(parent, name, mode);
        },mknod:function (parent, name, mode, dev) {
          var node = NODEFS.createNode(parent, name, mode, dev);
          // create the backing node for this in the fs root as well
          var path = NODEFS.realPath(node);
          try {
            if (FS.isDir(node.mode)) {
              fs.mkdirSync(path, node.mode);
            } else {
              fs.writeFileSync(path, '', { mode: node.mode });
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return node;
        },rename:function (oldNode, newDir, newName) {
          var oldPath = NODEFS.realPath(oldNode);
          var newPath = PATH.join2(NODEFS.realPath(newDir), newName);
          try {
            fs.renameSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },unlink:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.unlinkSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },rmdir:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.rmdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readdir:function (node) {
          var path = NODEFS.realPath(node);
          try {
            return fs.readdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },symlink:function (parent, newName, oldPath) {
          var newPath = PATH.join2(NODEFS.realPath(parent), newName);
          try {
            fs.symlinkSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readlink:function (node) {
          var path = NODEFS.realPath(node);
          try {
            return fs.readlinkSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        }},stream_ops:{open:function (stream) {
          var path = NODEFS.realPath(stream.node);
          try {
            if (FS.isFile(stream.node.mode)) {
              stream.nfd = fs.openSync(path, NODEFS.flagsToPermissionString(stream.flags));
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },close:function (stream) {
          try {
            if (FS.isFile(stream.node.mode) && stream.nfd) {
              fs.closeSync(stream.nfd);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },read:function (stream, buffer, offset, length, position) {
          if (length === 0) return 0; // node errors on 0 length reads
          // FIXME this is terrible.
          var nbuffer = new Buffer(length);
          var res;
          try {
            res = fs.readSync(stream.nfd, nbuffer, 0, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          if (res > 0) {
            for (var i = 0; i < res; i++) {
              buffer[offset + i] = nbuffer[i];
            }
          }
          return res;
        },write:function (stream, buffer, offset, length, position) {
          // FIXME this is terrible.
          var nbuffer = new Buffer(buffer.subarray(offset, offset + length));
          var res;
          try {
            res = fs.writeSync(stream.nfd, nbuffer, 0, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return res;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              try {
                var stat = fs.fstatSync(stream.nfd);
                position += stat.size;
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES[e.code]);
              }
            }
          }
  
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
  
          return position;
        }}};
  
  var _stdin=allocate(1, "i32*", ALLOC_STATIC);
  
  var _stdout=allocate(1, "i32*", ALLOC_STATIC);
  
  var _stderr=allocate(1, "i32*", ALLOC_STATIC);
  
  function _fflush(stream) {
      // int fflush(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fflush.html
  
      /*
      // Disabled, see https://github.com/kripken/emscripten/issues/2770
      stream = FS.getStreamFromPtr(stream);
      if (stream.stream_ops.flush) {
        stream.stream_ops.flush(stream);
      }
      */
    }var FS={root:null,mounts:[],devices:[null],streams:[],nextInode:1,nameTable:null,currentPath:"/",initialized:false,ignorePermissions:true,trackingDelegate:{},tracking:{openFlags:{READ:1,WRITE:2}},ErrnoError:null,genericErrors:{},handleFSError:function (e) {
        if (!(e instanceof FS.ErrnoError)) throw e + ' : ' + stackTrace();
        return ___setErrNo(e.errno);
      },lookupPath:function (path, opts) {
        path = PATH.resolve(FS.cwd(), path);
        opts = opts || {};
  
        if (!path) return { path: '', node: null };
  
        var defaults = {
          follow_mount: true,
          recurse_count: 0
        };
        for (var key in defaults) {
          if (opts[key] === undefined) {
            opts[key] = defaults[key];
          }
        }
  
        if (opts.recurse_count > 8) {  // max recursive lookup of 8
          throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
        }
  
        // split the path
        var parts = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), false);
  
        // start at the root
        var current = FS.root;
        var current_path = '/';
  
        for (var i = 0; i < parts.length; i++) {
          var islast = (i === parts.length-1);
          if (islast && opts.parent) {
            // stop resolving
            break;
          }
  
          current = FS.lookupNode(current, parts[i]);
          current_path = PATH.join2(current_path, parts[i]);
  
          // jump to the mount's root node if this is a mountpoint
          if (FS.isMountpoint(current)) {
            if (!islast || (islast && opts.follow_mount)) {
              current = current.mounted.root;
            }
          }
  
          // by default, lookupPath will not follow a symlink if it is the final path component.
          // setting opts.follow = true will override this behavior.
          if (!islast || opts.follow) {
            var count = 0;
            while (FS.isLink(current.mode)) {
              var link = FS.readlink(current_path);
              current_path = PATH.resolve(PATH.dirname(current_path), link);
              
              var lookup = FS.lookupPath(current_path, { recurse_count: opts.recurse_count });
              current = lookup.node;
  
              if (count++ > 40) {  // limit max consecutive symlinks to 40 (SYMLOOP_MAX).
                throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
              }
            }
          }
        }
  
        return { path: current_path, node: current };
      },getPath:function (node) {
        var path;
        while (true) {
          if (FS.isRoot(node)) {
            var mount = node.mount.mountpoint;
            if (!path) return mount;
            return mount[mount.length-1] !== '/' ? mount + '/' + path : mount + path;
          }
          path = path ? node.name + '/' + path : node.name;
          node = node.parent;
        }
      },hashName:function (parentid, name) {
        var hash = 0;
  
  
        for (var i = 0; i < name.length; i++) {
          hash = ((hash << 5) - hash + name.charCodeAt(i)) | 0;
        }
        return ((parentid + hash) >>> 0) % FS.nameTable.length;
      },hashAddNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        node.name_next = FS.nameTable[hash];
        FS.nameTable[hash] = node;
      },hashRemoveNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        if (FS.nameTable[hash] === node) {
          FS.nameTable[hash] = node.name_next;
        } else {
          var current = FS.nameTable[hash];
          while (current) {
            if (current.name_next === node) {
              current.name_next = node.name_next;
              break;
            }
            current = current.name_next;
          }
        }
      },lookupNode:function (parent, name) {
        var err = FS.mayLookup(parent);
        if (err) {
          throw new FS.ErrnoError(err, parent);
        }
        var hash = FS.hashName(parent.id, name);
        for (var node = FS.nameTable[hash]; node; node = node.name_next) {
          var nodeName = node.name;
          if (node.parent.id === parent.id && nodeName === name) {
            return node;
          }
        }
        // if we failed to find it in the cache, call into the VFS
        return FS.lookup(parent, name);
      },createNode:function (parent, name, mode, rdev) {
        if (!FS.FSNode) {
          FS.FSNode = function(parent, name, mode, rdev) {
            if (!parent) {
              parent = this;  // root node sets parent to itself
            }
            this.parent = parent;
            this.mount = parent.mount;
            this.mounted = null;
            this.id = FS.nextInode++;
            this.name = name;
            this.mode = mode;
            this.node_ops = {};
            this.stream_ops = {};
            this.rdev = rdev;
          };
  
          FS.FSNode.prototype = {};
  
          // compatibility
          var readMode = 292 | 73;
          var writeMode = 146;
  
          // NOTE we must use Object.defineProperties instead of individual calls to
          // Object.defineProperty in order to make closure compiler happy
          Object.defineProperties(FS.FSNode.prototype, {
            read: {
              get: function() { return (this.mode & readMode) === readMode; },
              set: function(val) { val ? this.mode |= readMode : this.mode &= ~readMode; }
            },
            write: {
              get: function() { return (this.mode & writeMode) === writeMode; },
              set: function(val) { val ? this.mode |= writeMode : this.mode &= ~writeMode; }
            },
            isFolder: {
              get: function() { return FS.isDir(this.mode); }
            },
            isDevice: {
              get: function() { return FS.isChrdev(this.mode); }
            }
          });
        }
  
        var node = new FS.FSNode(parent, name, mode, rdev);
  
        FS.hashAddNode(node);
  
        return node;
      },destroyNode:function (node) {
        FS.hashRemoveNode(node);
      },isRoot:function (node) {
        return node === node.parent;
      },isMountpoint:function (node) {
        return !!node.mounted;
      },isFile:function (mode) {
        return (mode & 61440) === 32768;
      },isDir:function (mode) {
        return (mode & 61440) === 16384;
      },isLink:function (mode) {
        return (mode & 61440) === 40960;
      },isChrdev:function (mode) {
        return (mode & 61440) === 8192;
      },isBlkdev:function (mode) {
        return (mode & 61440) === 24576;
      },isFIFO:function (mode) {
        return (mode & 61440) === 4096;
      },isSocket:function (mode) {
        return (mode & 49152) === 49152;
      },flagModes:{"r":0,"rs":1052672,"r+":2,"w":577,"wx":705,"xw":705,"w+":578,"wx+":706,"xw+":706,"a":1089,"ax":1217,"xa":1217,"a+":1090,"ax+":1218,"xa+":1218},modeStringToFlags:function (str) {
        var flags = FS.flagModes[str];
        if (typeof flags === 'undefined') {
          throw new Error('Unknown file open mode: ' + str);
        }
        return flags;
      },flagsToPermissionString:function (flag) {
        var accmode = flag & 2097155;
        var perms = ['r', 'w', 'rw'][accmode];
        if ((flag & 512)) {
          perms += 'w';
        }
        return perms;
      },nodePermissions:function (node, perms) {
        if (FS.ignorePermissions) {
          return 0;
        }
        // return 0 if any user, group or owner bits are set.
        if (perms.indexOf('r') !== -1 && !(node.mode & 292)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('w') !== -1 && !(node.mode & 146)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('x') !== -1 && !(node.mode & 73)) {
          return ERRNO_CODES.EACCES;
        }
        return 0;
      },mayLookup:function (dir) {
        var err = FS.nodePermissions(dir, 'x');
        if (err) return err;
        if (!dir.node_ops.lookup) return ERRNO_CODES.EACCES;
        return 0;
      },mayCreate:function (dir, name) {
        try {
          var node = FS.lookupNode(dir, name);
          return ERRNO_CODES.EEXIST;
        } catch (e) {
        }
        return FS.nodePermissions(dir, 'wx');
      },mayDelete:function (dir, name, isdir) {
        var node;
        try {
          node = FS.lookupNode(dir, name);
        } catch (e) {
          return e.errno;
        }
        var err = FS.nodePermissions(dir, 'wx');
        if (err) {
          return err;
        }
        if (isdir) {
          if (!FS.isDir(node.mode)) {
            return ERRNO_CODES.ENOTDIR;
          }
          if (FS.isRoot(node) || FS.getPath(node) === FS.cwd()) {
            return ERRNO_CODES.EBUSY;
          }
        } else {
          if (FS.isDir(node.mode)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return 0;
      },mayOpen:function (node, flags) {
        if (!node) {
          return ERRNO_CODES.ENOENT;
        }
        if (FS.isLink(node.mode)) {
          return ERRNO_CODES.ELOOP;
        } else if (FS.isDir(node.mode)) {
          if ((flags & 2097155) !== 0 ||  // opening for write
              (flags & 512)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return FS.nodePermissions(node, FS.flagsToPermissionString(flags));
      },MAX_OPEN_FDS:4096,nextfd:function (fd_start, fd_end) {
        fd_start = fd_start || 0;
        fd_end = fd_end || FS.MAX_OPEN_FDS;
        for (var fd = fd_start; fd <= fd_end; fd++) {
          if (!FS.streams[fd]) {
            return fd;
          }
        }
        throw new FS.ErrnoError(ERRNO_CODES.EMFILE);
      },getStream:function (fd) {
        return FS.streams[fd];
      },createStream:function (stream, fd_start, fd_end) {
        if (!FS.FSStream) {
          FS.FSStream = function(){};
          FS.FSStream.prototype = {};
          // compatibility
          Object.defineProperties(FS.FSStream.prototype, {
            object: {
              get: function() { return this.node; },
              set: function(val) { this.node = val; }
            },
            isRead: {
              get: function() { return (this.flags & 2097155) !== 1; }
            },
            isWrite: {
              get: function() { return (this.flags & 2097155) !== 0; }
            },
            isAppend: {
              get: function() { return (this.flags & 1024); }
            }
          });
        }
        // clone it, so we can return an instance of FSStream
        var newStream = new FS.FSStream();
        for (var p in stream) {
          newStream[p] = stream[p];
        }
        stream = newStream;
        var fd = FS.nextfd(fd_start, fd_end);
        stream.fd = fd;
        FS.streams[fd] = stream;
        return stream;
      },closeStream:function (fd) {
        FS.streams[fd] = null;
      },getStreamFromPtr:function (ptr) {
        return FS.streams[ptr - 1];
      },getPtrForStream:function (stream) {
        return stream ? stream.fd + 1 : 0;
      },chrdev_stream_ops:{open:function (stream) {
          var device = FS.getDevice(stream.node.rdev);
          // override node's stream ops with the device's
          stream.stream_ops = device.stream_ops;
          // forward the open call
          if (stream.stream_ops.open) {
            stream.stream_ops.open(stream);
          }
        },llseek:function () {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }},major:function (dev) {
        return ((dev) >> 8);
      },minor:function (dev) {
        return ((dev) & 0xff);
      },makedev:function (ma, mi) {
        return ((ma) << 8 | (mi));
      },registerDevice:function (dev, ops) {
        FS.devices[dev] = { stream_ops: ops };
      },getDevice:function (dev) {
        return FS.devices[dev];
      },getMounts:function (mount) {
        var mounts = [];
        var check = [mount];
  
        while (check.length) {
          var m = check.pop();
  
          mounts.push(m);
  
          check.push.apply(check, m.mounts);
        }
  
        return mounts;
      },syncfs:function (populate, callback) {
        if (typeof(populate) === 'function') {
          callback = populate;
          populate = false;
        }
  
        var mounts = FS.getMounts(FS.root.mount);
        var completed = 0;
  
        function done(err) {
          if (err) {
            if (!done.errored) {
              done.errored = true;
              return callback(err);
            }
            return;
          }
          if (++completed >= mounts.length) {
            callback(null);
          }
        };
  
        // sync all mounts
        mounts.forEach(function (mount) {
          if (!mount.type.syncfs) {
            return done(null);
          }
          mount.type.syncfs(mount, populate, done);
        });
      },mount:function (type, opts, mountpoint) {
        var root = mountpoint === '/';
        var pseudo = !mountpoint;
        var node;
  
        if (root && FS.root) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        } else if (!root && !pseudo) {
          var lookup = FS.lookupPath(mountpoint, { follow_mount: false });
  
          mountpoint = lookup.path;  // use the absolute path
          node = lookup.node;
  
          if (FS.isMountpoint(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
          }
  
          if (!FS.isDir(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
          }
        }
  
        var mount = {
          type: type,
          opts: opts,
          mountpoint: mountpoint,
          mounts: []
        };
  
        // create a root node for the fs
        var mountRoot = type.mount(mount);
        mountRoot.mount = mount;
        mount.root = mountRoot;
  
        if (root) {
          FS.root = mountRoot;
        } else if (node) {
          // set as a mountpoint
          node.mounted = mount;
  
          // add the new mount to the current mount's children
          if (node.mount) {
            node.mount.mounts.push(mount);
          }
        }
  
        return mountRoot;
      },unmount:function (mountpoint) {
        var lookup = FS.lookupPath(mountpoint, { follow_mount: false });
  
        if (!FS.isMountpoint(lookup.node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
  
        // destroy the nodes for this mount, and all its child mounts
        var node = lookup.node;
        var mount = node.mounted;
        var mounts = FS.getMounts(mount);
  
        Object.keys(FS.nameTable).forEach(function (hash) {
          var current = FS.nameTable[hash];
  
          while (current) {
            var next = current.name_next;
  
            if (mounts.indexOf(current.mount) !== -1) {
              FS.destroyNode(current);
            }
  
            current = next;
          }
        });
  
        // no longer a mountpoint
        node.mounted = null;
  
        // remove this mount from the child mounts
        var idx = node.mount.mounts.indexOf(mount);
        assert(idx !== -1);
        node.mount.mounts.splice(idx, 1);
      },lookup:function (parent, name) {
        return parent.node_ops.lookup(parent, name);
      },mknod:function (path, mode, dev) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        if (!name || name === '.' || name === '..') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.mayCreate(parent, name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.mknod) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.mknod(parent, name, mode, dev);
      },create:function (path, mode) {
        mode = mode !== undefined ? mode : 438 /* 0666 */;
        mode &= 4095;
        mode |= 32768;
        return FS.mknod(path, mode, 0);
      },mkdir:function (path, mode) {
        mode = mode !== undefined ? mode : 511 /* 0777 */;
        mode &= 511 | 512;
        mode |= 16384;
        return FS.mknod(path, mode, 0);
      },mkdev:function (path, mode, dev) {
        if (typeof(dev) === 'undefined') {
          dev = mode;
          mode = 438 /* 0666 */;
        }
        mode |= 8192;
        return FS.mknod(path, mode, dev);
      },symlink:function (oldpath, newpath) {
        if (!PATH.resolve(oldpath)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        var lookup = FS.lookupPath(newpath, { parent: true });
        var parent = lookup.node;
        if (!parent) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        var newname = PATH.basename(newpath);
        var err = FS.mayCreate(parent, newname);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.symlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.symlink(parent, newname, oldpath);
      },rename:function (old_path, new_path) {
        var old_dirname = PATH.dirname(old_path);
        var new_dirname = PATH.dirname(new_path);
        var old_name = PATH.basename(old_path);
        var new_name = PATH.basename(new_path);
        // parents must exist
        var lookup, old_dir, new_dir;
        try {
          lookup = FS.lookupPath(old_path, { parent: true });
          old_dir = lookup.node;
          lookup = FS.lookupPath(new_path, { parent: true });
          new_dir = lookup.node;
        } catch (e) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        if (!old_dir || !new_dir) throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        // need to be part of the same mount
        if (old_dir.mount !== new_dir.mount) {
          throw new FS.ErrnoError(ERRNO_CODES.EXDEV);
        }
        // source must exist
        var old_node = FS.lookupNode(old_dir, old_name);
        // old path should not be an ancestor of the new path
        var relative = PATH.relative(old_path, new_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        // new path should not be an ancestor of the old path
        relative = PATH.relative(new_path, old_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
        }
        // see if the new path already exists
        var new_node;
        try {
          new_node = FS.lookupNode(new_dir, new_name);
        } catch (e) {
          // not fatal
        }
        // early out if nothing needs to change
        if (old_node === new_node) {
          return;
        }
        // we'll need to delete the old entry
        var isdir = FS.isDir(old_node.mode);
        var err = FS.mayDelete(old_dir, old_name, isdir);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // need delete permissions if we'll be overwriting.
        // need create permissions if new doesn't already exist.
        err = new_node ?
          FS.mayDelete(new_dir, new_name, isdir) :
          FS.mayCreate(new_dir, new_name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!old_dir.node_ops.rename) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(old_node) || (new_node && FS.isMountpoint(new_node))) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // if we are going to change the parent, check write permissions
        if (new_dir !== old_dir) {
          err = FS.nodePermissions(old_dir, 'w');
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        try {
          if (FS.trackingDelegate['willMovePath']) {
            FS.trackingDelegate['willMovePath'](old_path, new_path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willMovePath']('"+old_path+"', '"+new_path+"') threw an exception: " + e.message);
        }
        // remove the node from the lookup hash
        FS.hashRemoveNode(old_node);
        // do the underlying fs rename
        try {
          old_dir.node_ops.rename(old_node, new_dir, new_name);
        } catch (e) {
          throw e;
        } finally {
          // add the node back to the hash (in case node_ops.rename
          // changed its name)
          FS.hashAddNode(old_node);
        }
        try {
          if (FS.trackingDelegate['onMovePath']) FS.trackingDelegate['onMovePath'](old_path, new_path);
        } catch(e) {
          console.log("FS.trackingDelegate['onMovePath']('"+old_path+"', '"+new_path+"') threw an exception: " + e.message);
        }
      },rmdir:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, true);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.rmdir) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        try {
          if (FS.trackingDelegate['willDeletePath']) {
            FS.trackingDelegate['willDeletePath'](path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willDeletePath']('"+path+"') threw an exception: " + e.message);
        }
        parent.node_ops.rmdir(parent, name);
        FS.destroyNode(node);
        try {
          if (FS.trackingDelegate['onDeletePath']) FS.trackingDelegate['onDeletePath'](path);
        } catch(e) {
          console.log("FS.trackingDelegate['onDeletePath']('"+path+"') threw an exception: " + e.message);
        }
      },readdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        if (!node.node_ops.readdir) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        return node.node_ops.readdir(node);
      },unlink:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, false);
        if (err) {
          // POSIX says unlink should set EPERM, not EISDIR
          if (err === ERRNO_CODES.EISDIR) err = ERRNO_CODES.EPERM;
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.unlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        try {
          if (FS.trackingDelegate['willDeletePath']) {
            FS.trackingDelegate['willDeletePath'](path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willDeletePath']('"+path+"') threw an exception: " + e.message);
        }
        parent.node_ops.unlink(parent, name);
        FS.destroyNode(node);
        try {
          if (FS.trackingDelegate['onDeletePath']) FS.trackingDelegate['onDeletePath'](path);
        } catch(e) {
          console.log("FS.trackingDelegate['onDeletePath']('"+path+"') threw an exception: " + e.message);
        }
      },readlink:function (path) {
        var lookup = FS.lookupPath(path);
        var link = lookup.node;
        if (!link) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        if (!link.node_ops.readlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        return link.node_ops.readlink(link);
      },stat:function (path, dontFollow) {
        var lookup = FS.lookupPath(path, { follow: !dontFollow });
        var node = lookup.node;
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        if (!node.node_ops.getattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return node.node_ops.getattr(node);
      },lstat:function (path) {
        return FS.stat(path, true);
      },chmod:function (path, mode, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          mode: (mode & 4095) | (node.mode & ~4095),
          timestamp: Date.now()
        });
      },lchmod:function (path, mode) {
        FS.chmod(path, mode, true);
      },fchmod:function (fd, mode) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chmod(stream.node, mode);
      },chown:function (path, uid, gid, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          timestamp: Date.now()
          // we ignore the uid / gid for now
        });
      },lchown:function (path, uid, gid) {
        FS.chown(path, uid, gid, true);
      },fchown:function (fd, uid, gid) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chown(stream.node, uid, gid);
      },truncate:function (path, len) {
        if (len < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: true });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!FS.isFile(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.nodePermissions(node, 'w');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        node.node_ops.setattr(node, {
          size: len,
          timestamp: Date.now()
        });
      },ftruncate:function (fd, len) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        FS.truncate(stream.node, len);
      },utime:function (path, atime, mtime) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        node.node_ops.setattr(node, {
          timestamp: Math.max(atime, mtime)
        });
      },open:function (path, flags, mode, fd_start, fd_end) {
        if (path === "") {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        flags = typeof flags === 'string' ? FS.modeStringToFlags(flags) : flags;
        mode = typeof mode === 'undefined' ? 438 /* 0666 */ : mode;
        if ((flags & 64)) {
          mode = (mode & 4095) | 32768;
        } else {
          mode = 0;
        }
        var node;
        if (typeof path === 'object') {
          node = path;
        } else {
          path = PATH.normalize(path);
          try {
            var lookup = FS.lookupPath(path, {
              follow: !(flags & 131072)
            });
            node = lookup.node;
          } catch (e) {
            // ignore
          }
        }
        // perhaps we need to create the node
        var created = false;
        if ((flags & 64)) {
          if (node) {
            // if O_CREAT and O_EXCL are set, error out if the node already exists
            if ((flags & 128)) {
              throw new FS.ErrnoError(ERRNO_CODES.EEXIST);
            }
          } else {
            // node doesn't exist, try to create it
            node = FS.mknod(path, mode, 0);
            created = true;
          }
        }
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        // can't truncate a device
        if (FS.isChrdev(node.mode)) {
          flags &= ~512;
        }
        // check permissions, if this is not a file we just created now (it is ok to
        // create and write to a file with read-only permissions; it is read-only
        // for later use)
        if (!created) {
          var err = FS.mayOpen(node, flags);
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        // do truncation if necessary
        if ((flags & 512)) {
          FS.truncate(node, 0);
        }
        // we've already handled these, don't pass down to the underlying vfs
        flags &= ~(128 | 512);
  
        // register the stream with the filesystem
        var stream = FS.createStream({
          node: node,
          path: FS.getPath(node),  // we want the absolute path to the node
          flags: flags,
          seekable: true,
          position: 0,
          stream_ops: node.stream_ops,
          // used by the file family libc calls (fopen, fwrite, ferror, etc.)
          ungotten: [],
          error: false
        }, fd_start, fd_end);
        // call the new stream's open function
        if (stream.stream_ops.open) {
          stream.stream_ops.open(stream);
        }
        if (Module['logReadFiles'] && !(flags & 1)) {
          if (!FS.readFiles) FS.readFiles = {};
          if (!(path in FS.readFiles)) {
            FS.readFiles[path] = 1;
            Module['printErr']('read file: ' + path);
          }
        }
        try {
          if (FS.trackingDelegate['onOpenFile']) {
            var trackingFlags = 0;
            if ((flags & 2097155) !== 1) {
              trackingFlags |= FS.tracking.openFlags.READ;
            }
            if ((flags & 2097155) !== 0) {
              trackingFlags |= FS.tracking.openFlags.WRITE;
            }
            FS.trackingDelegate['onOpenFile'](path, trackingFlags);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['onOpenFile']('"+path+"', flags) threw an exception: " + e.message);
        }
        return stream;
      },close:function (stream) {
        try {
          if (stream.stream_ops.close) {
            stream.stream_ops.close(stream);
          }
        } catch (e) {
          throw e;
        } finally {
          FS.closeStream(stream.fd);
        }
      },llseek:function (stream, offset, whence) {
        if (!stream.seekable || !stream.stream_ops.llseek) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        stream.position = stream.stream_ops.llseek(stream, offset, whence);
        stream.ungotten = [];
        return stream.position;
      },read:function (stream, buffer, offset, length, position) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.read) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesRead = stream.stream_ops.read(stream, buffer, offset, length, position);
        if (!seeking) stream.position += bytesRead;
        return bytesRead;
      },write:function (stream, buffer, offset, length, position, canOwn) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.write) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if (stream.flags & 1024) {
          // seek to the end before writing in append mode
          FS.llseek(stream, 0, 2);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesWritten = stream.stream_ops.write(stream, buffer, offset, length, position, canOwn);
        if (!seeking) stream.position += bytesWritten;
        try {
          if (stream.path && FS.trackingDelegate['onWriteToFile']) FS.trackingDelegate['onWriteToFile'](stream.path);
        } catch(e) {
          console.log("FS.trackingDelegate['onWriteToFile']('"+path+"') threw an exception: " + e.message);
        }
        return bytesWritten;
      },allocate:function (stream, offset, length) {
        if (offset < 0 || length <= 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (!FS.isFile(stream.node.mode) && !FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        if (!stream.stream_ops.allocate) {
          throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
        }
        stream.stream_ops.allocate(stream, offset, length);
      },mmap:function (stream, buffer, offset, length, position, prot, flags) {
        // TODO if PROT is PROT_WRITE, make sure we have write access
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EACCES);
        }
        if (!stream.stream_ops.mmap) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        return stream.stream_ops.mmap(stream, buffer, offset, length, position, prot, flags);
      },ioctl:function (stream, cmd, arg) {
        if (!stream.stream_ops.ioctl) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTTY);
        }
        return stream.stream_ops.ioctl(stream, cmd, arg);
      },readFile:function (path, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'r';
        opts.encoding = opts.encoding || 'binary';
        if (opts.encoding !== 'utf8' && opts.encoding !== 'binary') {
          throw new Error('Invalid encoding type "' + opts.encoding + '"');
        }
        var ret;
        var stream = FS.open(path, opts.flags);
        var stat = FS.stat(path);
        var length = stat.size;
        var buf = new Uint8Array(length);
        FS.read(stream, buf, 0, length, 0);
        if (opts.encoding === 'utf8') {
          ret = '';
          var utf8 = new Runtime.UTF8Processor();
          for (var i = 0; i < length; i++) {
            ret += utf8.processCChar(buf[i]);
          }
        } else if (opts.encoding === 'binary') {
          ret = buf;
        }
        FS.close(stream);
        return ret;
      },writeFile:function (path, data, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'w';
        opts.encoding = opts.encoding || 'utf8';
        if (opts.encoding !== 'utf8' && opts.encoding !== 'binary') {
          throw new Error('Invalid encoding type "' + opts.encoding + '"');
        }
        var stream = FS.open(path, opts.flags, opts.mode);
        if (opts.encoding === 'utf8') {
          var utf8 = new Runtime.UTF8Processor();
          var buf = new Uint8Array(utf8.processJSString(data));
          FS.write(stream, buf, 0, buf.length, 0, opts.canOwn);
        } else if (opts.encoding === 'binary') {
          FS.write(stream, data, 0, data.length, 0, opts.canOwn);
        }
        FS.close(stream);
      },cwd:function () {
        return FS.currentPath;
      },chdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        if (!FS.isDir(lookup.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        var err = FS.nodePermissions(lookup.node, 'x');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        FS.currentPath = lookup.path;
      },createDefaultDirectories:function () {
        FS.mkdir('/tmp');
        FS.mkdir('/home');
        FS.mkdir('/home/web_user');
      },createDefaultDevices:function () {
        // create /dev
        FS.mkdir('/dev');
        // setup /dev/null
        FS.registerDevice(FS.makedev(1, 3), {
          read: function() { return 0; },
          write: function() { return 0; }
        });
        FS.mkdev('/dev/null', FS.makedev(1, 3));
        // setup /dev/tty and /dev/tty1
        // stderr needs to print output using Module['printErr']
        // so we register a second tty just for it.
        TTY.register(FS.makedev(5, 0), TTY.default_tty_ops);
        TTY.register(FS.makedev(6, 0), TTY.default_tty1_ops);
        FS.mkdev('/dev/tty', FS.makedev(5, 0));
        FS.mkdev('/dev/tty1', FS.makedev(6, 0));
        // setup /dev/[u]random
        var random_device;
        if (typeof crypto !== 'undefined') {
          // for modern web browsers
          var randomBuffer = new Uint8Array(1);
          random_device = function() { crypto.getRandomValues(randomBuffer); return randomBuffer[0]; };
        } else if (ENVIRONMENT_IS_NODE) {
          // for nodejs
          random_device = function() { return require('crypto').randomBytes(1)[0]; };
        } else {
          // default for ES5 platforms
          random_device = function() { return (Math.random()*256)|0; };
        }
        FS.createDevice('/dev', 'random', random_device);
        FS.createDevice('/dev', 'urandom', random_device);
        // we're not going to emulate the actual shm device,
        // just create the tmp dirs that reside in it commonly
        FS.mkdir('/dev/shm');
        FS.mkdir('/dev/shm/tmp');
      },createStandardStreams:function () {
        // TODO deprecate the old functionality of a single
        // input / output callback and that utilizes FS.createDevice
        // and instead require a unique set of stream ops
  
        // by default, we symlink the standard streams to the
        // default tty devices. however, if the standard streams
        // have been overwritten we create a unique device for
        // them instead.
        if (Module['stdin']) {
          FS.createDevice('/dev', 'stdin', Module['stdin']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdin');
        }
        if (Module['stdout']) {
          FS.createDevice('/dev', 'stdout', null, Module['stdout']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdout');
        }
        if (Module['stderr']) {
          FS.createDevice('/dev', 'stderr', null, Module['stderr']);
        } else {
          FS.symlink('/dev/tty1', '/dev/stderr');
        }
  
        // open default streams for the stdin, stdout and stderr devices
        var stdin = FS.open('/dev/stdin', 'r');
        HEAP32[((_stdin)>>2)]=FS.getPtrForStream(stdin);
        assert(stdin.fd === 0, 'invalid handle for stdin (' + stdin.fd + ')');
  
        var stdout = FS.open('/dev/stdout', 'w');
        HEAP32[((_stdout)>>2)]=FS.getPtrForStream(stdout);
        assert(stdout.fd === 1, 'invalid handle for stdout (' + stdout.fd + ')');
  
        var stderr = FS.open('/dev/stderr', 'w');
        HEAP32[((_stderr)>>2)]=FS.getPtrForStream(stderr);
        assert(stderr.fd === 2, 'invalid handle for stderr (' + stderr.fd + ')');
      },ensureErrnoError:function () {
        if (FS.ErrnoError) return;
        FS.ErrnoError = function ErrnoError(errno, node) {
          this.node = node;
          this.setErrno = function(errno) {
            this.errno = errno;
            for (var key in ERRNO_CODES) {
              if (ERRNO_CODES[key] === errno) {
                this.code = key;
                break;
              }
            }
          };
          this.setErrno(errno);
          this.message = ERRNO_MESSAGES[errno];
        };
        FS.ErrnoError.prototype = new Error();
        FS.ErrnoError.prototype.constructor = FS.ErrnoError;
        // Some errors may happen quite a bit, to avoid overhead we reuse them (and suffer a lack of stack info)
        [ERRNO_CODES.ENOENT].forEach(function(code) {
          FS.genericErrors[code] = new FS.ErrnoError(code);
          FS.genericErrors[code].stack = '<generic error, no stack>';
        });
      },staticInit:function () {
        FS.ensureErrnoError();
  
        FS.nameTable = new Array(4096);
  
        FS.mount(MEMFS, {}, '/');
  
        FS.createDefaultDirectories();
        FS.createDefaultDevices();
      },init:function (input, output, error) {
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
  
        FS.ensureErrnoError();
  
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        Module['stdin'] = input || Module['stdin'];
        Module['stdout'] = output || Module['stdout'];
        Module['stderr'] = error || Module['stderr'];
  
        FS.createStandardStreams();
      },quit:function () {
        FS.init.initialized = false;
        for (var i = 0; i < FS.streams.length; i++) {
          var stream = FS.streams[i];
          if (!stream) {
            continue;
          }
          FS.close(stream);
        }
      },getMode:function (canRead, canWrite) {
        var mode = 0;
        if (canRead) mode |= 292 | 73;
        if (canWrite) mode |= 146;
        return mode;
      },joinPath:function (parts, forceRelative) {
        var path = PATH.join.apply(null, parts);
        if (forceRelative && path[0] == '/') path = path.substr(1);
        return path;
      },absolutePath:function (relative, base) {
        return PATH.resolve(base, relative);
      },standardizePath:function (path) {
        return PATH.normalize(path);
      },findObject:function (path, dontResolveLastLink) {
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },analyzePath:function (path, dontResolveLastLink) {
        // operate from within the context of the symlink's target
        try {
          var lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          path = lookup.path;
        } catch (e) {
        }
        var ret = {
          isRoot: false, exists: false, error: 0, name: null, path: null, object: null,
          parentExists: false, parentPath: null, parentObject: null
        };
        try {
          var lookup = FS.lookupPath(path, { parent: true });
          ret.parentExists = true;
          ret.parentPath = lookup.path;
          ret.parentObject = lookup.node;
          ret.name = PATH.basename(path);
          lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          ret.exists = true;
          ret.path = lookup.path;
          ret.object = lookup.node;
          ret.name = lookup.node.name;
          ret.isRoot = lookup.path === '/';
        } catch (e) {
          ret.error = e.errno;
        };
        return ret;
      },createFolder:function (parent, name, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.mkdir(path, mode);
      },createPath:function (parent, path, canRead, canWrite) {
        parent = typeof parent === 'string' ? parent : FS.getPath(parent);
        var parts = path.split('/').reverse();
        while (parts.length) {
          var part = parts.pop();
          if (!part) continue;
          var current = PATH.join2(parent, part);
          try {
            FS.mkdir(current);
          } catch (e) {
            // ignore EEXIST
          }
          parent = current;
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.create(path, mode);
      },createDataFile:function (parent, name, data, canRead, canWrite, canOwn) {
        var path = name ? PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name) : parent;
        var mode = FS.getMode(canRead, canWrite);
        var node = FS.create(path, mode);
        if (data) {
          if (typeof data === 'string') {
            var arr = new Array(data.length);
            for (var i = 0, len = data.length; i < len; ++i) arr[i] = data.charCodeAt(i);
            data = arr;
          }
          // make sure we can write to the file
          FS.chmod(node, mode | 146);
          var stream = FS.open(node, 'w');
          FS.write(stream, data, 0, data.length, 0, canOwn);
          FS.close(stream);
          FS.chmod(node, mode);
        }
        return node;
      },createDevice:function (parent, name, input, output) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(!!input, !!output);
        if (!FS.createDevice.major) FS.createDevice.major = 64;
        var dev = FS.makedev(FS.createDevice.major++, 0);
        // Create a fake device that a set of stream ops to emulate
        // the old behavior.
        FS.registerDevice(dev, {
          open: function(stream) {
            stream.seekable = false;
          },
          close: function(stream) {
            // flush any pending line data
            if (output && output.buffer && output.buffer.length) {
              output(10);
            }
          },
          read: function(stream, buffer, offset, length, pos /* ignored */) {
            var bytesRead = 0;
            for (var i = 0; i < length; i++) {
              var result;
              try {
                result = input();
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
              if (result === undefined && bytesRead === 0) {
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
              if (result === null || result === undefined) break;
              bytesRead++;
              buffer[offset+i] = result;
            }
            if (bytesRead) {
              stream.node.timestamp = Date.now();
            }
            return bytesRead;
          },
          write: function(stream, buffer, offset, length, pos) {
            for (var i = 0; i < length; i++) {
              try {
                output(buffer[offset+i]);
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
            }
            if (length) {
              stream.node.timestamp = Date.now();
            }
            return i;
          }
        });
        return FS.mkdev(path, mode, dev);
      },createLink:function (parent, name, target, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        return FS.symlink(target, path);
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
            obj.usedBytes = obj.contents.length;
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
        // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
        function LazyUint8Array() {
          this.lengthKnown = false;
          this.chunks = []; // Loaded chunks. Index is the chunk number
        }
        LazyUint8Array.prototype.get = function LazyUint8Array_get(idx) {
          if (idx > this.length-1 || idx < 0) {
            return undefined;
          }
          var chunkOffset = idx % this.chunkSize;
          var chunkNum = (idx / this.chunkSize)|0;
          return this.getter(chunkNum)[chunkOffset];
        }
        LazyUint8Array.prototype.setDataGetter = function LazyUint8Array_setDataGetter(getter) {
          this.getter = getter;
        }
        LazyUint8Array.prototype.cacheLength = function LazyUint8Array_cacheLength() {
          // Find length
          var xhr = new XMLHttpRequest();
          xhr.open('HEAD', url, false);
          xhr.send(null);
          if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
          var datalength = Number(xhr.getResponseHeader("Content-length"));
          var header;
          var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
          var chunkSize = 1024*1024; // Chunk size in bytes
  
          if (!hasByteServing) chunkSize = datalength;
  
          // Function to get a range from the remote URL.
          var doXHR = (function(from, to) {
            if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
            if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");
  
            // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
            var xhr = new XMLHttpRequest();
            xhr.open('GET', url, false);
            if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
  
            // Some hints to the browser that we want binary data.
            if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
            if (xhr.overrideMimeType) {
              xhr.overrideMimeType('text/plain; charset=x-user-defined');
            }
  
            xhr.send(null);
            if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
            if (xhr.response !== undefined) {
              return new Uint8Array(xhr.response || []);
            } else {
              return intArrayFromString(xhr.responseText || '', true);
            }
          });
          var lazyArray = this;
          lazyArray.setDataGetter(function(chunkNum) {
            var start = chunkNum * chunkSize;
            var end = (chunkNum+1) * chunkSize - 1; // including this byte
            end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
            if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
              lazyArray.chunks[chunkNum] = doXHR(start, end);
            }
            if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
            return lazyArray.chunks[chunkNum];
          });
  
          this._length = datalength;
          this._chunkSize = chunkSize;
          this.lengthKnown = true;
        }
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          var lazyArray = new LazyUint8Array();
          Object.defineProperty(lazyArray, "length", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._length;
              }
          });
          Object.defineProperty(lazyArray, "chunkSize", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._chunkSize;
              }
          });
  
          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }
  
        var node = FS.createFile(parent, name, properties, canRead, canWrite);
        // This is a total hack, but I want to get this lazy file code out of the
        // core of MEMFS. If we want to keep this lazy file concept I feel it should
        // be its own thin LAZYFS proxying calls to MEMFS.
        if (properties.contents) {
          node.contents = properties.contents;
        } else if (properties.url) {
          node.contents = null;
          node.url = properties.url;
        }
        // Add a function that defers querying the file size until it is asked the first time.
        Object.defineProperty(node, "usedBytes", {
            get: function() { return this.contents.length; }
        });
        // override each stream op with one that tries to force load the lazy file first
        var stream_ops = {};
        var keys = Object.keys(node.stream_ops);
        keys.forEach(function(key) {
          var fn = node.stream_ops[key];
          stream_ops[key] = function forceLoadLazyFile() {
            if (!FS.forceLoadFile(node)) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            return fn.apply(null, arguments);
          };
        });
        // use a custom read function
        stream_ops.read = function stream_ops_read(stream, buffer, offset, length, position) {
          if (!FS.forceLoadFile(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EIO);
          }
          var contents = stream.node.contents;
          if (position >= contents.length)
            return 0;
          var size = Math.min(contents.length - position, length);
          assert(size >= 0);
          if (contents.slice) { // normal array
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          } else {
            for (var i = 0; i < size; i++) { // LazyUint8Array from sync binary XHR
              buffer[offset + i] = contents.get(position + i);
            }
          }
          return size;
        };
        node.stream_ops = stream_ops;
        return node;
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile, canOwn) {
        Browser.init();
        // TODO we should allow people to just pass in a complete filename instead
        // of parent and name being that we just join them anyways
        var fullname = name ? PATH.resolve(PATH.join2(parent, name)) : parent;
        function processData(byteArray) {
          function finish(byteArray) {
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite, canOwn);
            }
            if (onload) onload();
            removeRunDependency('cp ' + fullname);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency('cp ' + fullname);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency('cp ' + fullname);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },indexedDB:function () {
        return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
      },DB_NAME:function () {
        return 'EM_FS_' + window.location.pathname;
      },DB_VERSION:20,DB_STORE_NAME:"FILE_DATA",saveFilesToDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = function openRequest_onupgradeneeded() {
          console.log('creating db');
          var db = openRequest.result;
          db.createObjectStore(FS.DB_STORE_NAME);
        };
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          var transaction = db.transaction([FS.DB_STORE_NAME], 'readwrite');
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var putRequest = files.put(FS.analyzePath(path).object.contents, path);
            putRequest.onsuccess = function putRequest_onsuccess() { ok++; if (ok + fail == total) finish() };
            putRequest.onerror = function putRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },loadFilesFromDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = onerror; // no database to load from
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          try {
            var transaction = db.transaction([FS.DB_STORE_NAME], 'readonly');
          } catch(e) {
            onerror(e);
            return;
          }
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var getRequest = files.get(path);
            getRequest.onsuccess = function getRequest_onsuccess() {
              if (FS.analyzePath(path).exists) {
                FS.unlink(path);
              }
              FS.createDataFile(PATH.dirname(path), PATH.basename(path), getRequest.result, true, true, true);
              ok++;
              if (ok + fail == total) finish();
            };
            getRequest.onerror = function getRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      }};
  
  
  
  
  function _mkport() { throw 'TODO' }var SOCKFS={mount:function (mount) {
        // If Module['websocket'] has already been defined (e.g. for configuring
        // the subprotocol/url) use that, if not initialise it to a new object.
        Module['websocket'] = (Module['websocket'] && 
                               ('object' === typeof Module['websocket'])) ? Module['websocket'] : {};
  
        // Add the Event registration mechanism to the exported websocket configuration
        // object so we can register network callbacks from native JavaScript too.
        // For more documentation see system/include/emscripten/emscripten.h
        Module['websocket']._callbacks = {};
        Module['websocket']['on'] = function(event, callback) {
  	    if ('function' === typeof callback) {
  		  this._callbacks[event] = callback;
          }
  	    return this;
        };
  
        Module['websocket'].emit = function(event, param) {
  	    if ('function' === typeof this._callbacks[event]) {
  		  this._callbacks[event].call(this, param);
          }
        };
  
        // If debug is enabled register simple default logging callbacks for each Event.
  
        return FS.createNode(null, '/', 16384 | 511 /* 0777 */, 0);
      },createSocket:function (family, type, protocol) {
        var streaming = type == 1;
        if (protocol) {
          assert(streaming == (protocol == 6)); // if SOCK_STREAM, must be tcp
        }
  
        // create our internal socket structure
        var sock = {
          family: family,
          type: type,
          protocol: protocol,
          server: null,
          error: null, // Used in getsockopt for SOL_SOCKET/SO_ERROR test
          peers: {},
          pending: [],
          recv_queue: [],
          sock_ops: SOCKFS.websocket_sock_ops
        };
  
        // create the filesystem node to store the socket structure
        var name = SOCKFS.nextname();
        var node = FS.createNode(SOCKFS.root, name, 49152, 0);
        node.sock = sock;
  
        // and the wrapping stream that enables library functions such
        // as read and write to indirectly interact with the socket
        var stream = FS.createStream({
          path: name,
          node: node,
          flags: FS.modeStringToFlags('r+'),
          seekable: false,
          stream_ops: SOCKFS.stream_ops
        });
  
        // map the new stream to the socket structure (sockets have a 1:1
        // relationship with a stream)
        sock.stream = stream;
  
        return sock;
      },getSocket:function (fd) {
        var stream = FS.getStream(fd);
        if (!stream || !FS.isSocket(stream.node.mode)) {
          return null;
        }
        return stream.node.sock;
      },stream_ops:{poll:function (stream) {
          var sock = stream.node.sock;
          return sock.sock_ops.poll(sock);
        },ioctl:function (stream, request, varargs) {
          var sock = stream.node.sock;
          return sock.sock_ops.ioctl(sock, request, varargs);
        },read:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          var msg = sock.sock_ops.recvmsg(sock, length);
          if (!msg) {
            // socket is closed
            return 0;
          }
          buffer.set(msg.buffer, offset);
          return msg.buffer.length;
        },write:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          return sock.sock_ops.sendmsg(sock, buffer, offset, length);
        },close:function (stream) {
          var sock = stream.node.sock;
          sock.sock_ops.close(sock);
        }},nextname:function () {
        if (!SOCKFS.nextname.current) {
          SOCKFS.nextname.current = 0;
        }
        return 'socket[' + (SOCKFS.nextname.current++) + ']';
      },websocket_sock_ops:{createPeer:function (sock, addr, port) {
          var ws;
  
          if (typeof addr === 'object') {
            ws = addr;
            addr = null;
            port = null;
          }
  
          if (ws) {
            // for sockets that've already connected (e.g. we're the server)
            // we can inspect the _socket property for the address
            if (ws._socket) {
              addr = ws._socket.remoteAddress;
              port = ws._socket.remotePort;
            }
            // if we're just now initializing a connection to the remote,
            // inspect the url property
            else {
              var result = /ws[s]?:\/\/([^:]+):(\d+)/.exec(ws.url);
              if (!result) {
                throw new Error('WebSocket URL must be in the format ws(s)://address:port');
              }
              addr = result[1];
              port = parseInt(result[2], 10);
            }
          } else {
            // create the actual websocket object and connect
            try {
              // runtimeConfig gets set to true if WebSocket runtime configuration is available.
              var runtimeConfig = (Module['websocket'] && ('object' === typeof Module['websocket']));
  
              // The default value is 'ws://' the replace is needed because the compiler replaces '//' comments with '#'
              // comments without checking context, so we'd end up with ws:#, the replace swaps the '#' for '//' again.
              var url = 'ws:#'.replace('#', '//');
  
              if (runtimeConfig) {
                if ('string' === typeof Module['websocket']['url']) {
                  url = Module['websocket']['url']; // Fetch runtime WebSocket URL config.
                }
              }
  
              if (url === 'ws://' || url === 'wss://') { // Is the supplied URL config just a prefix, if so complete it.
                var parts = addr.split('/');
                url = url + parts[0] + ":" + port + "/" + parts.slice(1).join('/');
              }
  
              // Make the WebSocket subprotocol (Sec-WebSocket-Protocol) default to binary if no configuration is set.
              var subProtocols = 'binary'; // The default value is 'binary'
  
              if (runtimeConfig) {
                if ('string' === typeof Module['websocket']['subprotocol']) {
                  subProtocols = Module['websocket']['subprotocol']; // Fetch runtime WebSocket subprotocol config.
                }
              }
  
              // The regex trims the string (removes spaces at the beginning and end, then splits the string by
              // <any space>,<any space> into an Array. Whitespace removal is important for Websockify and ws.
              subProtocols = subProtocols.replace(/^ +| +$/g,"").split(/ *, */);
  
              // The node ws library API for specifying optional subprotocol is slightly different than the browser's.
              var opts = ENVIRONMENT_IS_NODE ? {'protocol': subProtocols.toString()} : subProtocols;
  
              // If node we use the ws library.
              var WebSocket = ENVIRONMENT_IS_NODE ? require('ws') : window['WebSocket'];
              ws = new WebSocket(url, opts);
              ws.binaryType = 'arraybuffer';
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EHOSTUNREACH);
            }
          }
  
  
          var peer = {
            addr: addr,
            port: port,
            socket: ws,
            dgram_send_queue: []
          };
  
          SOCKFS.websocket_sock_ops.addPeer(sock, peer);
          SOCKFS.websocket_sock_ops.handlePeerEvents(sock, peer);
  
          // if this is a bound dgram socket, send the port number first to allow
          // us to override the ephemeral port reported to us by remotePort on the
          // remote end.
          if (sock.type === 2 && typeof sock.sport !== 'undefined') {
            peer.dgram_send_queue.push(new Uint8Array([
                255, 255, 255, 255,
                'p'.charCodeAt(0), 'o'.charCodeAt(0), 'r'.charCodeAt(0), 't'.charCodeAt(0),
                ((sock.sport & 0xff00) >> 8) , (sock.sport & 0xff)
            ]));
          }
  
          return peer;
        },getPeer:function (sock, addr, port) {
          return sock.peers[addr + ':' + port];
        },addPeer:function (sock, peer) {
          sock.peers[peer.addr + ':' + peer.port] = peer;
        },removePeer:function (sock, peer) {
          delete sock.peers[peer.addr + ':' + peer.port];
        },handlePeerEvents:function (sock, peer) {
          var first = true;
  
          var handleOpen = function () {
  
            Module['websocket'].emit('open', sock.stream.fd);
  
            try {
              var queued = peer.dgram_send_queue.shift();
              while (queued) {
                peer.socket.send(queued);
                queued = peer.dgram_send_queue.shift();
              }
            } catch (e) {
              // not much we can do here in the way of proper error handling as we've already
              // lied and said this data was sent. shut it down.
              peer.socket.close();
            }
          };
  
          function handleMessage(data) {
            assert(typeof data !== 'string' && data.byteLength !== undefined);  // must receive an ArrayBuffer
            data = new Uint8Array(data);  // make a typed array view on the array buffer
  
  
            // if this is the port message, override the peer's port with it
            var wasfirst = first;
            first = false;
            if (wasfirst &&
                data.length === 10 &&
                data[0] === 255 && data[1] === 255 && data[2] === 255 && data[3] === 255 &&
                data[4] === 'p'.charCodeAt(0) && data[5] === 'o'.charCodeAt(0) && data[6] === 'r'.charCodeAt(0) && data[7] === 't'.charCodeAt(0)) {
              // update the peer's port and it's key in the peer map
              var newport = ((data[8] << 8) | data[9]);
              SOCKFS.websocket_sock_ops.removePeer(sock, peer);
              peer.port = newport;
              SOCKFS.websocket_sock_ops.addPeer(sock, peer);
              return;
            }
  
            sock.recv_queue.push({ addr: peer.addr, port: peer.port, data: data });
            Module['websocket'].emit('message', sock.stream.fd);
          };
  
          if (ENVIRONMENT_IS_NODE) {
            peer.socket.on('open', handleOpen);
            peer.socket.on('message', function(data, flags) {
              if (!flags.binary) {
                return;
              }
              handleMessage((new Uint8Array(data)).buffer);  // copy from node Buffer -> ArrayBuffer
            });
            peer.socket.on('close', function() {
              Module['websocket'].emit('close', sock.stream.fd);
            });
            peer.socket.on('error', function(error) {
              // Although the ws library may pass errors that may be more descriptive than
              // ECONNREFUSED they are not necessarily the expected error code e.g. 
              // ENOTFOUND on getaddrinfo seems to be node.js specific, so using ECONNREFUSED
              // is still probably the most useful thing to do.
              sock.error = ERRNO_CODES.ECONNREFUSED; // Used in getsockopt for SOL_SOCKET/SO_ERROR test.
              Module['websocket'].emit('error', [sock.stream.fd, sock.error, 'ECONNREFUSED: Connection refused']);
              // don't throw
            });
          } else {
            peer.socket.onopen = handleOpen;
            peer.socket.onclose = function() {
              Module['websocket'].emit('close', sock.stream.fd);
            };
            peer.socket.onmessage = function peer_socket_onmessage(event) {
              handleMessage(event.data);
            };
            peer.socket.onerror = function(error) {
              // The WebSocket spec only allows a 'simple event' to be thrown on error,
              // so we only really know as much as ECONNREFUSED.
              sock.error = ERRNO_CODES.ECONNREFUSED; // Used in getsockopt for SOL_SOCKET/SO_ERROR test.
              Module['websocket'].emit('error', [sock.stream.fd, sock.error, 'ECONNREFUSED: Connection refused']);
            };
          }
        },poll:function (sock) {
          if (sock.type === 1 && sock.server) {
            // listen sockets should only say they're available for reading
            // if there are pending clients.
            return sock.pending.length ? (64 | 1) : 0;
          }
  
          var mask = 0;
          var dest = sock.type === 1 ?  // we only care about the socket state for connection-based sockets
            SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport) :
            null;
  
          if (sock.recv_queue.length ||
              !dest ||  // connection-less sockets are always ready to read
              (dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {  // let recv return 0 once closed
            mask |= (64 | 1);
          }
  
          if (!dest ||  // connection-less sockets are always ready to write
              (dest && dest.socket.readyState === dest.socket.OPEN)) {
            mask |= 4;
          }
  
          if ((dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {
            mask |= 16;
          }
  
          return mask;
        },ioctl:function (sock, request, arg) {
          switch (request) {
            case 21531:
              var bytes = 0;
              if (sock.recv_queue.length) {
                bytes = sock.recv_queue[0].data.length;
              }
              HEAP32[((arg)>>2)]=bytes;
              return 0;
            default:
              return ERRNO_CODES.EINVAL;
          }
        },close:function (sock) {
          // if we've spawned a listen server, close it
          if (sock.server) {
            try {
              sock.server.close();
            } catch (e) {
            }
            sock.server = null;
          }
          // close any peer connections
          var peers = Object.keys(sock.peers);
          for (var i = 0; i < peers.length; i++) {
            var peer = sock.peers[peers[i]];
            try {
              peer.socket.close();
            } catch (e) {
            }
            SOCKFS.websocket_sock_ops.removePeer(sock, peer);
          }
          return 0;
        },bind:function (sock, addr, port) {
          if (typeof sock.saddr !== 'undefined' || typeof sock.sport !== 'undefined') {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already bound
          }
          sock.saddr = addr;
          sock.sport = port || _mkport();
          // in order to emulate dgram sockets, we need to launch a listen server when
          // binding on a connection-less socket
          // note: this is only required on the server side
          if (sock.type === 2) {
            // close the existing server if it exists
            if (sock.server) {
              sock.server.close();
              sock.server = null;
            }
            // swallow error operation not supported error that occurs when binding in the
            // browser where this isn't supported
            try {
              sock.sock_ops.listen(sock, 0);
            } catch (e) {
              if (!(e instanceof FS.ErrnoError)) throw e;
              if (e.errno !== ERRNO_CODES.EOPNOTSUPP) throw e;
            }
          }
        },connect:function (sock, addr, port) {
          if (sock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }
  
          // TODO autobind
          // if (!sock.addr && sock.type == 2) {
          // }
  
          // early out if we're already connected / in the middle of connecting
          if (typeof sock.daddr !== 'undefined' && typeof sock.dport !== 'undefined') {
            var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
            if (dest) {
              if (dest.socket.readyState === dest.socket.CONNECTING) {
                throw new FS.ErrnoError(ERRNO_CODES.EALREADY);
              } else {
                throw new FS.ErrnoError(ERRNO_CODES.EISCONN);
              }
            }
          }
  
          // add the socket to our peer list and set our
          // destination address / port to match
          var peer = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
          sock.daddr = peer.addr;
          sock.dport = peer.port;
  
          // always "fail" in non-blocking mode
          throw new FS.ErrnoError(ERRNO_CODES.EINPROGRESS);
        },listen:function (sock, backlog) {
          if (!ENVIRONMENT_IS_NODE) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }
          if (sock.server) {
             throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already listening
          }
          var WebSocketServer = require('ws').Server;
          var host = sock.saddr;
          sock.server = new WebSocketServer({
            host: host,
            port: sock.sport
            // TODO support backlog
          });
          Module['websocket'].emit('listen', sock.stream.fd); // Send Event with listen fd.
  
          sock.server.on('connection', function(ws) {
            if (sock.type === 1) {
              var newsock = SOCKFS.createSocket(sock.family, sock.type, sock.protocol);
  
              // create a peer on the new socket
              var peer = SOCKFS.websocket_sock_ops.createPeer(newsock, ws);
              newsock.daddr = peer.addr;
              newsock.dport = peer.port;
  
              // push to queue for accept to pick up
              sock.pending.push(newsock);
              Module['websocket'].emit('connection', newsock.stream.fd);
            } else {
              // create a peer on the listen socket so calling sendto
              // with the listen socket and an address will resolve
              // to the correct client
              SOCKFS.websocket_sock_ops.createPeer(sock, ws);
              Module['websocket'].emit('connection', sock.stream.fd);
            }
          });
          sock.server.on('closed', function() {
            Module['websocket'].emit('close', sock.stream.fd);
            sock.server = null;
          });
          sock.server.on('error', function(error) {
            // Although the ws library may pass errors that may be more descriptive than
            // ECONNREFUSED they are not necessarily the expected error code e.g. 
            // ENOTFOUND on getaddrinfo seems to be node.js specific, so using EHOSTUNREACH
            // is still probably the most useful thing to do. This error shouldn't
            // occur in a well written app as errors should get trapped in the compiled
            // app's own getaddrinfo call.
            sock.error = ERRNO_CODES.EHOSTUNREACH; // Used in getsockopt for SOL_SOCKET/SO_ERROR test.
            Module['websocket'].emit('error', [sock.stream.fd, sock.error, 'EHOSTUNREACH: Host is unreachable']);
            // don't throw
          });
        },accept:function (listensock) {
          if (!listensock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          var newsock = listensock.pending.shift();
          newsock.stream.flags = listensock.stream.flags;
          return newsock;
        },getname:function (sock, peer) {
          var addr, port;
          if (peer) {
            if (sock.daddr === undefined || sock.dport === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            }
            addr = sock.daddr;
            port = sock.dport;
          } else {
            // TODO saddr and sport will be set for bind()'d UDP sockets, but what
            // should we be returning for TCP sockets that've been connect()'d?
            addr = sock.saddr || 0;
            port = sock.sport || 0;
          }
          return { addr: addr, port: port };
        },sendmsg:function (sock, buffer, offset, length, addr, port) {
          if (sock.type === 2) {
            // connection-less sockets will honor the message address,
            // and otherwise fall back to the bound destination address
            if (addr === undefined || port === undefined) {
              addr = sock.daddr;
              port = sock.dport;
            }
            // if there was no address to fall back to, error out
            if (addr === undefined || port === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.EDESTADDRREQ);
            }
          } else {
            // connection-based sockets will only use the bound
            addr = sock.daddr;
            port = sock.dport;
          }
  
          // find the peer for the destination address
          var dest = SOCKFS.websocket_sock_ops.getPeer(sock, addr, port);
  
          // early out if not connected with a connection-based socket
          if (sock.type === 1) {
            if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            } else if (dest.socket.readyState === dest.socket.CONNECTING) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
  
          // create a copy of the incoming data to send, as the WebSocket API
          // doesn't work entirely with an ArrayBufferView, it'll just send
          // the entire underlying buffer
          var data;
          if (buffer instanceof Array || buffer instanceof ArrayBuffer) {
            data = buffer.slice(offset, offset + length);
          } else {  // ArrayBufferView
            data = buffer.buffer.slice(buffer.byteOffset + offset, buffer.byteOffset + offset + length);
          }
  
          // if we're emulating a connection-less dgram socket and don't have
          // a cached connection, queue the buffer to send upon connect and
          // lie, saying the data was sent now.
          if (sock.type === 2) {
            if (!dest || dest.socket.readyState !== dest.socket.OPEN) {
              // if we're not connected, open a new connection
              if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                dest = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
              }
              dest.dgram_send_queue.push(data);
              return length;
            }
          }
  
          try {
            // send the actual data
            dest.socket.send(data);
            return length;
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
        },recvmsg:function (sock, length) {
          // http://pubs.opengroup.org/onlinepubs/7908799/xns/recvmsg.html
          if (sock.type === 1 && sock.server) {
            // tcp servers should not be recv()'ing on the listen socket
            throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
          }
  
          var queued = sock.recv_queue.shift();
          if (!queued) {
            if (sock.type === 1) {
              var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
  
              if (!dest) {
                // if we have a destination address but are not connected, error out
                throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
              }
              else if (dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                // return null if the socket has closed
                return null;
              }
              else {
                // else, our socket is in a valid state but truly has nothing available
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
            } else {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
  
          // queued.data will be an ArrayBuffer if it's unadulterated, but if it's
          // requeued TCP data it'll be an ArrayBufferView
          var queuedLength = queued.data.byteLength || queued.data.length;
          var queuedOffset = queued.data.byteOffset || 0;
          var queuedBuffer = queued.data.buffer || queued.data;
          var bytesRead = Math.min(length, queuedLength);
          var res = {
            buffer: new Uint8Array(queuedBuffer, queuedOffset, bytesRead),
            addr: queued.addr,
            port: queued.port
          };
  
  
          // push back any unread data for TCP connections
          if (sock.type === 1 && bytesRead < queuedLength) {
            var bytesRemaining = queuedLength - bytesRead;
            queued.data = new Uint8Array(queuedBuffer, queuedOffset + bytesRead, bytesRemaining);
            sock.recv_queue.unshift(queued);
          }
  
          return res;
        }}};function _send(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _write(fd, buf, len);
    }
  
  function _pwrite(fildes, buf, nbyte, offset) {
      // ssize_t pwrite(int fildes, const void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _write(fildes, buf, nbyte) {
      // ssize_t write(int fildes, const void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
  
  
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  
  function _fileno(stream) {
      // int fileno(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fileno.html
      stream = FS.getStreamFromPtr(stream);
      if (!stream) return -1;
      return stream.fd;
    }function _fwrite(ptr, size, nitems, stream) {
      // size_t fwrite(const void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fwrite.html
      var bytesToWrite = nitems * size;
      if (bytesToWrite == 0) return 0;
      var fd = _fileno(stream);
      var bytesWritten = _write(fd, ptr, bytesToWrite);
      if (bytesWritten == -1) {
        var streamObj = FS.getStreamFromPtr(stream);
        if (streamObj) streamObj.error = true;
        return 0;
      } else {
        return (bytesWritten / size)|0;
      }
    }
  
  
   
  Module["_strlen"] = _strlen;
  
  function __reallyNegative(x) {
      return x < 0 || (x === 0 && (1/x) === -Infinity);
    }function __formatString(format, varargs) {
      var textIndex = format;
      var argIndex = 0;
      function getNextArg(type) {
        // NOTE: Explicitly ignoring type safety. Otherwise this fails:
        //       int x = 4; printf("%c\n", (char)x);
        var ret;
        if (type === 'double') {
          ret = (HEAP32[((tempDoublePtr)>>2)]=HEAP32[(((varargs)+(argIndex))>>2)],HEAP32[(((tempDoublePtr)+(4))>>2)]=HEAP32[(((varargs)+((argIndex)+(4)))>>2)],(+(HEAPF64[(tempDoublePtr)>>3])));
        } else if (type == 'i64') {
          ret = [HEAP32[(((varargs)+(argIndex))>>2)],
                 HEAP32[(((varargs)+(argIndex+4))>>2)]];
  
        } else {
          type = 'i32'; // varargs are always i32, i64, or double
          ret = HEAP32[(((varargs)+(argIndex))>>2)];
        }
        argIndex += Runtime.getNativeFieldSize(type);
        return ret;
      }
  
      var ret = [];
      var curr, next, currArg;
      while(1) {
        var startTextIndex = textIndex;
        curr = HEAP8[((textIndex)>>0)];
        if (curr === 0) break;
        next = HEAP8[((textIndex+1)>>0)];
        if (curr == 37) {
          // Handle flags.
          var flagAlwaysSigned = false;
          var flagLeftAlign = false;
          var flagAlternative = false;
          var flagZeroPad = false;
          var flagPadSign = false;
          flagsLoop: while (1) {
            switch (next) {
              case 43:
                flagAlwaysSigned = true;
                break;
              case 45:
                flagLeftAlign = true;
                break;
              case 35:
                flagAlternative = true;
                break;
              case 48:
                if (flagZeroPad) {
                  break flagsLoop;
                } else {
                  flagZeroPad = true;
                  break;
                }
              case 32:
                flagPadSign = true;
                break;
              default:
                break flagsLoop;
            }
            textIndex++;
            next = HEAP8[((textIndex+1)>>0)];
          }
  
          // Handle width.
          var width = 0;
          if (next == 42) {
            width = getNextArg('i32');
            textIndex++;
            next = HEAP8[((textIndex+1)>>0)];
          } else {
            while (next >= 48 && next <= 57) {
              width = width * 10 + (next - 48);
              textIndex++;
              next = HEAP8[((textIndex+1)>>0)];
            }
          }
  
          // Handle precision.
          var precisionSet = false, precision = -1;
          if (next == 46) {
            precision = 0;
            precisionSet = true;
            textIndex++;
            next = HEAP8[((textIndex+1)>>0)];
            if (next == 42) {
              precision = getNextArg('i32');
              textIndex++;
            } else {
              while(1) {
                var precisionChr = HEAP8[((textIndex+1)>>0)];
                if (precisionChr < 48 ||
                    precisionChr > 57) break;
                precision = precision * 10 + (precisionChr - 48);
                textIndex++;
              }
            }
            next = HEAP8[((textIndex+1)>>0)];
          }
          if (precision < 0) {
            precision = 6; // Standard default.
            precisionSet = false;
          }
  
          // Handle integer sizes. WARNING: These assume a 32-bit architecture!
          var argSize;
          switch (String.fromCharCode(next)) {
            case 'h':
              var nextNext = HEAP8[((textIndex+2)>>0)];
              if (nextNext == 104) {
                textIndex++;
                argSize = 1; // char (actually i32 in varargs)
              } else {
                argSize = 2; // short (actually i32 in varargs)
              }
              break;
            case 'l':
              var nextNext = HEAP8[((textIndex+2)>>0)];
              if (nextNext == 108) {
                textIndex++;
                argSize = 8; // long long
              } else {
                argSize = 4; // long
              }
              break;
            case 'L': // long long
            case 'q': // int64_t
            case 'j': // intmax_t
              argSize = 8;
              break;
            case 'z': // size_t
            case 't': // ptrdiff_t
            case 'I': // signed ptrdiff_t or unsigned size_t
              argSize = 4;
              break;
            default:
              argSize = null;
          }
          if (argSize) textIndex++;
          next = HEAP8[((textIndex+1)>>0)];
  
          // Handle type specifier.
          switch (String.fromCharCode(next)) {
            case 'd': case 'i': case 'u': case 'o': case 'x': case 'X': case 'p': {
              // Integer.
              var signed = next == 100 || next == 105;
              argSize = argSize || 4;
              var currArg = getNextArg('i' + (argSize * 8));
              var origArg = currArg;
              var argText;
              // Flatten i64-1 [low, high] into a (slightly rounded) double
              if (argSize == 8) {
                currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == 117);
              }
              // Truncate to requested size.
              if (argSize <= 4) {
                var limit = Math.pow(256, argSize) - 1;
                currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
              }
              // Format the number.
              var currAbsArg = Math.abs(currArg);
              var prefix = '';
              if (next == 100 || next == 105) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], null); else
                argText = reSign(currArg, 8 * argSize, 1).toString(10);
              } else if (next == 117) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], true); else
                argText = unSign(currArg, 8 * argSize, 1).toString(10);
                currArg = Math.abs(currArg);
              } else if (next == 111) {
                argText = (flagAlternative ? '0' : '') + currAbsArg.toString(8);
              } else if (next == 120 || next == 88) {
                prefix = (flagAlternative && currArg != 0) ? '0x' : '';
                if (argSize == 8 && i64Math) {
                  if (origArg[1]) {
                    argText = (origArg[1]>>>0).toString(16);
                    var lower = (origArg[0]>>>0).toString(16);
                    while (lower.length < 8) lower = '0' + lower;
                    argText += lower;
                  } else {
                    argText = (origArg[0]>>>0).toString(16);
                  }
                } else
                if (currArg < 0) {
                  // Represent negative numbers in hex as 2's complement.
                  currArg = -currArg;
                  argText = (currAbsArg - 1).toString(16);
                  var buffer = [];
                  for (var i = 0; i < argText.length; i++) {
                    buffer.push((0xF - parseInt(argText[i], 16)).toString(16));
                  }
                  argText = buffer.join('');
                  while (argText.length < argSize * 2) argText = 'f' + argText;
                } else {
                  argText = currAbsArg.toString(16);
                }
                if (next == 88) {
                  prefix = prefix.toUpperCase();
                  argText = argText.toUpperCase();
                }
              } else if (next == 112) {
                if (currAbsArg === 0) {
                  argText = '(nil)';
                } else {
                  prefix = '0x';
                  argText = currAbsArg.toString(16);
                }
              }
              if (precisionSet) {
                while (argText.length < precision) {
                  argText = '0' + argText;
                }
              }
  
              // Add sign if needed
              if (currArg >= 0) {
                if (flagAlwaysSigned) {
                  prefix = '+' + prefix;
                } else if (flagPadSign) {
                  prefix = ' ' + prefix;
                }
              }
  
              // Move sign to prefix so we zero-pad after the sign
              if (argText.charAt(0) == '-') {
                prefix = '-' + prefix;
                argText = argText.substr(1);
              }
  
              // Add padding.
              while (prefix.length + argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad) {
                    argText = '0' + argText;
                  } else {
                    prefix = ' ' + prefix;
                  }
                }
              }
  
              // Insert the result into the buffer.
              argText = prefix + argText;
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 'f': case 'F': case 'e': case 'E': case 'g': case 'G': {
              // Float.
              var currArg = getNextArg('double');
              var argText;
              if (isNaN(currArg)) {
                argText = 'nan';
                flagZeroPad = false;
              } else if (!isFinite(currArg)) {
                argText = (currArg < 0 ? '-' : '') + 'inf';
                flagZeroPad = false;
              } else {
                var isGeneral = false;
                var effectivePrecision = Math.min(precision, 20);
  
                // Convert g/G to f/F or e/E, as per:
                // http://pubs.opengroup.org/onlinepubs/9699919799/functions/printf.html
                if (next == 103 || next == 71) {
                  isGeneral = true;
                  precision = precision || 1;
                  var exponent = parseInt(currArg.toExponential(effectivePrecision).split('e')[1], 10);
                  if (precision > exponent && exponent >= -4) {
                    next = ((next == 103) ? 'f' : 'F').charCodeAt(0);
                    precision -= exponent + 1;
                  } else {
                    next = ((next == 103) ? 'e' : 'E').charCodeAt(0);
                    precision--;
                  }
                  effectivePrecision = Math.min(precision, 20);
                }
  
                if (next == 101 || next == 69) {
                  argText = currArg.toExponential(effectivePrecision);
                  // Make sure the exponent has at least 2 digits.
                  if (/[eE][-+]\d$/.test(argText)) {
                    argText = argText.slice(0, -1) + '0' + argText.slice(-1);
                  }
                } else if (next == 102 || next == 70) {
                  argText = currArg.toFixed(effectivePrecision);
                  if (currArg === 0 && __reallyNegative(currArg)) {
                    argText = '-' + argText;
                  }
                }
  
                var parts = argText.split('e');
                if (isGeneral && !flagAlternative) {
                  // Discard trailing zeros and periods.
                  while (parts[0].length > 1 && parts[0].indexOf('.') != -1 &&
                         (parts[0].slice(-1) == '0' || parts[0].slice(-1) == '.')) {
                    parts[0] = parts[0].slice(0, -1);
                  }
                } else {
                  // Make sure we have a period in alternative mode.
                  if (flagAlternative && argText.indexOf('.') == -1) parts[0] += '.';
                  // Zero pad until required precision.
                  while (precision > effectivePrecision++) parts[0] += '0';
                }
                argText = parts[0] + (parts.length > 1 ? 'e' + parts[1] : '');
  
                // Capitalize 'E' if needed.
                if (next == 69) argText = argText.toUpperCase();
  
                // Add sign.
                if (currArg >= 0) {
                  if (flagAlwaysSigned) {
                    argText = '+' + argText;
                  } else if (flagPadSign) {
                    argText = ' ' + argText;
                  }
                }
              }
  
              // Add padding.
              while (argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad && (argText[0] == '-' || argText[0] == '+')) {
                    argText = argText[0] + '0' + argText.slice(1);
                  } else {
                    argText = (flagZeroPad ? '0' : ' ') + argText;
                  }
                }
              }
  
              // Adjust case.
              if (next < 97) argText = argText.toUpperCase();
  
              // Insert the result into the buffer.
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 's': {
              // String.
              var arg = getNextArg('i8*');
              var argLength = arg ? _strlen(arg) : '(null)'.length;
              if (precisionSet) argLength = Math.min(argLength, precision);
              if (!flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              if (arg) {
                for (var i = 0; i < argLength; i++) {
                  ret.push(HEAPU8[((arg++)>>0)]);
                }
              } else {
                ret = ret.concat(intArrayFromString('(null)'.substr(0, argLength), true));
              }
              if (flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              break;
            }
            case 'c': {
              // Character.
              if (flagLeftAlign) ret.push(getNextArg('i8'));
              while (--width > 0) {
                ret.push(32);
              }
              if (!flagLeftAlign) ret.push(getNextArg('i8'));
              break;
            }
            case 'n': {
              // Write the length written so far to the next parameter.
              var ptr = getNextArg('i32*');
              HEAP32[((ptr)>>2)]=ret.length;
              break;
            }
            case '%': {
              // Literal percent sign.
              ret.push(curr);
              break;
            }
            default: {
              // Unknown specifiers remain untouched.
              for (var i = startTextIndex; i < textIndex + 2; i++) {
                ret.push(HEAP8[((i)>>0)]);
              }
            }
          }
          textIndex += 2;
          // TODO: Support a/A (hex float) and m (last error) specifiers.
          // TODO: Support %1${specifier} for arg selection.
        } else {
          ret.push(curr);
          textIndex += 1;
        }
      }
      return ret;
    }function _fprintf(stream, format, varargs) {
      // int fprintf(FILE *restrict stream, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var stack = Runtime.stackSave();
      var ret = _fwrite(allocate(result, 'i8', ALLOC_STACK), 1, result.length, stream);
      Runtime.stackRestore(stack);
      return ret;
    }function _printf(format, varargs) {
      // int printf(const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var stdout = HEAP32[((_stdout)>>2)];
      return _fprintf(stdout, format, varargs);
    }

  function _pthread_once(ptr, func) {
      if (!_pthread_once.seen) _pthread_once.seen = {};
      if (ptr in _pthread_once.seen) return;
      Runtime.dynCall('v', func);
      _pthread_once.seen[ptr] = 1;
    }


  var _sqrtf=Math_sqrt;

  function _fputc(c, stream) {
      // int fputc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputc.html
      var chr = unSign(c & 0xFF);
      HEAP8[((_fputc.ret)>>0)]=chr;
      var fd = _fileno(stream);
      var ret = _write(fd, _fputc.ret, 1);
      if (ret == -1) {
        var streamObj = FS.getStreamFromPtr(stream);
        if (streamObj) streamObj.error = true;
        return -1;
      } else {
        return chr;
      }
    }

  
  var PTHREAD_SPECIFIC={};function _pthread_getspecific(key) {
      return PTHREAD_SPECIFIC[key] || 0;
    }

  function _sysconf(name) {
      // long sysconf(int name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/sysconf.html
      switch(name) {
        case 30: return PAGE_SIZE;
        case 132:
        case 133:
        case 12:
        case 137:
        case 138:
        case 15:
        case 235:
        case 16:
        case 17:
        case 18:
        case 19:
        case 20:
        case 149:
        case 13:
        case 10:
        case 236:
        case 153:
        case 9:
        case 21:
        case 22:
        case 159:
        case 154:
        case 14:
        case 77:
        case 78:
        case 139:
        case 80:
        case 81:
        case 79:
        case 82:
        case 68:
        case 67:
        case 164:
        case 11:
        case 29:
        case 47:
        case 48:
        case 95:
        case 52:
        case 51:
        case 46:
          return 200809;
        case 27:
        case 246:
        case 127:
        case 128:
        case 23:
        case 24:
        case 160:
        case 161:
        case 181:
        case 182:
        case 242:
        case 183:
        case 184:
        case 243:
        case 244:
        case 245:
        case 165:
        case 178:
        case 179:
        case 49:
        case 50:
        case 168:
        case 169:
        case 175:
        case 170:
        case 171:
        case 172:
        case 97:
        case 76:
        case 32:
        case 173:
        case 35:
          return -1;
        case 176:
        case 177:
        case 7:
        case 155:
        case 8:
        case 157:
        case 125:
        case 126:
        case 92:
        case 93:
        case 129:
        case 130:
        case 131:
        case 94:
        case 91:
          return 1;
        case 74:
        case 60:
        case 69:
        case 70:
        case 4:
          return 1024;
        case 31:
        case 42:
        case 72:
          return 32;
        case 87:
        case 26:
        case 33:
          return 2147483647;
        case 34:
        case 1:
          return 47839;
        case 38:
        case 36:
          return 99;
        case 43:
        case 37:
          return 2048;
        case 0: return 2097152;
        case 3: return 65536;
        case 28: return 32768;
        case 44: return 32767;
        case 75: return 16384;
        case 39: return 1000;
        case 89: return 700;
        case 71: return 256;
        case 40: return 255;
        case 2: return 100;
        case 180: return 64;
        case 25: return 20;
        case 5: return 16;
        case 6: return 6;
        case 73: return 4;
        case 84: {
          if (typeof navigator === 'object') return navigator['hardwareConcurrency'] || 1;
          return 1;
        }
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }

  
  function _fputs(s, stream) {
      // int fputs(const char *restrict s, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputs.html
      var fd = _fileno(stream);
      return _write(fd, s, _strlen(s));
    }function _puts(s) {
      // int puts(const char *s);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/puts.html
      // NOTE: puts() always writes an extra newline.
      var stdout = HEAP32[((_stdout)>>2)];
      var ret = _fputs(s, stdout);
      if (ret < 0) {
        return ret;
      } else {
        var newlineRet = _fputc(10, stdout);
        return (newlineRet < 0) ? -1 : ret + 1;
      }
    }

  
  var PTHREAD_SPECIFIC_NEXT_KEY=1;function _pthread_key_create(key, destructor) {
      if (key == 0) {
        return ERRNO_CODES.EINVAL;
      }
      HEAP32[((key)>>2)]=PTHREAD_SPECIFIC_NEXT_KEY;
      // values start at 0
      PTHREAD_SPECIFIC[PTHREAD_SPECIFIC_NEXT_KEY] = 0;
      PTHREAD_SPECIFIC_NEXT_KEY++;
      return 0;
    }

  
  
  function _emscripten_set_main_loop_timing(mode, value) {
      Browser.mainLoop.timingMode = mode;
      Browser.mainLoop.timingValue = value;
  
      if (!Browser.mainLoop.func) {
        return 1; // Return non-zero on failure, can't set timing mode when there is no main loop.
      }
  
      if (mode == 0 /*EM_TIMING_SETTIMEOUT*/) {
        Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler() {
          setTimeout(Browser.mainLoop.runner, value); // doing this each time means that on exception, we stop
        };
        Browser.mainLoop.method = 'timeout';
      } else if (mode == 1 /*EM_TIMING_RAF*/) {
        Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler() {
          Browser.requestAnimationFrame(Browser.mainLoop.runner);
        };
        Browser.mainLoop.method = 'rAF';
      }
      return 0;
    }function _emscripten_set_main_loop(func, fps, simulateInfiniteLoop, arg) {
      Module['noExitRuntime'] = true;
  
      assert(!Browser.mainLoop.func, 'emscripten_set_main_loop: there can only be one main loop function at once: call emscripten_cancel_main_loop to cancel the previous one before setting a new one with different parameters.');
  
      Browser.mainLoop.func = func;
      Browser.mainLoop.arg = arg;
  
      var thisMainLoopId = Browser.mainLoop.currentlyRunningMainloop;
  
      Browser.mainLoop.runner = function Browser_mainLoop_runner() {
        if (ABORT) return;
        if (Browser.mainLoop.queue.length > 0) {
          var start = Date.now();
          var blocker = Browser.mainLoop.queue.shift();
          blocker.func(blocker.arg);
          if (Browser.mainLoop.remainingBlockers) {
            var remaining = Browser.mainLoop.remainingBlockers;
            var next = remaining%1 == 0 ? remaining-1 : Math.floor(remaining);
            if (blocker.counted) {
              Browser.mainLoop.remainingBlockers = next;
            } else {
              // not counted, but move the progress along a tiny bit
              next = next + 0.5; // do not steal all the next one's progress
              Browser.mainLoop.remainingBlockers = (8*remaining + next)/9;
            }
          }
          console.log('main loop blocker "' + blocker.name + '" took ' + (Date.now() - start) + ' ms'); //, left: ' + Browser.mainLoop.remainingBlockers);
          Browser.mainLoop.updateStatus();
          setTimeout(Browser.mainLoop.runner, 0);
          return;
        }
  
        // catch pauses from non-main loop sources
        if (thisMainLoopId < Browser.mainLoop.currentlyRunningMainloop) return;
  
        // Implement very basic swap interval control
        Browser.mainLoop.currentFrameNumber = Browser.mainLoop.currentFrameNumber + 1 | 0;
        if (Browser.mainLoop.timingMode == 1/*EM_TIMING_RAF*/ && Browser.mainLoop.timingValue > 1 && Browser.mainLoop.currentFrameNumber % Browser.mainLoop.timingValue != 0) {
          // Not the scheduled time to render this frame - skip.
          Browser.mainLoop.scheduler();
          return;
        }
  
        // Signal GL rendering layer that processing of a new frame is about to start. This helps it optimize
        // VBO double-buffering and reduce GPU stalls.
  
        if (Browser.mainLoop.method === 'timeout' && Module.ctx) {
          Module.printErr('Looks like you are rendering without using requestAnimationFrame for the main loop. You should use 0 for the frame rate in emscripten_set_main_loop in order to use requestAnimationFrame, as that can greatly improve your frame rates!');
          Browser.mainLoop.method = ''; // just warn once per call to set main loop
        }
  
        Browser.mainLoop.runIter(function() {
          if (typeof arg !== 'undefined') {
            Runtime.dynCall('vi', func, [arg]);
          } else {
            Runtime.dynCall('v', func);
          }
        });
  
        // catch pauses from the main loop itself
        if (thisMainLoopId < Browser.mainLoop.currentlyRunningMainloop) return;
  
        // Queue new audio data. This is important to be right after the main loop invocation, so that we will immediately be able
        // to queue the newest produced audio samples.
        // TODO: Consider adding pre- and post- rAF callbacks so that GL.newRenderingFrameStarted() and SDL.audio.queueNewAudioData()
        //       do not need to be hardcoded into this function, but can be more generic.
        if (typeof SDL === 'object' && SDL.audio && SDL.audio.queueNewAudioData) SDL.audio.queueNewAudioData();
  
        Browser.mainLoop.scheduler();
      }
  
      if (fps && fps > 0) _emscripten_set_main_loop_timing(0/*EM_TIMING_SETTIMEOUT*/, 1000.0 / fps);
      else _emscripten_set_main_loop_timing(1/*EM_TIMING_RAF*/, 1); // Do rAF by rendering each frame (no decimating)
  
      Browser.mainLoop.scheduler();
  
      if (simulateInfiniteLoop) {
        throw 'SimulateInfiniteLoop';
      }
    }var Browser={mainLoop:{scheduler:null,method:"",currentlyRunningMainloop:0,func:null,arg:0,timingMode:0,timingValue:0,currentFrameNumber:0,queue:[],pause:function () {
          Browser.mainLoop.scheduler = null;
          Browser.mainLoop.currentlyRunningMainloop++; // Incrementing this signals the previous main loop that it's now become old, and it must return.
        },resume:function () {
          Browser.mainLoop.currentlyRunningMainloop++;
          var timingMode = Browser.mainLoop.timingMode;
          var timingValue = Browser.mainLoop.timingValue;
          var func = Browser.mainLoop.func;
          Browser.mainLoop.func = null;
          _emscripten_set_main_loop(func, 0, false, Browser.mainLoop.arg);
          _emscripten_set_main_loop_timing(timingMode, timingValue);
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        },runIter:function (func) {
          if (ABORT) return;
          if (Module['preMainLoop']) {
            var preRet = Module['preMainLoop']();
            if (preRet === false) {
              return; // |return false| skips a frame
            }
          }
          try {
            func();
          } catch (e) {
            if (e instanceof ExitStatus) {
              return;
            } else {
              if (e && typeof e === 'object' && e.stack) Module.printErr('exception thrown: ' + [e, e.stack]);
              throw e;
            }
          }
          if (Module['postMainLoop']) Module['postMainLoop']();
        }},isFullScreen:false,pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],init:function () {
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = []; // needs to exist even in workers
  
        if (Browser.initted) return;
        Browser.initted = true;
  
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : undefined;
        if (!Module.noImageDecoding && typeof Browser.URLObject === 'undefined') {
          console.log("warning: Browser does not support creating object URLs. Built-in browser image decoding will not be available.");
          Module.noImageDecoding = true;
        }
  
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
  
        var imagePlugin = {};
        imagePlugin['canHandle'] = function imagePlugin_canHandle(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/i.test(name);
        };
        imagePlugin['handle'] = function imagePlugin_handle(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: Browser.getMimetype(name) });
              if (b.size !== byteArray.length) { // Safari bug #118630
                // Safari's Blob can only take an ArrayBuffer
                b = new Blob([(new Uint8Array(byteArray)).buffer], { type: Browser.getMimetype(name) });
              }
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          var img = new Image();
          img.onload = function img_onload() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function img_onerror(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
  
        var audioPlugin = {};
        audioPlugin['canHandle'] = function audioPlugin_canHandle(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function audioPlugin_handle(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: Browser.getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function audio_onerror(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            Browser.safeSetTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
  
        // Canvas event setup
  
        var canvas = Module['canvas'];
        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === canvas ||
                                document['mozPointerLockElement'] === canvas ||
                                document['webkitPointerLockElement'] === canvas ||
                                document['msPointerLockElement'] === canvas;
        }
        if (canvas) {
          // forced aspect ratio can be enabled by defining 'forcedAspectRatio' on Module
          // Module['forcedAspectRatio'] = 4 / 3;
          
          canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                      canvas['mozRequestPointerLock'] ||
                                      canvas['webkitRequestPointerLock'] ||
                                      canvas['msRequestPointerLock'] ||
                                      function(){};
          canvas.exitPointerLock = document['exitPointerLock'] ||
                                   document['mozExitPointerLock'] ||
                                   document['webkitExitPointerLock'] ||
                                   document['msExitPointerLock'] ||
                                   function(){}; // no-op if function does not exist
          canvas.exitPointerLock = canvas.exitPointerLock.bind(document);
  
  
          document.addEventListener('pointerlockchange', pointerLockChange, false);
          document.addEventListener('mozpointerlockchange', pointerLockChange, false);
          document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
          document.addEventListener('mspointerlockchange', pointerLockChange, false);
  
          if (Module['elementPointerLock']) {
            canvas.addEventListener("click", function(ev) {
              if (!Browser.pointerLock && canvas.requestPointerLock) {
                canvas.requestPointerLock();
                ev.preventDefault();
              }
            }, false);
          }
        }
      },createContext:function (canvas, useWebGL, setInModule, webGLContextAttributes) {
        if (useWebGL && Module.ctx && canvas == Module.canvas) return Module.ctx; // no need to recreate GL context if it's already been created for this canvas.
  
        var ctx;
        var contextHandle;
        if (useWebGL) {
          // For GLES2/desktop GL compatibility, adjust a few defaults to be different to WebGL defaults, so that they align better with the desktop defaults.
          var contextAttributes = {
            antialias: false,
            alpha: false
          };
  
          if (webGLContextAttributes) {
            for (var attribute in webGLContextAttributes) {
              contextAttributes[attribute] = webGLContextAttributes[attribute];
            }
          }
  
          contextHandle = GL.createContext(canvas, contextAttributes);
          if (contextHandle) {
            ctx = GL.getContext(contextHandle).GLctx;
          }
          // Set the background of the WebGL canvas to black
          canvas.style.backgroundColor = "black";
        } else {
          ctx = canvas.getContext('2d');
        }
  
        if (!ctx) return null;
  
        if (setInModule) {
          if (!useWebGL) assert(typeof GLctx === 'undefined', 'cannot set in module if GLctx is used, but we are a non-GL context that would replace it');
  
          Module.ctx = ctx;
          if (useWebGL) GL.makeContextCurrent(contextHandle);
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
          Browser.init();
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},fullScreenHandlersInstalled:false,lockPointer:undefined,resizeCanvas:undefined,requestFullScreen:function (lockPointer, resizeCanvas) {
        Browser.lockPointer = lockPointer;
        Browser.resizeCanvas = resizeCanvas;
        if (typeof Browser.lockPointer === 'undefined') Browser.lockPointer = true;
        if (typeof Browser.resizeCanvas === 'undefined') Browser.resizeCanvas = false;
  
        var canvas = Module['canvas'];
        function fullScreenChange() {
          Browser.isFullScreen = false;
          var canvasContainer = canvas.parentNode;
          if ((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
               document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
               document['fullScreenElement'] || document['fullscreenElement'] ||
               document['msFullScreenElement'] || document['msFullscreenElement'] ||
               document['webkitCurrentFullScreenElement']) === canvasContainer) {
            canvas.cancelFullScreen = document['cancelFullScreen'] ||
                                      document['mozCancelFullScreen'] ||
                                      document['webkitCancelFullScreen'] ||
                                      document['msExitFullscreen'] ||
                                      document['exitFullscreen'] ||
                                      function() {};
            canvas.cancelFullScreen = canvas.cancelFullScreen.bind(document);
            if (Browser.lockPointer) canvas.requestPointerLock();
            Browser.isFullScreen = true;
            if (Browser.resizeCanvas) Browser.setFullScreenCanvasSize();
          } else {
            
            // remove the full screen specific parent of the canvas again to restore the HTML structure from before going full screen
            canvasContainer.parentNode.insertBefore(canvas, canvasContainer);
            canvasContainer.parentNode.removeChild(canvasContainer);
            
            if (Browser.resizeCanvas) Browser.setWindowedCanvasSize();
          }
          if (Module['onFullScreen']) Module['onFullScreen'](Browser.isFullScreen);
          Browser.updateCanvasDimensions(canvas);
        }
  
        if (!Browser.fullScreenHandlersInstalled) {
          Browser.fullScreenHandlersInstalled = true;
          document.addEventListener('fullscreenchange', fullScreenChange, false);
          document.addEventListener('mozfullscreenchange', fullScreenChange, false);
          document.addEventListener('webkitfullscreenchange', fullScreenChange, false);
          document.addEventListener('MSFullscreenChange', fullScreenChange, false);
        }
  
        // create a new parent to ensure the canvas has no siblings. this allows browsers to optimize full screen performance when its parent is the full screen root
        var canvasContainer = document.createElement("div");
        canvas.parentNode.insertBefore(canvasContainer, canvas);
        canvasContainer.appendChild(canvas);
        
        // use parent of canvas as full screen root to allow aspect ratio correction (Firefox stretches the root to screen size)
        canvasContainer.requestFullScreen = canvasContainer['requestFullScreen'] ||
                                            canvasContainer['mozRequestFullScreen'] ||
                                            canvasContainer['msRequestFullscreen'] ||
                                           (canvasContainer['webkitRequestFullScreen'] ? function() { canvasContainer['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
        canvasContainer.requestFullScreen();
      },nextRAF:0,fakeRequestAnimationFrame:function (func) {
        // try to keep 60fps between calls to here
        var now = Date.now();
        if (Browser.nextRAF === 0) {
          Browser.nextRAF = now + 1000/60;
        } else {
          while (now + 2 >= Browser.nextRAF) { // fudge a little, to avoid timer jitter causing us to do lots of delay:0
            Browser.nextRAF += 1000/60;
          }
        }
        var delay = Math.max(Browser.nextRAF - now, 0);
        setTimeout(func, delay);
      },requestAnimationFrame:function requestAnimationFrame(func) {
        if (typeof window === 'undefined') { // Provide fallback to setTimeout if window is undefined (e.g. in Node.js)
          Browser.fakeRequestAnimationFrame(func);
        } else {
          if (!window.requestAnimationFrame) {
            window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                           window['mozRequestAnimationFrame'] ||
                                           window['webkitRequestAnimationFrame'] ||
                                           window['msRequestAnimationFrame'] ||
                                           window['oRequestAnimationFrame'] ||
                                           Browser.fakeRequestAnimationFrame;
          }
          window.requestAnimationFrame(func);
        }
      },safeCallback:function (func) {
        return function() {
          if (!ABORT) return func.apply(null, arguments);
        };
      },safeRequestAnimationFrame:function (func) {
        return Browser.requestAnimationFrame(function() {
          if (!ABORT) func();
        });
      },safeSetTimeout:function (func, timeout) {
        Module['noExitRuntime'] = true;
        return setTimeout(function() {
          if (!ABORT) func();
        }, timeout);
      },safeSetInterval:function (func, timeout) {
        Module['noExitRuntime'] = true;
        return setInterval(function() {
          if (!ABORT) func();
        }, timeout);
      },getMimetype:function (name) {
        return {
          'jpg': 'image/jpeg',
          'jpeg': 'image/jpeg',
          'png': 'image/png',
          'bmp': 'image/bmp',
          'ogg': 'audio/ogg',
          'wav': 'audio/wav',
          'mp3': 'audio/mpeg'
        }[name.substr(name.lastIndexOf('.')+1)];
      },getUserMedia:function (func) {
        if(!window.getUserMedia) {
          window.getUserMedia = navigator['getUserMedia'] ||
                                navigator['mozGetUserMedia'];
        }
        window.getUserMedia(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },getMouseWheelDelta:function (event) {
        var delta = 0;
        switch (event.type) {
          case 'DOMMouseScroll': 
            delta = event.detail;
            break;
          case 'mousewheel': 
            delta = event.wheelDelta;
            break;
          case 'wheel': 
            delta = event['deltaY'];
            break;
          default:
            throw 'unrecognized mouse wheel event: ' + event.type;
        }
        return delta;
      },mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,touches:{},lastTouches:{},calculateMouseEvent:function (event) { // event should be mousemove, mousedown or mouseup
        if (Browser.pointerLock) {
          // When the pointer is locked, calculate the coordinates
          // based on the movement of the mouse.
          // Workaround for Firefox bug 764498
          if (event.type != 'mousemove' &&
              ('mozMovementX' in event)) {
            Browser.mouseMovementX = Browser.mouseMovementY = 0;
          } else {
            Browser.mouseMovementX = Browser.getMovementX(event);
            Browser.mouseMovementY = Browser.getMovementY(event);
          }
          
          // check if SDL is available
          if (typeof SDL != "undefined") {
          	Browser.mouseX = SDL.mouseX + Browser.mouseMovementX;
          	Browser.mouseY = SDL.mouseY + Browser.mouseMovementY;
          } else {
          	// just add the mouse delta to the current absolut mouse position
          	// FIXME: ideally this should be clamped against the canvas size and zero
          	Browser.mouseX += Browser.mouseMovementX;
          	Browser.mouseY += Browser.mouseMovementY;
          }        
        } else {
          // Otherwise, calculate the movement based on the changes
          // in the coordinates.
          var rect = Module["canvas"].getBoundingClientRect();
          var cw = Module["canvas"].width;
          var ch = Module["canvas"].height;
  
          // Neither .scrollX or .pageXOffset are defined in a spec, but
          // we prefer .scrollX because it is currently in a spec draft.
          // (see: http://www.w3.org/TR/2013/WD-cssom-view-20131217/)
          var scrollX = ((typeof window.scrollX !== 'undefined') ? window.scrollX : window.pageXOffset);
          var scrollY = ((typeof window.scrollY !== 'undefined') ? window.scrollY : window.pageYOffset);
  
          if (event.type === 'touchstart' || event.type === 'touchend' || event.type === 'touchmove') {
            var touch = event.touch;
            if (touch === undefined) {
              return; // the "touch" property is only defined in SDL
  
            }
            var adjustedX = touch.pageX - (scrollX + rect.left);
            var adjustedY = touch.pageY - (scrollY + rect.top);
  
            adjustedX = adjustedX * (cw / rect.width);
            adjustedY = adjustedY * (ch / rect.height);
  
            var coords = { x: adjustedX, y: adjustedY };
            
            if (event.type === 'touchstart') {
              Browser.lastTouches[touch.identifier] = coords;
              Browser.touches[touch.identifier] = coords;
            } else if (event.type === 'touchend' || event.type === 'touchmove') {
              Browser.lastTouches[touch.identifier] = Browser.touches[touch.identifier];
              Browser.touches[touch.identifier] = { x: adjustedX, y: adjustedY };
            } 
            return;
          }
  
          var x = event.pageX - (scrollX + rect.left);
          var y = event.pageY - (scrollY + rect.top);
  
          // the canvas might be CSS-scaled compared to its backbuffer;
          // SDL-using content will want mouse coordinates in terms
          // of backbuffer units.
          x = x * (cw / rect.width);
          y = y * (ch / rect.height);
  
          Browser.mouseMovementX = x - Browser.mouseX;
          Browser.mouseMovementY = y - Browser.mouseY;
          Browser.mouseX = x;
          Browser.mouseY = y;
        }
      },xhrLoad:function (url, onload, onerror) {
        var xhr = new XMLHttpRequest();
        xhr.open('GET', url, true);
        xhr.responseType = 'arraybuffer';
        xhr.onload = function xhr_onload() {
          if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) { // file URLs can return 0
            onload(xhr.response);
          } else {
            onerror();
          }
        };
        xhr.onerror = onerror;
        xhr.send(null);
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        Browser.xhrLoad(url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (!noRunDep) removeRunDependency('al ' + url);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (!noRunDep) addRunDependency('al ' + url);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        Browser.updateCanvasDimensions(canvas, width, height);
        if (!noUpdates) Browser.updateResizeListeners();
      },windowedWidth:0,windowedHeight:0,setFullScreenCanvasSize:function () {
        // check if SDL is available   
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags | 0x00800000; // set SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },setWindowedCanvasSize:function () {
        // check if SDL is available       
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags & ~0x00800000; // clear SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },updateCanvasDimensions:function (canvas, wNative, hNative) {
        if (wNative && hNative) {
          canvas.widthNative = wNative;
          canvas.heightNative = hNative;
        } else {
          wNative = canvas.widthNative;
          hNative = canvas.heightNative;
        }
        var w = wNative;
        var h = hNative;
        if (Module['forcedAspectRatio'] && Module['forcedAspectRatio'] > 0) {
          if (w/h < Module['forcedAspectRatio']) {
            w = Math.round(h * Module['forcedAspectRatio']);
          } else {
            h = Math.round(w / Module['forcedAspectRatio']);
          }
        }
        if (((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
             document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
             document['fullScreenElement'] || document['fullscreenElement'] ||
             document['msFullScreenElement'] || document['msFullscreenElement'] ||
             document['webkitCurrentFullScreenElement']) === canvas.parentNode) && (typeof screen != 'undefined')) {
           var factor = Math.min(screen.width / w, screen.height / h);
           w = Math.round(w * factor);
           h = Math.round(h * factor);
        }
        if (Browser.resizeCanvas) {
          if (canvas.width  != w) canvas.width  = w;
          if (canvas.height != h) canvas.height = h;
          if (typeof canvas.style != 'undefined') {
            canvas.style.removeProperty( "width");
            canvas.style.removeProperty("height");
          }
        } else {
          if (canvas.width  != wNative) canvas.width  = wNative;
          if (canvas.height != hNative) canvas.height = hNative;
          if (typeof canvas.style != 'undefined') {
            if (w != wNative || h != hNative) {
              canvas.style.setProperty( "width", w + "px", "important");
              canvas.style.setProperty("height", h + "px", "important");
            } else {
              canvas.style.removeProperty( "width");
              canvas.style.removeProperty("height");
            }
          }
        }
      },wgetRequests:{},nextWgetRequestHandle:0,getNextWgetRequestHandle:function () {
        var handle = Browser.nextWgetRequestHandle;
        Browser.nextWgetRequestHandle++;
        return handle;
      }};

  function _pthread_setspecific(key, value) {
      if (!(key in PTHREAD_SPECIFIC)) {
        return ERRNO_CODES.EINVAL;
      }
      PTHREAD_SPECIFIC[key] = value;
      return 0;
    }

  
  function _malloc(bytes) {
      /* Over-allocate to make sure it is byte-aligned by 8.
       * This will leak memory, but this is only the dummy
       * implementation (replaced by dlmalloc normally) so
       * not an issue.
       */
      var ptr = Runtime.dynamicAlloc(bytes + 8);
      return (ptr+8) & 0xFFFFFFF8;
    }
  Module["_malloc"] = _malloc;function ___cxa_allocate_exception(size) {
      return _malloc(size);
    }

  function _b2WorldEndContactParticle(particleSystemPtr, indexA, indexB) {
      b2World.EndContactParticle(particleSystemPtr, indexA, indexB);
    }

   
  Module["_i64Add"] = _i64Add;

  function ___cxa_pure_virtual() {
      ABORT = true;
      throw 'Pure virtual function called!';
    }

  function _b2WorldEndContactBody(contactPtr) {
      b2World.EndContactBody(contactPtr);
    }

  function _b2WorldEndContactParticleBody(fixturePtr, particleSystemPtr, index) {
      b2World.EndContactParticleBody(fixturePtr, particleSystemPtr, index);
    }

  function _time(ptr) {
      var ret = (Date.now()/1000)|0;
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret;
      }
      return ret;
    }

  function _b2WorldPreSolve(contactPtr, oldManifoldPtr) {
      b2World.PreSolve(contactPtr, oldManifoldPtr);
    }

  function _vfprintf(s, f, va_arg) {
      return _fprintf(s, f, HEAP32[((va_arg)>>2)]);
    }

  function ___cxa_begin_catch(ptr) {
      __ZSt18uncaught_exceptionv.uncaught_exception--;
      EXCEPTIONS.caught.push(ptr);
      EXCEPTIONS.addRef(EXCEPTIONS.deAdjust(ptr));
      return ptr;
    }

  var _sinf=Math_sin;

  
  function _emscripten_memcpy_big(dest, src, num) {
      HEAPU8.set(HEAPU8.subarray(src, src+num), dest);
      return dest;
    } 
  Module["_memcpy"] = _memcpy;

  function _b2WorldQueryAABB(fixturePtr) {
      return b2World.QueryAABB(fixturePtr);
    }

  function _sbrk(bytes) {
      // Implement a Linux-like 'memory area' for our 'process'.
      // Changes the size of the memory area by |bytes|; returns the
      // address of the previous top ('break') of the memory area
      // We control the "dynamic" memory - DYNAMIC_BASE to DYNAMICTOP
      var self = _sbrk;
      if (!self.called) {
        DYNAMICTOP = alignMemoryPage(DYNAMICTOP); // make sure we start out aligned
        self.called = true;
        assert(Runtime.dynamicAlloc);
        self.alloc = Runtime.dynamicAlloc;
        Runtime.dynamicAlloc = function() { abort('cannot dynamically allocate, sbrk now has control') };
      }
      var ret = DYNAMICTOP;
      if (bytes != 0) self.alloc(bytes);
      return ret;  // Previous break location.
    }

   
  Module["_memmove"] = _memmove;

  function ___errno_location() {
      return ___errno_state;
    }

  function _b2WorldPostSolve(contactPtr, impulsePtr) {
      b2World.PostSolve(contactPtr, impulsePtr);
    }

  var _FtoILow=true;

  function _b2WorldBeginContactParticleBody(particleSystemPtr, particleBodyContactPtr) {
      b2World.BeginContactParticleBody(particleSystemPtr, particleBodyContactPtr);
    }

FS.staticInit();__ATINIT__.unshift({ func: function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() } });__ATMAIN__.push({ func: function() { FS.ignorePermissions = false } });__ATEXIT__.push({ func: function() { FS.quit() } });Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;
___errno_state = Runtime.staticAlloc(4); HEAP32[((___errno_state)>>2)]=0;
__ATINIT__.unshift({ func: function() { TTY.init() } });__ATEXIT__.push({ func: function() { TTY.shutdown() } });TTY.utf8 = new Runtime.UTF8Processor();
if (ENVIRONMENT_IS_NODE) { var fs = require("fs"); NODEFS.staticInit(); }
__ATINIT__.push({ func: function() { SOCKFS.root = FS.mount(SOCKFS, {}, null); } });
_fputc.ret = allocate([0], "i8", ALLOC_STATIC);
Module["requestFullScreen"] = function Module_requestFullScreen(lockPointer, resizeCanvas) { Browser.requestFullScreen(lockPointer, resizeCanvas) };
  Module["requestAnimationFrame"] = function Module_requestAnimationFrame(func) { Browser.requestAnimationFrame(func) };
  Module["setCanvasSize"] = function Module_setCanvasSize(width, height, noUpdates) { Browser.setCanvasSize(width, height, noUpdates) };
  Module["pauseMainLoop"] = function Module_pauseMainLoop() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function Module_resumeMainLoop() { Browser.mainLoop.resume() };
  Module["getUserMedia"] = function Module_getUserMedia() { Browser.getUserMedia() }
STACK_BASE = STACKTOP = Runtime.alignMemory(STATICTOP);

staticSealed = true; // seal the static portion of memory

STACK_MAX = STACK_BASE + TOTAL_STACK;

DYNAMIC_BASE = DYNAMICTOP = Runtime.alignMemory(STACK_MAX);

assert(DYNAMIC_BASE < TOTAL_MEMORY, "TOTAL_MEMORY not big enough for stack");

 var ctlz_i8 = allocate([8,7,6,6,5,5,5,5,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_DYNAMIC);
 var cttz_i8 = allocate([8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0], "i8", ALLOC_DYNAMIC);


function invoke_diiiiid(index,a1,a2,a3,a4,a5,a6) {
  try {
    return Module["dynCall_diiiiid"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_ii(index,a1) {
  try {
    return Module["dynCall_ii"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiii(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_did(index,a1,a2) {
  try {
    return Module["dynCall_did"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vi(index,a1) {
  try {
    Module["dynCall_vi"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_diiiid(index,a1,a2,a3,a4,a5) {
  try {
    return Module["dynCall_diiiid"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vii(index,a1,a2) {
  try {
    Module["dynCall_vii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viii(index,a1,a2,a3) {
  try {
    Module["dynCall_viii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_v(index) {
  try {
    Module["dynCall_v"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viid(index,a1,a2,a3) {
  try {
    Module["dynCall_viid"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iii(index,a1,a2) {
  try {
    return Module["dynCall_iii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiii(index,a1,a2,a3,a4,a5) {
  try {
    return Module["dynCall_iiiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiii(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

Module.asmGlobalArg = { "Math": Math, "Int8Array": Int8Array, "Int16Array": Int16Array, "Int32Array": Int32Array, "Uint8Array": Uint8Array, "Uint16Array": Uint16Array, "Uint32Array": Uint32Array, "Float32Array": Float32Array, "Float64Array": Float64Array };
Module.asmLibraryArg = { "abort": abort, "assert": assert, "min": Math_min, "invoke_diiiiid": invoke_diiiiid, "invoke_ii": invoke_ii, "invoke_viiiii": invoke_viiiii, "invoke_did": invoke_did, "invoke_vi": invoke_vi, "invoke_diiiid": invoke_diiiid, "invoke_vii": invoke_vii, "invoke_iiii": invoke_iiii, "invoke_viii": invoke_viii, "invoke_v": invoke_v, "invoke_viid": invoke_viid, "invoke_iiiii": invoke_iiiii, "invoke_viiiiii": invoke_viiiiii, "invoke_iii": invoke_iii, "invoke_iiiiii": invoke_iiiiii, "invoke_viiii": invoke_viiii, "__formatString": __formatString, "_cosf": _cosf, "_send": _send, "_sqrtf": _sqrtf, "_emscripten_set_main_loop_timing": _emscripten_set_main_loop_timing, "_vfprintf": _vfprintf, "_write": _write, "___cxa_allocate_exception": ___cxa_allocate_exception, "__ZSt18uncaught_exceptionv": __ZSt18uncaught_exceptionv, "_fflush": _fflush, "_pwrite": _pwrite, "__reallyNegative": __reallyNegative, "_b2WorldQueryAABB": _b2WorldQueryAABB, "_b2WorldBeginContactParticle": _b2WorldBeginContactParticle, "___setErrNo": ___setErrNo, "_sbrk": _sbrk, "___cxa_begin_catch": ___cxa_begin_catch, "_sinf": _sinf, "_fileno": _fileno, "___resumeException": ___resumeException, "___cxa_find_matching_catch": ___cxa_find_matching_catch, "_b2WorldRayCastCallback": _b2WorldRayCastCallback, "_pthread_getspecific": _pthread_getspecific, "_emscripten_memcpy_big": _emscripten_memcpy_big, "_pthread_once": _pthread_once, "_puts": _puts, "_printf": _printf, "_floorf": _floorf, "_pthread_key_create": _pthread_key_create, "_b2WorldBeginContactParticleBody": _b2WorldBeginContactParticleBody, "_b2WorldBeginContactBody": _b2WorldBeginContactBody, "___errno_location": ___errno_location, "_b2WorldEndContactParticleBody": _b2WorldEndContactParticleBody, "_pthread_setspecific": _pthread_setspecific, "_mkport": _mkport, "___cxa_throw": ___cxa_throw, "_sysconf": _sysconf, "_fputc": _fputc, "_emscripten_set_main_loop": _emscripten_set_main_loop, "_abort": _abort, "_fwrite": _fwrite, "_time": _time, "_fprintf": _fprintf, "_b2WorldEndContactBody": _b2WorldEndContactBody, "_fputs": _fputs, "_b2WorldEndContactParticle": _b2WorldEndContactParticle, "_b2WorldPostSolve": _b2WorldPostSolve, "___cxa_pure_virtual": ___cxa_pure_virtual, "_b2WorldPreSolve": _b2WorldPreSolve, "STACKTOP": STACKTOP, "STACK_MAX": STACK_MAX, "tempDoublePtr": tempDoublePtr, "ABORT": ABORT, "cttz_i8": cttz_i8, "ctlz_i8": ctlz_i8, "NaN": NaN, "Infinity": Infinity, "_stderr": _stderr };
// EMSCRIPTEN_START_ASM
var asm = (function(global, env, buffer) {
  'use asm';
  
  var HEAP8 = new global.Int8Array(buffer);
  var HEAP16 = new global.Int16Array(buffer);
  var HEAP32 = new global.Int32Array(buffer);
  var HEAPU8 = new global.Uint8Array(buffer);
  var HEAPU16 = new global.Uint16Array(buffer);
  var HEAPU32 = new global.Uint32Array(buffer);
  var HEAPF32 = new global.Float32Array(buffer);
  var HEAPF64 = new global.Float64Array(buffer);


  var STACKTOP=env.STACKTOP|0;
  var STACK_MAX=env.STACK_MAX|0;
  var tempDoublePtr=env.tempDoublePtr|0;
  var ABORT=env.ABORT|0;
  var cttz_i8=env.cttz_i8|0;
  var ctlz_i8=env.ctlz_i8|0;
  var _stderr=env._stderr|0;

  var __THREW__ = 0;
  var threwValue = 0;
  var setjmpId = 0;
  var undef = 0;
  var nan = +env.NaN, inf = +env.Infinity;
  var tempInt = 0, tempBigInt = 0, tempBigIntP = 0, tempBigIntS = 0, tempBigIntR = 0.0, tempBigIntI = 0, tempBigIntD = 0, tempValue = 0, tempDouble = 0.0;

  var tempRet0 = 0;
  var tempRet1 = 0;
  var tempRet2 = 0;
  var tempRet3 = 0;
  var tempRet4 = 0;
  var tempRet5 = 0;
  var tempRet6 = 0;
  var tempRet7 = 0;
  var tempRet8 = 0;
  var tempRet9 = 0;
  var Math_floor=global.Math.floor;
  var Math_abs=global.Math.abs;
  var Math_sqrt=global.Math.sqrt;
  var Math_pow=global.Math.pow;
  var Math_cos=global.Math.cos;
  var Math_sin=global.Math.sin;
  var Math_tan=global.Math.tan;
  var Math_acos=global.Math.acos;
  var Math_asin=global.Math.asin;
  var Math_atan=global.Math.atan;
  var Math_atan2=global.Math.atan2;
  var Math_exp=global.Math.exp;
  var Math_log=global.Math.log;
  var Math_ceil=global.Math.ceil;
  var Math_imul=global.Math.imul;
  var abort=env.abort;
  var assert=env.assert;
  var Math_min=env.min;
  var invoke_diiiiid=env.invoke_diiiiid;
  var invoke_ii=env.invoke_ii;
  var invoke_viiiii=env.invoke_viiiii;
  var invoke_did=env.invoke_did;
  var invoke_vi=env.invoke_vi;
  var invoke_diiiid=env.invoke_diiiid;
  var invoke_vii=env.invoke_vii;
  var invoke_iiii=env.invoke_iiii;
  var invoke_viii=env.invoke_viii;
  var invoke_v=env.invoke_v;
  var invoke_viid=env.invoke_viid;
  var invoke_iiiii=env.invoke_iiiii;
  var invoke_viiiiii=env.invoke_viiiiii;
  var invoke_iii=env.invoke_iii;
  var invoke_iiiiii=env.invoke_iiiiii;
  var invoke_viiii=env.invoke_viiii;
  var __formatString=env.__formatString;
  var _cosf=env._cosf;
  var _send=env._send;
  var _sqrtf=env._sqrtf;
  var _emscripten_set_main_loop_timing=env._emscripten_set_main_loop_timing;
  var _vfprintf=env._vfprintf;
  var _write=env._write;
  var ___cxa_allocate_exception=env.___cxa_allocate_exception;
  var __ZSt18uncaught_exceptionv=env.__ZSt18uncaught_exceptionv;
  var _fflush=env._fflush;
  var _pwrite=env._pwrite;
  var __reallyNegative=env.__reallyNegative;
  var _b2WorldQueryAABB=env._b2WorldQueryAABB;
  var _b2WorldBeginContactParticle=env._b2WorldBeginContactParticle;
  var ___setErrNo=env.___setErrNo;
  var _sbrk=env._sbrk;
  var ___cxa_begin_catch=env.___cxa_begin_catch;
  var _sinf=env._sinf;
  var _fileno=env._fileno;
  var ___resumeException=env.___resumeException;
  var ___cxa_find_matching_catch=env.___cxa_find_matching_catch;
  var _b2WorldRayCastCallback=env._b2WorldRayCastCallback;
  var _pthread_getspecific=env._pthread_getspecific;
  var _emscripten_memcpy_big=env._emscripten_memcpy_big;
  var _pthread_once=env._pthread_once;
  var _puts=env._puts;
  var _printf=env._printf;
  var _floorf=env._floorf;
  var _pthread_key_create=env._pthread_key_create;
  var _b2WorldBeginContactParticleBody=env._b2WorldBeginContactParticleBody;
  var _b2WorldBeginContactBody=env._b2WorldBeginContactBody;
  var ___errno_location=env.___errno_location;
  var _b2WorldEndContactParticleBody=env._b2WorldEndContactParticleBody;
  var _pthread_setspecific=env._pthread_setspecific;
  var _mkport=env._mkport;
  var ___cxa_throw=env.___cxa_throw;
  var _sysconf=env._sysconf;
  var _fputc=env._fputc;
  var _emscripten_set_main_loop=env._emscripten_set_main_loop;
  var _abort=env._abort;
  var _fwrite=env._fwrite;
  var _time=env._time;
  var _fprintf=env._fprintf;
  var _b2WorldEndContactBody=env._b2WorldEndContactBody;
  var _fputs=env._fputs;
  var _b2WorldEndContactParticle=env._b2WorldEndContactParticle;
  var _b2WorldPostSolve=env._b2WorldPostSolve;
  var ___cxa_pure_virtual=env.___cxa_pure_virtual;
  var _b2WorldPreSolve=env._b2WorldPreSolve;
  var tempFloat = 0.0;

// EMSCRIPTEN_START_FUNCS
function stackAlloc(size) {
  size = size|0;
  var ret = 0;
  ret = STACKTOP;
  STACKTOP = (STACKTOP + size)|0;
STACKTOP = (STACKTOP + 15)&-16;

  return ret|0;
}
function stackSave() {
  return STACKTOP|0;
}
function stackRestore(top) {
  top = top|0;
  STACKTOP = top;
}

function setThrew(threw, value) {
  threw = threw|0;
  value = value|0;
  if ((__THREW__|0) == 0) {
    __THREW__ = threw;
    threwValue = value;
  }
}
function copyTempFloat(ptr) {
  ptr = ptr|0;
  HEAP8[tempDoublePtr>>0] = HEAP8[ptr>>0];
  HEAP8[tempDoublePtr+1>>0] = HEAP8[ptr+1>>0];
  HEAP8[tempDoublePtr+2>>0] = HEAP8[ptr+2>>0];
  HEAP8[tempDoublePtr+3>>0] = HEAP8[ptr+3>>0];
}
function copyTempDouble(ptr) {
  ptr = ptr|0;
  HEAP8[tempDoublePtr>>0] = HEAP8[ptr>>0];
  HEAP8[tempDoublePtr+1>>0] = HEAP8[ptr+1>>0];
  HEAP8[tempDoublePtr+2>>0] = HEAP8[ptr+2>>0];
  HEAP8[tempDoublePtr+3>>0] = HEAP8[ptr+3>>0];
  HEAP8[tempDoublePtr+4>>0] = HEAP8[ptr+4>>0];
  HEAP8[tempDoublePtr+5>>0] = HEAP8[ptr+5>>0];
  HEAP8[tempDoublePtr+6>>0] = HEAP8[ptr+6>>0];
  HEAP8[tempDoublePtr+7>>0] = HEAP8[ptr+7>>0];
}
function setTempRet0(value) {
  value = value|0;
  tempRet0 = value;
}
function getTempRet0() {
  return tempRet0|0;
}

function _b2Manifold_GetPointCount($manifold) {
 $manifold = $manifold|0;
 var $0 = 0, $1 = 0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($manifold) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (+($1|0));
 STACKTOP = sp;return (+$2);
}
function _b2ChainShape_CreateFixture($body,$density,$friction,$isSensor,$restitution,$userData,$categoryBits,$groupIndex,$maskBits,$vertices,$length) {
 $body = $body|0;
 $density = +$density;
 $friction = +$friction;
 $isSensor = +$isSensor;
 $restitution = +$restitution;
 $userData = +$userData;
 $categoryBits = +$categoryBits;
 $groupIndex = +$groupIndex;
 $maskBits = +$maskBits;
 $vertices = $vertices|0;
 $length = +$length;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $2 = 0.0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0.0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0.0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0.0, $chain = 0, $def = 0, $i$02 = 0, $j$01 = 0, $vertexArr = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1120|0;
 $0 = sp + 8|0;
 $def = sp + 1080|0;
 $chain = sp + 1040|0;
 $vertexArr = sp + 16|0;
 $1 = sp;
 HEAPF64[$0>>3] = $userData;
 __ZN12b2FixtureDefC2Ev($def);
 $2 = $density;
 $3 = (($def) + 16|0);
 HEAPF32[$3>>2] = $2;
 $4 = $friction;
 $5 = (($def) + 8|0);
 HEAPF32[$5>>2] = $4;
 $6 = $isSensor != 0.0;
 $7 = (($def) + 20|0);
 $8 = $6&1;
 HEAP8[$7>>0] = $8;
 $9 = $restitution;
 $10 = (($def) + 12|0);
 HEAPF32[$10>>2] = $9;
 $11 = (($def) + 4|0);
 HEAP32[$11>>2] = $0;
 $12 = (~~(($categoryBits))&65535);
 $13 = (($def) + 22|0);
 HEAP16[$13>>1] = $12;
 $14 = (~~(($groupIndex)));
 $15 = (($def) + 26|0);
 HEAP16[$15>>1] = $14;
 $16 = (~~(($maskBits))&65535);
 $17 = (($def) + 24|0);
 HEAP16[$17>>1] = $16;
 __ZN12b2ChainShapeC2Ev($chain);
 $18 = $length * 0.5;
 $19 = (~~(($18)));
 $20 = $length > 0.0;
 if ($20) {
  $i$02 = 0;$j$01 = 0;
 } else {
  __ZN12b2ChainShape11CreateChainEPK6b2Vec2i($chain,$vertexArr,$19);
  HEAP32[$def>>2] = $chain;
  $41 = (__ZN6b2Body13CreateFixtureEPK12b2FixtureDef($body,$def)|0);
  __ZN12b2ChainShapeD2Ev($chain);
  STACKTOP = sp;return ($41|0);
 }
 while(1) {
  $21 = (($vertexArr) + ($j$01<<3)|0);
  $22 = (($vertices) + ($i$02<<2)|0);
  $23 = +HEAPF32[$22>>2];
  $24 = $i$02 | 1;
  $25 = (($vertices) + ($24<<2)|0);
  $26 = +HEAPF32[$25>>2];
  __ZN6b2Vec2C2Eff($1,$23,$26);
  $27 = $1;
  $28 = $27;
  $29 = HEAP32[$28>>2]|0;
  $30 = (($27) + 4)|0;
  $31 = $30;
  $32 = HEAP32[$31>>2]|0;
  $33 = $21;
  $34 = $33;
  HEAP32[$34>>2] = $29;
  $35 = (($33) + 4)|0;
  $36 = $35;
  HEAP32[$36>>2] = $32;
  $37 = (($i$02) + 2)|0;
  $38 = (($j$01) + 1)|0;
  $39 = (+($37|0));
  $40 = $39 < $length;
  if ($40) {
   $i$02 = $37;$j$01 = $38;
  } else {
   break;
  }
 }
 __ZN12b2ChainShape11CreateChainEPK6b2Vec2i($chain,$vertexArr,$19);
 HEAP32[$def>>2] = $chain;
 $41 = (__ZN6b2Body13CreateFixtureEPK12b2FixtureDef($body,$def)|0);
 __ZN12b2ChainShapeD2Ev($chain);
 STACKTOP = sp;return ($41|0);
}
function __ZN12b2FixtureDefC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 22|0);
 __ZN8b2FilterC2Ev($0);
 HEAP32[$this>>2] = 0;
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 8|0);
 HEAPF32[$2>>2] = 0.20000000298023224;
 $3 = (($this) + 12|0);
 HEAPF32[$3>>2] = 0.0;
 $4 = (($this) + 16|0);
 HEAPF32[$4>>2] = 0.0;
 $5 = (($this) + 20|0);
 HEAP8[$5>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN12b2ChainShapeC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7b2ShapeC2Ev($this);
 HEAP32[$this>>2] = ((2176 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 3;
 $1 = (($this) + 8|0);
 HEAPF32[$1>>2] = 0.0099999997764825821;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 36|0);
 HEAP8[$4>>0] = 0;
 $5 = (($this) + 37|0);
 HEAP8[$5>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN6b2Vec2C2Eff($this,$x,$y) {
 $this = $this|0;
 $x = +$x;
 $y = +$y;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$this>>2] = $x;
 $0 = (($this) + 4|0);
 HEAPF32[$0>>2] = $y;
 STACKTOP = sp;return;
}
function ___clang_call_terminate($0) {
 $0 = $0|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (___cxa_begin_catch(($0|0))|0);
 __ZSt9terminatev();
 // unreachable;
}
function _b2CircleShape_CreateFixture($body,$density,$friction,$isSensor,$restitution,$userData,$categoryBits,$groupIndex,$maskBits,$px,$py,$radius) {
 $body = $body|0;
 $density = +$density;
 $friction = +$friction;
 $isSensor = +$isSensor;
 $restitution = +$restitution;
 $userData = +$userData;
 $categoryBits = +$categoryBits;
 $groupIndex = +$groupIndex;
 $maskBits = +$maskBits;
 $px = +$px;
 $py = +$py;
 $radius = +$radius;
 var $0 = 0, $1 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0.0, $9 = 0, $circle = 0, $def = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp;
 $def = sp + 28|0;
 $circle = sp + 8|0;
 HEAPF64[$0>>3] = $userData;
 __ZN12b2FixtureDefC2Ev($def);
 $1 = $density;
 $2 = (($def) + 16|0);
 HEAPF32[$2>>2] = $1;
 $3 = $friction;
 $4 = (($def) + 8|0);
 HEAPF32[$4>>2] = $3;
 $5 = $isSensor != 0.0;
 $6 = (($def) + 20|0);
 $7 = $5&1;
 HEAP8[$6>>0] = $7;
 $8 = $restitution;
 $9 = (($def) + 12|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($def) + 4|0);
 HEAP32[$10>>2] = $0;
 $11 = (~~(($categoryBits))&65535);
 $12 = (($def) + 22|0);
 HEAP16[$12>>1] = $11;
 $13 = (~~(($groupIndex)));
 $14 = (($def) + 26|0);
 HEAP16[$14>>1] = $13;
 $15 = (~~(($maskBits))&65535);
 $16 = (($def) + 24|0);
 HEAP16[$16>>1] = $15;
 __ZN13b2CircleShapeC2Ev($circle);
 $17 = (($circle) + 12|0);
 $18 = $px;
 $19 = $py;
 __ZN6b2Vec23SetEff($17,$18,$19);
 $20 = $radius;
 $21 = (($circle) + 8|0);
 HEAPF32[$21>>2] = $20;
 HEAP32[$def>>2] = $circle;
 $22 = (__ZN6b2Body13CreateFixtureEPK12b2FixtureDef($body,$def)|0);
 STACKTOP = sp;return ($22|0);
}
function __ZN13b2CircleShapeC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7b2ShapeC2Ev($this);
 HEAP32[$this>>2] = ((2096 + 8|0));
 $0 = (($this) + 12|0);
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 8|0);
 HEAPF32[$2>>2] = 0.0;
 __ZN6b2Vec27SetZeroEv($0);
 STACKTOP = sp;return;
}
function __ZN6b2Vec23SetEff($this,$x_,$y_) {
 $this = $this|0;
 $x_ = +$x_;
 $y_ = +$y_;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$this>>2] = $x_;
 $0 = (($this) + 4|0);
 HEAPF32[$0>>2] = $y_;
 STACKTOP = sp;return;
}
function __ZN7b2ShapeD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function _b2CircleShape_CreateParticleGroup($particleSystem,$angle,$angularVelocity,$colorR,$colorG,$colorB,$colorA,$flags,$group,$groupFlags,$lifetime,$linearVelocityX,$linearVelocityY,$positionX,$positionY,$positionData,$particleCount,$strength,$stride,$userData,$px,$py,$radius) {
 $particleSystem = $particleSystem|0;
 $angle = +$angle;
 $angularVelocity = +$angularVelocity;
 $colorR = +$colorR;
 $colorG = +$colorG;
 $colorB = +$colorB;
 $colorA = +$colorA;
 $flags = +$flags;
 $group = +$group;
 $groupFlags = +$groupFlags;
 $lifetime = +$lifetime;
 $linearVelocityX = +$linearVelocityX;
 $linearVelocityY = +$linearVelocityY;
 $positionX = +$positionX;
 $positionY = +$positionY;
 $positionData = +$positionData;
 $particleCount = +$particleCount;
 $strength = +$strength;
 $stride = +$stride;
 $userData = +$userData;
 $px = +$px;
 $py = +$py;
 $radius = +$radius;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0.0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0.0, $70 = 0, $71 = 0, $72 = 0.0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $c = 0, $def = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $0 = sp + 24|0;
 $def = sp + 52|0;
 $1 = sp + 128|0;
 $2 = sp + 16|0;
 $3 = sp + 8|0;
 $c = sp + 32|0;
 $4 = sp;
 HEAPF64[$0>>3] = $userData;
 __ZN18b2ParticleGroupDefC2Ev($def);
 $5 = $angle;
 $6 = (($def) + 16|0);
 HEAPF32[$6>>2] = $5;
 $7 = $angularVelocity;
 $8 = (($def) + 28|0);
 HEAPF32[$8>>2] = $7;
 $9 = (~~(($colorR))&255);
 $10 = (~~(($colorG))&255);
 $11 = (~~(($colorB))&255);
 $12 = (~~(($colorA))&255);
 HEAP8[$1>>0] = $9;
 $13 = (($1) + 1|0);
 HEAP8[$13>>0] = $10;
 $14 = (($1) + 2|0);
 HEAP8[$14>>0] = $11;
 $15 = (($1) + 3|0);
 HEAP8[$15>>0] = $12;
 $16 = (($def) + 32|0);
 (__ZN15b2ParticleColoraSERKS_($16,$1)|0);
 $17 = (~~(($flags))>>>0);
 HEAP32[$def>>2] = $17;
 $18 = (($def) + 72|0);
 HEAP32[$18>>2] = 0;
 $19 = (~~(($groupFlags))>>>0);
 $20 = (($def) + 4|0);
 HEAP32[$20>>2] = $19;
 $21 = $lifetime;
 $22 = (($def) + 64|0);
 HEAPF32[$22>>2] = $21;
 $23 = (($def) + 20|0);
 $24 = $linearVelocityX;
 $25 = $linearVelocityY;
 __ZN6b2Vec2C2Eff($2,$24,$25);
 $26 = $2;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($26) + 4)|0;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = $23;
 $33 = $32;
 HEAP32[$33>>2] = $28;
 $34 = (($32) + 4)|0;
 $35 = $34;
 HEAP32[$35>>2] = $31;
 $36 = (($def) + 8|0);
 $37 = $positionX;
 $38 = $positionY;
 __ZN6b2Vec2C2Eff($3,$37,$38);
 $39 = $3;
 $40 = $39;
 $41 = HEAP32[$40>>2]|0;
 $42 = (($39) + 4)|0;
 $43 = $42;
 $44 = HEAP32[$43>>2]|0;
 $45 = $36;
 $46 = $45;
 HEAP32[$46>>2] = $41;
 $47 = (($45) + 4)|0;
 $48 = $47;
 HEAP32[$48>>2] = $44;
 $49 = (($def) + 60|0);
 HEAP32[$49>>2] = 0;
 $50 = (~~(($particleCount)));
 $51 = (($def) + 56|0);
 HEAP32[$51>>2] = $50;
 $52 = (($def) + 48|0);
 HEAP32[$52>>2] = 0;
 $53 = (($def) + 44|0);
 HEAP32[$53>>2] = 0;
 $54 = $strength;
 $55 = (($def) + 36|0);
 HEAPF32[$55>>2] = $54;
 $56 = $stride;
 $57 = (($def) + 52|0);
 HEAPF32[$57>>2] = $56;
 $58 = (($def) + 68|0);
 HEAP32[$58>>2] = $0;
 __ZN13b2CircleShapeC2Ev($c);
 $59 = (($c) + 12|0);
 $60 = $px;
 $61 = $py;
 __ZN6b2Vec2C2Eff($4,$60,$61);
 $62 = $4;
 $63 = $62;
 $64 = HEAP32[$63>>2]|0;
 $65 = (($62) + 4)|0;
 $66 = $65;
 $67 = HEAP32[$66>>2]|0;
 $68 = $59;
 $69 = $68;
 HEAP32[$69>>2] = $64;
 $70 = (($68) + 4)|0;
 $71 = $70;
 HEAP32[$71>>2] = $67;
 $72 = $radius;
 $73 = (($c) + 8|0);
 HEAPF32[$73>>2] = $72;
 $74 = (($def) + 40|0);
 HEAP32[$74>>2] = $c;
 $75 = (__ZN16b2ParticleSystem19CreateParticleGroupERK18b2ParticleGroupDef($particleSystem,$def)|0);
 STACKTOP = sp;return ($75|0);
}
function __ZN18b2ParticleGroupDefC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = (($this) + 20|0);
 $2 = (($this) + 32|0);
 HEAP32[$this>>2] = 0;
 $3 = (($this) + 4|0);
 HEAP32[$3>>2] = 0;
 $4 = 10224;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = $0;
 $11 = $10;
 HEAP32[$11>>2] = $6;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = $9;
 $14 = (($this) + 16|0);
 HEAPF32[$14>>2] = 0.0;
 $15 = 10224;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = $1;
 $22 = $21;
 HEAP32[$22>>2] = $17;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = $20;
 $25 = (($this) + 28|0);
 HEAPF32[$25>>2] = 0.0;
 (__ZN15b2ParticleColoraSERKS_($2,9504)|0);
 $26 = (($this) + 36|0);
 HEAPF32[$26>>2] = 1.0;
 $27 = (($this) + 40|0);
 dest=$27+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return;
}
function __ZN15b2ParticleColoraSERKS_($this,$color) {
 $this = $this|0;
 $color = $color|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$color>>0]|0;
 $1 = (($color) + 1|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = (($color) + 2|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = (($color) + 3|0);
 $6 = HEAP8[$5>>0]|0;
 HEAP8[$this>>0] = $0;
 $7 = (($this) + 1|0);
 HEAP8[$7>>0] = $2;
 $8 = (($this) + 2|0);
 HEAP8[$8>>0] = $4;
 $9 = (($this) + 3|0);
 HEAP8[$9>>0] = $6;
 STACKTOP = sp;return ($this|0);
}
function _b2CircleShape_DestroyParticlesInShape($particleSystem,$px,$py,$radius,$xfpX,$xfpY,$xfqS,$xfqC) {
 $particleSystem = $particleSystem|0;
 $px = +$px;
 $py = +$py;
 $radius = +$radius;
 $xfpX = +$xfpX;
 $xfpY = +$xfpY;
 $xfqS = +$xfqS;
 $xfqC = +$xfqC;
 var $0 = 0, $1 = 0.0, $10 = 0, $11 = 0, $12 = 0.0, $2 = 0.0, $3 = 0.0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0.0, $circle = 0, $xf = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $circle = sp + 16|0;
 $xf = sp;
 __ZN13b2CircleShapeC2Ev($circle);
 $0 = (($circle) + 12|0);
 $1 = $px;
 $2 = $py;
 __ZN6b2Vec23SetEff($0,$1,$2);
 $3 = $radius;
 $4 = (($circle) + 8|0);
 HEAPF32[$4>>2] = $3;
 $5 = $xfpX;
 $6 = $xfpY;
 __ZN6b2Vec23SetEff($xf,$5,$6);
 $7 = $xfqS;
 $8 = (($xf) + 8|0);
 HEAPF32[$8>>2] = $7;
 $9 = $xfqC;
 $10 = (($xf) + 12|0);
 HEAPF32[$10>>2] = $9;
 $11 = (__ZN16b2ParticleSystem23DestroyParticlesInShapeERK7b2ShapeRK11b2Transform($particleSystem,$circle,$xf)|0);
 $12 = (+($11|0));
 STACKTOP = sp;return (+$12);
}
function __ZN16b2ParticleSystem23DestroyParticlesInShapeERK7b2ShapeRK11b2Transform($this,$shape,$xf) {
 $this = $this|0;
 $shape = $shape|0;
 $xf = $xf|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN16b2ParticleSystem23DestroyParticlesInShapeERK7b2ShapeRK11b2Transformb($this,$shape,$xf,0)|0);
 STACKTOP = sp;return ($0|0);
}
function _b2EdgeShape_CreateFixture($body,$density,$friction,$isSensor,$restitution,$userData,$categoryBits,$groupIndex,$maskBits,$hasVertex0,$hasVertex3,$x0,$y0,$x1,$y1,$x2,$y2,$x3,$y3) {
 $body = $body|0;
 $density = +$density;
 $friction = +$friction;
 $isSensor = +$isSensor;
 $restitution = +$restitution;
 $userData = +$userData;
 $categoryBits = +$categoryBits;
 $groupIndex = +$groupIndex;
 $maskBits = +$maskBits;
 $hasVertex0 = +$hasVertex0;
 $hasVertex3 = +$hasVertex3;
 $x0 = +$x0;
 $y0 = +$y0;
 $x1 = +$x1;
 $y1 = +$y1;
 $x2 = +$x2;
 $y2 = +$y2;
 $x3 = +$x3;
 $y3 = +$y3;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0.0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0.0, $5 = 0.0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0.0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0.0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0;
 var $def = 0, $edge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $0 = sp + 32|0;
 $def = sp + 88|0;
 $edge = sp + 40|0;
 $1 = sp + 24|0;
 $2 = sp + 16|0;
 $3 = sp + 8|0;
 $4 = sp;
 HEAPF64[$0>>3] = $userData;
 __ZN12b2FixtureDefC2Ev($def);
 $5 = $density;
 $6 = (($def) + 16|0);
 HEAPF32[$6>>2] = $5;
 $7 = $friction;
 $8 = (($def) + 8|0);
 HEAPF32[$8>>2] = $7;
 $9 = $isSensor != 0.0;
 $10 = (($def) + 20|0);
 $11 = $9&1;
 HEAP8[$10>>0] = $11;
 $12 = $restitution;
 $13 = (($def) + 12|0);
 HEAPF32[$13>>2] = $12;
 $14 = (($def) + 4|0);
 HEAP32[$14>>2] = $0;
 $15 = (~~(($categoryBits))&65535);
 $16 = (($def) + 22|0);
 HEAP16[$16>>1] = $15;
 $17 = (~~(($groupIndex)));
 $18 = (($def) + 26|0);
 HEAP16[$18>>1] = $17;
 $19 = (~~(($maskBits))&65535);
 $20 = (($def) + 24|0);
 HEAP16[$20>>1] = $19;
 __ZN11b2EdgeShapeC2Ev($edge);
 $21 = (($edge) + 28|0);
 $22 = $x0;
 $23 = $y0;
 __ZN6b2Vec2C2Eff($1,$22,$23);
 $24 = $1;
 $25 = $24;
 $26 = HEAP32[$25>>2]|0;
 $27 = (($24) + 4)|0;
 $28 = $27;
 $29 = HEAP32[$28>>2]|0;
 $30 = $21;
 $31 = $30;
 HEAP32[$31>>2] = $26;
 $32 = (($30) + 4)|0;
 $33 = $32;
 HEAP32[$33>>2] = $29;
 $34 = (($edge) + 12|0);
 $35 = $x1;
 $36 = $y1;
 __ZN6b2Vec2C2Eff($2,$35,$36);
 $37 = $2;
 $38 = $37;
 $39 = HEAP32[$38>>2]|0;
 $40 = (($37) + 4)|0;
 $41 = $40;
 $42 = HEAP32[$41>>2]|0;
 $43 = $34;
 $44 = $43;
 HEAP32[$44>>2] = $39;
 $45 = (($43) + 4)|0;
 $46 = $45;
 HEAP32[$46>>2] = $42;
 $47 = (($edge) + 20|0);
 $48 = $x2;
 $49 = $y2;
 __ZN6b2Vec2C2Eff($3,$48,$49);
 $50 = $3;
 $51 = $50;
 $52 = HEAP32[$51>>2]|0;
 $53 = (($50) + 4)|0;
 $54 = $53;
 $55 = HEAP32[$54>>2]|0;
 $56 = $47;
 $57 = $56;
 HEAP32[$57>>2] = $52;
 $58 = (($56) + 4)|0;
 $59 = $58;
 HEAP32[$59>>2] = $55;
 $60 = (($edge) + 36|0);
 $61 = $x3;
 $62 = $y3;
 __ZN6b2Vec2C2Eff($4,$61,$62);
 $63 = $4;
 $64 = $63;
 $65 = HEAP32[$64>>2]|0;
 $66 = (($63) + 4)|0;
 $67 = $66;
 $68 = HEAP32[$67>>2]|0;
 $69 = $60;
 $70 = $69;
 HEAP32[$70>>2] = $65;
 $71 = (($69) + 4)|0;
 $72 = $71;
 HEAP32[$72>>2] = $68;
 $73 = $hasVertex0 != 0.0;
 $74 = (($edge) + 44|0);
 $75 = $73&1;
 HEAP8[$74>>0] = $75;
 $76 = $hasVertex3 != 0.0;
 $77 = (($edge) + 45|0);
 $78 = $76&1;
 HEAP8[$77>>0] = $78;
 HEAP32[$def>>2] = $edge;
 $79 = (__ZN6b2Body13CreateFixtureEPK12b2FixtureDef($body,$def)|0);
 STACKTOP = sp;return ($79|0);
}
function __ZN11b2EdgeShapeC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7b2ShapeC2Ev($this);
 HEAP32[$this>>2] = ((1928 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 1;
 $1 = (($this) + 8|0);
 HEAPF32[$1>>2] = 0.0099999997764825821;
 $2 = (($this) + 28|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP16[$2+16>>1]=0|0;
 STACKTOP = sp;return;
}
function _b2PolygonShape_CreateFixture_3($body,$density,$friction,$isSensor,$restitution,$userData,$categoryBits,$groupIndex,$maskBits,$x0,$y0,$x1,$y1,$x2,$y2) {
 $body = $body|0;
 $density = +$density;
 $friction = +$friction;
 $isSensor = +$isSensor;
 $restitution = +$restitution;
 $userData = +$userData;
 $categoryBits = +$categoryBits;
 $groupIndex = +$groupIndex;
 $maskBits = +$maskBits;
 $x0 = +$x0;
 $y0 = +$y0;
 $x1 = +$x1;
 $y1 = +$y1;
 $x2 = +$x2;
 $y2 = +$y2;
 var $0 = 0, $1 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $3 = 0.0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, $def = 0, $points = 0, $polygon = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $0 = sp;
 $def = sp + 184|0;
 $points = sp + 160|0;
 $polygon = sp + 8|0;
 HEAPF64[$0>>3] = $userData;
 __ZN12b2FixtureDefC2Ev($def);
 $1 = $density;
 $2 = (($def) + 16|0);
 HEAPF32[$2>>2] = $1;
 $3 = $friction;
 $4 = (($def) + 8|0);
 HEAPF32[$4>>2] = $3;
 $5 = $isSensor != 0.0;
 $6 = (($def) + 20|0);
 $7 = $5&1;
 HEAP8[$6>>0] = $7;
 $8 = $restitution;
 $9 = (($def) + 12|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($def) + 4|0);
 HEAP32[$10>>2] = $0;
 $11 = (~~(($categoryBits))&65535);
 $12 = (($def) + 22|0);
 HEAP16[$12>>1] = $11;
 $13 = (~~(($groupIndex)));
 $14 = (($def) + 26|0);
 HEAP16[$14>>1] = $13;
 $15 = (~~(($maskBits))&65535);
 $16 = (($def) + 24|0);
 HEAP16[$16>>1] = $15;
 $17 = $x0;
 $18 = $y0;
 __ZN6b2Vec2C2Eff($points,$17,$18);
 $19 = (($points) + 8|0);
 $20 = $x1;
 $21 = $y1;
 __ZN6b2Vec2C2Eff($19,$20,$21);
 $22 = (($points) + 16|0);
 $23 = $x2;
 $24 = $y2;
 __ZN6b2Vec2C2Eff($22,$23,$24);
 __ZN14b2PolygonShapeC2Ev($polygon);
 __ZN14b2PolygonShape3SetEPK6b2Vec2i($polygon,$points,3);
 HEAP32[$def>>2] = $polygon;
 $25 = (__ZN6b2Body13CreateFixtureEPK12b2FixtureDef($body,$def)|0);
 STACKTOP = sp;return ($25|0);
}
function __ZN14b2PolygonShapeC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7b2ShapeC2Ev($this);
 HEAP32[$this>>2] = ((2008 + 8|0));
 $0 = (($this) + 12|0);
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = 2;
 $2 = (($this) + 8|0);
 HEAPF32[$2>>2] = 0.0099999997764825821;
 $3 = (($this) + 148|0);
 HEAP32[$3>>2] = 0;
 __ZN6b2Vec27SetZeroEv($0);
 STACKTOP = sp;return;
}
function _b2PolygonShape_CreateFixture_4($body,$density,$friction,$isSensor,$restitution,$userData,$categoryBits,$groupIndex,$maskBits,$x0,$y0,$x1,$y1,$x2,$y2,$x3,$y3) {
 $body = $body|0;
 $density = +$density;
 $friction = +$friction;
 $isSensor = +$isSensor;
 $restitution = +$restitution;
 $userData = +$userData;
 $categoryBits = +$categoryBits;
 $groupIndex = +$groupIndex;
 $maskBits = +$maskBits;
 $x0 = +$x0;
 $y0 = +$y0;
 $x1 = +$x1;
 $y1 = +$y1;
 $x2 = +$x2;
 $y2 = +$y2;
 $x3 = +$x3;
 $y3 = +$y3;
 var $0 = 0, $1 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0.0;
 var $27 = 0.0, $28 = 0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, $def = 0, $points = 0, $polygon = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $0 = sp;
 $def = sp + 192|0;
 $points = sp + 160|0;
 $polygon = sp + 8|0;
 HEAPF64[$0>>3] = $userData;
 __ZN12b2FixtureDefC2Ev($def);
 $1 = $density;
 $2 = (($def) + 16|0);
 HEAPF32[$2>>2] = $1;
 $3 = $friction;
 $4 = (($def) + 8|0);
 HEAPF32[$4>>2] = $3;
 $5 = $isSensor != 0.0;
 $6 = (($def) + 20|0);
 $7 = $5&1;
 HEAP8[$6>>0] = $7;
 $8 = $restitution;
 $9 = (($def) + 12|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($def) + 4|0);
 HEAP32[$10>>2] = $0;
 $11 = (~~(($categoryBits))&65535);
 $12 = (($def) + 22|0);
 HEAP16[$12>>1] = $11;
 $13 = (~~(($groupIndex)));
 $14 = (($def) + 26|0);
 HEAP16[$14>>1] = $13;
 $15 = (~~(($maskBits))&65535);
 $16 = (($def) + 24|0);
 HEAP16[$16>>1] = $15;
 $17 = $x0;
 $18 = $y0;
 __ZN6b2Vec2C2Eff($points,$17,$18);
 $19 = (($points) + 8|0);
 $20 = $x1;
 $21 = $y1;
 __ZN6b2Vec2C2Eff($19,$20,$21);
 $22 = (($points) + 16|0);
 $23 = $x2;
 $24 = $y2;
 __ZN6b2Vec2C2Eff($22,$23,$24);
 $25 = (($points) + 24|0);
 $26 = $x3;
 $27 = $y3;
 __ZN6b2Vec2C2Eff($25,$26,$27);
 __ZN14b2PolygonShapeC2Ev($polygon);
 __ZN14b2PolygonShape3SetEPK6b2Vec2i($polygon,$points,4);
 HEAP32[$def>>2] = $polygon;
 $28 = (__ZN6b2Body13CreateFixtureEPK12b2FixtureDef($body,$def)|0);
 STACKTOP = sp;return ($28|0);
}
function _b2PolygonShape_CreateFixture_5($body,$density,$friction,$isSensor,$restitution,$userData,$categoryBits,$groupIndex,$maskBits,$x0,$y0,$x1,$y1,$x2,$y2,$x3,$y3,$x4,$y4) {
 $body = $body|0;
 $density = +$density;
 $friction = +$friction;
 $isSensor = +$isSensor;
 $restitution = +$restitution;
 $userData = +$userData;
 $categoryBits = +$categoryBits;
 $groupIndex = +$groupIndex;
 $maskBits = +$maskBits;
 $x0 = +$x0;
 $y0 = +$y0;
 $x1 = +$x1;
 $y1 = +$y1;
 $x2 = +$x2;
 $y2 = +$y2;
 $x3 = +$x3;
 $y3 = +$y3;
 $x4 = +$x4;
 $y4 = +$y4;
 var $0 = 0, $1 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0.0;
 var $27 = 0.0, $28 = 0, $29 = 0.0, $3 = 0.0, $30 = 0.0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, $def = 0, $points = 0, $polygon = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $0 = sp;
 $def = sp + 200|0;
 $points = sp + 160|0;
 $polygon = sp + 8|0;
 HEAPF64[$0>>3] = $userData;
 __ZN12b2FixtureDefC2Ev($def);
 $1 = $density;
 $2 = (($def) + 16|0);
 HEAPF32[$2>>2] = $1;
 $3 = $friction;
 $4 = (($def) + 8|0);
 HEAPF32[$4>>2] = $3;
 $5 = $isSensor != 0.0;
 $6 = (($def) + 20|0);
 $7 = $5&1;
 HEAP8[$6>>0] = $7;
 $8 = $restitution;
 $9 = (($def) + 12|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($def) + 4|0);
 HEAP32[$10>>2] = $0;
 $11 = (~~(($categoryBits))&65535);
 $12 = (($def) + 22|0);
 HEAP16[$12>>1] = $11;
 $13 = (~~(($groupIndex)));
 $14 = (($def) + 26|0);
 HEAP16[$14>>1] = $13;
 $15 = (~~(($maskBits))&65535);
 $16 = (($def) + 24|0);
 HEAP16[$16>>1] = $15;
 $17 = $x0;
 $18 = $y0;
 __ZN6b2Vec2C2Eff($points,$17,$18);
 $19 = (($points) + 8|0);
 $20 = $x1;
 $21 = $y1;
 __ZN6b2Vec2C2Eff($19,$20,$21);
 $22 = (($points) + 16|0);
 $23 = $x2;
 $24 = $y2;
 __ZN6b2Vec2C2Eff($22,$23,$24);
 $25 = (($points) + 24|0);
 $26 = $x3;
 $27 = $y3;
 __ZN6b2Vec2C2Eff($25,$26,$27);
 $28 = (($points) + 32|0);
 $29 = $x4;
 $30 = $y4;
 __ZN6b2Vec2C2Eff($28,$29,$30);
 __ZN14b2PolygonShapeC2Ev($polygon);
 __ZN14b2PolygonShape3SetEPK6b2Vec2i($polygon,$points,5);
 HEAP32[$def>>2] = $polygon;
 $31 = (__ZN6b2Body13CreateFixtureEPK12b2FixtureDef($body,$def)|0);
 STACKTOP = sp;return ($31|0);
}
function _b2PolygonShape_CreateFixture_6($body,$density,$friction,$isSensor,$restitution,$userData,$categoryBits,$groupIndex,$maskBits,$x0,$y0,$x1,$y1,$x2,$y2,$x3,$y3,$x4,$y4,$x5,$y5) {
 $body = $body|0;
 $density = +$density;
 $friction = +$friction;
 $isSensor = +$isSensor;
 $restitution = +$restitution;
 $userData = +$userData;
 $categoryBits = +$categoryBits;
 $groupIndex = +$groupIndex;
 $maskBits = +$maskBits;
 $x0 = +$x0;
 $y0 = +$y0;
 $x1 = +$x1;
 $y1 = +$y1;
 $x2 = +$x2;
 $y2 = +$y2;
 $x3 = +$x3;
 $y3 = +$y3;
 $x4 = +$x4;
 $y4 = +$y4;
 $x5 = +$x5;
 $y5 = +$y5;
 var $0 = 0, $1 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0.0;
 var $27 = 0.0, $28 = 0, $29 = 0.0, $3 = 0.0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, $def = 0, $points = 0, $polygon = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 240|0;
 $0 = sp;
 $def = sp + 208|0;
 $points = sp + 160|0;
 $polygon = sp + 8|0;
 HEAPF64[$0>>3] = $userData;
 __ZN12b2FixtureDefC2Ev($def);
 $1 = $density;
 $2 = (($def) + 16|0);
 HEAPF32[$2>>2] = $1;
 $3 = $friction;
 $4 = (($def) + 8|0);
 HEAPF32[$4>>2] = $3;
 $5 = $isSensor != 0.0;
 $6 = (($def) + 20|0);
 $7 = $5&1;
 HEAP8[$6>>0] = $7;
 $8 = $restitution;
 $9 = (($def) + 12|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($def) + 4|0);
 HEAP32[$10>>2] = $0;
 $11 = (~~(($categoryBits))&65535);
 $12 = (($def) + 22|0);
 HEAP16[$12>>1] = $11;
 $13 = (~~(($groupIndex)));
 $14 = (($def) + 26|0);
 HEAP16[$14>>1] = $13;
 $15 = (~~(($maskBits))&65535);
 $16 = (($def) + 24|0);
 HEAP16[$16>>1] = $15;
 $17 = $x0;
 $18 = $y0;
 __ZN6b2Vec2C2Eff($points,$17,$18);
 $19 = (($points) + 8|0);
 $20 = $x1;
 $21 = $y1;
 __ZN6b2Vec2C2Eff($19,$20,$21);
 $22 = (($points) + 16|0);
 $23 = $x2;
 $24 = $y2;
 __ZN6b2Vec2C2Eff($22,$23,$24);
 $25 = (($points) + 24|0);
 $26 = $x3;
 $27 = $y3;
 __ZN6b2Vec2C2Eff($25,$26,$27);
 $28 = (($points) + 32|0);
 $29 = $x4;
 $30 = $y4;
 __ZN6b2Vec2C2Eff($28,$29,$30);
 $31 = (($points) + 40|0);
 $32 = $x5;
 $33 = $y5;
 __ZN6b2Vec2C2Eff($31,$32,$33);
 __ZN14b2PolygonShapeC2Ev($polygon);
 __ZN14b2PolygonShape3SetEPK6b2Vec2i($polygon,$points,6);
 HEAP32[$def>>2] = $polygon;
 $34 = (__ZN6b2Body13CreateFixtureEPK12b2FixtureDef($body,$def)|0);
 STACKTOP = sp;return ($34|0);
}
function _b2PolygonShape_CreateFixture_7($body,$density,$friction,$isSensor,$restitution,$userData,$categoryBits,$groupIndex,$maskBits,$x0,$y0,$x1,$y1,$x2,$y2,$x3,$y3,$x4,$y4,$x5,$y5,$x6,$y6) {
 $body = $body|0;
 $density = +$density;
 $friction = +$friction;
 $isSensor = +$isSensor;
 $restitution = +$restitution;
 $userData = +$userData;
 $categoryBits = +$categoryBits;
 $groupIndex = +$groupIndex;
 $maskBits = +$maskBits;
 $x0 = +$x0;
 $y0 = +$y0;
 $x1 = +$x1;
 $y1 = +$y1;
 $x2 = +$x2;
 $y2 = +$y2;
 $x3 = +$x3;
 $y3 = +$y3;
 $x4 = +$x4;
 $y4 = +$y4;
 $x5 = +$x5;
 $y5 = +$y5;
 $x6 = +$x6;
 $y6 = +$y6;
 var $0 = 0, $1 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0.0;
 var $27 = 0.0, $28 = 0, $29 = 0.0, $3 = 0.0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0.0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, $def = 0, $points = 0;
 var $polygon = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $0 = sp;
 $def = sp + 216|0;
 $points = sp + 160|0;
 $polygon = sp + 8|0;
 HEAPF64[$0>>3] = $userData;
 __ZN12b2FixtureDefC2Ev($def);
 $1 = $density;
 $2 = (($def) + 16|0);
 HEAPF32[$2>>2] = $1;
 $3 = $friction;
 $4 = (($def) + 8|0);
 HEAPF32[$4>>2] = $3;
 $5 = $isSensor != 0.0;
 $6 = (($def) + 20|0);
 $7 = $5&1;
 HEAP8[$6>>0] = $7;
 $8 = $restitution;
 $9 = (($def) + 12|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($def) + 4|0);
 HEAP32[$10>>2] = $0;
 $11 = (~~(($categoryBits))&65535);
 $12 = (($def) + 22|0);
 HEAP16[$12>>1] = $11;
 $13 = (~~(($groupIndex)));
 $14 = (($def) + 26|0);
 HEAP16[$14>>1] = $13;
 $15 = (~~(($maskBits))&65535);
 $16 = (($def) + 24|0);
 HEAP16[$16>>1] = $15;
 $17 = $x0;
 $18 = $y0;
 __ZN6b2Vec2C2Eff($points,$17,$18);
 $19 = (($points) + 8|0);
 $20 = $x1;
 $21 = $y1;
 __ZN6b2Vec2C2Eff($19,$20,$21);
 $22 = (($points) + 16|0);
 $23 = $x2;
 $24 = $y2;
 __ZN6b2Vec2C2Eff($22,$23,$24);
 $25 = (($points) + 24|0);
 $26 = $x3;
 $27 = $y3;
 __ZN6b2Vec2C2Eff($25,$26,$27);
 $28 = (($points) + 32|0);
 $29 = $x4;
 $30 = $y4;
 __ZN6b2Vec2C2Eff($28,$29,$30);
 $31 = (($points) + 40|0);
 $32 = $x5;
 $33 = $y5;
 __ZN6b2Vec2C2Eff($31,$32,$33);
 $34 = (($points) + 48|0);
 $35 = $x6;
 $36 = $y6;
 __ZN6b2Vec2C2Eff($34,$35,$36);
 __ZN14b2PolygonShapeC2Ev($polygon);
 __ZN14b2PolygonShape3SetEPK6b2Vec2i($polygon,$points,7);
 HEAP32[$def>>2] = $polygon;
 $37 = (__ZN6b2Body13CreateFixtureEPK12b2FixtureDef($body,$def)|0);
 STACKTOP = sp;return ($37|0);
}
function _b2PolygonShape_CreateFixture_8($body,$density,$friction,$isSensor,$restitution,$userData,$categoryBits,$groupIndex,$maskBits,$x0,$y0,$x1,$y1,$x2,$y2,$x3,$y3,$x4,$y4,$x5,$y5,$x6,$y6,$x7,$y7) {
 $body = $body|0;
 $density = +$density;
 $friction = +$friction;
 $isSensor = +$isSensor;
 $restitution = +$restitution;
 $userData = +$userData;
 $categoryBits = +$categoryBits;
 $groupIndex = +$groupIndex;
 $maskBits = +$maskBits;
 $x0 = +$x0;
 $y0 = +$y0;
 $x1 = +$x1;
 $y1 = +$y1;
 $x2 = +$x2;
 $y2 = +$y2;
 $x3 = +$x3;
 $y3 = +$y3;
 $x4 = +$x4;
 $y4 = +$y4;
 $x5 = +$x5;
 $y5 = +$y5;
 $x6 = +$x6;
 $y6 = +$y6;
 $x7 = +$x7;
 $y7 = +$y7;
 var $0 = 0, $1 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0.0;
 var $27 = 0.0, $28 = 0, $29 = 0.0, $3 = 0.0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0;
 var $9 = 0, $def = 0, $points = 0, $polygon = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $0 = sp;
 $def = sp + 224|0;
 $points = sp + 160|0;
 $polygon = sp + 8|0;
 HEAPF64[$0>>3] = $userData;
 __ZN12b2FixtureDefC2Ev($def);
 $1 = $density;
 $2 = (($def) + 16|0);
 HEAPF32[$2>>2] = $1;
 $3 = $friction;
 $4 = (($def) + 8|0);
 HEAPF32[$4>>2] = $3;
 $5 = $isSensor != 0.0;
 $6 = (($def) + 20|0);
 $7 = $5&1;
 HEAP8[$6>>0] = $7;
 $8 = $restitution;
 $9 = (($def) + 12|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($def) + 4|0);
 HEAP32[$10>>2] = $0;
 $11 = (~~(($categoryBits))&65535);
 $12 = (($def) + 22|0);
 HEAP16[$12>>1] = $11;
 $13 = (~~(($groupIndex)));
 $14 = (($def) + 26|0);
 HEAP16[$14>>1] = $13;
 $15 = (~~(($maskBits))&65535);
 $16 = (($def) + 24|0);
 HEAP16[$16>>1] = $15;
 $17 = $x0;
 $18 = $y0;
 __ZN6b2Vec2C2Eff($points,$17,$18);
 $19 = (($points) + 8|0);
 $20 = $x1;
 $21 = $y1;
 __ZN6b2Vec2C2Eff($19,$20,$21);
 $22 = (($points) + 16|0);
 $23 = $x2;
 $24 = $y2;
 __ZN6b2Vec2C2Eff($22,$23,$24);
 $25 = (($points) + 24|0);
 $26 = $x3;
 $27 = $y3;
 __ZN6b2Vec2C2Eff($25,$26,$27);
 $28 = (($points) + 32|0);
 $29 = $x4;
 $30 = $y4;
 __ZN6b2Vec2C2Eff($28,$29,$30);
 $31 = (($points) + 40|0);
 $32 = $x5;
 $33 = $y5;
 __ZN6b2Vec2C2Eff($31,$32,$33);
 $34 = (($points) + 48|0);
 $35 = $x6;
 $36 = $y6;
 __ZN6b2Vec2C2Eff($34,$35,$36);
 $37 = (($points) + 56|0);
 $38 = $x7;
 $39 = $y7;
 __ZN6b2Vec2C2Eff($37,$38,$39);
 __ZN14b2PolygonShapeC2Ev($polygon);
 __ZN14b2PolygonShape3SetEPK6b2Vec2i($polygon,$points,8);
 HEAP32[$def>>2] = $polygon;
 $40 = (__ZN6b2Body13CreateFixtureEPK12b2FixtureDef($body,$def)|0);
 STACKTOP = sp;return ($40|0);
}
function _b2PolygonShape_CreateParticleGroup_4($particleSystem,$angle,$angularVelocity,$colorR,$colorG,$colorB,$colorA,$flags,$group,$groupFlags,$lifetime,$linearVelocityX,$linearVelocityY,$positionX,$positionY,$positionData,$particleCount,$strength,$stride,$userData,$x0,$y0,$x1,$y1,$x2,$y2,$x3,$y3) {
 $particleSystem = $particleSystem|0;
 $angle = +$angle;
 $angularVelocity = +$angularVelocity;
 $colorR = +$colorR;
 $colorG = +$colorG;
 $colorB = +$colorB;
 $colorA = +$colorA;
 $flags = +$flags;
 $group = +$group;
 $groupFlags = +$groupFlags;
 $lifetime = +$lifetime;
 $linearVelocityX = +$linearVelocityX;
 $linearVelocityY = +$linearVelocityY;
 $positionX = +$positionX;
 $positionY = +$positionY;
 $positionData = +$positionData;
 $particleCount = +$particleCount;
 $strength = +$strength;
 $stride = +$stride;
 $userData = +$userData;
 $x0 = +$x0;
 $y0 = +$y0;
 $x1 = +$x1;
 $y1 = +$y1;
 $x2 = +$x2;
 $y2 = +$y2;
 $x3 = +$x3;
 $y3 = +$y3;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0.0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0, $58 = 0.0, $59 = 0.0, $6 = 0.0, $60 = 0, $61 = 0.0, $62 = 0.0;
 var $63 = 0, $64 = 0.0, $65 = 0.0, $66 = 0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $def = 0, $p = 0, $points = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $0 = sp + 16|0;
 $def = sp + 208|0;
 $1 = sp + 284|0;
 $2 = sp + 8|0;
 $3 = sp;
 $points = sp + 176|0;
 $p = sp + 24|0;
 HEAPF64[$0>>3] = $userData;
 __ZN18b2ParticleGroupDefC2Ev($def);
 $4 = $angle;
 $5 = (($def) + 16|0);
 HEAPF32[$5>>2] = $4;
 $6 = $angularVelocity;
 $7 = (($def) + 28|0);
 HEAPF32[$7>>2] = $6;
 $8 = (~~(($colorR))&255);
 $9 = (~~(($colorG))&255);
 $10 = (~~(($colorB))&255);
 $11 = (~~(($colorA))&255);
 HEAP8[$1>>0] = $8;
 $12 = (($1) + 1|0);
 HEAP8[$12>>0] = $9;
 $13 = (($1) + 2|0);
 HEAP8[$13>>0] = $10;
 $14 = (($1) + 3|0);
 HEAP8[$14>>0] = $11;
 $15 = (($def) + 32|0);
 (__ZN15b2ParticleColoraSERKS_($15,$1)|0);
 $16 = (~~(($flags))>>>0);
 HEAP32[$def>>2] = $16;
 $17 = (($def) + 72|0);
 HEAP32[$17>>2] = 0;
 $18 = (~~(($groupFlags))>>>0);
 $19 = (($def) + 4|0);
 HEAP32[$19>>2] = $18;
 $20 = $lifetime;
 $21 = (($def) + 64|0);
 HEAPF32[$21>>2] = $20;
 $22 = (($def) + 20|0);
 $23 = $linearVelocityX;
 $24 = $linearVelocityY;
 __ZN6b2Vec2C2Eff($2,$23,$24);
 $25 = $2;
 $26 = $25;
 $27 = HEAP32[$26>>2]|0;
 $28 = (($25) + 4)|0;
 $29 = $28;
 $30 = HEAP32[$29>>2]|0;
 $31 = $22;
 $32 = $31;
 HEAP32[$32>>2] = $27;
 $33 = (($31) + 4)|0;
 $34 = $33;
 HEAP32[$34>>2] = $30;
 $35 = (($def) + 8|0);
 $36 = $positionX;
 $37 = $positionY;
 __ZN6b2Vec2C2Eff($3,$36,$37);
 $38 = $3;
 $39 = $38;
 $40 = HEAP32[$39>>2]|0;
 $41 = (($38) + 4)|0;
 $42 = $41;
 $43 = HEAP32[$42>>2]|0;
 $44 = $35;
 $45 = $44;
 HEAP32[$45>>2] = $40;
 $46 = (($44) + 4)|0;
 $47 = $46;
 HEAP32[$47>>2] = $43;
 $48 = (($def) + 60|0);
 HEAP32[$48>>2] = 0;
 $49 = (~~(($particleCount)));
 $50 = (($def) + 56|0);
 HEAP32[$50>>2] = $49;
 $51 = (($def) + 48|0);
 HEAP32[$51>>2] = 0;
 $52 = (($def) + 44|0);
 HEAP32[$52>>2] = 0;
 $53 = $strength;
 $54 = (($def) + 36|0);
 HEAPF32[$54>>2] = $53;
 $55 = $stride;
 $56 = (($def) + 52|0);
 HEAPF32[$56>>2] = $55;
 $57 = (($def) + 68|0);
 HEAP32[$57>>2] = $0;
 $58 = $x0;
 $59 = $y0;
 __ZN6b2Vec2C2Eff($points,$58,$59);
 $60 = (($points) + 8|0);
 $61 = $x1;
 $62 = $y1;
 __ZN6b2Vec2C2Eff($60,$61,$62);
 $63 = (($points) + 16|0);
 $64 = $x2;
 $65 = $y2;
 __ZN6b2Vec2C2Eff($63,$64,$65);
 $66 = (($points) + 24|0);
 $67 = $x3;
 $68 = $y3;
 __ZN6b2Vec2C2Eff($66,$67,$68);
 __ZN14b2PolygonShapeC2Ev($p);
 __ZN14b2PolygonShape3SetEPK6b2Vec2i($p,$points,4);
 $69 = (($def) + 40|0);
 HEAP32[$69>>2] = $p;
 $70 = (__ZN16b2ParticleSystem19CreateParticleGroupERK18b2ParticleGroupDef($particleSystem,$def)|0);
 STACKTOP = sp;return ($70|0);
}
function _b2PolygonShape_DestroyParticlesInShape_4($particleSystem,$x0,$y0,$x1,$y1,$x2,$y2,$x3,$y3,$xfpX,$xfpY,$xfqS,$xfqC) {
 $particleSystem = $particleSystem|0;
 $x0 = +$x0;
 $y0 = +$y0;
 $x1 = +$x1;
 $y1 = +$y1;
 $x2 = +$x2;
 $y2 = +$y2;
 $x3 = +$x3;
 $y3 = +$y3;
 $xfpX = +$xfpX;
 $xfpY = +$xfpY;
 $xfqS = +$xfqS;
 $xfqC = +$xfqC;
 var $0 = 0.0, $1 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0.0, $2 = 0, $3 = 0.0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0.0, $p = 0;
 var $points = 0, $xf = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $points = sp + 168|0;
 $p = sp + 16|0;
 $xf = sp;
 $0 = $x0;
 $1 = $y0;
 __ZN6b2Vec2C2Eff($points,$0,$1);
 $2 = (($points) + 8|0);
 $3 = $x1;
 $4 = $y1;
 __ZN6b2Vec2C2Eff($2,$3,$4);
 $5 = (($points) + 16|0);
 $6 = $x2;
 $7 = $y2;
 __ZN6b2Vec2C2Eff($5,$6,$7);
 $8 = (($points) + 24|0);
 $9 = $x3;
 $10 = $y3;
 __ZN6b2Vec2C2Eff($8,$9,$10);
 __ZN14b2PolygonShapeC2Ev($p);
 __ZN14b2PolygonShape3SetEPK6b2Vec2i($p,$points,4);
 $11 = $xfpX;
 $12 = $xfpY;
 __ZN6b2Vec23SetEff($xf,$11,$12);
 $13 = $xfqS;
 $14 = (($xf) + 8|0);
 HEAPF32[$14>>2] = $13;
 $15 = $xfqC;
 $16 = (($xf) + 12|0);
 HEAPF32[$16>>2] = $15;
 $17 = (__ZN16b2ParticleSystem23DestroyParticlesInShapeERK7b2ShapeRK11b2Transform($particleSystem,$p,$xf)|0);
 $18 = (+($17|0));
 STACKTOP = sp;return (+$18);
}
function _b2Body_ApplyAngularImpulse($body,$impulse,$wake) {
 $body = $body|0;
 $impulse = +$impulse;
 $wake = +$wake;
 var $0 = 0.0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $impulse;
 $1 = $wake != 0.0;
 __ZN6b2Body19ApplyAngularImpulseEfb($body,$0,$1);
 STACKTOP = sp;return;
}
function __ZN6b2Body19ApplyAngularImpulseEfb($this,$impulse,$wake) {
 $this = $this|0;
 $impulse = +$impulse;
 $wake = $wake|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(2);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 if ($wake) {
  $2 = (($this) + 4|0);
  $3 = HEAP16[$2>>1]|0;
  $4 = $3 & 2;
  $5 = ($4<<16>>16)==(0);
  if ($5) {
   __ZN6b2Body8SetAwakeEb($this,1);
  }
 }
 $6 = (($this) + 4|0);
 $7 = HEAP16[$6>>1]|0;
 $8 = $7 & 2;
 $9 = ($8<<16>>16)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = (($this) + 144|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $11 * $impulse;
 $13 = (($this) + 88|0);
 $14 = +HEAPF32[$13>>2];
 $15 = $14 + $12;
 HEAPF32[$13>>2] = $15;
 STACKTOP = sp;return;
}
function _b2Body_ApplyForce($body,$forceX,$forceY,$pointX,$pointY,$wake) {
 $body = $body|0;
 $forceX = +$forceX;
 $forceY = +$forceY;
 $pointX = +$pointX;
 $pointY = +$pointY;
 $wake = +$wake;
 var $0 = 0, $1 = 0, $2 = 0.0, $3 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = $forceX;
 $3 = $forceY;
 __ZN6b2Vec2C2Eff($0,$2,$3);
 $4 = $pointX;
 $5 = $pointY;
 __ZN6b2Vec2C2Eff($1,$4,$5);
 $6 = $wake != 0.0;
 __ZN6b2Body10ApplyForceERK6b2Vec2S2_b($body,$0,$1,$6);
 STACKTOP = sp;return;
}
function __ZN6b2Body10ApplyForceERK6b2Vec2S2_b($this,$force,$point,$wake) {
 $this = $this|0;
 $force = $force|0;
 $point = $point|0;
 $wake = $wake|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = ($1|0)==(2);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 if ($wake) {
  $3 = (($this) + 4|0);
  $4 = HEAP16[$3>>1]|0;
  $5 = $4 & 2;
  $6 = ($5<<16>>16)==(0);
  if ($6) {
   __ZN6b2Body8SetAwakeEb($this,1);
  }
 }
 $7 = (($this) + 4|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = $8 & 2;
 $10 = ($9<<16>>16)==(0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (($this) + 92|0);
 __ZN6b2Vec2pLERKS_($11,$force);
 $12 = (($this) + 60|0);
 __ZmiRK6b2Vec2S1_($0,$point,$12);
 $13 = (+__Z7b2CrossRK6b2Vec2S1_($0,$force));
 $14 = (($this) + 100|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $13 + $15;
 HEAPF32[$14>>2] = $16;
 STACKTOP = sp;return;
}
function _b2Body_ApplyForceToCenter($body,$forceX,$forceY,$wake) {
 $body = $body|0;
 $forceX = +$forceX;
 $forceY = +$forceY;
 $wake = +$wake;
 var $0 = 0, $1 = 0.0, $2 = 0.0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = $forceX;
 $2 = $forceY;
 __ZN6b2Vec2C2Eff($0,$1,$2);
 $3 = $wake != 0.0;
 __ZN6b2Body18ApplyForceToCenterERK6b2Vec2b($body,$0,$3);
 STACKTOP = sp;return;
}
function __ZN6b2Body18ApplyForceToCenterERK6b2Vec2b($this,$force,$wake) {
 $this = $this|0;
 $force = $force|0;
 $wake = $wake|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(2);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 if ($wake) {
  $2 = (($this) + 4|0);
  $3 = HEAP16[$2>>1]|0;
  $4 = $3 & 2;
  $5 = ($4<<16>>16)==(0);
  if ($5) {
   __ZN6b2Body8SetAwakeEb($this,1);
  }
 }
 $6 = (($this) + 4|0);
 $7 = HEAP16[$6>>1]|0;
 $8 = $7 & 2;
 $9 = ($8<<16>>16)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = (($this) + 92|0);
 __ZN6b2Vec2pLERKS_($10,$force);
 STACKTOP = sp;return;
}
function _b2Body_ApplyTorque($body,$force,$wake) {
 $body = $body|0;
 $force = +$force;
 $wake = +$wake;
 var $0 = 0.0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $force;
 $1 = $wake != 0.0;
 __ZN6b2Body11ApplyTorqueEfb($body,$0,$1);
 STACKTOP = sp;return;
}
function __ZN6b2Body11ApplyTorqueEfb($this,$torque,$wake) {
 $this = $this|0;
 $torque = +$torque;
 $wake = $wake|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(2);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 if ($wake) {
  $2 = (($this) + 4|0);
  $3 = HEAP16[$2>>1]|0;
  $4 = $3 & 2;
  $5 = ($4<<16>>16)==(0);
  if ($5) {
   __ZN6b2Body8SetAwakeEb($this,1);
  }
 }
 $6 = (($this) + 4|0);
 $7 = HEAP16[$6>>1]|0;
 $8 = $7 & 2;
 $9 = ($8<<16>>16)==(0);
 if ($9) {
  STACKTOP = sp;return;
 }
 $10 = (($this) + 100|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $11 + $torque;
 HEAPF32[$10>>2] = $12;
 STACKTOP = sp;return;
}
function _b2Body_DestroyFixture($body,$fixture) {
 $body = $body|0;
 $fixture = $fixture|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6b2Body14DestroyFixtureEP9b2Fixture($body,$fixture);
 STACKTOP = sp;return;
}
function _b2Body_GetAngle($body) {
 $body = $body|0;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+__ZNK6b2Body8GetAngleEv($body));
 $1 = $0;
 STACKTOP = sp;return (+$1);
}
function __ZNK6b2Body8GetAngleEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 72|0);
 $1 = +HEAPF32[$0>>2];
 STACKTOP = sp;return (+$1);
}
function _b2Body_GetAngularVelocity($body) {
 $body = $body|0;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+__ZNK6b2Body18GetAngularVelocityEv($body));
 $1 = $0;
 STACKTOP = sp;return (+$1);
}
function __ZNK6b2Body18GetAngularVelocityEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = +HEAPF32[$0>>2];
 STACKTOP = sp;return (+$1);
}
function _b2Body_GetInertia($body) {
 $body = $body|0;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+__ZNK6b2Body10GetInertiaEv($body));
 $1 = $0;
 STACKTOP = sp;return (+$1);
}
function __ZNK6b2Body10GetInertiaEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0.0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 140|0);
 $1 = +HEAPF32[$0>>2];
 $2 = (($this) + 132|0);
 $3 = +HEAPF32[$2>>2];
 $4 = (($this) + 44|0);
 $5 = (+__Z5b2DotRK6b2Vec2S1_($4,$4));
 $6 = $3 * $5;
 $7 = $1 + $6;
 STACKTOP = sp;return (+$7);
}
function _b2Body_GetLinearVelocity($body,$arr) {
 $body = $body|0;
 $arr = $arr|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0.0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK6b2Body17GetLinearVelocityEv($body)|0);
 $1 = +HEAPF32[$0>>2];
 $2 = (($0) + 4|0);
 $3 = +HEAPF32[$2>>2];
 HEAPF32[$arr>>2] = $1;
 $4 = (($arr) + 4|0);
 HEAPF32[$4>>2] = $3;
 STACKTOP = sp;return;
}
function __ZNK6b2Body17GetLinearVelocityEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 STACKTOP = sp;return ($0|0);
}
function _b2Body_GetLocalPoint($body,$pointX,$pointY,$arr) {
 $body = $body|0;
 $pointX = +$pointX;
 $pointY = +$pointY;
 $arr = $arr|0;
 var $0 = 0, $1 = 0.0, $2 = 0.0, $3 = 0.0, $4 = 0, $5 = 0.0, $6 = 0, $localPoint = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localPoint = sp + 8|0;
 $0 = sp;
 $1 = $pointX;
 $2 = $pointY;
 __ZN6b2Vec2C2Eff($0,$1,$2);
 __ZNK6b2Body13GetLocalPointERK6b2Vec2($localPoint,$body,$0);
 $3 = +HEAPF32[$localPoint>>2];
 HEAPF32[$arr>>2] = $3;
 $4 = (($localPoint) + 4|0);
 $5 = +HEAPF32[$4>>2];
 $6 = (($arr) + 4|0);
 HEAPF32[$6>>2] = $5;
 STACKTOP = sp;return;
}
function __ZNK6b2Body13GetLocalPointERK6b2Vec2($agg$result,$this,$worldPoint) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $worldPoint = $worldPoint|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __Z6b2MulTRK11b2TransformRK6b2Vec2($agg$result,$0,$worldPoint);
 STACKTOP = sp;return;
}
function _b2Body_GetLocalVector($body,$vX,$vY,$arr) {
 $body = $body|0;
 $vX = +$vX;
 $vY = +$vY;
 $arr = $arr|0;
 var $0 = 0, $1 = 0.0, $2 = 0.0, $3 = 0.0, $4 = 0, $5 = 0.0, $6 = 0, $localVector = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $localVector = sp + 8|0;
 $0 = sp;
 $1 = $vX;
 $2 = $vY;
 __ZN6b2Vec2C2Eff($0,$1,$2);
 __ZNK6b2Body13GetLocalPointERK6b2Vec2($localVector,$body,$0);
 $3 = +HEAPF32[$localVector>>2];
 HEAPF32[$arr>>2] = $3;
 $4 = (($localVector) + 4|0);
 $5 = +HEAPF32[$4>>2];
 $6 = (($arr) + 4|0);
 HEAPF32[$6>>2] = $5;
 STACKTOP = sp;return;
}
function _b2Body_GetMass($body) {
 $body = $body|0;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+__ZNK6b2Body7GetMassEv($body));
 $1 = $0;
 STACKTOP = sp;return (+$1);
}
function __ZNK6b2Body7GetMassEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 132|0);
 $1 = +HEAPF32[$0>>2];
 STACKTOP = sp;return (+$1);
}
function _b2Body_GetPosition($body,$arr) {
 $body = $body|0;
 $arr = $arr|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0.0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK6b2Body11GetPositionEv($body)|0);
 $1 = +HEAPF32[$0>>2];
 $2 = (($0) + 4|0);
 $3 = +HEAPF32[$2>>2];
 HEAPF32[$arr>>2] = $1;
 $4 = (($arr) + 4|0);
 HEAPF32[$4>>2] = $3;
 STACKTOP = sp;return;
}
function __ZNK6b2Body11GetPositionEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 STACKTOP = sp;return ($0|0);
}
function _b2Body_GetTransform($body,$arr) {
 $body = $body|0;
 $arr = $arr|0;
 var $0 = 0, $1 = 0.0, $10 = 0, $2 = 0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK6b2Body12GetTransformEv($body)|0);
 $1 = +HEAPF32[$0>>2];
 HEAPF32[$arr>>2] = $1;
 $2 = (($0) + 4|0);
 $3 = +HEAPF32[$2>>2];
 $4 = (($arr) + 4|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($0) + 8|0);
 $6 = +HEAPF32[$5>>2];
 $7 = (($arr) + 8|0);
 HEAPF32[$7>>2] = $6;
 $8 = (($0) + 12|0);
 $9 = +HEAPF32[$8>>2];
 $10 = (($arr) + 12|0);
 HEAPF32[$10>>2] = $9;
 STACKTOP = sp;return;
}
function __ZNK6b2Body12GetTransformEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 STACKTOP = sp;return ($0|0);
}
function _b2Body_GetType($body) {
 $body = $body|0;
 var $0 = 0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK6b2Body7GetTypeEv($body)|0);
 $1 = (+($0>>>0));
 STACKTOP = sp;return (+$1);
}
function __ZNK6b2Body7GetTypeEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function _b2Body_GetWorldCenter($body,$arr) {
 $body = $body|0;
 $arr = $arr|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0.0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK6b2Body14GetWorldCenterEv($body)|0);
 $1 = +HEAPF32[$0>>2];
 $2 = (($0) + 4|0);
 $3 = +HEAPF32[$2>>2];
 HEAPF32[$arr>>2] = $1;
 $4 = (($arr) + 4|0);
 HEAPF32[$4>>2] = $3;
 STACKTOP = sp;return;
}
function __ZNK6b2Body14GetWorldCenterEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 STACKTOP = sp;return ($0|0);
}
function _b2Body_GetWorldPoint($body,$pointX,$pointY,$arr) {
 $body = $body|0;
 $pointX = +$pointX;
 $pointY = +$pointY;
 $arr = $arr|0;
 var $0 = 0, $1 = 0.0, $2 = 0.0, $3 = 0.0, $4 = 0, $5 = 0.0, $6 = 0, $worldPoint = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $worldPoint = sp + 8|0;
 $0 = sp;
 $1 = $pointX;
 $2 = $pointY;
 __ZN6b2Vec2C2Eff($0,$1,$2);
 __ZNK6b2Body13GetWorldPointERK6b2Vec2($worldPoint,$body,$0);
 $3 = +HEAPF32[$worldPoint>>2];
 HEAPF32[$arr>>2] = $3;
 $4 = (($worldPoint) + 4|0);
 $5 = +HEAPF32[$4>>2];
 $6 = (($arr) + 4|0);
 HEAPF32[$6>>2] = $5;
 STACKTOP = sp;return;
}
function __ZNK6b2Body13GetWorldPointERK6b2Vec2($agg$result,$this,$localPoint) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $localPoint = $localPoint|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __Z5b2MulRK11b2TransformRK6b2Vec2($agg$result,$0,$localPoint);
 STACKTOP = sp;return;
}
function _b2Body_GetWorldVector($body,$vX,$vY,$arr) {
 $body = $body|0;
 $vX = +$vX;
 $vY = +$vY;
 $arr = $arr|0;
 var $0 = 0, $1 = 0.0, $2 = 0.0, $3 = 0.0, $4 = 0, $5 = 0.0, $6 = 0, $worldVec = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $worldVec = sp + 8|0;
 $0 = sp;
 $1 = $vX;
 $2 = $vY;
 __ZN6b2Vec2C2Eff($0,$1,$2);
 __ZNK6b2Body13GetWorldPointERK6b2Vec2($worldVec,$body,$0);
 $3 = +HEAPF32[$worldVec>>2];
 HEAPF32[$arr>>2] = $3;
 $4 = (($worldVec) + 4|0);
 $5 = +HEAPF32[$4>>2];
 $6 = (($arr) + 4|0);
 HEAPF32[$6>>2] = $5;
 STACKTOP = sp;return;
}
function _b2Body_SetAwake($body,$flag) {
 $body = $body|0;
 $flag = +$flag;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $flag != 0.0;
 __ZN6b2Body8SetAwakeEb($body,$0);
 STACKTOP = sp;return;
}
function __ZN6b2Body8SetAwakeEb($this,$flag) {
 $this = $this|0;
 $flag = $flag|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1&65535;
 if (!($flag)) {
  $8 = $2 & 65533;
  $9 = $8&65535;
  HEAP16[$0>>1] = $9;
  $10 = (($this) + 160|0);
  HEAPF32[$10>>2] = 0.0;
  $11 = (($this) + 80|0);
  __ZN6b2Vec27SetZeroEv($11);
  $12 = (($this) + 88|0);
  HEAPF32[$12>>2] = 0.0;
  $13 = (($this) + 92|0);
  __ZN6b2Vec27SetZeroEv($13);
  $14 = (($this) + 100|0);
  HEAPF32[$14>>2] = 0.0;
  STACKTOP = sp;return;
 }
 $3 = $2 & 2;
 $4 = ($3|0)==(0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = $2 | 2;
 $6 = $5&65535;
 HEAP16[$0>>1] = $6;
 $7 = (($this) + 160|0);
 HEAPF32[$7>>2] = 0.0;
 STACKTOP = sp;return;
}
function _b2Body_SetAngularVelocity($body,$angle) {
 $body = $body|0;
 $angle = +$angle;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $angle;
 __ZN6b2Body18SetAngularVelocityEf($body,$0);
 STACKTOP = sp;return;
}
function __ZN6b2Body18SetAngularVelocityEf($this,$w) {
 $this = $this|0;
 $w = +$w;
 var $0 = 0, $1 = 0, $2 = 0.0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = $w * $w;
 $3 = $2 > 0.0;
 if ($3) {
  __ZN6b2Body8SetAwakeEb($this,1);
 }
 $4 = (($this) + 88|0);
 HEAPF32[$4>>2] = $w;
 STACKTOP = sp;return;
}
function _b2Body_SetLinearVelocity($body,$x,$y) {
 $body = $body|0;
 $x = +$x;
 $y = +$y;
 var $0 = 0, $1 = 0.0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = $x;
 $2 = $y;
 __ZN6b2Vec2C2Eff($0,$1,$2);
 __ZN6b2Body17SetLinearVelocityERK6b2Vec2($body,$0);
 STACKTOP = sp;return;
}
function __ZN6b2Body17SetLinearVelocityERK6b2Vec2($this,$v) {
 $this = $this|0;
 $v = $v|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0.0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (+__Z5b2DotRK6b2Vec2S1_($v,$v));
 $3 = $2 > 0.0;
 if ($3) {
  __ZN6b2Body8SetAwakeEb($this,1);
 }
 $4 = (($this) + 80|0);
 $5 = $v;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $4;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 STACKTOP = sp;return;
}
function _b2Body_SetMassData($body,$mass,$centerX,$centerY,$inertia) {
 $body = $body|0;
 $mass = +$mass;
 $centerX = +$centerX;
 $centerY = +$centerY;
 $inertia = +$inertia;
 var $0 = 0.0, $1 = 0, $2 = 0.0, $3 = 0.0, $4 = 0.0, $5 = 0, $m = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $m = sp;
 $0 = $mass;
 HEAPF32[$m>>2] = $0;
 $1 = (($m) + 4|0);
 $2 = $centerX;
 $3 = $centerY;
 __ZN6b2Vec23SetEff($1,$2,$3);
 $4 = $inertia;
 $5 = (($m) + 12|0);
 HEAPF32[$5>>2] = $4;
 __ZN6b2Body11SetMassDataEPK10b2MassData($body,$m);
 STACKTOP = sp;return;
}
function _b2Body_SetTransform($body,$x,$y,$angle) {
 $body = $body|0;
 $x = +$x;
 $y = +$y;
 $angle = +$angle;
 var $0 = 0, $1 = 0.0, $2 = 0.0, $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = $x;
 $2 = $y;
 __ZN6b2Vec2C2Eff($0,$1,$2);
 $3 = $angle;
 __ZN6b2Body12SetTransformERK6b2Vec2f($body,$0,$3);
 STACKTOP = sp;return;
}
function _b2Body_SetType($body,$type) {
 $body = $body|0;
 $type = +$type;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (~~(($type))>>>0);
 __ZN6b2Body7SetTypeE10b2BodyType($body,$0);
 STACKTOP = sp;return;
}
function _b2Fixture_TestPoint($fixture,$x,$y) {
 $fixture = $fixture|0;
 $x = +$x;
 $y = +$y;
 var $0 = 0, $1 = 0.0, $2 = 0.0, $3 = 0, $4 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = $x;
 $2 = $y;
 __ZN6b2Vec2C2Eff($0,$1,$2);
 $3 = (__ZNK9b2Fixture9TestPointERK6b2Vec2($fixture,$0)|0);
 $4 = (+($3&1));
 STACKTOP = sp;return (+$4);
}
function __ZNK9b2Fixture9TestPointERK6b2Vec2($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__ZNK6b2Body12GetTransformEv($6)|0);
 $8 = (FUNCTION_TABLE_iiii[$4 & 15]($1,$7,$p)|0);
 STACKTOP = sp;return ($8|0);
}
function ___cxx_global_var_init() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN22b2WorldContactListenerC2Ev(8);
 STACKTOP = sp;return;
}
function __ZN22b2WorldContactListenerC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17b2ContactListenerC2Ev($this);
 HEAP32[$this>>2] = ((1376 + 8|0));
 STACKTOP = sp;return;
}
function __ZN17b2ContactListenerD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function ___cxx_global_var_init1() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17QueryAABBCallbackC2Ev(16);
 STACKTOP = sp;return;
}
function __ZN17QueryAABBCallbackC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN15b2QueryCallbackC2Ev($this);
 HEAP32[$this>>2] = ((1240 + 8|0));
 STACKTOP = sp;return;
}
function __ZN15b2QueryCallbackD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function ___cxx_global_var_init2() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN15RayCastCallbackC2Ev(24);
 STACKTOP = sp;return;
}
function __ZN15RayCastCallbackC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN17b2RayCastCallbackC2Ev($this);
 HEAP32[$this>>2] = ((1104 + 8|0));
 STACKTOP = sp;return;
}
function _b2World_Create($x,$y) {
 $x = +$x;
 $y = +$y;
 var $0 = 0, $1 = 0, $2 = 0.0, $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__Znwj(103048)|0);
 $2 = $x;
 $3 = $y;
 __ZN6b2Vec2C2Eff($0,$2,$3);
 __ZN7b2WorldC2ERK6b2Vec2($1,$0);
 STACKTOP = sp;return ($1|0);
}
function _b2World_CreateBody($world,$active,$allowSleep,$angle,$angularVelocity,$angularDamping,$awake,$bullet,$fixedRotation,$gravityScale,$linearDamping,$linearVelocityX,$linearVelocityY,$positionX,$positionY,$type,$userData) {
 $world = $world|0;
 $active = +$active;
 $allowSleep = +$allowSleep;
 $angle = +$angle;
 $angularVelocity = +$angularVelocity;
 $angularDamping = +$angularDamping;
 $awake = +$awake;
 $bullet = +$bullet;
 $fixedRotation = +$fixedRotation;
 $gravityScale = +$gravityScale;
 $linearDamping = +$linearDamping;
 $linearVelocityX = +$linearVelocityX;
 $linearVelocityY = +$linearVelocityY;
 $positionX = +$positionX;
 $positionY = +$positionY;
 $type = +$type;
 $userData = $userData|0;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0.0;
 var $27 = 0.0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, $def = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $def = sp;
 __ZN9b2BodyDefC2Ev($def);
 $0 = $active != 0.0;
 $1 = (($def) + 40|0);
 $2 = $0&1;
 HEAP8[$1>>0] = $2;
 $3 = $allowSleep != 0.0;
 $4 = (($def) + 36|0);
 $5 = $3&1;
 HEAP8[$4>>0] = $5;
 $6 = $angle;
 $7 = (($def) + 12|0);
 HEAPF32[$7>>2] = $6;
 $8 = $angularVelocity;
 $9 = (($def) + 24|0);
 HEAPF32[$9>>2] = $8;
 $10 = $angularDamping;
 $11 = (($def) + 32|0);
 HEAPF32[$11>>2] = $10;
 $12 = $awake != 0.0;
 $13 = (($def) + 37|0);
 $14 = $12&1;
 HEAP8[$13>>0] = $14;
 $15 = $bullet != 0.0;
 $16 = (($def) + 39|0);
 $17 = $15&1;
 HEAP8[$16>>0] = $17;
 $18 = $fixedRotation != 0.0;
 $19 = (($def) + 38|0);
 $20 = $18&1;
 HEAP8[$19>>0] = $20;
 $21 = $gravityScale;
 $22 = (($def) + 48|0);
 HEAPF32[$22>>2] = $21;
 $23 = $linearDamping;
 $24 = (($def) + 28|0);
 HEAPF32[$24>>2] = $23;
 $25 = (($def) + 16|0);
 $26 = $linearVelocityX;
 $27 = $linearVelocityY;
 __ZN6b2Vec23SetEff($25,$26,$27);
 $28 = (($def) + 4|0);
 $29 = $positionX;
 $30 = $positionY;
 __ZN6b2Vec23SetEff($28,$29,$30);
 $31 = (~~(($type))>>>0);
 HEAP32[$def>>2] = $31;
 $32 = (($def) + 44|0);
 HEAP32[$32>>2] = $userData;
 $33 = (__ZN7b2World10CreateBodyEPK9b2BodyDef($world,$def)|0);
 STACKTOP = sp;return ($33|0);
}
function __ZN9b2BodyDefC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = (($this) + 16|0);
 $2 = (($this) + 44|0);
 HEAP32[$2>>2] = 0;
 __ZN6b2Vec23SetEff($0,0.0,0.0);
 $3 = (($this) + 12|0);
 HEAPF32[$3>>2] = 0.0;
 __ZN6b2Vec23SetEff($1,0.0,0.0);
 $4 = (($this) + 24|0);
 HEAPF32[$4>>2] = 0.0;
 $5 = (($this) + 28|0);
 HEAPF32[$5>>2] = 0.0;
 $6 = (($this) + 32|0);
 HEAPF32[$6>>2] = 0.0;
 $7 = (($this) + 36|0);
 HEAP8[$7>>0] = 1;
 $8 = (($this) + 37|0);
 HEAP8[$8>>0] = 1;
 $9 = (($this) + 38|0);
 HEAP8[$9>>0] = 0;
 $10 = (($this) + 39|0);
 HEAP8[$10>>0] = 0;
 HEAP32[$this>>2] = 0;
 $11 = (($this) + 40|0);
 HEAP8[$11>>0] = 1;
 $12 = (($this) + 48|0);
 HEAPF32[$12>>2] = 1.0;
 STACKTOP = sp;return;
}
function _b2World_CreateParticleSystem($world,$colorMixingStrength,$dampingStrength,$destroyByAge,$ejectionStrength,$elasticStrength,$lifetimeGranularity,$powderStrength,$pressureStrength,$radius,$repulsiveStrength,$springStrength,$staticPressureIterations,$staticPressureRelaxation,$staticPressureStrength,$surfaceTensionNormalStrength,$surfaceTensionPressureStrength,$viscousStrength) {
 $world = $world|0;
 $colorMixingStrength = +$colorMixingStrength;
 $dampingStrength = +$dampingStrength;
 $destroyByAge = +$destroyByAge;
 $ejectionStrength = +$ejectionStrength;
 $elasticStrength = +$elasticStrength;
 $lifetimeGranularity = +$lifetimeGranularity;
 $powderStrength = +$powderStrength;
 $pressureStrength = +$pressureStrength;
 $radius = +$radius;
 $repulsiveStrength = +$repulsiveStrength;
 $springStrength = +$springStrength;
 $staticPressureIterations = +$staticPressureIterations;
 $staticPressureRelaxation = +$staticPressureRelaxation;
 $staticPressureStrength = +$staticPressureStrength;
 $surfaceTensionNormalStrength = +$surfaceTensionNormalStrength;
 $surfaceTensionPressureStrength = +$surfaceTensionPressureStrength;
 $viscousStrength = +$viscousStrength;
 var $0 = 0.0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0.0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0;
 var $27 = 0.0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0.0, $def = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $def = sp;
 __ZN19b2ParticleSystemDefC2Ev($def);
 $0 = $colorMixingStrength;
 $1 = (($def) + 72|0);
 HEAPF32[$1>>2] = $0;
 $2 = $dampingStrength;
 $3 = (($def) + 24|0);
 HEAPF32[$3>>2] = $2;
 $4 = $destroyByAge != 0.0;
 $5 = (($def) + 76|0);
 $6 = $4&1;
 HEAP8[$5>>0] = $6;
 $7 = $ejectionStrength;
 $8 = (($def) + 56|0);
 HEAPF32[$8>>2] = $7;
 $9 = $elasticStrength;
 $10 = (($def) + 28|0);
 HEAPF32[$10>>2] = $9;
 $11 = $lifetimeGranularity;
 $12 = (($def) + 80|0);
 HEAPF32[$12>>2] = $11;
 $13 = $powderStrength;
 $14 = (($def) + 52|0);
 HEAPF32[$14>>2] = $13;
 $15 = $pressureStrength;
 $16 = (($def) + 20|0);
 HEAPF32[$16>>2] = $15;
 $17 = $radius;
 $18 = (($def) + 12|0);
 HEAPF32[$18>>2] = $17;
 $19 = $repulsiveStrength;
 $20 = (($def) + 48|0);
 HEAPF32[$20>>2] = $19;
 $21 = $springStrength;
 $22 = (($def) + 32|0);
 HEAPF32[$22>>2] = $21;
 $23 = (~~(($staticPressureIterations)));
 $24 = (($def) + 68|0);
 HEAP32[$24>>2] = $23;
 $25 = $staticPressureRelaxation;
 $26 = (($def) + 64|0);
 HEAPF32[$26>>2] = $25;
 $27 = $staticPressureStrength;
 $28 = (($def) + 60|0);
 HEAPF32[$28>>2] = $27;
 $29 = $surfaceTensionNormalStrength;
 $30 = (($def) + 44|0);
 HEAPF32[$30>>2] = $29;
 $31 = $surfaceTensionPressureStrength;
 $32 = (($def) + 40|0);
 HEAPF32[$32>>2] = $31;
 $33 = $viscousStrength;
 $34 = (($def) + 36|0);
 HEAPF32[$34>>2] = $33;
 $35 = (__ZN7b2World20CreateParticleSystemEPK19b2ParticleSystemDef($world,$def)|0);
 STACKTOP = sp;return ($35|0);
}
function __ZN19b2ParticleSystemDefC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP8[$this>>0] = 0;
 $0 = (($this) + 4|0);
 HEAPF32[$0>>2] = 1.0;
 $1 = (($this) + 8|0);
 HEAPF32[$1>>2] = 1.0;
 $2 = (($this) + 12|0);
 HEAPF32[$2>>2] = 1.0;
 $3 = (($this) + 16|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 20|0);
 HEAPF32[$4>>2] = 0.05000000074505806;
 $5 = (($this) + 24|0);
 HEAPF32[$5>>2] = 1.0;
 $6 = (($this) + 28|0);
 HEAPF32[$6>>2] = 0.25;
 $7 = (($this) + 32|0);
 HEAPF32[$7>>2] = 0.25;
 $8 = (($this) + 36|0);
 HEAPF32[$8>>2] = 0.25;
 $9 = (($this) + 40|0);
 HEAPF32[$9>>2] = 0.20000000298023224;
 $10 = (($this) + 44|0);
 HEAPF32[$10>>2] = 0.20000000298023224;
 $11 = (($this) + 48|0);
 HEAPF32[$11>>2] = 1.0;
 $12 = (($this) + 52|0);
 HEAPF32[$12>>2] = 0.5;
 $13 = (($this) + 56|0);
 HEAPF32[$13>>2] = 0.5;
 $14 = (($this) + 60|0);
 HEAPF32[$14>>2] = 0.20000000298023224;
 $15 = (($this) + 64|0);
 HEAPF32[$15>>2] = 0.20000000298023224;
 $16 = (($this) + 68|0);
 HEAP32[$16>>2] = 8;
 $17 = (($this) + 72|0);
 HEAPF32[$17>>2] = 0.5;
 $18 = (($this) + 76|0);
 HEAP8[$18>>0] = 1;
 $19 = (($this) + 80|0);
 HEAPF32[$19>>2] = 0.01666666753590107;
 STACKTOP = sp;return;
}
function _b2World_Delete($world) {
 $world = $world|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($world|0)==(0|0);
 if (!($0)) {
  __ZN7b2WorldD2Ev($world);
  __ZdlPv($world);
 }
 STACKTOP = sp;return;
}
function _b2World_DestroyBody($world,$body) {
 $world = $world|0;
 $body = $body|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7b2World11DestroyBodyEP6b2Body($world,$body);
 STACKTOP = sp;return;
}
function _b2World_DestroyJoint($world,$joint) {
 $world = $world|0;
 $joint = $joint|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7b2World12DestroyJointEP7b2Joint($world,$joint);
 STACKTOP = sp;return;
}
function _b2World_DestroyParticleSystem($world,$particleSystem) {
 $world = $world|0;
 $particleSystem = $particleSystem|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7b2World21DestroyParticleSystemEP16b2ParticleSystem($world,$particleSystem);
 STACKTOP = sp;return;
}
function _b2World_QueryAABB($world,$aabbLowerBoundX,$aabbLowerBoundY,$aabbUpperBoundX,$aabbUpperBoundY) {
 $world = $world|0;
 $aabbLowerBoundX = +$aabbLowerBoundX;
 $aabbLowerBoundY = +$aabbLowerBoundY;
 $aabbUpperBoundX = +$aabbUpperBoundX;
 $aabbUpperBoundY = +$aabbUpperBoundY;
 var $0 = 0, $1 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0.0, $3 = 0, $4 = 0.0, $5 = 0.0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $aabb = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $aabb = sp + 8|0;
 $0 = sp;
 $1 = $aabbLowerBoundX;
 $2 = $aabbLowerBoundY;
 __ZN6b2Vec2C2Eff($aabb,$1,$2);
 $3 = (($aabb) + 8|0);
 $4 = $aabbUpperBoundX;
 $5 = $aabbUpperBoundY;
 __ZN6b2Vec2C2Eff($0,$4,$5);
 $6 = $0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $3;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 __ZNK7b2World9QueryAABBEP15b2QueryCallbackRK6b2AABB($world,16,$aabb);
 STACKTOP = sp;return;
}
function _b2World_RayCast($world,$point1X,$point1Y,$point2X,$point2Y) {
 $world = $world|0;
 $point1X = +$point1X;
 $point1Y = +$point1Y;
 $point2X = +$point2X;
 $point2Y = +$point2Y;
 var $0 = 0, $1 = 0, $2 = 0.0, $3 = 0.0, $4 = 0.0, $5 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = $point1X;
 $3 = $point1Y;
 __ZN6b2Vec2C2Eff($0,$2,$3);
 $4 = $point2X;
 $5 = $point2Y;
 __ZN6b2Vec2C2Eff($1,$4,$5);
 __ZNK7b2World7RayCastEP17b2RayCastCallbackRK6b2Vec2S4_($world,24,$0,$1);
 STACKTOP = sp;return;
}
function _b2World_SetContactListener($world) {
 $world = $world|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7b2World18SetContactListenerEP17b2ContactListener($world,8);
 STACKTOP = sp;return;
}
function _b2World_SetGravity($world,$x,$y) {
 $world = $world|0;
 $x = +$x;
 $y = +$y;
 var $0 = 0, $1 = 0.0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = $x;
 $2 = $y;
 __ZN6b2Vec2C2Eff($0,$1,$2);
 __ZN7b2World10SetGravityERK6b2Vec2($world,$0);
 STACKTOP = sp;return;
}
function __ZN7b2World10SetGravityERK6b2Vec2($this,$gravity) {
 $this = $this|0;
 $gravity = $gravity|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 102980|0);
 $1 = $gravity;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 STACKTOP = sp;return;
}
function _b2World_Step($world,$step,$vIterations,$pIterations) {
 $world = $world|0;
 $step = +$step;
 $vIterations = +$vIterations;
 $pIterations = +$pIterations;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (~~(($vIterations)));
 $1 = (~~(($pIterations)));
 __ZN7b2World4StepEfiii($world,$step,$0,$1,3);
 STACKTOP = sp;return;
}
function _b2Contact_GetManifold($contact) {
 $contact = $contact|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN9b2Contact11GetManifoldEv($contact)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN9b2Contact11GetManifoldEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 64|0);
 STACKTOP = sp;return ($0|0);
}
function _b2Contact_GetWorldManifold($contact) {
 $contact = $contact|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNK9b2Contact16GetWorldManifoldEP15b2WorldManifold($contact,32);
 STACKTOP = sp;return (32|0);
}
function __ZNK9b2Contact16GetWorldManifoldEP15b2WorldManifold($this,$worldManifold) {
 $this = $this|0;
 $worldManifold = $worldManifold|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN9b2Fixture7GetBodyEv($1)|0);
 $3 = (($this) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZN9b2Fixture7GetBodyEv($4)|0);
 $6 = (__ZN9b2Fixture8GetShapeEv($1)|0);
 $7 = (__ZN9b2Fixture8GetShapeEv($4)|0);
 $8 = (($this) + 64|0);
 $9 = (__ZNK6b2Body12GetTransformEv($2)|0);
 $10 = (($6) + 8|0);
 $11 = +HEAPF32[$10>>2];
 $12 = (__ZNK6b2Body12GetTransformEv($5)|0);
 $13 = (($7) + 8|0);
 $14 = +HEAPF32[$13>>2];
 __ZN15b2WorldManifold10InitializeEPK10b2ManifoldRK11b2TransformfS5_f($worldManifold,$8,$9,$11,$12,$14);
 STACKTOP = sp;return;
}
function _b2DistanceJointDef_Create($world,$bodyA,$bodyB,$collideConnected,$dampingRatio,$frequencyHz,$length,$localAnchorAx,$localAnchorAy,$localAnchorBx,$localAnchorBy) {
 $world = $world|0;
 $bodyA = $bodyA|0;
 $bodyB = $bodyB|0;
 $collideConnected = +$collideConnected;
 $dampingRatio = +$dampingRatio;
 $frequencyHz = +$frequencyHz;
 $length = +$length;
 $localAnchorAx = +$localAnchorAx;
 $localAnchorAy = +$localAnchorAy;
 $localAnchorBx = +$localAnchorBx;
 $localAnchorBy = +$localAnchorBy;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0.0;
 var $def = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $def = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 __ZN18b2DistanceJointDefC2Ev($def);
 $2 = (($def) + 8|0);
 HEAP32[$2>>2] = $bodyA;
 $3 = (($def) + 12|0);
 HEAP32[$3>>2] = $bodyB;
 $4 = $collideConnected != 0.0;
 $5 = (($def) + 16|0);
 $6 = $4&1;
 HEAP8[$5>>0] = $6;
 $7 = $dampingRatio;
 $8 = (($def) + 44|0);
 HEAPF32[$8>>2] = $7;
 $9 = $frequencyHz;
 $10 = (($def) + 40|0);
 HEAPF32[$10>>2] = $9;
 $11 = $length;
 $12 = (($def) + 36|0);
 HEAPF32[$12>>2] = $11;
 $13 = (($def) + 20|0);
 $14 = $localAnchorAx;
 $15 = $localAnchorAy;
 __ZN6b2Vec2C2Eff($0,$14,$15);
 $16 = $0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16) + 4)|0;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = $13;
 $23 = $22;
 HEAP32[$23>>2] = $18;
 $24 = (($22) + 4)|0;
 $25 = $24;
 HEAP32[$25>>2] = $21;
 $26 = (($def) + 28|0);
 $27 = $localAnchorBx;
 $28 = $localAnchorBy;
 __ZN6b2Vec2C2Eff($1,$27,$28);
 $29 = $1;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = (($29) + 4)|0;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = $26;
 $36 = $35;
 HEAP32[$36>>2] = $31;
 $37 = (($35) + 4)|0;
 $38 = $37;
 HEAP32[$38>>2] = $34;
 $39 = (__ZN7b2World11CreateJointEPK10b2JointDef($world,$def)|0);
 STACKTOP = sp;return ($39|0);
}
function __ZN18b2DistanceJointDefC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10b2JointDefC2Ev($this);
 $0 = (($this) + 20|0);
 $1 = (($this) + 28|0);
 HEAP32[$this>>2] = 3;
 __ZN6b2Vec23SetEff($0,0.0,0.0);
 __ZN6b2Vec23SetEff($1,0.0,0.0);
 $2 = (($this) + 36|0);
 HEAPF32[$2>>2] = 1.0;
 $3 = (($this) + 40|0);
 HEAPF32[$3>>2] = 0.0;
 $4 = (($this) + 44|0);
 HEAPF32[$4>>2] = 0.0;
 STACKTOP = sp;return;
}
function _b2DistanceJointDef_InitializeAndCreate($world,$bodyA,$bodyB,$anchorAx,$anchorAy,$anchorBx,$anchorBy,$collideConnected,$dampingRatio,$frequencyHz) {
 $world = $world|0;
 $bodyA = $bodyA|0;
 $bodyB = $bodyB|0;
 $anchorAx = +$anchorAx;
 $anchorAy = +$anchorAy;
 $anchorBx = +$anchorBx;
 $anchorBy = +$anchorBy;
 $collideConnected = +$collideConnected;
 $dampingRatio = +$dampingRatio;
 $frequencyHz = +$frequencyHz;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0.0, $def = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $def = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 __ZN18b2DistanceJointDefC2Ev($def);
 $2 = $collideConnected != 0.0;
 $3 = (($def) + 16|0);
 $4 = $2&1;
 HEAP8[$3>>0] = $4;
 $5 = $dampingRatio;
 $6 = (($def) + 44|0);
 HEAPF32[$6>>2] = $5;
 $7 = $frequencyHz;
 $8 = (($def) + 40|0);
 HEAPF32[$8>>2] = $7;
 $9 = $anchorAx;
 $10 = $anchorAy;
 __ZN6b2Vec2C2Eff($0,$9,$10);
 $11 = $anchorBx;
 $12 = $anchorBy;
 __ZN6b2Vec2C2Eff($1,$11,$12);
 __ZN18b2DistanceJointDef10InitializeEP6b2BodyS1_RK6b2Vec2S4_($def,$bodyA,$bodyB,$0,$1);
 $13 = (__ZN7b2World11CreateJointEPK10b2JointDef($world,$def)|0);
 STACKTOP = sp;return ($13|0);
}
function _b2FrictionJointDef_Create($world,$bodyA,$bodyB,$collideConnected,$localAnchorAx,$localAnchorAy,$localAnchorBx,$localAnchorBy,$maxForce,$maxTorque) {
 $world = $world|0;
 $bodyA = $bodyA|0;
 $bodyB = $bodyB|0;
 $collideConnected = +$collideConnected;
 $localAnchorAx = +$localAnchorAx;
 $localAnchorAy = +$localAnchorAy;
 $localAnchorBx = +$localAnchorBx;
 $localAnchorBy = +$localAnchorBy;
 $maxForce = +$maxForce;
 $maxTorque = +$maxTorque;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0.0, $def = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $def = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 __ZN18b2FrictionJointDefC2Ev($def);
 $2 = (($def) + 8|0);
 HEAP32[$2>>2] = $bodyA;
 $3 = (($def) + 12|0);
 HEAP32[$3>>2] = $bodyB;
 $4 = $collideConnected != 0.0;
 $5 = (($def) + 16|0);
 $6 = $4&1;
 HEAP8[$5>>0] = $6;
 $7 = (($def) + 20|0);
 $8 = $localAnchorAx;
 $9 = $localAnchorAy;
 __ZN6b2Vec2C2Eff($0,$8,$9);
 $10 = $0;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 4)|0;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = $7;
 $17 = $16;
 HEAP32[$17>>2] = $12;
 $18 = (($16) + 4)|0;
 $19 = $18;
 HEAP32[$19>>2] = $15;
 $20 = (($def) + 28|0);
 $21 = $localAnchorBx;
 $22 = $localAnchorBy;
 __ZN6b2Vec2C2Eff($1,$21,$22);
 $23 = $1;
 $24 = $23;
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23) + 4)|0;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = $20;
 $30 = $29;
 HEAP32[$30>>2] = $25;
 $31 = (($29) + 4)|0;
 $32 = $31;
 HEAP32[$32>>2] = $28;
 $33 = $maxForce;
 $34 = (($def) + 36|0);
 HEAPF32[$34>>2] = $33;
 $35 = $maxTorque;
 $36 = (($def) + 40|0);
 HEAPF32[$36>>2] = $35;
 $37 = (__ZN7b2World11CreateJointEPK10b2JointDef($world,$def)|0);
 STACKTOP = sp;return ($37|0);
}
function __ZN18b2FrictionJointDefC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10b2JointDefC2Ev($this);
 $0 = (($this) + 20|0);
 $1 = (($this) + 28|0);
 HEAP32[$this>>2] = 9;
 __ZN6b2Vec27SetZeroEv($0);
 __ZN6b2Vec27SetZeroEv($1);
 $2 = (($this) + 36|0);
 HEAPF32[$2>>2] = 0.0;
 $3 = (($this) + 40|0);
 HEAPF32[$3>>2] = 0.0;
 STACKTOP = sp;return;
}
function _b2FrictionJointDef_InitializeAndCreate($world,$bodyA,$bodyB,$anchorX,$anchorY,$collideConnected,$maxForce,$maxTorque) {
 $world = $world|0;
 $bodyA = $bodyA|0;
 $bodyB = $bodyB|0;
 $anchorX = +$anchorX;
 $anchorY = +$anchorY;
 $collideConnected = +$collideConnected;
 $maxForce = +$maxForce;
 $maxTorque = +$maxTorque;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, $fJoint = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $fJoint = sp + 8|0;
 $0 = sp;
 __ZN18b2FrictionJointDefC2Ev($fJoint);
 $1 = $collideConnected != 0.0;
 $2 = (($fJoint) + 16|0);
 $3 = $1&1;
 HEAP8[$2>>0] = $3;
 $4 = $maxForce;
 $5 = (($fJoint) + 36|0);
 HEAPF32[$5>>2] = $4;
 $6 = $maxTorque;
 $7 = (($fJoint) + 40|0);
 HEAPF32[$7>>2] = $6;
 $8 = $anchorX;
 $9 = $anchorY;
 __ZN6b2Vec2C2Eff($0,$8,$9);
 __ZN18b2FrictionJointDef10InitializeEP6b2BodyS1_RK6b2Vec2($fJoint,$bodyA,$bodyB,$0);
 $10 = (__ZN7b2World11CreateJointEPK10b2JointDef($world,$fJoint)|0);
 STACKTOP = sp;return ($10|0);
}
function _b2GearJoint_GetRatio($joint) {
 $joint = $joint|0;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+__ZNK11b2GearJoint8GetRatioEv($joint));
 $1 = $0;
 STACKTOP = sp;return (+$1);
}
function _b2GearJointDef_Create($world,$bodyA,$bodyB,$collideConnected,$joint1,$joint2,$ratio) {
 $world = $world|0;
 $bodyA = $bodyA|0;
 $bodyB = $bodyB|0;
 $collideConnected = +$collideConnected;
 $joint1 = $joint1|0;
 $joint2 = $joint2|0;
 $ratio = +$ratio;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0, $def = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $def = sp;
 __ZN14b2GearJointDefC2Ev($def);
 $0 = (($def) + 8|0);
 HEAP32[$0>>2] = $bodyA;
 $1 = (($def) + 12|0);
 HEAP32[$1>>2] = $bodyB;
 $2 = $collideConnected != 0.0;
 $3 = (($def) + 16|0);
 $4 = $2&1;
 HEAP8[$3>>0] = $4;
 $5 = (($def) + 20|0);
 HEAP32[$5>>2] = $joint1;
 $6 = (($def) + 24|0);
 HEAP32[$6>>2] = $joint2;
 $7 = $ratio;
 $8 = (($def) + 28|0);
 HEAPF32[$8>>2] = $7;
 $9 = (__ZN7b2World11CreateJointEPK10b2JointDef($world,$def)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZN14b2GearJointDefC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10b2JointDefC2Ev($this);
 HEAP32[$this>>2] = 6;
 $0 = (($this) + 20|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 24|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 28|0);
 HEAPF32[$2>>2] = 1.0;
 STACKTOP = sp;return;
}
function _b2Joint_GetBodyA($joint) {
 $joint = $joint|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN7b2Joint8GetBodyAEv($joint)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN7b2Joint8GetBodyAEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function _b2Joint_GetBodyB($joint) {
 $joint = $joint|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN7b2Joint8GetBodyBEv($joint)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN7b2Joint8GetBodyBEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function _b2MotorJoint_SetAngularOffset($motorJoint,$angle) {
 $motorJoint = $motorJoint|0;
 $angle = +$angle;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $angle;
 __ZN12b2MotorJoint16SetAngularOffsetEf($motorJoint,$0);
 STACKTOP = sp;return;
}
function _b2MotorJoint_SetLinearOffset($motorJoint,$x,$y) {
 $motorJoint = $motorJoint|0;
 $x = +$x;
 $y = +$y;
 var $0 = 0, $1 = 0.0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = $x;
 $2 = $y;
 __ZN6b2Vec2C2Eff($0,$1,$2);
 __ZN12b2MotorJoint15SetLinearOffsetERK6b2Vec2($motorJoint,$0);
 STACKTOP = sp;return;
}
function _b2MotorJointDef_Create($world,$bodyA,$bodyB,$collideConnected,$angularOffset,$correctionFactor,$linearOffsetX,$linearOffsetY,$maxForce,$maxTorque) {
 $world = $world|0;
 $bodyA = $bodyA|0;
 $bodyB = $bodyB|0;
 $collideConnected = +$collideConnected;
 $angularOffset = +$angularOffset;
 $correctionFactor = +$correctionFactor;
 $linearOffsetX = +$linearOffsetX;
 $linearOffsetY = +$linearOffsetY;
 $maxForce = +$maxForce;
 $maxTorque = +$maxTorque;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0.0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, $def = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $def = sp + 8|0;
 $0 = sp;
 __ZN15b2MotorJointDefC2Ev($def);
 $1 = (($def) + 8|0);
 HEAP32[$1>>2] = $bodyA;
 $2 = (($def) + 12|0);
 HEAP32[$2>>2] = $bodyB;
 $3 = $collideConnected != 0.0;
 $4 = (($def) + 16|0);
 $5 = $3&1;
 HEAP8[$4>>0] = $5;
 $6 = $angularOffset;
 $7 = (($def) + 28|0);
 HEAPF32[$7>>2] = $6;
 $8 = $correctionFactor;
 $9 = (($def) + 40|0);
 HEAPF32[$9>>2] = $8;
 $10 = (($def) + 20|0);
 $11 = $linearOffsetX;
 $12 = $linearOffsetY;
 __ZN6b2Vec2C2Eff($0,$11,$12);
 $13 = $0;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 4)|0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = $10;
 $20 = $19;
 HEAP32[$20>>2] = $15;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $18;
 $23 = $maxForce;
 $24 = (($def) + 32|0);
 HEAPF32[$24>>2] = $23;
 $25 = $maxTorque;
 $26 = (($def) + 36|0);
 HEAPF32[$26>>2] = $25;
 $27 = (__ZN7b2World11CreateJointEPK10b2JointDef($world,$def)|0);
 STACKTOP = sp;return ($27|0);
}
function __ZN15b2MotorJointDefC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10b2JointDefC2Ev($this);
 $0 = (($this) + 20|0);
 HEAP32[$this>>2] = 11;
 __ZN6b2Vec27SetZeroEv($0);
 $1 = (($this) + 28|0);
 HEAPF32[$1>>2] = 0.0;
 $2 = (($this) + 32|0);
 HEAPF32[$2>>2] = 1.0;
 $3 = (($this) + 36|0);
 HEAPF32[$3>>2] = 1.0;
 $4 = (($this) + 40|0);
 HEAPF32[$4>>2] = 0.30000001192092896;
 STACKTOP = sp;return;
}
function _b2MotorJointDef_InitializeAndCreate($world,$bodyA,$bodyB,$collideConnected,$correctionFactor,$maxForce,$maxTorque) {
 $world = $world|0;
 $bodyA = $bodyA|0;
 $bodyB = $bodyB|0;
 $collideConnected = +$collideConnected;
 $correctionFactor = +$correctionFactor;
 $maxForce = +$maxForce;
 $maxTorque = +$maxTorque;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0.0, $4 = 0, $5 = 0.0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0, $def = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $def = sp;
 __ZN15b2MotorJointDefC2Ev($def);
 $0 = $collideConnected != 0.0;
 $1 = (($def) + 16|0);
 $2 = $0&1;
 HEAP8[$1>>0] = $2;
 $3 = $correctionFactor;
 $4 = (($def) + 40|0);
 HEAPF32[$4>>2] = $3;
 $5 = $maxForce;
 $6 = (($def) + 32|0);
 HEAPF32[$6>>2] = $5;
 $7 = $maxTorque;
 $8 = (($def) + 36|0);
 HEAPF32[$8>>2] = $7;
 __ZN15b2MotorJointDef10InitializeEP6b2BodyS1_($def,$bodyA,$bodyB);
 $9 = (__ZN7b2World11CreateJointEPK10b2JointDef($world,$def)|0);
 STACKTOP = sp;return ($9|0);
}
function _b2MouseJoint_SetTarget($mouseJoint,$x,$y) {
 $mouseJoint = $mouseJoint|0;
 $x = +$x;
 $y = +$y;
 var $0 = 0, $1 = 0.0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = $x;
 $2 = $y;
 __ZN6b2Vec2C2Eff($0,$1,$2);
 __ZN12b2MouseJoint9SetTargetERK6b2Vec2($mouseJoint,$0);
 STACKTOP = sp;return;
}
function _b2MouseJointDef_Create($world,$bodyA,$bodyB,$collideConnected,$dampingRatio,$frequencyHz,$maxForce,$targetX,$targetY) {
 $world = $world|0;
 $bodyA = $bodyA|0;
 $bodyB = $bodyB|0;
 $collideConnected = +$collideConnected;
 $dampingRatio = +$dampingRatio;
 $frequencyHz = +$frequencyHz;
 $maxForce = +$maxForce;
 $targetX = +$targetX;
 $targetY = +$targetY;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0, $def = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $def = sp + 8|0;
 $0 = sp;
 __ZN15b2MouseJointDefC2Ev($def);
 $1 = (($def) + 8|0);
 HEAP32[$1>>2] = $bodyA;
 $2 = (($def) + 12|0);
 HEAP32[$2>>2] = $bodyB;
 $3 = $collideConnected != 0.0;
 $4 = (($def) + 16|0);
 $5 = $3&1;
 HEAP8[$4>>0] = $5;
 $6 = $dampingRatio;
 $7 = (($def) + 36|0);
 HEAPF32[$7>>2] = $6;
 $8 = $frequencyHz;
 $9 = (($def) + 32|0);
 HEAPF32[$9>>2] = $8;
 $10 = $maxForce;
 $11 = (($def) + 28|0);
 HEAPF32[$11>>2] = $10;
 $12 = (($def) + 20|0);
 $13 = $targetX;
 $14 = $targetY;
 __ZN6b2Vec2C2Eff($0,$13,$14);
 $15 = $0;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = $12;
 $22 = $21;
 HEAP32[$22>>2] = $17;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = $20;
 $25 = (__ZN7b2World11CreateJointEPK10b2JointDef($world,$def)|0);
 STACKTOP = sp;return ($25|0);
}
function __ZN15b2MouseJointDefC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10b2JointDefC2Ev($this);
 $0 = (($this) + 20|0);
 HEAP32[$this>>2] = 5;
 __ZN6b2Vec23SetEff($0,0.0,0.0);
 $1 = (($this) + 28|0);
 HEAPF32[$1>>2] = 0.0;
 $2 = (($this) + 32|0);
 HEAPF32[$2>>2] = 5.0;
 $3 = (($this) + 36|0);
 HEAPF32[$3>>2] = 0.69999998807907104;
 STACKTOP = sp;return;
}
function _b2PrismaticJoint_EnableLimit($joint,$flag) {
 $joint = $joint|0;
 $flag = +$flag;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $flag != 0.0;
 __ZN16b2PrismaticJoint11EnableLimitEb($joint,$0);
 STACKTOP = sp;return;
}
function _b2PrismaticJoint_EnableMotor($joint,$flag) {
 $joint = $joint|0;
 $flag = +$flag;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $flag != 0.0;
 __ZN16b2PrismaticJoint11EnableMotorEb($joint,$0);
 STACKTOP = sp;return;
}
function _b2PrismaticJoint_GetJointTranslation($joint) {
 $joint = $joint|0;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+__ZNK16b2PrismaticJoint19GetJointTranslationEv($joint));
 $1 = $0;
 STACKTOP = sp;return (+$1);
}
function _b2PrismaticJoint_GetMotorSpeed($joint) {
 $joint = $joint|0;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+__ZNK16b2PrismaticJoint13GetMotorSpeedEv($joint));
 $1 = $0;
 STACKTOP = sp;return (+$1);
}
function __ZNK16b2PrismaticJoint13GetMotorSpeedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 132|0);
 $1 = +HEAPF32[$0>>2];
 STACKTOP = sp;return (+$1);
}
function _b2PrismaticJoint_GetMotorForce($joint,$hz) {
 $joint = $joint|0;
 $hz = +$hz;
 var $0 = 0.0, $1 = 0.0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $hz;
 $1 = (+__ZNK16b2PrismaticJoint13GetMotorForceEf($joint,$0));
 $2 = $1;
 STACKTOP = sp;return (+$2);
}
function _b2PrismaticJoint_IsLimitEnabled($joint) {
 $joint = $joint|0;
 var $0 = 0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK16b2PrismaticJoint14IsLimitEnabledEv($joint)|0);
 $1 = (+($0&1));
 STACKTOP = sp;return (+$1);
}
function _b2PrismaticJoint_IsMotorEnabled($joint) {
 $joint = $joint|0;
 var $0 = 0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK16b2PrismaticJoint14IsMotorEnabledEv($joint)|0);
 $1 = (+($0&1));
 STACKTOP = sp;return (+$1);
}
function _b2PrismaticJoint_SetMotorSpeed($joint,$speed) {
 $joint = $joint|0;
 $speed = +$speed;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $speed;
 __ZN16b2PrismaticJoint13SetMotorSpeedEf($joint,$0);
 STACKTOP = sp;return;
}
function _b2PrismaticJointDef_Create($world,$bodyA,$bodyB,$collideConnected,$enableLimit,$enableMotor,$localAnchorAx,$localAnchorAy,$localAnchorBx,$localAnchorBy,$localAxisAx,$localAxisAy,$lowerTranslation,$maxMotorForce,$motorSpeed,$referenceAngle,$upperTranslation) {
 $world = $world|0;
 $bodyA = $bodyA|0;
 $bodyB = $bodyB|0;
 $collideConnected = +$collideConnected;
 $enableLimit = +$enableLimit;
 $enableMotor = +$enableMotor;
 $localAnchorAx = +$localAnchorAx;
 $localAnchorAy = +$localAnchorAy;
 $localAnchorBx = +$localAnchorBx;
 $localAnchorBy = +$localAnchorBy;
 $localAxisAx = +$localAxisAx;
 $localAxisAy = +$localAxisAy;
 $lowerTranslation = +$lowerTranslation;
 $maxMotorForce = +$maxMotorForce;
 $motorSpeed = +$motorSpeed;
 $referenceAngle = +$referenceAngle;
 $upperTranslation = +$upperTranslation;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0.0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0;
 var $63 = 0, $7 = 0, $8 = 0, $9 = 0, $def = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $def = sp + 24|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 $2 = sp;
 __ZN19b2PrismaticJointDefC2Ev($def);
 $3 = (($def) + 8|0);
 HEAP32[$3>>2] = $bodyA;
 $4 = (($def) + 12|0);
 HEAP32[$4>>2] = $bodyB;
 $5 = $collideConnected != 0.0;
 $6 = (($def) + 16|0);
 $7 = $5&1;
 HEAP8[$6>>0] = $7;
 $8 = $enableLimit != 0.0;
 $9 = (($def) + 48|0);
 $10 = $8&1;
 HEAP8[$9>>0] = $10;
 $11 = $enableMotor != 0.0;
 $12 = (($def) + 60|0);
 $13 = $11&1;
 HEAP8[$12>>0] = $13;
 $14 = (($def) + 20|0);
 $15 = $localAnchorAx;
 $16 = $localAnchorAy;
 __ZN6b2Vec2C2Eff($0,$15,$16);
 $17 = $0;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) + 4)|0;
 $21 = $20;
 $22 = HEAP32[$21>>2]|0;
 $23 = $14;
 $24 = $23;
 HEAP32[$24>>2] = $19;
 $25 = (($23) + 4)|0;
 $26 = $25;
 HEAP32[$26>>2] = $22;
 $27 = (($def) + 28|0);
 $28 = $localAnchorBx;
 $29 = $localAnchorBy;
 __ZN6b2Vec2C2Eff($1,$28,$29);
 $30 = $1;
 $31 = $30;
 $32 = HEAP32[$31>>2]|0;
 $33 = (($30) + 4)|0;
 $34 = $33;
 $35 = HEAP32[$34>>2]|0;
 $36 = $27;
 $37 = $36;
 HEAP32[$37>>2] = $32;
 $38 = (($36) + 4)|0;
 $39 = $38;
 HEAP32[$39>>2] = $35;
 $40 = (($def) + 36|0);
 $41 = $localAxisAx;
 $42 = $localAxisAy;
 __ZN6b2Vec2C2Eff($2,$41,$42);
 $43 = $2;
 $44 = $43;
 $45 = HEAP32[$44>>2]|0;
 $46 = (($43) + 4)|0;
 $47 = $46;
 $48 = HEAP32[$47>>2]|0;
 $49 = $40;
 $50 = $49;
 HEAP32[$50>>2] = $45;
 $51 = (($49) + 4)|0;
 $52 = $51;
 HEAP32[$52>>2] = $48;
 $53 = $lowerTranslation;
 $54 = (($def) + 52|0);
 HEAPF32[$54>>2] = $53;
 $55 = $maxMotorForce;
 $56 = (($def) + 64|0);
 HEAPF32[$56>>2] = $55;
 $57 = $motorSpeed;
 $58 = (($def) + 68|0);
 HEAPF32[$58>>2] = $57;
 $59 = $referenceAngle;
 $60 = (($def) + 44|0);
 HEAPF32[$60>>2] = $59;
 $61 = $upperTranslation;
 $62 = (($def) + 56|0);
 HEAPF32[$62>>2] = $61;
 $63 = (__ZN7b2World11CreateJointEPK10b2JointDef($world,$def)|0);
 STACKTOP = sp;return ($63|0);
}
function __ZN19b2PrismaticJointDefC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10b2JointDefC2Ev($this);
 $0 = (($this) + 20|0);
 $1 = (($this) + 28|0);
 $2 = (($this) + 36|0);
 HEAP32[$this>>2] = 2;
 __ZN6b2Vec27SetZeroEv($0);
 __ZN6b2Vec27SetZeroEv($1);
 __ZN6b2Vec23SetEff($2,1.0,0.0);
 $3 = (($this) + 44|0);
 HEAPF32[$3>>2] = 0.0;
 $4 = (($this) + 48|0);
 HEAP8[$4>>0] = 0;
 $5 = (($this) + 52|0);
 HEAPF32[$5>>2] = 0.0;
 $6 = (($this) + 56|0);
 HEAPF32[$6>>2] = 0.0;
 $7 = (($this) + 60|0);
 HEAP8[$7>>0] = 0;
 $8 = (($this) + 64|0);
 HEAPF32[$8>>2] = 0.0;
 $9 = (($this) + 68|0);
 HEAPF32[$9>>2] = 0.0;
 STACKTOP = sp;return;
}
function _b2PrismaticJointDef_InitializeAndCreate($world,$bodyA,$bodyB,$anchorX,$anchorY,$axisX,$axisY,$collideConnected,$enableLimit,$enableMotor,$lowerTranslation,$maxMotorForce,$motorSpeed,$upperTranslation) {
 $world = $world|0;
 $bodyA = $bodyA|0;
 $bodyB = $bodyB|0;
 $anchorX = +$anchorX;
 $anchorY = +$anchorY;
 $axisX = +$axisX;
 $axisY = +$axisY;
 $collideConnected = +$collideConnected;
 $enableLimit = +$enableLimit;
 $enableMotor = +$enableMotor;
 $lowerTranslation = +$lowerTranslation;
 $maxMotorForce = +$maxMotorForce;
 $motorSpeed = +$motorSpeed;
 $upperTranslation = +$upperTranslation;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $def = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $def = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 __ZN19b2PrismaticJointDefC2Ev($def);
 $2 = $collideConnected != 0.0;
 $3 = (($def) + 16|0);
 $4 = $2&1;
 HEAP8[$3>>0] = $4;
 $5 = $enableLimit != 0.0;
 $6 = (($def) + 48|0);
 $7 = $5&1;
 HEAP8[$6>>0] = $7;
 $8 = $enableMotor != 0.0;
 $9 = (($def) + 60|0);
 $10 = $8&1;
 HEAP8[$9>>0] = $10;
 $11 = $lowerTranslation;
 $12 = (($def) + 52|0);
 HEAPF32[$12>>2] = $11;
 $13 = $maxMotorForce;
 $14 = (($def) + 64|0);
 HEAPF32[$14>>2] = $13;
 $15 = $motorSpeed;
 $16 = (($def) + 68|0);
 HEAPF32[$16>>2] = $15;
 $17 = $upperTranslation;
 $18 = (($def) + 56|0);
 HEAPF32[$18>>2] = $17;
 $19 = $anchorX;
 $20 = $anchorY;
 __ZN6b2Vec2C2Eff($0,$19,$20);
 $21 = $axisX;
 $22 = $axisY;
 __ZN6b2Vec2C2Eff($1,$21,$22);
 __ZN19b2PrismaticJointDef10InitializeEP6b2BodyS1_RK6b2Vec2S4_($def,$bodyA,$bodyB,$0,$1);
 $23 = (__ZN7b2World11CreateJointEPK10b2JointDef($world,$def)|0);
 STACKTOP = sp;return ($23|0);
}
function _b2PulleyJointDef_Create($world,$bodyA,$bodyB,$collideConnected,$groundAnchorAx,$groundAnchorAy,$groundAnchorBx,$groundAnchorBy,$lengthA,$lengthB,$localAnchorAx,$localAnchorAy,$localAnchorBx,$localAnchorBy,$ratio) {
 $world = $world|0;
 $bodyA = $bodyA|0;
 $bodyB = $bodyB|0;
 $collideConnected = +$collideConnected;
 $groundAnchorAx = +$groundAnchorAx;
 $groundAnchorAy = +$groundAnchorAy;
 $groundAnchorBx = +$groundAnchorBx;
 $groundAnchorBy = +$groundAnchorBy;
 $lengthA = +$lengthA;
 $lengthB = +$lengthB;
 $localAnchorAx = +$localAnchorAx;
 $localAnchorAy = +$localAnchorAy;
 $localAnchorBx = +$localAnchorBx;
 $localAnchorBy = +$localAnchorBy;
 $ratio = +$ratio;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0.0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $def = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $def = sp + 32|0;
 $0 = sp + 24|0;
 $1 = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp;
 __ZN16b2PulleyJointDefC2Ev($def);
 $4 = (($def) + 8|0);
 HEAP32[$4>>2] = $bodyA;
 $5 = (($def) + 12|0);
 HEAP32[$5>>2] = $bodyB;
 $6 = $collideConnected != 0.0;
 $7 = (($def) + 16|0);
 $8 = $6&1;
 HEAP8[$7>>0] = $8;
 $9 = (($def) + 20|0);
 $10 = $groundAnchorAx;
 $11 = $groundAnchorAy;
 __ZN6b2Vec2C2Eff($0,$10,$11);
 $12 = $0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($12) + 4)|0;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = $9;
 $19 = $18;
 HEAP32[$19>>2] = $14;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = $17;
 $22 = (($def) + 28|0);
 $23 = $groundAnchorBx;
 $24 = $groundAnchorBy;
 __ZN6b2Vec2C2Eff($1,$23,$24);
 $25 = $1;
 $26 = $25;
 $27 = HEAP32[$26>>2]|0;
 $28 = (($25) + 4)|0;
 $29 = $28;
 $30 = HEAP32[$29>>2]|0;
 $31 = $22;
 $32 = $31;
 HEAP32[$32>>2] = $27;
 $33 = (($31) + 4)|0;
 $34 = $33;
 HEAP32[$34>>2] = $30;
 $35 = $lengthA;
 $36 = (($def) + 52|0);
 HEAPF32[$36>>2] = $35;
 $37 = $lengthB;
 $38 = (($def) + 56|0);
 HEAPF32[$38>>2] = $37;
 $39 = (($def) + 36|0);
 $40 = $localAnchorAx;
 $41 = $localAnchorAy;
 __ZN6b2Vec2C2Eff($2,$40,$41);
 $42 = $2;
 $43 = $42;
 $44 = HEAP32[$43>>2]|0;
 $45 = (($42) + 4)|0;
 $46 = $45;
 $47 = HEAP32[$46>>2]|0;
 $48 = $39;
 $49 = $48;
 HEAP32[$49>>2] = $44;
 $50 = (($48) + 4)|0;
 $51 = $50;
 HEAP32[$51>>2] = $47;
 $52 = (($def) + 44|0);
 $53 = $localAnchorBx;
 $54 = $localAnchorBy;
 __ZN6b2Vec2C2Eff($3,$53,$54);
 $55 = $3;
 $56 = $55;
 $57 = HEAP32[$56>>2]|0;
 $58 = (($55) + 4)|0;
 $59 = $58;
 $60 = HEAP32[$59>>2]|0;
 $61 = $52;
 $62 = $61;
 HEAP32[$62>>2] = $57;
 $63 = (($61) + 4)|0;
 $64 = $63;
 HEAP32[$64>>2] = $60;
 $65 = $ratio;
 $66 = (($def) + 60|0);
 HEAPF32[$66>>2] = $65;
 $67 = (__ZN7b2World11CreateJointEPK10b2JointDef($world,$def)|0);
 STACKTOP = sp;return ($67|0);
}
function __ZN16b2PulleyJointDefC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10b2JointDefC2Ev($this);
 $0 = (($this) + 20|0);
 $1 = (($this) + 28|0);
 $2 = (($this) + 36|0);
 $3 = (($this) + 44|0);
 HEAP32[$this>>2] = 4;
 __ZN6b2Vec23SetEff($0,-1.0,1.0);
 __ZN6b2Vec23SetEff($1,1.0,1.0);
 __ZN6b2Vec23SetEff($2,-1.0,0.0);
 __ZN6b2Vec23SetEff($3,1.0,0.0);
 $4 = (($this) + 52|0);
 HEAPF32[$4>>2] = 0.0;
 $5 = (($this) + 56|0);
 HEAPF32[$5>>2] = 0.0;
 $6 = (($this) + 60|0);
 HEAPF32[$6>>2] = 1.0;
 $7 = (($this) + 16|0);
 HEAP8[$7>>0] = 1;
 STACKTOP = sp;return;
}
function _b2PulleyJointDef_InitializeAndCreate($world,$bodyA,$bodyB,$anchorAx,$anchorAy,$anchorBx,$anchorBy,$groundAnchorAx,$groundAnchorAy,$groundAnchorBx,$groundAnchorBy,$ratio,$collideConnected) {
 $world = $world|0;
 $bodyA = $bodyA|0;
 $bodyB = $bodyB|0;
 $anchorAx = +$anchorAx;
 $anchorAy = +$anchorAy;
 $anchorBx = +$anchorBx;
 $anchorBy = +$anchorBy;
 $groundAnchorAx = +$groundAnchorAx;
 $groundAnchorAy = +$groundAnchorAy;
 $groundAnchorBx = +$groundAnchorBx;
 $groundAnchorBy = +$groundAnchorBy;
 $ratio = +$ratio;
 $collideConnected = +$collideConnected;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, $def = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $def = sp + 32|0;
 $0 = sp + 24|0;
 $1 = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp;
 __ZN16b2PulleyJointDefC2Ev($def);
 $4 = $collideConnected != 0.0;
 $5 = (($def) + 16|0);
 $6 = $4&1;
 HEAP8[$5>>0] = $6;
 $7 = $groundAnchorAx;
 $8 = $groundAnchorAy;
 __ZN6b2Vec2C2Eff($0,$7,$8);
 $9 = $groundAnchorBx;
 $10 = $groundAnchorBy;
 __ZN6b2Vec2C2Eff($1,$9,$10);
 $11 = $anchorAx;
 $12 = $anchorAy;
 __ZN6b2Vec2C2Eff($2,$11,$12);
 $13 = $anchorBx;
 $14 = $anchorBy;
 __ZN6b2Vec2C2Eff($3,$13,$14);
 $15 = $ratio;
 __ZN16b2PulleyJointDef10InitializeEP6b2BodyS1_RK6b2Vec2S4_S4_S4_f($def,$bodyA,$bodyB,$0,$1,$2,$3,$15);
 $16 = (__ZN7b2World11CreateJointEPK10b2JointDef($world,$def)|0);
 STACKTOP = sp;return ($16|0);
}
function _b2RevoluteJoint_EnableLimit($joint,$flag) {
 $joint = $joint|0;
 $flag = +$flag;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $flag != 0.0;
 __ZN15b2RevoluteJoint11EnableLimitEb($joint,$0);
 STACKTOP = sp;return;
}
function _b2RevoluteJoint_EnableMotor($joint,$flag) {
 $joint = $joint|0;
 $flag = +$flag;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $flag != 0.0;
 __ZN15b2RevoluteJoint11EnableMotorEb($joint,$0);
 STACKTOP = sp;return;
}
function _b2RevoluteJoint_GetJointAngle($joint) {
 $joint = $joint|0;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+__ZNK15b2RevoluteJoint13GetJointAngleEv($joint));
 $1 = $0;
 STACKTOP = sp;return (+$1);
}
function _b2RevoluteJoint_IsLimitEnabled($joint) {
 $joint = $joint|0;
 var $0 = 0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK15b2RevoluteJoint14IsLimitEnabledEv($joint)|0);
 $1 = (+($0&1));
 STACKTOP = sp;return (+$1);
}
function _b2RevoluteJoint_IsMotorEnabled($joint) {
 $joint = $joint|0;
 var $0 = 0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK15b2RevoluteJoint14IsMotorEnabledEv($joint)|0);
 $1 = (+($0&1));
 STACKTOP = sp;return (+$1);
}
function _b2RevoluteJointDef_Create($world,$bodyA,$bodyB,$collideConnected,$enableLimit,$enableMotor,$lowerAngle,$localAnchorAx,$localAnchorAy,$localAnchorBx,$localAnchorBy,$maxMotorTorque,$motorSpeed,$referenceAngle,$upperAngle) {
 $world = $world|0;
 $bodyA = $bodyA|0;
 $bodyB = $bodyB|0;
 $collideConnected = +$collideConnected;
 $enableLimit = +$enableLimit;
 $enableMotor = +$enableMotor;
 $lowerAngle = +$lowerAngle;
 $localAnchorAx = +$localAnchorAx;
 $localAnchorAy = +$localAnchorAy;
 $localAnchorBx = +$localAnchorBx;
 $localAnchorBy = +$localAnchorBy;
 $maxMotorTorque = +$maxMotorTorque;
 $motorSpeed = +$motorSpeed;
 $referenceAngle = +$referenceAngle;
 $upperAngle = +$upperAngle;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0;
 var $45 = 0.0, $46 = 0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $revJoint = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $revJoint = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 __ZN18b2RevoluteJointDefC2Ev($revJoint);
 $2 = (($revJoint) + 8|0);
 HEAP32[$2>>2] = $bodyA;
 $3 = (($revJoint) + 12|0);
 HEAP32[$3>>2] = $bodyB;
 $4 = $collideConnected != 0.0;
 $5 = (($revJoint) + 16|0);
 $6 = $4&1;
 HEAP8[$5>>0] = $6;
 $7 = $enableLimit != 0.0;
 $8 = (($revJoint) + 40|0);
 $9 = $7&1;
 HEAP8[$8>>0] = $9;
 $10 = $enableMotor != 0.0;
 $11 = (($revJoint) + 52|0);
 $12 = $10&1;
 HEAP8[$11>>0] = $12;
 $13 = (($revJoint) + 20|0);
 $14 = $localAnchorAx;
 $15 = $localAnchorAy;
 __ZN6b2Vec2C2Eff($0,$14,$15);
 $16 = $0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16) + 4)|0;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = $13;
 $23 = $22;
 HEAP32[$23>>2] = $18;
 $24 = (($22) + 4)|0;
 $25 = $24;
 HEAP32[$25>>2] = $21;
 $26 = (($revJoint) + 28|0);
 $27 = $localAnchorBx;
 $28 = $localAnchorBy;
 __ZN6b2Vec2C2Eff($1,$27,$28);
 $29 = $1;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = (($29) + 4)|0;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = $26;
 $36 = $35;
 HEAP32[$36>>2] = $31;
 $37 = (($35) + 4)|0;
 $38 = $37;
 HEAP32[$38>>2] = $34;
 $39 = $lowerAngle;
 $40 = (($revJoint) + 44|0);
 HEAPF32[$40>>2] = $39;
 $41 = $maxMotorTorque;
 $42 = (($revJoint) + 60|0);
 HEAPF32[$42>>2] = $41;
 $43 = $motorSpeed;
 $44 = (($revJoint) + 56|0);
 HEAPF32[$44>>2] = $43;
 $45 = $referenceAngle;
 $46 = (($revJoint) + 36|0);
 HEAPF32[$46>>2] = $45;
 $47 = $upperAngle;
 $48 = (($revJoint) + 48|0);
 HEAPF32[$48>>2] = $47;
 $49 = (__ZN7b2World11CreateJointEPK10b2JointDef($world,$revJoint)|0);
 STACKTOP = sp;return ($49|0);
}
function __ZN18b2RevoluteJointDefC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10b2JointDefC2Ev($this);
 $0 = (($this) + 20|0);
 $1 = (($this) + 28|0);
 HEAP32[$this>>2] = 1;
 __ZN6b2Vec23SetEff($0,0.0,0.0);
 __ZN6b2Vec23SetEff($1,0.0,0.0);
 $2 = (($this) + 36|0);
 HEAPF32[$2>>2] = 0.0;
 $3 = (($this) + 44|0);
 HEAPF32[$3>>2] = 0.0;
 $4 = (($this) + 48|0);
 HEAPF32[$4>>2] = 0.0;
 $5 = (($this) + 60|0);
 HEAPF32[$5>>2] = 0.0;
 $6 = (($this) + 56|0);
 HEAPF32[$6>>2] = 0.0;
 $7 = (($this) + 40|0);
 HEAP8[$7>>0] = 0;
 $8 = (($this) + 52|0);
 HEAP8[$8>>0] = 0;
 STACKTOP = sp;return;
}
function _b2RevoluteJointDef_InitializeAndCreate($world,$bodyA,$bodyB,$anchorX,$anchorY,$collideConnected,$enableLimit,$enableMotor,$lowerAngle,$maxMotorTorque,$motorSpeed,$upperAngle) {
 $world = $world|0;
 $bodyA = $bodyA|0;
 $bodyB = $bodyB|0;
 $anchorX = +$anchorX;
 $anchorY = +$anchorY;
 $collideConnected = +$collideConnected;
 $enableLimit = +$enableLimit;
 $enableMotor = +$enableMotor;
 $lowerAngle = +$lowerAngle;
 $maxMotorTorque = +$maxMotorTorque;
 $motorSpeed = +$motorSpeed;
 $upperAngle = +$upperAngle;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $revJoint = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $revJoint = sp + 8|0;
 $0 = sp;
 __ZN18b2RevoluteJointDefC2Ev($revJoint);
 $1 = $collideConnected != 0.0;
 $2 = (($revJoint) + 16|0);
 $3 = $1&1;
 HEAP8[$2>>0] = $3;
 $4 = $enableLimit != 0.0;
 $5 = (($revJoint) + 40|0);
 $6 = $4&1;
 HEAP8[$5>>0] = $6;
 $7 = $enableMotor != 0.0;
 $8 = (($revJoint) + 52|0);
 $9 = $7&1;
 HEAP8[$8>>0] = $9;
 $10 = $lowerAngle;
 $11 = (($revJoint) + 44|0);
 HEAPF32[$11>>2] = $10;
 $12 = $maxMotorTorque;
 $13 = (($revJoint) + 60|0);
 HEAPF32[$13>>2] = $12;
 $14 = $motorSpeed;
 $15 = (($revJoint) + 56|0);
 HEAPF32[$15>>2] = $14;
 $16 = $upperAngle;
 $17 = (($revJoint) + 48|0);
 HEAPF32[$17>>2] = $16;
 $18 = $anchorX;
 $19 = $anchorY;
 __ZN6b2Vec2C2Eff($0,$18,$19);
 __ZN18b2RevoluteJointDef10InitializeEP6b2BodyS1_RK6b2Vec2($revJoint,$bodyA,$bodyB,$0);
 $20 = (__ZN7b2World11CreateJointEPK10b2JointDef($world,$revJoint)|0);
 STACKTOP = sp;return ($20|0);
}
function _b2RevoluteJoint_SetMotorSpeed($joint,$speed) {
 $joint = $joint|0;
 $speed = +$speed;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $speed;
 __ZN15b2RevoluteJoint13SetMotorSpeedEf($joint,$0);
 STACKTOP = sp;return;
}
function _b2RopeJointDef_Create($world,$bodyA,$bodyB,$collideConnected,$localAnchorAx,$localAnchorAy,$localAnchorBx,$localAnchorBy,$maxLength) {
 $world = $world|0;
 $bodyA = $bodyA|0;
 $bodyB = $bodyB|0;
 $collideConnected = +$collideConnected;
 $localAnchorAx = +$localAnchorAx;
 $localAnchorAy = +$localAnchorAy;
 $localAnchorBx = +$localAnchorBx;
 $localAnchorBy = +$localAnchorBy;
 $maxLength = +$maxLength;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0.0, $def = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $def = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 __ZN14b2RopeJointDefC2Ev($def);
 $2 = (($def) + 8|0);
 HEAP32[$2>>2] = $bodyA;
 $3 = (($def) + 12|0);
 HEAP32[$3>>2] = $bodyB;
 $4 = $collideConnected != 0.0;
 $5 = (($def) + 16|0);
 $6 = $4&1;
 HEAP8[$5>>0] = $6;
 $7 = (($def) + 20|0);
 $8 = $localAnchorAx;
 $9 = $localAnchorAy;
 __ZN6b2Vec2C2Eff($0,$8,$9);
 $10 = $0;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 4)|0;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = $7;
 $17 = $16;
 HEAP32[$17>>2] = $12;
 $18 = (($16) + 4)|0;
 $19 = $18;
 HEAP32[$19>>2] = $15;
 $20 = (($def) + 28|0);
 $21 = $localAnchorBx;
 $22 = $localAnchorBy;
 __ZN6b2Vec2C2Eff($1,$21,$22);
 $23 = $1;
 $24 = $23;
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23) + 4)|0;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = $20;
 $30 = $29;
 HEAP32[$30>>2] = $25;
 $31 = (($29) + 4)|0;
 $32 = $31;
 HEAP32[$32>>2] = $28;
 $33 = $maxLength;
 $34 = (($def) + 36|0);
 HEAPF32[$34>>2] = $33;
 $35 = (__ZN7b2World11CreateJointEPK10b2JointDef($world,$def)|0);
 STACKTOP = sp;return ($35|0);
}
function __ZN14b2RopeJointDefC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10b2JointDefC2Ev($this);
 $0 = (($this) + 20|0);
 $1 = (($this) + 28|0);
 HEAP32[$this>>2] = 10;
 __ZN6b2Vec23SetEff($0,-1.0,0.0);
 __ZN6b2Vec23SetEff($1,1.0,0.0);
 $2 = (($this) + 36|0);
 HEAPF32[$2>>2] = 0.0;
 STACKTOP = sp;return;
}
function _b2WeldJointDef_Create($world,$bodyA,$bodyB,$collideConnected,$dampingRatio,$frequencyHz,$localAnchorAx,$localAnchorAy,$localAnchorBx,$localAnchorBy,$referenceAngle) {
 $world = $world|0;
 $bodyA = $bodyA|0;
 $bodyB = $bodyB|0;
 $collideConnected = +$collideConnected;
 $dampingRatio = +$dampingRatio;
 $frequencyHz = +$frequencyHz;
 $localAnchorAx = +$localAnchorAx;
 $localAnchorAy = +$localAnchorAy;
 $localAnchorBx = +$localAnchorBx;
 $localAnchorBy = +$localAnchorBy;
 $referenceAngle = +$referenceAngle;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0.0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0.0;
 var $def = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $def = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 __ZN14b2WeldJointDefC2Ev($def);
 $2 = (($def) + 8|0);
 HEAP32[$2>>2] = $bodyA;
 $3 = (($def) + 12|0);
 HEAP32[$3>>2] = $bodyB;
 $4 = $collideConnected != 0.0;
 $5 = (($def) + 16|0);
 $6 = $4&1;
 HEAP8[$5>>0] = $6;
 $7 = $dampingRatio;
 $8 = (($def) + 44|0);
 HEAPF32[$8>>2] = $7;
 $9 = $frequencyHz;
 $10 = (($def) + 40|0);
 HEAPF32[$10>>2] = $9;
 $11 = (($def) + 20|0);
 $12 = $localAnchorAx;
 $13 = $localAnchorAy;
 __ZN6b2Vec2C2Eff($0,$12,$13);
 $14 = $0;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14) + 4)|0;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = $11;
 $21 = $20;
 HEAP32[$21>>2] = $16;
 $22 = (($20) + 4)|0;
 $23 = $22;
 HEAP32[$23>>2] = $19;
 $24 = (($def) + 28|0);
 $25 = $localAnchorBx;
 $26 = $localAnchorBy;
 __ZN6b2Vec2C2Eff($1,$25,$26);
 $27 = $1;
 $28 = $27;
 $29 = HEAP32[$28>>2]|0;
 $30 = (($27) + 4)|0;
 $31 = $30;
 $32 = HEAP32[$31>>2]|0;
 $33 = $24;
 $34 = $33;
 HEAP32[$34>>2] = $29;
 $35 = (($33) + 4)|0;
 $36 = $35;
 HEAP32[$36>>2] = $32;
 $37 = $referenceAngle;
 $38 = (($def) + 36|0);
 HEAPF32[$38>>2] = $37;
 $39 = (__ZN7b2World11CreateJointEPK10b2JointDef($world,$def)|0);
 STACKTOP = sp;return ($39|0);
}
function __ZN14b2WeldJointDefC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10b2JointDefC2Ev($this);
 $0 = (($this) + 20|0);
 $1 = (($this) + 28|0);
 HEAP32[$this>>2] = 8;
 __ZN6b2Vec23SetEff($0,0.0,0.0);
 __ZN6b2Vec23SetEff($1,0.0,0.0);
 $2 = (($this) + 36|0);
 HEAPF32[$2>>2] = 0.0;
 $3 = (($this) + 40|0);
 HEAPF32[$3>>2] = 0.0;
 $4 = (($this) + 44|0);
 HEAPF32[$4>>2] = 0.0;
 STACKTOP = sp;return;
}
function _b2WeldJointDef_InitializeAndCreate($world,$bodyA,$bodyB,$anchorX,$anchorY,$collideConnected,$dampingRatio,$frequencyHz) {
 $world = $world|0;
 $bodyA = $bodyA|0;
 $bodyB = $bodyB|0;
 $anchorX = +$anchorX;
 $anchorY = +$anchorY;
 $collideConnected = +$collideConnected;
 $dampingRatio = +$dampingRatio;
 $frequencyHz = +$frequencyHz;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, $def = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $def = sp + 8|0;
 $0 = sp;
 __ZN14b2WeldJointDefC2Ev($def);
 $1 = $collideConnected != 0.0;
 $2 = (($def) + 16|0);
 $3 = $1&1;
 HEAP8[$2>>0] = $3;
 $4 = $dampingRatio;
 $5 = (($def) + 44|0);
 HEAPF32[$5>>2] = $4;
 $6 = $frequencyHz;
 $7 = (($def) + 40|0);
 HEAPF32[$7>>2] = $6;
 $8 = $anchorX;
 $9 = $anchorY;
 __ZN6b2Vec2C2Eff($0,$8,$9);
 __ZN14b2WeldJointDef10InitializeEP6b2BodyS1_RK6b2Vec2($def,$bodyA,$bodyB,$0);
 $10 = (__ZN7b2World11CreateJointEPK10b2JointDef($world,$def)|0);
 STACKTOP = sp;return ($10|0);
}
function _b2WheelJoint_SetMotorSpeed($wheel,$speed) {
 $wheel = $wheel|0;
 $speed = +$speed;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $speed;
 __ZN12b2WheelJoint13SetMotorSpeedEf($wheel,$0);
 STACKTOP = sp;return;
}
function _b2WheelJoint_SetSpringFrequencyHz($wheel,$frequency) {
 $wheel = $wheel|0;
 $frequency = +$frequency;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $frequency;
 __ZN12b2WheelJoint20SetSpringFrequencyHzEf($wheel,$0);
 STACKTOP = sp;return;
}
function __ZN12b2WheelJoint20SetSpringFrequencyHzEf($this,$hz) {
 $this = $this|0;
 $hz = +$hz;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 HEAPF32[$0>>2] = $hz;
 STACKTOP = sp;return;
}
function _b2WheelJointDef_Create($world,$bodyA,$bodyB,$collideConnected,$dampingRatio,$enableMotor,$frequencyHz,$localAnchorAx,$localAnchorAy,$localAnchorBx,$localAnchorBy,$localAxisAx,$localAxisAy,$maxMotorTorque,$motorSpeed) {
 $world = $world|0;
 $bodyA = $bodyA|0;
 $bodyB = $bodyB|0;
 $collideConnected = +$collideConnected;
 $dampingRatio = +$dampingRatio;
 $enableMotor = +$enableMotor;
 $frequencyHz = +$frequencyHz;
 $localAnchorAx = +$localAnchorAx;
 $localAnchorAy = +$localAnchorAy;
 $localAnchorBx = +$localAnchorBx;
 $localAnchorBy = +$localAnchorBy;
 $localAxisAx = +$localAxisAx;
 $localAxisAy = +$localAxisAy;
 $maxMotorTorque = +$maxMotorTorque;
 $motorSpeed = +$motorSpeed;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0.0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, $def = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $def = sp + 24|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 $2 = sp;
 __ZN15b2WheelJointDefC2Ev($def);
 $3 = (($def) + 8|0);
 HEAP32[$3>>2] = $bodyA;
 $4 = (($def) + 12|0);
 HEAP32[$4>>2] = $bodyB;
 $5 = $collideConnected != 0.0;
 $6 = (($def) + 16|0);
 $7 = $5&1;
 HEAP8[$6>>0] = $7;
 $8 = $dampingRatio;
 $9 = (($def) + 60|0);
 HEAPF32[$9>>2] = $8;
 $10 = $enableMotor != 0.0;
 $11 = (($def) + 44|0);
 $12 = $10&1;
 HEAP8[$11>>0] = $12;
 $13 = $frequencyHz;
 $14 = (($def) + 56|0);
 HEAPF32[$14>>2] = $13;
 $15 = (($def) + 20|0);
 $16 = $localAnchorAx;
 $17 = $localAnchorAy;
 __ZN6b2Vec2C2Eff($0,$16,$17);
 $18 = $0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + 4)|0;
 $22 = $21;
 $23 = HEAP32[$22>>2]|0;
 $24 = $15;
 $25 = $24;
 HEAP32[$25>>2] = $20;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = $23;
 $28 = (($def) + 28|0);
 $29 = $localAnchorBx;
 $30 = $localAnchorBy;
 __ZN6b2Vec2C2Eff($1,$29,$30);
 $31 = $1;
 $32 = $31;
 $33 = HEAP32[$32>>2]|0;
 $34 = (($31) + 4)|0;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = $28;
 $38 = $37;
 HEAP32[$38>>2] = $33;
 $39 = (($37) + 4)|0;
 $40 = $39;
 HEAP32[$40>>2] = $36;
 $41 = (($def) + 36|0);
 $42 = $localAxisAx;
 $43 = $localAxisAy;
 __ZN6b2Vec2C2Eff($2,$42,$43);
 $44 = $2;
 $45 = $44;
 $46 = HEAP32[$45>>2]|0;
 $47 = (($44) + 4)|0;
 $48 = $47;
 $49 = HEAP32[$48>>2]|0;
 $50 = $41;
 $51 = $50;
 HEAP32[$51>>2] = $46;
 $52 = (($50) + 4)|0;
 $53 = $52;
 HEAP32[$53>>2] = $49;
 $54 = $maxMotorTorque;
 $55 = (($def) + 48|0);
 HEAPF32[$55>>2] = $54;
 $56 = $motorSpeed;
 $57 = (($def) + 52|0);
 HEAPF32[$57>>2] = $56;
 $58 = (__ZN7b2World11CreateJointEPK10b2JointDef($world,$def)|0);
 STACKTOP = sp;return ($58|0);
}
function __ZN15b2WheelJointDefC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10b2JointDefC2Ev($this);
 $0 = (($this) + 20|0);
 $1 = (($this) + 28|0);
 $2 = (($this) + 36|0);
 HEAP32[$this>>2] = 7;
 __ZN6b2Vec27SetZeroEv($0);
 __ZN6b2Vec27SetZeroEv($1);
 __ZN6b2Vec23SetEff($2,1.0,0.0);
 $3 = (($this) + 44|0);
 HEAP8[$3>>0] = 0;
 $4 = (($this) + 48|0);
 HEAPF32[$4>>2] = 0.0;
 $5 = (($this) + 52|0);
 HEAPF32[$5>>2] = 0.0;
 $6 = (($this) + 56|0);
 HEAPF32[$6>>2] = 2.0;
 $7 = (($this) + 60|0);
 HEAPF32[$7>>2] = 0.69999998807907104;
 STACKTOP = sp;return;
}
function _b2WheelJointDef_InitializeAndCreate($world,$bodyA,$bodyB,$anchorX,$anchorY,$axisX,$axisY,$collideConnected,$dampingRatio,$enableMotor,$frequencyHz,$maxMotorTorque,$motorSpeed) {
 $world = $world|0;
 $bodyA = $bodyA|0;
 $bodyB = $bodyB|0;
 $anchorX = +$anchorX;
 $anchorY = +$anchorY;
 $axisX = +$axisX;
 $axisY = +$axisY;
 $collideConnected = +$collideConnected;
 $dampingRatio = +$dampingRatio;
 $enableMotor = +$enableMotor;
 $frequencyHz = +$frequencyHz;
 $maxMotorTorque = +$maxMotorTorque;
 $motorSpeed = +$motorSpeed;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $def = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $def = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 __ZN15b2WheelJointDefC2Ev($def);
 $2 = $collideConnected != 0.0;
 $3 = (($def) + 16|0);
 $4 = $2&1;
 HEAP8[$3>>0] = $4;
 $5 = $dampingRatio;
 $6 = (($def) + 60|0);
 HEAPF32[$6>>2] = $5;
 $7 = $enableMotor != 0.0;
 $8 = (($def) + 44|0);
 $9 = $7&1;
 HEAP8[$8>>0] = $9;
 $10 = $frequencyHz;
 $11 = (($def) + 56|0);
 HEAPF32[$11>>2] = $10;
 $12 = $maxMotorTorque;
 $13 = (($def) + 48|0);
 HEAPF32[$13>>2] = $12;
 $14 = $motorSpeed;
 $15 = (($def) + 52|0);
 HEAPF32[$15>>2] = $14;
 $16 = $anchorX;
 $17 = $anchorY;
 __ZN6b2Vec2C2Eff($0,$16,$17);
 $18 = $axisX;
 $19 = $axisY;
 __ZN6b2Vec2C2Eff($1,$18,$19);
 __ZN15b2WheelJointDef10InitializeEP6b2BodyS1_RK6b2Vec2S4_($def,$bodyA,$bodyB,$0,$1);
 $20 = (__ZN7b2World11CreateJointEPK10b2JointDef($world,$def)|0);
 STACKTOP = sp;return ($20|0);
}
function _b2ParticleGroup_ApplyForce($particleGroup,$forceX,$forceY) {
 $particleGroup = $particleGroup|0;
 $forceX = +$forceX;
 $forceY = +$forceY;
 var $0 = 0, $1 = 0.0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = $forceX;
 $2 = $forceY;
 __ZN6b2Vec2C2Eff($0,$1,$2);
 __ZN15b2ParticleGroup10ApplyForceERK6b2Vec2($particleGroup,$0);
 STACKTOP = sp;return;
}
function _b2ParticleGroup_ApplyLinearImpulse($particleGroup,$impulseX,$impulseY) {
 $particleGroup = $particleGroup|0;
 $impulseX = +$impulseX;
 $impulseY = +$impulseY;
 var $0 = 0, $1 = 0.0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = $impulseX;
 $2 = $impulseY;
 __ZN6b2Vec2C2Eff($0,$1,$2);
 __ZN15b2ParticleGroup18ApplyLinearImpulseERK6b2Vec2($particleGroup,$0);
 STACKTOP = sp;return;
}
function _b2ParticleGroup_DestroyParticles($particleGroup,$flag) {
 $particleGroup = $particleGroup|0;
 $flag = +$flag;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $flag != 0.0;
 __ZN15b2ParticleGroup16DestroyParticlesEb($particleGroup,$0);
 STACKTOP = sp;return;
}
function _b2ParticleGroup_GetBufferIndex($particleGroup) {
 $particleGroup = $particleGroup|0;
 var $0 = 0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK15b2ParticleGroup14GetBufferIndexEv($particleGroup)|0);
 $1 = (+($0|0));
 STACKTOP = sp;return (+$1);
}
function __ZNK15b2ParticleGroup14GetBufferIndexEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function _b2ParticleGroup_GetParticleCount($particleGroup) {
 $particleGroup = $particleGroup|0;
 var $0 = 0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK15b2ParticleGroup16GetParticleCountEv($particleGroup)|0);
 $1 = (+($0|0));
 STACKTOP = sp;return (+$1);
}
function __ZNK15b2ParticleGroup16GetParticleCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) - ($3))|0;
 STACKTOP = sp;return ($4|0);
}
function _b2ParticleContact_GetNormal($particleContact,$arr) {
 $particleContact = $particleContact|0;
 $arr = $arr|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0.0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK17b2ParticleContact9GetNormalEv($particleContact)|0);
 $1 = +HEAPF32[$0>>2];
 $2 = (($0) + 4|0);
 $3 = +HEAPF32[$2>>2];
 HEAPF32[$arr>>2] = $1;
 $4 = (($arr) + 4|0);
 HEAPF32[$4>>2] = $3;
 STACKTOP = sp;return;
}
function __ZNK17b2ParticleContact9GetNormalEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 STACKTOP = sp;return ($0|0);
}
function _b2ParticleBodyContact_GetNormal($particleBodyContact,$arr) {
 $particleBodyContact = $particleBodyContact|0;
 $arr = $arr|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0.0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($particleBodyContact) + 16|0);
 $1 = +HEAPF32[$0>>2];
 $2 = (($particleBodyContact) + 20|0);
 $3 = +HEAPF32[$2>>2];
 HEAPF32[$arr>>2] = $1;
 $4 = (($arr) + 4|0);
 HEAPF32[$4>>2] = $3;
 STACKTOP = sp;return;
}
function _b2ParticleSystem_CreateParticle($particleSystem,$colorR,$colorB,$colorG,$colorA,$flags,$group,$lifetime,$positionX,$positionY,$userData,$velocityX,$velocityY) {
 $particleSystem = $particleSystem|0;
 $colorR = +$colorR;
 $colorB = +$colorB;
 $colorG = +$colorG;
 $colorA = +$colorA;
 $flags = +$flags;
 $group = +$group;
 $lifetime = +$lifetime;
 $positionX = +$positionX;
 $positionY = +$positionY;
 $userData = +$userData;
 $velocityX = +$velocityX;
 $velocityY = +$velocityY;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0.0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $def = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $0 = sp + 24|0;
 $1 = sp + 16|0;
 $def = sp + 32|0;
 $2 = sp + 68|0;
 $3 = sp + 8|0;
 $4 = sp;
 HEAPF64[$0>>3] = $group;
 HEAPF64[$1>>3] = $userData;
 __ZN13b2ParticleDefC2Ev($def);
 $5 = (($def) + 20|0);
 $6 = (~~(($colorR))&255);
 $7 = (~~(($colorG))&255);
 $8 = (~~(($colorB))&255);
 $9 = (~~(($colorA))&255);
 HEAP8[$2>>0] = $6;
 $10 = (($2) + 1|0);
 HEAP8[$10>>0] = $7;
 $11 = (($2) + 2|0);
 HEAP8[$11>>0] = $8;
 $12 = (($2) + 3|0);
 HEAP8[$12>>0] = $9;
 (__ZN15b2ParticleColoraSERKS_($5,$2)|0);
 $13 = (~~(($flags))>>>0);
 HEAP32[$def>>2] = $13;
 $14 = (($def) + 32|0);
 HEAP32[$14>>2] = $0;
 $15 = $lifetime;
 $16 = (($def) + 24|0);
 HEAPF32[$16>>2] = $15;
 $17 = (($def) + 4|0);
 $18 = $positionX;
 $19 = $positionY;
 __ZN6b2Vec2C2Eff($3,$18,$19);
 $20 = $3;
 $21 = $20;
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20) + 4)|0;
 $24 = $23;
 $25 = HEAP32[$24>>2]|0;
 $26 = $17;
 $27 = $26;
 HEAP32[$27>>2] = $22;
 $28 = (($26) + 4)|0;
 $29 = $28;
 HEAP32[$29>>2] = $25;
 $30 = (($def) + 28|0);
 HEAP32[$30>>2] = $1;
 $31 = (($def) + 12|0);
 $32 = $velocityX;
 $33 = $velocityY;
 __ZN6b2Vec2C2Eff($4,$32,$33);
 $34 = $4;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = (($34) + 4)|0;
 $38 = $37;
 $39 = HEAP32[$38>>2]|0;
 $40 = $31;
 $41 = $40;
 HEAP32[$41>>2] = $36;
 $42 = (($40) + 4)|0;
 $43 = $42;
 HEAP32[$43>>2] = $39;
 $44 = (__ZN16b2ParticleSystem14CreateParticleERK13b2ParticleDef($particleSystem,$def)|0);
 $45 = (+($44|0));
 STACKTOP = sp;return (+$45);
}
function __ZN13b2ParticleDefC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = (($this) + 12|0);
 $2 = (($this) + 20|0);
 HEAP32[$this>>2] = 0;
 $3 = 10224;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $0;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = 10224;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 4)|0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = $1;
 $20 = $19;
 HEAP32[$20>>2] = $15;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $18;
 (__ZN15b2ParticleColoraSERKS_($2,9504)|0);
 $23 = (($this) + 24|0);
 HEAPF32[$23>>2] = 0.0;
 $24 = (($this) + 28|0);
 HEAP32[$24>>2] = 0;
 $25 = (($this) + 32|0);
 HEAP32[$25>>2] = 0;
 STACKTOP = sp;return;
}
function _b2ParticleSystem_GetColorBuffer($particleSystem) {
 $particleSystem = $particleSystem|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN16b2ParticleSystem14GetColorBufferEv($particleSystem)|0);
 STACKTOP = sp;return ($0|0);
}
function _b2ParticleSystem_GetParticleCount($particleSystem) {
 $particleSystem = $particleSystem|0;
 var $0 = 0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK16b2ParticleSystem16GetParticleCountEv($particleSystem)|0);
 $1 = (+($0|0));
 STACKTOP = sp;return (+$1);
}
function __ZNK16b2ParticleSystem16GetParticleCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function _b2ParticleSystem_GetPositionBuffer($particleSystem) {
 $particleSystem = $particleSystem|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN16b2ParticleSystem17GetPositionBufferEv($particleSystem)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN16b2ParticleSystem17GetPositionBufferEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 96|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function _b2ParticleSystem_GetVelocityBuffer($particleSystem) {
 $particleSystem = $particleSystem|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN16b2ParticleSystem17GetVelocityBufferEv($particleSystem)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN16b2ParticleSystem17GetVelocityBufferEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function _b2ParticleSystem_SetDamping($particleSystem,$damping) {
 $particleSystem = $particleSystem|0;
 $damping = +$damping;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $damping;
 __ZN16b2ParticleSystem10SetDampingEf($particleSystem,$0);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem10SetDampingEf($this,$damping) {
 $this = $this|0;
 $damping = +$damping;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 340|0);
 HEAPF32[$0>>2] = $damping;
 STACKTOP = sp;return;
}
function _b2ParticleSystem_SetDensity($particleSystem,$density) {
 $particleSystem = $particleSystem|0;
 $density = +$density;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $density;
 __ZN16b2ParticleSystem10SetDensityEf($particleSystem,$0);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem10SetDensityEf($this,$density) {
 $this = $this|0;
 $density = +$density;
 var $0 = 0, $1 = 0.0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 320|0);
 HEAPF32[$0>>2] = $density;
 $1 = 1.0 / $density;
 $2 = (($this) + 28|0);
 HEAPF32[$2>>2] = $1;
 STACKTOP = sp;return;
}
function _b2ParticleSystem_SetRadius($particleSystem,$radius) {
 $particleSystem = $particleSystem|0;
 $radius = +$radius;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $radius;
 __ZN16b2ParticleSystem9SetRadiusEf($particleSystem,$0);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem9SetRadiusEf($this,$radius) {
 $this = $this|0;
 $radius = +$radius;
 var $0 = 0.0, $1 = 0, $2 = 0.0, $3 = 0, $4 = 0.0, $5 = 0.0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $radius * 2.0;
 $1 = (($this) + 32|0);
 HEAPF32[$1>>2] = $0;
 $2 = $0 * $0;
 $3 = (($this) + 40|0);
 HEAPF32[$3>>2] = $2;
 $4 = +HEAPF32[$1>>2];
 $5 = 1.0 / $4;
 $6 = (($this) + 36|0);
 HEAPF32[$6>>2] = $5;
 STACKTOP = sp;return;
}
function __Z12PrintOffsetsP6b2Body($b) {
 $b = $b|0;
 var $vararg_buffer70 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer70 = sp;
 (_puts((1624|0))|0);
 HEAP32[$vararg_buffer70>>2] = 0;
 (_printf((64|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 8;
 (_printf((80|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 12;
 (_printf((104|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 28;
 (_printf((120|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 44;
 (_printf((136|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 80;
 (_printf((152|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 88;
 (_printf((176|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 92;
 (_printf((200|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 100;
 (_printf((216|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 104;
 (_printf((232|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 108;
 (_printf((248|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 112;
 (_printf((264|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 116;
 (_printf((280|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 120;
 (_printf((304|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 124;
 (_printf((328|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 128;
 (_printf((352|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 132;
 (_printf((376|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 136;
 (_printf((392|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 140;
 (_printf((408|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 144;
 (_printf((424|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 148;
 (_printf((440|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 152;
 (_printf((464|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 156;
 (_printf((488|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 160;
 (_printf((512|0),($vararg_buffer70|0))|0);
 HEAP32[$vararg_buffer70>>2] = 164;
 (_printf((536|0),($vararg_buffer70|0))|0);
 (_puts((1640|0))|0);
 STACKTOP = sp;return;
}
function __Z12PrintOffsetsP9b2Fixture($f) {
 $f = $f|0;
 var $vararg_buffer28 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer28 = sp;
 (_puts((1648|0))|0);
 HEAP32[$vararg_buffer28>>2] = 0;
 (_printf((632|0),($vararg_buffer28|0))|0);
 HEAP32[$vararg_buffer28>>2] = 4;
 (_printf((264|0),($vararg_buffer28|0))|0);
 HEAP32[$vararg_buffer28>>2] = 8;
 (_printf((648|0),($vararg_buffer28|0))|0);
 HEAP32[$vararg_buffer28>>2] = 12;
 (_printf((664|0),($vararg_buffer28|0))|0);
 HEAP32[$vararg_buffer28>>2] = 16;
 (_printf((584|0),($vararg_buffer28|0))|0);
 HEAP32[$vararg_buffer28>>2] = 20;
 (_printf((608|0),($vararg_buffer28|0))|0);
 HEAP32[$vararg_buffer28>>2] = 24;
 (_printf((680|0),($vararg_buffer28|0))|0);
 HEAP32[$vararg_buffer28>>2] = 28;
 (_printf((696|0),($vararg_buffer28|0))|0);
 HEAP32[$vararg_buffer28>>2] = 32;
 (_printf((720|0),($vararg_buffer28|0))|0);
 HEAP32[$vararg_buffer28>>2] = 38;
 (_printf((736|0),($vararg_buffer28|0))|0);
 HEAP32[$vararg_buffer28>>2] = 40;
 (_printf((536|0),($vararg_buffer28|0))|0);
 (_puts((1664|0))|0);
 STACKTOP = sp;return;
}
function __Z12PrintOffsetsP15b2ParticleGroup($p) {
 $p = $p|0;
 var $vararg_buffer40 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer40 = sp;
 (_puts((1672|0))|0);
 HEAP32[$vararg_buffer40>>2] = 0;
 (_printf((760|0),($vararg_buffer40|0))|0);
 HEAP32[$vararg_buffer40>>2] = 4;
 (_printf((776|0),($vararg_buffer40|0))|0);
 HEAP32[$vararg_buffer40>>2] = 8;
 (_printf((800|0),($vararg_buffer40|0))|0);
 HEAP32[$vararg_buffer40>>2] = 12;
 (_printf((824|0),($vararg_buffer40|0))|0);
 HEAP32[$vararg_buffer40>>2] = 16;
 (_printf((848|0),($vararg_buffer40|0))|0);
 HEAP32[$vararg_buffer40>>2] = 20;
 (_printf((248|0),($vararg_buffer40|0))|0);
 HEAP32[$vararg_buffer40>>2] = 24;
 (_printf((264|0),($vararg_buffer40|0))|0);
 HEAP32[$vararg_buffer40>>2] = 28;
 (_printf((872|0),($vararg_buffer40|0))|0);
 HEAP32[$vararg_buffer40>>2] = 32;
 (_printf((376|0),($vararg_buffer40|0))|0);
 HEAP32[$vararg_buffer40>>2] = 36;
 (_printf((896|0),($vararg_buffer40|0))|0);
 HEAP32[$vararg_buffer40>>2] = 40;
 (_printf((912|0),($vararg_buffer40|0))|0);
 HEAP32[$vararg_buffer40>>2] = 48;
 (_printf((152|0),($vararg_buffer40|0))|0);
 HEAP32[$vararg_buffer40>>2] = 56;
 (_printf((176|0),($vararg_buffer40|0))|0);
 HEAP32[$vararg_buffer40>>2] = 60;
 (_printf((928|0),($vararg_buffer40|0))|0);
 HEAP32[$vararg_buffer40>>2] = 76;
 (_printf((536|0),($vararg_buffer40|0))|0);
 (_puts((1696|0))|0);
 STACKTOP = sp;return;
}
function __Z12PrintOffsetsP7b2World($w) {
 $w = $w|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 (_puts((1704|0))|0);
 HEAP32[$vararg_buffer>>2] = 102960;
 (_printf((952|0),($vararg_buffer|0))|0);
 (_puts((1720|0))|0);
 STACKTOP = sp;return;
}
function __Z12PrintOffsetsP15b2WorldManifold($wm) {
 $wm = $wm|0;
 var $vararg_buffer4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer4 = sp;
 (_puts((1728|0))|0);
 HEAP32[$vararg_buffer4>>2] = 0;
 (_printf((968|0),($vararg_buffer4|0))|0);
 HEAP32[$vararg_buffer4>>2] = 8;
 (_printf((984|0),($vararg_buffer4|0))|0);
 HEAP32[$vararg_buffer4>>2] = 24;
 (_printf((1000|0),($vararg_buffer4|0))|0);
 (_puts((1752|0))|0);
 STACKTOP = sp;return;
}
function __Z12PrintOffsetsP17b2ParticleContact($pc) {
 $pc = $pc|0;
 var $vararg_buffer10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer10 = sp;
 (_puts((1760|0))|0);
 HEAP32[$vararg_buffer10>>2] = 0;
 (_printf((552|0),($vararg_buffer10|0))|0);
 HEAP32[$vararg_buffer10>>2] = 4;
 (_printf((568|0),($vararg_buffer10|0))|0);
 HEAP32[$vararg_buffer10>>2] = 8;
 (_printf((1024|0),($vararg_buffer10|0))|0);
 HEAP32[$vararg_buffer10>>2] = 12;
 (_printf((968|0),($vararg_buffer10|0))|0);
 HEAP32[$vararg_buffer10>>2] = 20;
 (_printf((1040|0),($vararg_buffer10|0))|0);
 (_puts((1784|0))|0);
 STACKTOP = sp;return;
}
function __Z12PrintOffsetsP21b2ParticleBodyContact($pbc) {
 $pbc = $pbc|0;
 var $vararg_buffer13 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer13 = sp;
 (_puts((1792|0))|0);
 HEAP32[$vararg_buffer13>>2] = 0;
 (_printf((1056|0),($vararg_buffer13|0))|0);
 HEAP32[$vararg_buffer13>>2] = 4;
 (_printf((648|0),($vararg_buffer13|0))|0);
 HEAP32[$vararg_buffer13>>2] = 8;
 (_printf((1072|0),($vararg_buffer13|0))|0);
 HEAP32[$vararg_buffer13>>2] = 12;
 (_printf((1024|0),($vararg_buffer13|0))|0);
 HEAP32[$vararg_buffer13>>2] = 16;
 (_printf((968|0),($vararg_buffer13|0))|0);
 HEAP32[$vararg_buffer13>>2] = 24;
 (_printf((1088|0),($vararg_buffer13|0))|0);
 (_puts((1824|0))|0);
 STACKTOP = sp;return;
}
function _GenerateOffsets() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $d = 0, $def = 0, $pbc = 0, $pc = 0, $pgd = 0, $psd = 0, $s = 0, $world = 0, $worldManifold = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 103408|0;
 $world = sp + 360|0;
 $0 = sp + 352|0;
 $def = sp + 296|0;
 $s = sp + 276|0;
 $d = sp + 248|0;
 $psd = sp + 164|0;
 $pgd = sp + 88|0;
 $worldManifold = sp + 56|0;
 $pc = sp + 32|0;
 $pbc = sp;
 (_puts((1832|0))|0);
 __ZN6b2Vec2C2Eff($0,0.0,0.0);
 __ZN7b2WorldC2ERK6b2Vec2($world,$0);
 __ZN9b2BodyDefC2Ev($def);
 $1 = (__ZN7b2World10CreateBodyEPK9b2BodyDef($world,$def)|0);
 __ZN13b2CircleShapeC2Ev($s);
 __ZN12b2FixtureDefC2Ev($d);
 HEAP32[$d>>2] = $s;
 $2 = (__ZN6b2Body13CreateFixtureEPK12b2FixtureDef($1,$d)|0);
 __ZN19b2ParticleSystemDefC2Ev($psd);
 $3 = (__ZN7b2World20CreateParticleSystemEPK19b2ParticleSystemDef($world,$psd)|0);
 __ZN18b2ParticleGroupDefC2Ev($pgd);
 $4 = (__ZN16b2ParticleSystem19CreateParticleGroupERK18b2ParticleGroupDef($3,$pgd)|0);
 __Z12PrintOffsetsP6b2Body($1);
 __Z12PrintOffsetsP9b2Fixture($2);
 __Z12PrintOffsetsP15b2ParticleGroup($4);
 __Z12PrintOffsetsP7b2World($world);
 __Z12PrintOffsetsP15b2WorldManifold($worldManifold);
 __Z12PrintOffsetsP17b2ParticleContact($pc);
 __Z12PrintOffsetsP21b2ParticleBodyContact($pbc);
 (_puts((1840|0))|0);
 __ZN7b2WorldD2Ev($world);
 STACKTOP = sp;return;
}
function __ZN10b2JointDefC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;HEAP8[$this+16>>0]=0|0;
 STACKTOP = sp;return;
}
function __ZN6b2Vec27SetZeroEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$this>>2] = 0.0;
 $0 = (($this) + 4|0);
 HEAPF32[$0>>2] = 0.0;
 STACKTOP = sp;return;
}
function __ZN9b2Fixture7GetBodyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN9b2Fixture8GetShapeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN17b2RayCastCallbackC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((1208 + 8|0));
 STACKTOP = sp;return;
}
function __ZN15RayCastCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN15RayCastCallback13ReportFixtureEP9b2FixtureRK6b2Vec2S4_f($this,$fixture,$point,$normal,$fraction) {
 $this = $this|0;
 $fixture = $fixture|0;
 $point = $point|0;
 $normal = $normal|0;
 $fraction = +$fraction;
 var $0 = 0.0, $1 = 0.0, $10 = 0.0, $11 = 0.0, $2 = 0, $3 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$point>>2];
 $1 = $0;
 $2 = (($point) + 4|0);
 $3 = +HEAPF32[$2>>2];
 $4 = $3;
 $5 = +HEAPF32[$normal>>2];
 $6 = $5;
 $7 = (($normal) + 4|0);
 $8 = +HEAPF32[$7>>2];
 $9 = $8;
 $10 = $fraction;
 $11 = (+_b2WorldRayCastCallback(($fixture|0),(+$1),(+$4),(+$6),(+$9),(+$10)));
 STACKTOP = sp;return (+$11);
}
function __ZN17b2RayCastCallback14ReportParticleEPK16b2ParticleSystemiRK6b2Vec2S5_f($this,$particleSystem,$index,$point,$normal,$fraction) {
 $this = $this|0;
 $particleSystem = $particleSystem|0;
 $index = $index|0;
 $point = $point|0;
 $normal = $normal|0;
 $fraction = +$fraction;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return +0;
}
function __ZN17b2RayCastCallback25ShouldQueryParticleSystemEPK16b2ParticleSystem($this,$particleSystem) {
 $this = $this|0;
 $particleSystem = $particleSystem|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN17b2RayCastCallbackD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN17b2RayCastCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN15b2QueryCallbackC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((1344 + 8|0));
 STACKTOP = sp;return;
}
function __ZN17QueryAABBCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN17QueryAABBCallback13ReportFixtureEP9b2Fixture($this,$fixture) {
 $this = $this|0;
 $fixture = $fixture|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_b2WorldQueryAABB(($fixture|0))|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN15b2QueryCallback14ReportParticleEPK16b2ParticleSystemi($this,$particleSystem,$index) {
 $this = $this|0;
 $particleSystem = $particleSystem|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZN15b2QueryCallback25ShouldQueryParticleSystemEPK16b2ParticleSystem($this,$particleSystem) {
 $this = $this|0;
 $particleSystem = $particleSystem|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN15b2QueryCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN17b2ContactListenerC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((1504 + 8|0));
 STACKTOP = sp;return;
}
function __ZN22b2WorldContactListenerD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN22b2WorldContactListener12BeginContactEP9b2Contact($this,$contact) {
 $this = $this|0;
 $contact = $contact|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _b2WorldBeginContactBody(($contact|0));
 STACKTOP = sp;return;
}
function __ZN22b2WorldContactListener10EndContactEP9b2Contact($this,$contact) {
 $this = $this|0;
 $contact = $contact|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _b2WorldEndContactBody(($contact|0));
 STACKTOP = sp;return;
}
function __ZN22b2WorldContactListener12BeginContactEP16b2ParticleSystemP21b2ParticleBodyContact($this,$particleSystem,$particleBodyContact) {
 $this = $this|0;
 $particleSystem = $particleSystem|0;
 $particleBodyContact = $particleBodyContact|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _b2WorldBeginContactParticleBody(($particleSystem|0),($particleBodyContact|0));
 STACKTOP = sp;return;
}
function __ZN22b2WorldContactListener10EndContactEP9b2FixtureP16b2ParticleSystemi($this,$fixture,$particleSystem,$index) {
 $this = $this|0;
 $fixture = $fixture|0;
 $particleSystem = $particleSystem|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _b2WorldEndContactParticleBody(($fixture|0),($particleSystem|0),($index|0));
 STACKTOP = sp;return;
}
function __ZN22b2WorldContactListener12BeginContactEP16b2ParticleSystemP17b2ParticleContact($this,$particleSystem,$particleContact) {
 $this = $this|0;
 $particleSystem = $particleSystem|0;
 $particleContact = $particleContact|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _b2WorldBeginContactParticle(($particleSystem|0),($particleContact|0));
 STACKTOP = sp;return;
}
function __ZN22b2WorldContactListener10EndContactEP16b2ParticleSystemii($this,$particleSystem,$indexA,$indexB) {
 $this = $this|0;
 $particleSystem = $particleSystem|0;
 $indexA = $indexA|0;
 $indexB = $indexB|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _b2WorldEndContactParticle(($particleSystem|0),($indexA|0),($indexB|0));
 STACKTOP = sp;return;
}
function __ZN22b2WorldContactListener8PreSolveEP9b2ContactPK10b2Manifold($this,$contact,$oldManifold) {
 $this = $this|0;
 $contact = $contact|0;
 $oldManifold = $oldManifold|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _b2WorldPreSolve(($contact|0),($oldManifold|0));
 STACKTOP = sp;return;
}
function __ZN22b2WorldContactListener9PostSolveEP9b2ContactPK16b2ContactImpulse($this,$contact,$impulse) {
 $this = $this|0;
 $contact = $contact|0;
 $impulse = $impulse|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _b2WorldPostSolve(($contact|0),($impulse|0));
 STACKTOP = sp;return;
}
function __ZN17b2ContactListenerD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN17b2ContactListener12BeginContactEP9b2Contact($this,$contact) {
 $this = $this|0;
 $contact = $contact|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN17b2ContactListener10EndContactEP9b2Contact($this,$contact) {
 $this = $this|0;
 $contact = $contact|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN17b2ContactListener12BeginContactEP16b2ParticleSystemP21b2ParticleBodyContact($this,$particleSystem,$particleBodyContact) {
 $this = $this|0;
 $particleSystem = $particleSystem|0;
 $particleBodyContact = $particleBodyContact|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN17b2ContactListener10EndContactEP9b2FixtureP16b2ParticleSystemi($this,$fixture,$particleSystem,$index) {
 $this = $this|0;
 $fixture = $fixture|0;
 $particleSystem = $particleSystem|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN17b2ContactListener12BeginContactEP16b2ParticleSystemP17b2ParticleContact($this,$particleSystem,$particleContact) {
 $this = $this|0;
 $particleSystem = $particleSystem|0;
 $particleContact = $particleContact|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN17b2ContactListener10EndContactEP16b2ParticleSystemii($this,$particleSystem,$indexA,$indexB) {
 $this = $this|0;
 $particleSystem = $particleSystem|0;
 $indexA = $indexA|0;
 $indexB = $indexB|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN17b2ContactListener8PreSolveEP9b2ContactPK10b2Manifold($this,$contact,$oldManifold) {
 $this = $this|0;
 $contact = $contact|0;
 $oldManifold = $oldManifold|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN17b2ContactListener9PostSolveEP9b2ContactPK16b2ContactImpulse($this,$contact,$impulse) {
 $this = $this|0;
 $contact = $contact|0;
 $impulse = $impulse|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __Z5b2DotRK6b2Vec2S1_($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0.0, $1 = 0.0, $2 = 0.0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$a>>2];
 $1 = +HEAPF32[$b>>2];
 $2 = $0 * $1;
 $3 = (($a) + 4|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($b) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $4 * $6;
 $8 = $2 + $7;
 STACKTOP = sp;return (+$8);
}
function __Z5b2MulRK11b2TransformRK6b2Vec2($agg$result,$T,$v) {
 $agg$result = $agg$result|0;
 $T = $T|0;
 $v = $v|0;
 var $0 = 0, $1 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0.0, $2 = 0.0, $3 = 0.0, $4 = 0, $5 = 0.0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($T) + 12|0);
 $1 = +HEAPF32[$0>>2];
 $2 = +HEAPF32[$v>>2];
 $3 = $1 * $2;
 $4 = (($T) + 8|0);
 $5 = +HEAPF32[$4>>2];
 $6 = (($v) + 4|0);
 $7 = +HEAPF32[$6>>2];
 $8 = $5 * $7;
 $9 = $3 - $8;
 $10 = +HEAPF32[$T>>2];
 $11 = $10 + $9;
 $12 = $2 * $5;
 $13 = $1 * $7;
 $14 = $12 + $13;
 $15 = (($T) + 4|0);
 $16 = +HEAPF32[$15>>2];
 $17 = $14 + $16;
 __ZN6b2Vec2C2Eff($agg$result,$11,$17);
 STACKTOP = sp;return;
}
function __Z6b2MulTRK11b2TransformRK6b2Vec2($agg$result,$T,$v) {
 $agg$result = $agg$result|0;
 $T = $T|0;
 $v = $v|0;
 var $0 = 0.0, $1 = 0.0, $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $2 = 0.0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$v>>2];
 $1 = +HEAPF32[$T>>2];
 $2 = $0 - $1;
 $3 = (($v) + 4|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($T) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $4 - $6;
 $8 = (($T) + 12|0);
 $9 = +HEAPF32[$8>>2];
 $10 = $2 * $9;
 $11 = (($T) + 8|0);
 $12 = +HEAPF32[$11>>2];
 $13 = $7 * $12;
 $14 = $10 + $13;
 $15 = $2 * $12;
 $16 = $9 * $7;
 $17 = $16 - $15;
 __ZN6b2Vec2C2Eff($agg$result,$14,$17);
 STACKTOP = sp;return;
}
function __ZN6b2Vec2pLERKS_($this,$v) {
 $this = $this|0;
 $v = $v|0;
 var $0 = 0.0, $1 = 0.0, $2 = 0.0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$v>>2];
 $1 = +HEAPF32[$this>>2];
 $2 = $0 + $1;
 HEAPF32[$this>>2] = $2;
 $3 = (($v) + 4|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($this) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $4 + $6;
 HEAPF32[$5>>2] = $7;
 STACKTOP = sp;return;
}
function __Z7b2CrossRK6b2Vec2S1_($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0.0, $1 = 0, $2 = 0.0, $3 = 0.0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$a>>2];
 $1 = (($b) + 4|0);
 $2 = +HEAPF32[$1>>2];
 $3 = $0 * $2;
 $4 = (($a) + 4|0);
 $5 = +HEAPF32[$4>>2];
 $6 = +HEAPF32[$b>>2];
 $7 = $5 * $6;
 $8 = $3 - $7;
 STACKTOP = sp;return (+$8);
}
function __ZmiRK6b2Vec2S1_($agg$result,$a,$b) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = 0.0, $1 = 0.0, $2 = 0.0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$a>>2];
 $1 = +HEAPF32[$b>>2];
 $2 = $0 - $1;
 $3 = (($a) + 4|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($b) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $4 - $6;
 __ZN6b2Vec2C2Eff($agg$result,$2,$7);
 STACKTOP = sp;return;
}
function __ZN7b2ShapeC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((1552 + 8|0));
 STACKTOP = sp;return;
}
function __ZN7b2ShapeD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN8b2FilterC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP16[$this>>1] = 1;
 $0 = (($this) + 2|0);
 HEAP16[$0>>1] = -1;
 $1 = (($this) + 4|0);
 HEAP16[$1>>1] = 0;
 STACKTOP = sp;return;
}
function __GLOBAL__I_a() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 ___cxx_global_var_init();
 ___cxx_global_var_init1();
 ___cxx_global_var_init2();
 STACKTOP = sp;return;
}
function __Z10b2DistanceRK6b2Vec2S1_($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0.0, $c = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $c = sp;
 __ZmiRK6b2Vec2S1_($c,$a,$b);
 $0 = (+__ZNK6b2Vec26LengthEv($c));
 STACKTOP = sp;return (+$0);
}
function __ZmlfRK6b2Vec2($agg$result,$s,$a) {
 $agg$result = $agg$result|0;
 $s = +$s;
 $a = $a|0;
 var $0 = 0.0, $1 = 0.0, $2 = 0, $3 = 0.0, $4 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$a>>2];
 $1 = $0 * $s;
 $2 = (($a) + 4|0);
 $3 = +HEAPF32[$2>>2];
 $4 = $3 * $s;
 __ZN6b2Vec2C2Eff($agg$result,$1,$4);
 STACKTOP = sp;return;
}
function __ZN6b2Vec2mLEf($this,$a) {
 $this = $this|0;
 $a = +$a;
 var $0 = 0.0, $1 = 0.0, $2 = 0, $3 = 0.0, $4 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$this>>2];
 $1 = $0 * $a;
 HEAPF32[$this>>2] = $1;
 $2 = (($this) + 4|0);
 $3 = +HEAPF32[$2>>2];
 $4 = $3 * $a;
 HEAPF32[$2>>2] = $4;
 STACKTOP = sp;return;
}
function __ZN6b2Vec29NormalizeEv($this) {
 $this = $this|0;
 var $$0 = 0.0, $0 = 0.0, $1 = 0, $2 = 0.0, $3 = 0.0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+__ZNK6b2Vec26LengthEv($this));
 $1 = $0 < 1.1920928955078125E-7;
 if ($1) {
  $$0 = 0.0;
  STACKTOP = sp;return (+$$0);
 }
 $2 = 1.0 / $0;
 $3 = +HEAPF32[$this>>2];
 $4 = $2 * $3;
 HEAPF32[$this>>2] = $4;
 $5 = (($this) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $2 * $6;
 HEAPF32[$5>>2] = $7;
 $$0 = $0;
 STACKTOP = sp;return (+$$0);
}
function __ZN6b2Vec2mIERKS_($this,$v) {
 $this = $this|0;
 $v = $v|0;
 var $0 = 0.0, $1 = 0.0, $2 = 0.0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$v>>2];
 $1 = +HEAPF32[$this>>2];
 $2 = $1 - $0;
 HEAPF32[$this>>2] = $2;
 $3 = (($v) + 4|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($this) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $6 - $4;
 HEAPF32[$5>>2] = $7;
 STACKTOP = sp;return;
}
function __ZNK6b2Vec213LengthSquaredEv($this) {
 $this = $this|0;
 var $0 = 0.0, $1 = 0.0, $2 = 0, $3 = 0.0, $4 = 0.0, $5 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$this>>2];
 $1 = $0 * $0;
 $2 = (($this) + 4|0);
 $3 = +HEAPF32[$2>>2];
 $4 = $3 * $3;
 $5 = $1 + $4;
 STACKTOP = sp;return (+$5);
}
function __ZNK6b2Vec2ngEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0.0, $1 = 0.0, $2 = 0, $3 = 0.0, $4 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$this>>2];
 $1 = -$0;
 $2 = (($this) + 4|0);
 $3 = +HEAPF32[$2>>2];
 $4 = -$3;
 __ZN6b2Vec23SetEff($agg$result,$1,$4);
 STACKTOP = sp;return;
}
function __ZNK6b2Vec26LengthEv($this) {
 $this = $this|0;
 var $0 = 0.0, $1 = 0.0, $2 = 0, $3 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$this>>2];
 $1 = $0 * $0;
 $2 = (($this) + 4|0);
 $3 = +HEAPF32[$2>>2];
 $4 = $3 * $3;
 $5 = $1 + $4;
 $6 = (+Math_sqrt((+$5)));
 STACKTOP = sp;return (+$6);
}
function __Z14b2TimeOfImpactP11b2TOIOutputPK10b2TOIInput($output,$input) {
 $output = $output|0;
 $input = $input|0;
 var $$s1$0 = 0.0, $0 = 0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0;
 var $26 = 0, $27 = 0.0, $28 = 0, $29 = 0, $3 = 0.0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0;
 var $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $8 = 0.0, $9 = 0, $a1$0 = 0.0, $a2$0 = 0.0, $a2$0$t$0 = 0.0, $cache = 0, $distanceInput = 0;
 var $distanceOutput = 0, $fcn = 0, $indexA = 0, $indexB = 0, $iter$0 = 0, $iter$1 = 0, $pushBackIter$0 = 0, $rootIterCount$0 = 0, $s1$0 = 0.0, $s2$0 = 0.0, $s2$0$ = 0.0, $sweepA = 0, $sweepB = 0, $t$0 = 0.0, $t$0$a1$0 = 0.0, $t1$0 = 0.0, $t1$1 = 0.0, $t2$0 = 0.0, $t2$1 = 0.0, $timer = 0;
 var $xfA = 0, $xfB = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 352|0;
 $timer = sp;
 $sweepA = sp + 316|0;
 $sweepB = sp + 280|0;
 $cache = sp + 268|0;
 $distanceInput = sp + 176|0;
 $xfA = sp + 160|0;
 $xfB = sp + 144|0;
 $distanceOutput = sp + 120|0;
 $fcn = sp + 16|0;
 $indexA = sp + 12|0;
 $indexB = sp + 8|0;
 __ZN7b2TimerC2Ev($timer);
 $0 = HEAP32[1864>>2]|0;
 $1 = (($0) + 1)|0;
 HEAP32[1864>>2] = $1;
 HEAP32[$output>>2] = 0;
 $2 = (($input) + 128|0);
 $3 = +HEAPF32[$2>>2];
 $4 = (($output) + 4|0);
 HEAPF32[$4>>2] = $3;
 $5 = (($input) + 28|0);
 $6 = (($input) + 56|0);
 dest=$sweepA+0|0; src=$6+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $7 = (($input) + 92|0);
 dest=$sweepB+0|0; src=$7+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 __ZN7b2Sweep9NormalizeEv($sweepA);
 __ZN7b2Sweep9NormalizeEv($sweepB);
 $8 = +HEAPF32[$2>>2];
 $9 = (($input) + 24|0);
 $10 = +HEAPF32[$9>>2];
 $11 = (($input) + 52|0);
 $12 = +HEAPF32[$11>>2];
 $13 = $10 + $12;
 $14 = $13 + -0.014999999664723873;
 $15 = (+__Z5b2MaxIfET_S0_S0_(0.004999999888241291,$14));
 $16 = (($cache) + 4|0);
 HEAP16[$16>>1] = 0;
 __ZN15b2DistanceInputC2Ev($distanceInput);
 ;HEAP32[$distanceInput+0>>2]=HEAP32[$input+0>>2]|0;HEAP32[$distanceInput+4>>2]=HEAP32[$input+4>>2]|0;HEAP32[$distanceInput+8>>2]=HEAP32[$input+8>>2]|0;HEAP32[$distanceInput+12>>2]=HEAP32[$input+12>>2]|0;HEAP32[$distanceInput+16>>2]=HEAP32[$input+16>>2]|0;HEAP32[$distanceInput+20>>2]=HEAP32[$input+20>>2]|0;HEAP32[$distanceInput+24>>2]=HEAP32[$input+24>>2]|0;
 $17 = (($distanceInput) + 28|0);
 ;HEAP32[$17+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$17+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$17+12>>2]=HEAP32[$5+12>>2]|0;HEAP32[$17+16>>2]=HEAP32[$5+16>>2]|0;HEAP32[$17+20>>2]=HEAP32[$5+20>>2]|0;HEAP32[$17+24>>2]=HEAP32[$5+24>>2]|0;
 $18 = (($distanceInput) + 88|0);
 HEAP8[$18>>0] = 0;
 $19 = (($distanceInput) + 56|0);
 $20 = (($distanceInput) + 72|0);
 $21 = (($distanceOutput) + 16|0);
 $22 = $15 + 0.0012499999720603228;
 $23 = $15 + -0.0012499999720603228;
 $iter$0 = 0;$t1$0 = 0.0;
 L1: while(1) {
  __ZNK7b2Sweep12GetTransformEP11b2Transformf($sweepA,$xfA,$t1$0);
  __ZNK7b2Sweep12GetTransformEP11b2Transformf($sweepB,$xfB,$t1$0);
  ;HEAP32[$19+0>>2]=HEAP32[$xfA+0>>2]|0;HEAP32[$19+4>>2]=HEAP32[$xfA+4>>2]|0;HEAP32[$19+8>>2]=HEAP32[$xfA+8>>2]|0;HEAP32[$19+12>>2]=HEAP32[$xfA+12>>2]|0;
  ;HEAP32[$20+0>>2]=HEAP32[$xfB+0>>2]|0;HEAP32[$20+4>>2]=HEAP32[$xfB+4>>2]|0;HEAP32[$20+8>>2]=HEAP32[$xfB+8>>2]|0;HEAP32[$20+12>>2]=HEAP32[$xfB+12>>2]|0;
  __Z10b2DistanceP16b2DistanceOutputP14b2SimplexCachePK15b2DistanceInput($distanceOutput,$cache,$distanceInput);
  $24 = +HEAPF32[$21>>2];
  $25 = !($24 <= 0.0);
  if (!($25)) {
   label = 3;
   break;
  }
  $26 = $24 < $22;
  if ($26) {
   label = 5;
   break;
  }
  (+__ZN20b2SeparationFunction10InitializeEPK14b2SimplexCachePK15b2DistanceProxyRK7b2SweepS5_S8_f($fcn,$cache,$input,$sweepA,$5,$sweepB,$t1$0));
  $pushBackIter$0 = 0;$t2$0 = $8;
  while(1) {
   $27 = (+__ZNK20b2SeparationFunction17FindMinSeparationEPiS0_f($fcn,$indexA,$indexB,$t2$0));
   $28 = $27 > $22;
   if ($28) {
    label = 8;
    break L1;
   }
   $29 = $27 > $23;
   if ($29) {
    $t1$1 = $t2$0;
    break;
   }
   $30 = HEAP32[$indexA>>2]|0;
   $31 = HEAP32[$indexB>>2]|0;
   $32 = (+__ZNK20b2SeparationFunction8EvaluateEiif($fcn,$30,$31,$t1$0));
   $33 = $32 < $23;
   if ($33) {
    label = 11;
    break L1;
   }
   $34 = !($32 <= $22);
   if (!($34)) {
    label = 14;
    break L1;
   }
   $35 = HEAP32[$indexA>>2]|0;
   $36 = HEAP32[$indexB>>2]|0;
   $a1$0 = $t1$0;$a2$0 = $t2$0;$rootIterCount$0 = 0;$s1$0 = $32;$s2$0 = $27;
   while(1) {
    $37 = $rootIterCount$0 & 1;
    $38 = ($37|0)==(0);
    if ($38) {
     $45 = $a1$0 + $a2$0;
     $46 = $45 * 0.5;
     $t$0 = $46;
    } else {
     $39 = $15 - $s1$0;
     $40 = $a2$0 - $a1$0;
     $41 = $39 * $40;
     $42 = $s2$0 - $s1$0;
     $43 = $41 / $42;
     $44 = $a1$0 + $43;
     $t$0 = $44;
    }
    $47 = (($rootIterCount$0) + 1)|0;
    $48 = HEAP32[1888>>2]|0;
    $49 = (($48) + 1)|0;
    HEAP32[1888>>2] = $49;
    $50 = (+__ZNK20b2SeparationFunction8EvaluateEiif($fcn,$35,$36,$t$0));
    $51 = $50 - $15;
    $52 = (+__Z5b2AbsIfET_S0_($51));
    $53 = $52 < 0.0012499999720603228;
    if ($53) {
     $t2$1 = $t$0;
     break;
    }
    $54 = $50 > $15;
    $s2$0$ = $54 ? $s2$0 : $50;
    $$s1$0 = $54 ? $50 : $s1$0;
    $t$0$a1$0 = $54 ? $t$0 : $a1$0;
    $a2$0$t$0 = $54 ? $a2$0 : $t$0;
    $55 = ($47|0)==(50);
    if ($55) {
     $t2$1 = $t2$0;
     break;
    } else {
     $a1$0 = $t$0$a1$0;$a2$0 = $a2$0$t$0;$rootIterCount$0 = $47;$s1$0 = $$s1$0;$s2$0 = $s2$0$;
    }
   }
   $56 = HEAP32[1896>>2]|0;
   $57 = (__Z5b2MaxIiET_S0_S0_($56,$47)|0);
   HEAP32[1896>>2] = $57;
   $58 = (($pushBackIter$0) + 1)|0;
   $59 = ($58|0)==(8);
   if ($59) {
    $t1$1 = $t1$0;
    break;
   } else {
    $pushBackIter$0 = $58;$t2$0 = $t2$1;
   }
  }
  $63 = (($iter$0) + 1)|0;
  $64 = HEAP32[1872>>2]|0;
  $65 = (($64) + 1)|0;
  HEAP32[1872>>2] = $65;
  $66 = ($63|0)==(20);
  if ($66) {
   label = 23;
   break;
  } else {
   $iter$0 = $63;$t1$0 = $t1$1;
  }
 }
 if ((label|0) == 3) {
  HEAP32[$output>>2] = 2;
  HEAPF32[$4>>2] = 0.0;
  $iter$1 = $iter$0;
 }
 else if ((label|0) == 5) {
  HEAP32[$output>>2] = 3;
  HEAPF32[$4>>2] = $t1$0;
  $iter$1 = $iter$0;
 }
 else if ((label|0) == 8) {
  HEAP32[$output>>2] = 4;
  HEAPF32[$4>>2] = $8;
  label = 21;
 }
 else if ((label|0) == 11) {
  HEAP32[$output>>2] = 1;
  HEAPF32[$4>>2] = $t1$0;
  label = 21;
 }
 else if ((label|0) == 14) {
  HEAP32[$output>>2] = 3;
  HEAPF32[$4>>2] = $t1$0;
  label = 21;
 }
 else if ((label|0) == 23) {
  HEAP32[$output>>2] = 1;
  HEAPF32[$4>>2] = $t1$1;
  $iter$1 = 20;
 }
 if ((label|0) == 21) {
  $60 = (($iter$0) + 1)|0;
  $61 = HEAP32[1872>>2]|0;
  $62 = (($61) + 1)|0;
  HEAP32[1872>>2] = $62;
  $iter$1 = $60;
 }
 $67 = HEAP32[1880>>2]|0;
 $68 = (__Z5b2MaxIiET_S0_S0_($67,$iter$1)|0);
 HEAP32[1880>>2] = $68;
 $69 = (+__ZNK7b2Timer15GetMillisecondsEv($timer));
 $70 = +HEAPF32[1856>>2];
 $71 = (+__Z5b2MaxIfET_S0_S0_($70,$69));
 HEAPF32[1856>>2] = $71;
 $72 = +HEAPF32[1848>>2];
 $73 = $69 + $72;
 HEAPF32[1848>>2] = $73;
 STACKTOP = sp;return;
}
function __ZN7b2Sweep9NormalizeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0.0, $2 = 0.0, $3 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0, $7 = 0.0, $8 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = +HEAPF32[$0>>2];
 $2 = $1 / 6.2831854820251465;
 $3 = (+Math_floor((+$2)));
 $4 = $3 * 6.2831854820251465;
 $5 = $1 - $4;
 HEAPF32[$0>>2] = $5;
 $6 = (($this) + 28|0);
 $7 = +HEAPF32[$6>>2];
 $8 = $7 - $4;
 HEAPF32[$6>>2] = $8;
 STACKTOP = sp;return;
}
function __Z5b2MaxIfET_S0_S0_($a,$b) {
 $a = +$a;
 $b = +$b;
 var $0 = 0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $a > $b;
 $1 = $0 ? $a : $b;
 STACKTOP = sp;return (+$1);
}
function __ZN15b2DistanceInputC2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN15b2DistanceProxyC2Ev($this);
 $0 = (($this) + 28|0);
 __ZN15b2DistanceProxyC2Ev($0);
 STACKTOP = sp;return;
}
function __ZNK7b2Sweep12GetTransformEP11b2Transformf($this,$xf,$beta) {
 $this = $this|0;
 $xf = $xf|0;
 $beta = +$beta;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0, $3 = 0, $4 = 0.0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = sp + 24|0;
 $2 = sp + 16|0;
 $3 = sp + 8|0;
 $4 = 1.0 - $beta;
 $5 = (($this) + 8|0);
 __ZmlfRK6b2Vec2($1,$4,$5);
 $6 = (($this) + 16|0);
 __ZmlfRK6b2Vec2($2,$beta,$6);
 __ZplRK6b2Vec2S1_($0,$1,$2);
 $7 = $0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 4)|0;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = $xf;
 $14 = $13;
 HEAP32[$14>>2] = $9;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = $12;
 $17 = (($this) + 24|0);
 $18 = +HEAPF32[$17>>2];
 $19 = $4 * $18;
 $20 = (($this) + 28|0);
 $21 = +HEAPF32[$20>>2];
 $22 = $21 * $beta;
 $23 = $19 + $22;
 $24 = (($xf) + 8|0);
 __ZN5b2Rot3SetEf($24,$23);
 __Z5b2MulRK5b2RotRK6b2Vec2($3,$24,$this);
 __ZN6b2Vec2mIERKS_($xf,$3);
 STACKTOP = sp;return;
}
function __ZN20b2SeparationFunction10InitializeEPK14b2SimplexCachePK15b2DistanceProxyRK7b2SweepS5_S8_f($this,$cache,$proxyA,$sweepA,$proxyB,$sweepB,$t1) {
 $this = $this|0;
 $cache = $cache|0;
 $proxyA = $proxyA|0;
 $sweepA = $sweepA|0;
 $proxyB = $proxyB|0;
 $sweepB = $sweepB|0;
 $t1 = +$t1;
 var $$0 = 0.0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0.0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0.0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0.0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0.0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $localPointA = 0, $localPointA1 = 0, $localPointA2 = 0, $localPointA25 = 0;
 var $localPointB = 0, $localPointB1 = 0, $localPointB2 = 0, $localPointB8 = 0, $normal = 0, $normal6 = 0, $pointA = 0, $pointA3 = 0, $pointA7 = 0, $pointB = 0, $pointB1 = 0, $pointB9 = 0, $xfA = 0, $xfB = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $xfA = sp + 248|0;
 $xfB = sp + 232|0;
 $localPointA = sp + 112|0;
 $localPointB = sp + 104|0;
 $pointA = sp + 224|0;
 $pointB = sp + 216|0;
 $0 = sp + 96|0;
 $localPointB1 = sp + 88|0;
 $localPointB2 = sp + 80|0;
 $1 = sp + 72|0;
 $2 = sp + 208|0;
 $normal = sp + 200|0;
 $3 = sp + 64|0;
 $4 = sp + 192|0;
 $pointB1 = sp + 184|0;
 $localPointA2 = sp + 56|0;
 $pointA3 = sp + 176|0;
 $5 = sp + 168|0;
 $6 = sp + 48|0;
 $localPointA1 = sp + 40|0;
 $localPointA25 = sp + 32|0;
 $7 = sp + 24|0;
 $8 = sp + 160|0;
 $normal6 = sp + 152|0;
 $9 = sp + 16|0;
 $10 = sp + 144|0;
 $pointA7 = sp + 136|0;
 $localPointB8 = sp + 8|0;
 $pointB9 = sp + 128|0;
 $11 = sp + 120|0;
 $12 = sp;
 HEAP32[$this>>2] = $proxyA;
 $13 = (($this) + 4|0);
 HEAP32[$13>>2] = $proxyB;
 $14 = (($cache) + 4|0);
 $15 = HEAP16[$14>>1]|0;
 $16 = (($this) + 8|0);
 dest=$16+0|0; src=$sweepA+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $17 = (($this) + 44|0);
 dest=$17+0|0; src=$sweepB+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 __ZNK7b2Sweep12GetTransformEP11b2Transformf($16,$xfA,$t1);
 __ZNK7b2Sweep12GetTransformEP11b2Transformf($17,$xfB,$t1);
 $18 = ($15<<16>>16)==(1);
 if ($18) {
  $19 = (($this) + 80|0);
  HEAP32[$19>>2] = 0;
  $20 = HEAP32[$this>>2]|0;
  $21 = (($cache) + 6|0);
  $22 = HEAP8[$21>>0]|0;
  $23 = $22&255;
  $24 = (__ZNK15b2DistanceProxy9GetVertexEi($20,$23)|0);
  $25 = $24;
  $26 = $25;
  $27 = HEAP32[$26>>2]|0;
  $28 = (($25) + 4)|0;
  $29 = $28;
  $30 = HEAP32[$29>>2]|0;
  $31 = $localPointA;
  $32 = $31;
  HEAP32[$32>>2] = $27;
  $33 = (($31) + 4)|0;
  $34 = $33;
  HEAP32[$34>>2] = $30;
  $35 = HEAP32[$13>>2]|0;
  $36 = (($cache) + 9|0);
  $37 = HEAP8[$36>>0]|0;
  $38 = $37&255;
  $39 = (__ZNK15b2DistanceProxy9GetVertexEi($35,$38)|0);
  $40 = $39;
  $41 = $40;
  $42 = HEAP32[$41>>2]|0;
  $43 = (($40) + 4)|0;
  $44 = $43;
  $45 = HEAP32[$44>>2]|0;
  $46 = $localPointB;
  $47 = $46;
  HEAP32[$47>>2] = $42;
  $48 = (($46) + 4)|0;
  $49 = $48;
  HEAP32[$49>>2] = $45;
  __Z5b2MulRK11b2TransformRK6b2Vec2($pointA,$xfA,$localPointA);
  __Z5b2MulRK11b2TransformRK6b2Vec2($pointB,$xfB,$localPointB);
  $50 = (($this) + 92|0);
  __ZmiRK6b2Vec2S1_($0,$pointB,$pointA);
  $51 = $0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = (($51) + 4)|0;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = $50;
  $58 = $57;
  HEAP32[$58>>2] = $53;
  $59 = (($57) + 4)|0;
  $60 = $59;
  HEAP32[$60>>2] = $56;
  $61 = (+__ZN6b2Vec29NormalizeEv($50));
  $62 = (($this) + 84|0);
  $63 = 10224;
  $64 = $63;
  $65 = HEAP32[$64>>2]|0;
  $66 = (($63) + 4)|0;
  $67 = $66;
  $68 = HEAP32[$67>>2]|0;
  $69 = $62;
  $70 = $69;
  HEAP32[$70>>2] = $65;
  $71 = (($69) + 4)|0;
  $72 = $71;
  HEAP32[$72>>2] = $68;
  $$0 = $61;
  STACKTOP = sp;return (+$$0);
 }
 $73 = (($cache) + 6|0);
 $74 = HEAP8[$73>>0]|0;
 $75 = (($cache) + 7|0);
 $76 = HEAP8[$75>>0]|0;
 $77 = ($74<<24>>24)==($76<<24>>24);
 $78 = (($this) + 80|0);
 if ($77) {
  HEAP32[$78>>2] = 2;
  $79 = (($cache) + 9|0);
  $80 = HEAP8[$79>>0]|0;
  $81 = $80&255;
  $82 = (__ZNK15b2DistanceProxy9GetVertexEi($proxyB,$81)|0);
  $83 = $82;
  $84 = $83;
  $85 = HEAP32[$84>>2]|0;
  $86 = (($83) + 4)|0;
  $87 = $86;
  $88 = HEAP32[$87>>2]|0;
  $89 = $localPointB1;
  $90 = $89;
  HEAP32[$90>>2] = $85;
  $91 = (($89) + 4)|0;
  $92 = $91;
  HEAP32[$92>>2] = $88;
  $93 = (($cache) + 10|0);
  $94 = HEAP8[$93>>0]|0;
  $95 = $94&255;
  $96 = (__ZNK15b2DistanceProxy9GetVertexEi($proxyB,$95)|0);
  $97 = $96;
  $98 = $97;
  $99 = HEAP32[$98>>2]|0;
  $100 = (($97) + 4)|0;
  $101 = $100;
  $102 = HEAP32[$101>>2]|0;
  $103 = $localPointB2;
  $104 = $103;
  HEAP32[$104>>2] = $99;
  $105 = (($103) + 4)|0;
  $106 = $105;
  HEAP32[$106>>2] = $102;
  $107 = (($this) + 92|0);
  __ZmiRK6b2Vec2S1_($2,$localPointB2,$localPointB1);
  __Z7b2CrossRK6b2Vec2f($1,$2,1.0);
  $108 = $1;
  $109 = $108;
  $110 = HEAP32[$109>>2]|0;
  $111 = (($108) + 4)|0;
  $112 = $111;
  $113 = HEAP32[$112>>2]|0;
  $114 = $107;
  $115 = $114;
  HEAP32[$115>>2] = $110;
  $116 = (($114) + 4)|0;
  $117 = $116;
  HEAP32[$117>>2] = $113;
  (+__ZN6b2Vec29NormalizeEv($107));
  $118 = (($xfB) + 8|0);
  __Z5b2MulRK5b2RotRK6b2Vec2($normal,$118,$107);
  $119 = (($this) + 84|0);
  __ZplRK6b2Vec2S1_($4,$localPointB1,$localPointB2);
  __ZmlfRK6b2Vec2($3,0.5,$4);
  $120 = $3;
  $121 = $120;
  $122 = HEAP32[$121>>2]|0;
  $123 = (($120) + 4)|0;
  $124 = $123;
  $125 = HEAP32[$124>>2]|0;
  $126 = $119;
  $127 = $126;
  HEAP32[$127>>2] = $122;
  $128 = (($126) + 4)|0;
  $129 = $128;
  HEAP32[$129>>2] = $125;
  __Z5b2MulRK11b2TransformRK6b2Vec2($pointB1,$xfB,$119);
  $130 = HEAP8[$73>>0]|0;
  $131 = $130&255;
  $132 = (__ZNK15b2DistanceProxy9GetVertexEi($proxyA,$131)|0);
  $133 = $132;
  $134 = $133;
  $135 = HEAP32[$134>>2]|0;
  $136 = (($133) + 4)|0;
  $137 = $136;
  $138 = HEAP32[$137>>2]|0;
  $139 = $localPointA2;
  $140 = $139;
  HEAP32[$140>>2] = $135;
  $141 = (($139) + 4)|0;
  $142 = $141;
  HEAP32[$142>>2] = $138;
  __Z5b2MulRK11b2TransformRK6b2Vec2($pointA3,$xfA,$localPointA2);
  __ZmiRK6b2Vec2S1_($5,$pointA3,$pointB1);
  $143 = (+__Z5b2DotRK6b2Vec2S1_($5,$normal));
  $144 = $143 < 0.0;
  if (!($144)) {
   $$0 = $143;
   STACKTOP = sp;return (+$$0);
  }
  __ZNK6b2Vec2ngEv($6,$107);
  $145 = $6;
  $146 = $145;
  $147 = HEAP32[$146>>2]|0;
  $148 = (($145) + 4)|0;
  $149 = $148;
  $150 = HEAP32[$149>>2]|0;
  $151 = $107;
  $152 = $151;
  HEAP32[$152>>2] = $147;
  $153 = (($151) + 4)|0;
  $154 = $153;
  HEAP32[$154>>2] = $150;
  $155 = -$143;
  $$0 = $155;
  STACKTOP = sp;return (+$$0);
 } else {
  HEAP32[$78>>2] = 1;
  $156 = HEAP32[$this>>2]|0;
  $157 = HEAP8[$73>>0]|0;
  $158 = $157&255;
  $159 = (__ZNK15b2DistanceProxy9GetVertexEi($156,$158)|0);
  $160 = $159;
  $161 = $160;
  $162 = HEAP32[$161>>2]|0;
  $163 = (($160) + 4)|0;
  $164 = $163;
  $165 = HEAP32[$164>>2]|0;
  $166 = $localPointA1;
  $167 = $166;
  HEAP32[$167>>2] = $162;
  $168 = (($166) + 4)|0;
  $169 = $168;
  HEAP32[$169>>2] = $165;
  $170 = HEAP32[$this>>2]|0;
  $171 = HEAP8[$75>>0]|0;
  $172 = $171&255;
  $173 = (__ZNK15b2DistanceProxy9GetVertexEi($170,$172)|0);
  $174 = $173;
  $175 = $174;
  $176 = HEAP32[$175>>2]|0;
  $177 = (($174) + 4)|0;
  $178 = $177;
  $179 = HEAP32[$178>>2]|0;
  $180 = $localPointA25;
  $181 = $180;
  HEAP32[$181>>2] = $176;
  $182 = (($180) + 4)|0;
  $183 = $182;
  HEAP32[$183>>2] = $179;
  $184 = (($this) + 92|0);
  __ZmiRK6b2Vec2S1_($8,$localPointA25,$localPointA1);
  __Z7b2CrossRK6b2Vec2f($7,$8,1.0);
  $185 = $7;
  $186 = $185;
  $187 = HEAP32[$186>>2]|0;
  $188 = (($185) + 4)|0;
  $189 = $188;
  $190 = HEAP32[$189>>2]|0;
  $191 = $184;
  $192 = $191;
  HEAP32[$192>>2] = $187;
  $193 = (($191) + 4)|0;
  $194 = $193;
  HEAP32[$194>>2] = $190;
  (+__ZN6b2Vec29NormalizeEv($184));
  $195 = (($xfA) + 8|0);
  __Z5b2MulRK5b2RotRK6b2Vec2($normal6,$195,$184);
  $196 = (($this) + 84|0);
  __ZplRK6b2Vec2S1_($10,$localPointA1,$localPointA25);
  __ZmlfRK6b2Vec2($9,0.5,$10);
  $197 = $9;
  $198 = $197;
  $199 = HEAP32[$198>>2]|0;
  $200 = (($197) + 4)|0;
  $201 = $200;
  $202 = HEAP32[$201>>2]|0;
  $203 = $196;
  $204 = $203;
  HEAP32[$204>>2] = $199;
  $205 = (($203) + 4)|0;
  $206 = $205;
  HEAP32[$206>>2] = $202;
  __Z5b2MulRK11b2TransformRK6b2Vec2($pointA7,$xfA,$196);
  $207 = HEAP32[$13>>2]|0;
  $208 = (($cache) + 9|0);
  $209 = HEAP8[$208>>0]|0;
  $210 = $209&255;
  $211 = (__ZNK15b2DistanceProxy9GetVertexEi($207,$210)|0);
  $212 = $211;
  $213 = $212;
  $214 = HEAP32[$213>>2]|0;
  $215 = (($212) + 4)|0;
  $216 = $215;
  $217 = HEAP32[$216>>2]|0;
  $218 = $localPointB8;
  $219 = $218;
  HEAP32[$219>>2] = $214;
  $220 = (($218) + 4)|0;
  $221 = $220;
  HEAP32[$221>>2] = $217;
  __Z5b2MulRK11b2TransformRK6b2Vec2($pointB9,$xfB,$localPointB8);
  __ZmiRK6b2Vec2S1_($11,$pointB9,$pointA7);
  $222 = (+__Z5b2DotRK6b2Vec2S1_($11,$normal6));
  $223 = $222 < 0.0;
  if (!($223)) {
   $$0 = $222;
   STACKTOP = sp;return (+$$0);
  }
  __ZNK6b2Vec2ngEv($12,$184);
  $224 = $12;
  $225 = $224;
  $226 = HEAP32[$225>>2]|0;
  $227 = (($224) + 4)|0;
  $228 = $227;
  $229 = HEAP32[$228>>2]|0;
  $230 = $184;
  $231 = $230;
  HEAP32[$231>>2] = $226;
  $232 = (($230) + 4)|0;
  $233 = $232;
  HEAP32[$233>>2] = $229;
  $234 = -$222;
  $$0 = $234;
  STACKTOP = sp;return (+$$0);
 }
 return +(0.0);
}
function __ZNK20b2SeparationFunction17FindMinSeparationEPiS0_f($this,$indexA,$indexB,$t) {
 $this = $this|0;
 $indexA = $indexA|0;
 $indexB = $indexB|0;
 $t = +$t;
 var $$0 = 0.0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0.0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0.0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0.0, $9 = 0, $axisA = 0, $axisA8 = 0, $axisB = 0, $axisB2 = 0, $localPointA = 0, $localPointA9 = 0, $localPointB = 0, $localPointB3 = 0, $normal = 0, $normal6 = 0, $pointA = 0, $pointA1 = 0, $pointA10 = 0, $pointB = 0, $pointB4 = 0;
 var $pointB7 = 0, $xfA = 0, $xfB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $xfA = sp + 192|0;
 $xfB = sp + 176|0;
 $axisA = sp + 168|0;
 $axisB = sp + 160|0;
 $0 = sp + 152|0;
 $localPointA = sp + 24|0;
 $localPointB = sp + 16|0;
 $pointA = sp + 144|0;
 $pointB = sp + 136|0;
 $1 = sp + 128|0;
 $normal = sp + 120|0;
 $pointA1 = sp + 112|0;
 $axisB2 = sp + 104|0;
 $2 = sp + 96|0;
 $localPointB3 = sp + 8|0;
 $pointB4 = sp + 88|0;
 $3 = sp + 80|0;
 $normal6 = sp + 72|0;
 $pointB7 = sp + 64|0;
 $axisA8 = sp + 56|0;
 $4 = sp + 48|0;
 $localPointA9 = sp;
 $pointA10 = sp + 40|0;
 $5 = sp + 32|0;
 $6 = (($this) + 8|0);
 __ZNK7b2Sweep12GetTransformEP11b2Transformf($6,$xfA,$t);
 $7 = (($this) + 44|0);
 __ZNK7b2Sweep12GetTransformEP11b2Transformf($7,$xfB,$t);
 $8 = (($this) + 80|0);
 $9 = HEAP32[$8>>2]|0;
 if ((($9|0) == 2)) {
  $65 = (($xfB) + 8|0);
  $66 = (($this) + 92|0);
  __Z5b2MulRK5b2RotRK6b2Vec2($normal6,$65,$66);
  $67 = (($this) + 84|0);
  __Z5b2MulRK11b2TransformRK6b2Vec2($pointB7,$xfB,$67);
  $68 = (($xfA) + 8|0);
  __ZNK6b2Vec2ngEv($4,$normal6);
  __Z6b2MulTRK5b2RotRK6b2Vec2($axisA8,$68,$4);
  HEAP32[$indexB>>2] = -1;
  $69 = HEAP32[$this>>2]|0;
  $70 = (__ZNK15b2DistanceProxy10GetSupportERK6b2Vec2($69,$axisA8)|0);
  HEAP32[$indexA>>2] = $70;
  $71 = HEAP32[$this>>2]|0;
  $72 = (__ZNK15b2DistanceProxy9GetVertexEi($71,$70)|0);
  $73 = $72;
  $74 = $73;
  $75 = HEAP32[$74>>2]|0;
  $76 = (($73) + 4)|0;
  $77 = $76;
  $78 = HEAP32[$77>>2]|0;
  $79 = $localPointA9;
  $80 = $79;
  HEAP32[$80>>2] = $75;
  $81 = (($79) + 4)|0;
  $82 = $81;
  HEAP32[$82>>2] = $78;
  __Z5b2MulRK11b2TransformRK6b2Vec2($pointA10,$xfA,$localPointA9);
  __ZmiRK6b2Vec2S1_($5,$pointA10,$pointB7);
  $83 = (+__Z5b2DotRK6b2Vec2S1_($5,$normal6));
  $$0 = $83;
  STACKTOP = sp;return (+$$0);
 } else if ((($9|0) == 1)) {
  $45 = (($xfA) + 8|0);
  $46 = (($this) + 92|0);
  __Z5b2MulRK5b2RotRK6b2Vec2($normal,$45,$46);
  $47 = (($this) + 84|0);
  __Z5b2MulRK11b2TransformRK6b2Vec2($pointA1,$xfA,$47);
  $48 = (($xfB) + 8|0);
  __ZNK6b2Vec2ngEv($2,$normal);
  __Z6b2MulTRK5b2RotRK6b2Vec2($axisB2,$48,$2);
  HEAP32[$indexA>>2] = -1;
  $49 = (($this) + 4|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = (__ZNK15b2DistanceProxy10GetSupportERK6b2Vec2($50,$axisB2)|0);
  HEAP32[$indexB>>2] = $51;
  $52 = HEAP32[$49>>2]|0;
  $53 = (__ZNK15b2DistanceProxy9GetVertexEi($52,$51)|0);
  $54 = $53;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = (($54) + 4)|0;
  $58 = $57;
  $59 = HEAP32[$58>>2]|0;
  $60 = $localPointB3;
  $61 = $60;
  HEAP32[$61>>2] = $56;
  $62 = (($60) + 4)|0;
  $63 = $62;
  HEAP32[$63>>2] = $59;
  __Z5b2MulRK11b2TransformRK6b2Vec2($pointB4,$xfB,$localPointB3);
  __ZmiRK6b2Vec2S1_($3,$pointB4,$pointA1);
  $64 = (+__Z5b2DotRK6b2Vec2S1_($3,$normal));
  $$0 = $64;
  STACKTOP = sp;return (+$$0);
 } else if ((($9|0) == 0)) {
  $10 = (($xfA) + 8|0);
  $11 = (($this) + 92|0);
  __Z6b2MulTRK5b2RotRK6b2Vec2($axisA,$10,$11);
  $12 = (($xfB) + 8|0);
  __ZNK6b2Vec2ngEv($0,$11);
  __Z6b2MulTRK5b2RotRK6b2Vec2($axisB,$12,$0);
  $13 = HEAP32[$this>>2]|0;
  $14 = (__ZNK15b2DistanceProxy10GetSupportERK6b2Vec2($13,$axisA)|0);
  HEAP32[$indexA>>2] = $14;
  $15 = (($this) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (__ZNK15b2DistanceProxy10GetSupportERK6b2Vec2($16,$axisB)|0);
  HEAP32[$indexB>>2] = $17;
  $18 = HEAP32[$this>>2]|0;
  $19 = HEAP32[$indexA>>2]|0;
  $20 = (__ZNK15b2DistanceProxy9GetVertexEi($18,$19)|0);
  $21 = $20;
  $22 = $21;
  $23 = HEAP32[$22>>2]|0;
  $24 = (($21) + 4)|0;
  $25 = $24;
  $26 = HEAP32[$25>>2]|0;
  $27 = $localPointA;
  $28 = $27;
  HEAP32[$28>>2] = $23;
  $29 = (($27) + 4)|0;
  $30 = $29;
  HEAP32[$30>>2] = $26;
  $31 = HEAP32[$15>>2]|0;
  $32 = HEAP32[$indexB>>2]|0;
  $33 = (__ZNK15b2DistanceProxy9GetVertexEi($31,$32)|0);
  $34 = $33;
  $35 = $34;
  $36 = HEAP32[$35>>2]|0;
  $37 = (($34) + 4)|0;
  $38 = $37;
  $39 = HEAP32[$38>>2]|0;
  $40 = $localPointB;
  $41 = $40;
  HEAP32[$41>>2] = $36;
  $42 = (($40) + 4)|0;
  $43 = $42;
  HEAP32[$43>>2] = $39;
  __Z5b2MulRK11b2TransformRK6b2Vec2($pointA,$xfA,$localPointA);
  __Z5b2MulRK11b2TransformRK6b2Vec2($pointB,$xfB,$localPointB);
  __ZmiRK6b2Vec2S1_($1,$pointB,$pointA);
  $44 = (+__Z5b2DotRK6b2Vec2S1_($1,$11));
  $$0 = $44;
  STACKTOP = sp;return (+$$0);
 } else {
  HEAP32[$indexA>>2] = -1;
  HEAP32[$indexB>>2] = -1;
  $$0 = 0.0;
  STACKTOP = sp;return (+$$0);
 }
 return +(0.0);
}
function __ZNK20b2SeparationFunction8EvaluateEiif($this,$indexA,$indexB,$t) {
 $this = $this|0;
 $indexA = $indexA|0;
 $indexB = $indexB|0;
 $t = +$t;
 var $$0 = 0.0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0.0, $7 = 0, $8 = 0, $9 = 0, $localPointA = 0, $localPointA7 = 0, $localPointB = 0, $localPointB2 = 0, $normal = 0, $normal5 = 0, $pointA = 0, $pointA1 = 0, $pointA8 = 0, $pointB = 0, $pointB3 = 0, $pointB6 = 0;
 var $xfA = 0, $xfB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $xfA = sp + 136|0;
 $xfB = sp + 120|0;
 $localPointA = sp + 24|0;
 $localPointB = sp + 16|0;
 $pointA = sp + 112|0;
 $pointB = sp + 104|0;
 $0 = sp + 96|0;
 $normal = sp + 88|0;
 $pointA1 = sp + 80|0;
 $localPointB2 = sp + 8|0;
 $pointB3 = sp + 72|0;
 $1 = sp + 64|0;
 $normal5 = sp + 56|0;
 $pointB6 = sp + 48|0;
 $localPointA7 = sp;
 $pointA8 = sp + 40|0;
 $2 = sp + 32|0;
 $3 = (($this) + 8|0);
 __ZNK7b2Sweep12GetTransformEP11b2Transformf($3,$xfA,$t);
 $4 = (($this) + 44|0);
 __ZNK7b2Sweep12GetTransformEP11b2Transformf($4,$xfB,$t);
 $5 = (($this) + 80|0);
 $6 = HEAP32[$5>>2]|0;
 if ((($6|0) == 0)) {
  $7 = HEAP32[$this>>2]|0;
  $8 = (__ZNK15b2DistanceProxy9GetVertexEi($7,$indexA)|0);
  $9 = $8;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = (($9) + 4)|0;
  $13 = $12;
  $14 = HEAP32[$13>>2]|0;
  $15 = $localPointA;
  $16 = $15;
  HEAP32[$16>>2] = $11;
  $17 = (($15) + 4)|0;
  $18 = $17;
  HEAP32[$18>>2] = $14;
  $19 = (($this) + 4|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (__ZNK15b2DistanceProxy9GetVertexEi($20,$indexB)|0);
  $22 = $21;
  $23 = $22;
  $24 = HEAP32[$23>>2]|0;
  $25 = (($22) + 4)|0;
  $26 = $25;
  $27 = HEAP32[$26>>2]|0;
  $28 = $localPointB;
  $29 = $28;
  HEAP32[$29>>2] = $24;
  $30 = (($28) + 4)|0;
  $31 = $30;
  HEAP32[$31>>2] = $27;
  __Z5b2MulRK11b2TransformRK6b2Vec2($pointA,$xfA,$localPointA);
  __Z5b2MulRK11b2TransformRK6b2Vec2($pointB,$xfB,$localPointB);
  __ZmiRK6b2Vec2S1_($0,$pointB,$pointA);
  $32 = (($this) + 92|0);
  $33 = (+__Z5b2DotRK6b2Vec2S1_($0,$32));
  $$0 = $33;
  STACKTOP = sp;return (+$$0);
 } else if ((($6|0) == 2)) {
  $51 = (($xfB) + 8|0);
  $52 = (($this) + 92|0);
  __Z5b2MulRK5b2RotRK6b2Vec2($normal5,$51,$52);
  $53 = (($this) + 84|0);
  __Z5b2MulRK11b2TransformRK6b2Vec2($pointB6,$xfB,$53);
  $54 = HEAP32[$this>>2]|0;
  $55 = (__ZNK15b2DistanceProxy9GetVertexEi($54,$indexA)|0);
  $56 = $55;
  $57 = $56;
  $58 = HEAP32[$57>>2]|0;
  $59 = (($56) + 4)|0;
  $60 = $59;
  $61 = HEAP32[$60>>2]|0;
  $62 = $localPointA7;
  $63 = $62;
  HEAP32[$63>>2] = $58;
  $64 = (($62) + 4)|0;
  $65 = $64;
  HEAP32[$65>>2] = $61;
  __Z5b2MulRK11b2TransformRK6b2Vec2($pointA8,$xfA,$localPointA7);
  __ZmiRK6b2Vec2S1_($2,$pointA8,$pointB6);
  $66 = (+__Z5b2DotRK6b2Vec2S1_($2,$normal5));
  $$0 = $66;
  STACKTOP = sp;return (+$$0);
 } else if ((($6|0) == 1)) {
  $34 = (($xfA) + 8|0);
  $35 = (($this) + 92|0);
  __Z5b2MulRK5b2RotRK6b2Vec2($normal,$34,$35);
  $36 = (($this) + 84|0);
  __Z5b2MulRK11b2TransformRK6b2Vec2($pointA1,$xfA,$36);
  $37 = (($this) + 4|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (__ZNK15b2DistanceProxy9GetVertexEi($38,$indexB)|0);
  $40 = $39;
  $41 = $40;
  $42 = HEAP32[$41>>2]|0;
  $43 = (($40) + 4)|0;
  $44 = $43;
  $45 = HEAP32[$44>>2]|0;
  $46 = $localPointB2;
  $47 = $46;
  HEAP32[$47>>2] = $42;
  $48 = (($46) + 4)|0;
  $49 = $48;
  HEAP32[$49>>2] = $45;
  __Z5b2MulRK11b2TransformRK6b2Vec2($pointB3,$xfB,$localPointB2);
  __ZmiRK6b2Vec2S1_($1,$pointB3,$pointA1);
  $50 = (+__Z5b2DotRK6b2Vec2S1_($1,$normal));
  $$0 = $50;
  STACKTOP = sp;return (+$$0);
 } else {
  $$0 = 0.0;
  STACKTOP = sp;return (+$$0);
 }
 return +(0.0);
}
function __Z5b2AbsIfET_S0_($a) {
 $a = +$a;
 var $0 = 0, $1 = 0.0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $a > 0.0;
 if ($0) {
  $2 = $a;
 } else {
  $1 = -$a;
  $2 = $1;
 }
 STACKTOP = sp;return (+$2);
}
function __Z5b2MaxIiET_S0_S0_($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($a|0)>($b|0);
 $1 = $0 ? $a : $b;
 STACKTOP = sp;return ($1|0);
}
function __ZN15b2DistanceProxyC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 20|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 24|0);
 HEAPF32[$2>>2] = 0.0;
 STACKTOP = sp;return;
}
function __ZplRK6b2Vec2S1_($agg$result,$a,$b) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = 0.0, $1 = 0.0, $2 = 0.0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$a>>2];
 $1 = +HEAPF32[$b>>2];
 $2 = $0 + $1;
 $3 = (($a) + 4|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($b) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $4 + $6;
 __ZN6b2Vec2C2Eff($agg$result,$2,$7);
 STACKTOP = sp;return;
}
function __ZN5b2Rot3SetEf($this,$angle) {
 $this = $this|0;
 $angle = +$angle;
 var $0 = 0.0, $1 = 0.0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+Math_sin((+$angle)));
 HEAPF32[$this>>2] = $0;
 $1 = (+Math_cos((+$angle)));
 $2 = (($this) + 4|0);
 HEAPF32[$2>>2] = $1;
 STACKTOP = sp;return;
}
function __Z5b2MulRK5b2RotRK6b2Vec2($agg$result,$q,$v) {
 $agg$result = $agg$result|0;
 $q = $q|0;
 $v = $v|0;
 var $0 = 0, $1 = 0.0, $10 = 0.0, $11 = 0.0, $2 = 0.0, $3 = 0.0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($q) + 4|0);
 $1 = +HEAPF32[$0>>2];
 $2 = +HEAPF32[$v>>2];
 $3 = $1 * $2;
 $4 = +HEAPF32[$q>>2];
 $5 = (($v) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $4 * $6;
 $8 = $3 - $7;
 $9 = $2 * $4;
 $10 = $1 * $6;
 $11 = $9 + $10;
 __ZN6b2Vec2C2Eff($agg$result,$8,$11);
 STACKTOP = sp;return;
}
function __ZNK15b2DistanceProxy9GetVertexEi($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($index<<3)|0);
 STACKTOP = sp;return ($2|0);
}
function __Z7b2CrossRK6b2Vec2f($agg$result,$a,$s) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 $s = +$s;
 var $0 = 0, $1 = 0.0, $2 = 0.0, $3 = 0.0, $4 = 0.0, $5 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($a) + 4|0);
 $1 = +HEAPF32[$0>>2];
 $2 = $1 * $s;
 $3 = +HEAPF32[$a>>2];
 $4 = $3 * $s;
 $5 = -$4;
 __ZN6b2Vec2C2Eff($agg$result,$2,$5);
 STACKTOP = sp;return;
}
function __Z6b2MulTRK5b2RotRK6b2Vec2($agg$result,$q,$v) {
 $agg$result = $agg$result|0;
 $q = $q|0;
 $v = $v|0;
 var $0 = 0, $1 = 0.0, $10 = 0.0, $11 = 0.0, $2 = 0.0, $3 = 0.0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($q) + 4|0);
 $1 = +HEAPF32[$0>>2];
 $2 = +HEAPF32[$v>>2];
 $3 = $1 * $2;
 $4 = +HEAPF32[$q>>2];
 $5 = (($v) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $4 * $6;
 $8 = $3 + $7;
 $9 = $2 * $4;
 $10 = $1 * $6;
 $11 = $10 - $9;
 __ZN6b2Vec2C2Eff($agg$result,$8,$11);
 STACKTOP = sp;return;
}
function __ZNK15b2DistanceProxy10GetSupportERK6b2Vec2($this,$d) {
 $this = $this|0;
 $d = $d|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, $bestIndex$0$lcssa = 0, $bestIndex$03 = 0, $bestIndex$1 = 0, $bestValue$01 = 0.0, $bestValue$1 = 0.0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(1);
 if (!($2)) {
  $bestIndex$0$lcssa = 0;
  STACKTOP = sp;return ($bestIndex$0$lcssa|0);
 }
 $3 = (($this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (+__Z5b2DotRK6b2Vec2S1_($4,$d));
 $6 = HEAP32[$0>>2]|0;
 $bestIndex$03 = 0;$bestValue$01 = $5;$i$02 = 1;
 while(1) {
  $7 = (($4) + ($i$02<<3)|0);
  $8 = (+__Z5b2DotRK6b2Vec2S1_($7,$d));
  $9 = $8 > $bestValue$01;
  $bestValue$1 = $9 ? $8 : $bestValue$01;
  $bestIndex$1 = $9 ? $i$02 : $bestIndex$03;
  $10 = (($i$02) + 1)|0;
  $11 = ($10|0)<($6|0);
  if ($11) {
   $bestIndex$03 = $bestIndex$1;$bestValue$01 = $bestValue$1;$i$02 = $10;
  } else {
   $bestIndex$0$lcssa = $bestIndex$1;
   break;
  }
 }
 STACKTOP = sp;return ($bestIndex$0$lcssa|0);
}
function __ZN15b2DistanceProxy3SetEPK7b2Shapei($this,$shape,$index) {
 $this = $this|0;
 $shape = $shape|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0.0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0.0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK7b2Shape7GetTypeEv($shape)|0);
 if ((($0|0) == 2)) {
  $7 = (($shape) + 20|0);
  $8 = (($this) + 16|0);
  HEAP32[$8>>2] = $7;
  $9 = (($shape) + 148|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($this) + 20|0);
  HEAP32[$11>>2] = $10;
  $12 = (($shape) + 8|0);
  $13 = +HEAPF32[$12>>2];
  $14 = (($this) + 24|0);
  HEAPF32[$14>>2] = $13;
  STACKTOP = sp;return;
 } else if ((($0|0) == 3)) {
  $15 = (($shape) + 12|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + ($index<<3)|0);
  $18 = $17;
  $19 = $18;
  $20 = HEAP32[$19>>2]|0;
  $21 = (($18) + 4)|0;
  $22 = $21;
  $23 = HEAP32[$22>>2]|0;
  $24 = $this;
  $25 = $24;
  HEAP32[$25>>2] = $20;
  $26 = (($24) + 4)|0;
  $27 = $26;
  HEAP32[$27>>2] = $23;
  $28 = (($index) + 1)|0;
  $29 = (($shape) + 16|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = ($28|0)<($30|0);
  $32 = (($this) + 8|0);
  $33 = HEAP32[$15>>2]|0;
  if ($31) {
   $34 = (($33) + ($28<<3)|0);
   $35 = $34;
   $36 = $35;
   $37 = HEAP32[$36>>2]|0;
   $38 = (($35) + 4)|0;
   $39 = $38;
   $40 = HEAP32[$39>>2]|0;
   $41 = $32;
   $42 = $41;
   HEAP32[$42>>2] = $37;
   $43 = (($41) + 4)|0;
   $44 = $43;
   HEAP32[$44>>2] = $40;
  } else {
   $45 = $33;
   $46 = $45;
   $47 = HEAP32[$46>>2]|0;
   $48 = (($45) + 4)|0;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = $32;
   $52 = $51;
   HEAP32[$52>>2] = $47;
   $53 = (($51) + 4)|0;
   $54 = $53;
   HEAP32[$54>>2] = $50;
  }
  $55 = (($this) + 16|0);
  HEAP32[$55>>2] = $this;
  $56 = (($this) + 20|0);
  HEAP32[$56>>2] = 2;
  $57 = (($shape) + 8|0);
  $58 = +HEAPF32[$57>>2];
  $59 = (($this) + 24|0);
  HEAPF32[$59>>2] = $58;
  STACKTOP = sp;return;
 } else if ((($0|0) == 0)) {
  $1 = (($shape) + 12|0);
  $2 = (($this) + 16|0);
  HEAP32[$2>>2] = $1;
  $3 = (($this) + 20|0);
  HEAP32[$3>>2] = 1;
  $4 = (($shape) + 8|0);
  $5 = +HEAPF32[$4>>2];
  $6 = (($this) + 24|0);
  HEAPF32[$6>>2] = $5;
  STACKTOP = sp;return;
 } else if ((($0|0) == 1)) {
  $60 = (($shape) + 12|0);
  $61 = (($this) + 16|0);
  HEAP32[$61>>2] = $60;
  $62 = (($this) + 20|0);
  HEAP32[$62>>2] = 2;
  $63 = (($shape) + 8|0);
  $64 = +HEAPF32[$63>>2];
  $65 = (($this) + 24|0);
  HEAPF32[$65>>2] = $64;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN9b2Simplex6Solve2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0.0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $e12 = 0;
 var $w1 = 0, $w2 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $w1 = sp + 8|0;
 $w2 = sp;
 $e12 = sp + 16|0;
 $0 = (($this) + 16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $w1;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 $11 = (($this) + 36|0);
 $12 = (($this) + 52|0);
 $13 = $12;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 4)|0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = $w2;
 $20 = $19;
 HEAP32[$20>>2] = $15;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $18;
 __ZmiRK6b2Vec2S1_($e12,$w2,$w1);
 $23 = (+__Z5b2DotRK6b2Vec2S1_($w1,$e12));
 $24 = !($23 >= -0.0);
 if (!($24)) {
  $25 = (($this) + 24|0);
  HEAPF32[$25>>2] = 1.0;
  $26 = (($this) + 108|0);
  HEAP32[$26>>2] = 1;
  STACKTOP = sp;return;
 }
 $27 = (+__Z5b2DotRK6b2Vec2S1_($w2,$e12));
 $28 = !($27 <= 0.0);
 if ($28) {
  $31 = $27 - $23;
  $32 = 1.0 / $31;
  $33 = $27 * $32;
  $34 = (($this) + 24|0);
  HEAPF32[$34>>2] = $33;
  $35 = $23 * $32;
  $36 = -$35;
  $37 = (($this) + 60|0);
  HEAPF32[$37>>2] = $36;
  $38 = (($this) + 108|0);
  HEAP32[$38>>2] = 2;
  STACKTOP = sp;return;
 } else {
  $29 = (($this) + 60|0);
  HEAPF32[$29>>2] = 1.0;
  $30 = (($this) + 108|0);
  HEAP32[$30>>2] = 1;
  dest=$this+0|0; src=$11+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 }
}
function __ZN9b2Simplex6Solve3Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0;
 var $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0, $59 = 0.0, $6 = 0;
 var $60 = 0.0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0;
 var $97 = 0, $98 = 0.0, $99 = 0, $e12 = 0, $e13 = 0, $e23 = 0, $or$cond = 0, $or$cond11 = 0, $or$cond13 = 0, $or$cond15 = 0, $or$cond17 = 0, $or$cond3 = 0, $or$cond5 = 0, $or$cond7 = 0, $or$cond9 = 0, $w1 = 0, $w2 = 0, $w3 = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $w1 = sp + 16|0;
 $w2 = sp + 8|0;
 $w3 = sp;
 $e12 = sp + 40|0;
 $e13 = sp + 32|0;
 $e23 = sp + 24|0;
 $0 = (($this) + 16|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $w1;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 $11 = (($this) + 36|0);
 $12 = (($this) + 52|0);
 $13 = $12;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 4)|0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = $w2;
 $20 = $19;
 HEAP32[$20>>2] = $15;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $18;
 $23 = (($this) + 72|0);
 $24 = (($this) + 88|0);
 $25 = $24;
 $26 = $25;
 $27 = HEAP32[$26>>2]|0;
 $28 = (($25) + 4)|0;
 $29 = $28;
 $30 = HEAP32[$29>>2]|0;
 $31 = $w3;
 $32 = $31;
 HEAP32[$32>>2] = $27;
 $33 = (($31) + 4)|0;
 $34 = $33;
 HEAP32[$34>>2] = $30;
 __ZmiRK6b2Vec2S1_($e12,$w2,$w1);
 $35 = (+__Z5b2DotRK6b2Vec2S1_($w1,$e12));
 $36 = (+__Z5b2DotRK6b2Vec2S1_($w2,$e12));
 __ZmiRK6b2Vec2S1_($e13,$w3,$w1);
 $37 = (+__Z5b2DotRK6b2Vec2S1_($w1,$e13));
 $38 = (+__Z5b2DotRK6b2Vec2S1_($w3,$e13));
 __ZmiRK6b2Vec2S1_($e23,$w3,$w2);
 $39 = (+__Z5b2DotRK6b2Vec2S1_($w2,$e23));
 $40 = (+__Z5b2DotRK6b2Vec2S1_($w3,$e23));
 $41 = (+__Z7b2CrossRK6b2Vec2S1_($e12,$e13));
 $42 = (+__Z7b2CrossRK6b2Vec2S1_($w2,$w3));
 $43 = $41 * $42;
 $44 = (+__Z7b2CrossRK6b2Vec2S1_($w3,$w1));
 $45 = $41 * $44;
 $46 = (+__Z7b2CrossRK6b2Vec2S1_($w1,$w2));
 $47 = $41 * $46;
 $48 = $35 >= -0.0;
 $49 = $37 >= -0.0;
 $or$cond = $48 & $49;
 if ($or$cond) {
  $50 = (($this) + 24|0);
  HEAPF32[$50>>2] = 1.0;
  $51 = (($this) + 108|0);
  HEAP32[$51>>2] = 1;
  STACKTOP = sp;return;
 }
 $52 = $36 > 0.0;
 $53 = $35 < -0.0;
 $or$cond3 = $52 & $53;
 $54 = $47 <= 0.0;
 $or$cond5 = $or$cond3 & $54;
 if ($or$cond5) {
  $55 = $36 - $35;
  $56 = 1.0 / $55;
  $57 = $36 * $56;
  $58 = (($this) + 24|0);
  HEAPF32[$58>>2] = $57;
  $59 = $35 * $56;
  $60 = -$59;
  $61 = (($this) + 60|0);
  HEAPF32[$61>>2] = $60;
  $62 = (($this) + 108|0);
  HEAP32[$62>>2] = 2;
  STACKTOP = sp;return;
 }
 $63 = $38 > 0.0;
 $64 = $37 < -0.0;
 $or$cond7 = $63 & $64;
 $65 = $45 <= 0.0;
 $or$cond9 = $or$cond7 & $65;
 if ($or$cond9) {
  $66 = $38 - $37;
  $67 = 1.0 / $66;
  $68 = $38 * $67;
  $69 = (($this) + 24|0);
  HEAPF32[$69>>2] = $68;
  $70 = $37 * $67;
  $71 = -$70;
  $72 = (($this) + 96|0);
  HEAPF32[$72>>2] = $71;
  $73 = (($this) + 108|0);
  HEAP32[$73>>2] = 2;
  dest=$11+0|0; src=$23+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 }
 $74 = $36 <= 0.0;
 $75 = $39 >= -0.0;
 $or$cond11 = $74 & $75;
 if ($or$cond11) {
  $76 = (($this) + 60|0);
  HEAPF32[$76>>2] = 1.0;
  $77 = (($this) + 108|0);
  HEAP32[$77>>2] = 1;
  dest=$this+0|0; src=$11+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 }
 $78 = $38 <= 0.0;
 $79 = $40 <= 0.0;
 $or$cond13 = $78 & $79;
 if ($or$cond13) {
  $80 = (($this) + 96|0);
  HEAPF32[$80>>2] = 1.0;
  $81 = (($this) + 108|0);
  HEAP32[$81>>2] = 1;
  dest=$this+0|0; src=$23+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 }
 $82 = $40 > 0.0;
 $83 = $39 < -0.0;
 $or$cond15 = $82 & $83;
 $84 = $43 <= 0.0;
 $or$cond17 = $or$cond15 & $84;
 if ($or$cond17) {
  $85 = $40 - $39;
  $86 = 1.0 / $85;
  $87 = $40 * $86;
  $88 = (($this) + 60|0);
  HEAPF32[$88>>2] = $87;
  $89 = $39 * $86;
  $90 = -$89;
  $91 = (($this) + 96|0);
  HEAPF32[$91>>2] = $90;
  $92 = (($this) + 108|0);
  HEAP32[$92>>2] = 2;
  dest=$this+0|0; src=$23+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 } else {
  $93 = $43 + $45;
  $94 = $93 + $47;
  $95 = 1.0 / $94;
  $96 = $43 * $95;
  $97 = (($this) + 24|0);
  HEAPF32[$97>>2] = $96;
  $98 = $45 * $95;
  $99 = (($this) + 60|0);
  HEAPF32[$99>>2] = $98;
  $100 = $47 * $95;
  $101 = (($this) + 96|0);
  HEAPF32[$101>>2] = $100;
  $102 = (($this) + 108|0);
  HEAP32[$102>>2] = 3;
  STACKTOP = sp;return;
 }
}
function __Z10b2DistanceP16b2DistanceOutputP14b2SimplexCachePK15b2DistanceInput($output,$cache,$input) {
 $output = $output|0;
 $cache = $cache|0;
 $input = $input|0;
 var $$pr = 0, $$pr11 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0, $103 = 0, $104 = 0.0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0.0, $98 = 0, $99 = 0.0, $d = 0, $exitcond = 0, $i$04 = 0, $i1$05 = 0, $iter$010 = 0, $iter$1 = 0, $normal = 0, $or$cond = 0, $p = 0, $p2 = 0, $saveA = 0, $saveB = 0, $simplex = 0;
 var $transformA = 0, $transformB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $transformA = sp + 256|0;
 $transformB = sp + 240|0;
 $simplex = sp + 128|0;
 $saveA = sp + 116|0;
 $saveB = sp + 104|0;
 $p = sp + 96|0;
 $d = sp + 88|0;
 $0 = sp + 80|0;
 $1 = sp + 72|0;
 $2 = sp + 24|0;
 $3 = sp + 64|0;
 $4 = sp + 16|0;
 $5 = sp + 8|0;
 $normal = sp + 56|0;
 $6 = sp + 48|0;
 $7 = sp + 40|0;
 $p2 = sp;
 $8 = sp + 32|0;
 $9 = HEAP32[1904>>2]|0;
 $10 = (($9) + 1)|0;
 HEAP32[1904>>2] = $10;
 $11 = (($input) + 28|0);
 $12 = (($input) + 56|0);
 ;HEAP32[$transformA+0>>2]=HEAP32[$12+0>>2]|0;HEAP32[$transformA+4>>2]=HEAP32[$12+4>>2]|0;HEAP32[$transformA+8>>2]=HEAP32[$12+8>>2]|0;HEAP32[$transformA+12>>2]=HEAP32[$12+12>>2]|0;
 $13 = (($input) + 72|0);
 ;HEAP32[$transformB+0>>2]=HEAP32[$13+0>>2]|0;HEAP32[$transformB+4>>2]=HEAP32[$13+4>>2]|0;HEAP32[$transformB+8>>2]=HEAP32[$13+8>>2]|0;HEAP32[$transformB+12>>2]=HEAP32[$13+12>>2]|0;
 __ZN9b2Simplex9ReadCacheEPK14b2SimplexCachePK15b2DistanceProxyRK11b2TransformS5_S8_($simplex,$cache,$input,$transformA,$11,$transformB);
 ;HEAP32[$saveA+0>>2]=0|0;HEAP32[$saveA+4>>2]=0|0;HEAP32[$saveA+8>>2]=0|0;
 ;HEAP32[$saveB+0>>2]=0|0;HEAP32[$saveB+4>>2]=0|0;HEAP32[$saveB+8>>2]=0|0;
 $14 = (($simplex) + 108|0);
 $15 = (($transformA) + 8|0);
 $16 = (($transformB) + 8|0);
 $$pr11 = HEAP32[$14>>2]|0;
 $17 = $$pr11;$iter$010 = 0;
 L1: while(1) {
  $18 = ($17|0)>(0);
  if ($18) {
   $i$04 = 0;
   while(1) {
    $19 = ((($simplex) + (($i$04*36)|0)|0) + 28|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (($saveA) + ($i$04<<2)|0);
    HEAP32[$21>>2] = $20;
    $22 = ((($simplex) + (($i$04*36)|0)|0) + 32|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($saveB) + ($i$04<<2)|0);
    HEAP32[$24>>2] = $23;
    $25 = (($i$04) + 1)|0;
    $exitcond = ($25|0)==($17|0);
    if ($exitcond) {
     break;
    } else {
     $i$04 = $25;
    }
   }
  }
  $26 = HEAP32[$14>>2]|0;
  if ((($26|0) == 3)) {
   __ZN9b2Simplex6Solve3Ev($simplex);
   label = 7;
  } else if ((($26|0) == 2)) {
   __ZN9b2Simplex6Solve2Ev($simplex);
   label = 7;
  }
  if ((label|0) == 7) {
   label = 0;
   $$pr = HEAP32[$14>>2]|0;
   $27 = ($$pr|0)==(3);
   if ($27) {
    $iter$1 = $iter$010;
    break;
   }
  }
  __ZNK9b2Simplex15GetClosestPointEv($p,$simplex);
  __ZNK9b2Simplex18GetSearchDirectionEv($d,$simplex);
  $28 = (+__ZNK6b2Vec213LengthSquaredEv($d));
  $29 = $28 < 1.4210854715202004E-14;
  if ($29) {
   $iter$1 = $iter$010;
   break;
  }
  $30 = HEAP32[$14>>2]|0;
  $31 = (($simplex) + (($30*36)|0)|0);
  __ZNK6b2Vec2ngEv($1,$d);
  __Z6b2MulTRK5b2RotRK6b2Vec2($0,$15,$1);
  $32 = (__ZNK15b2DistanceProxy10GetSupportERK6b2Vec2($input,$0)|0);
  $33 = ((($simplex) + (($30*36)|0)|0) + 28|0);
  HEAP32[$33>>2] = $32;
  $34 = (__ZNK15b2DistanceProxy9GetVertexEi($input,$32)|0);
  __Z5b2MulRK11b2TransformRK6b2Vec2($2,$transformA,$34);
  $35 = $2;
  $36 = $35;
  $37 = HEAP32[$36>>2]|0;
  $38 = (($35) + 4)|0;
  $39 = $38;
  $40 = HEAP32[$39>>2]|0;
  $41 = $31;
  $42 = $41;
  HEAP32[$42>>2] = $37;
  $43 = (($41) + 4)|0;
  $44 = $43;
  HEAP32[$44>>2] = $40;
  __Z6b2MulTRK5b2RotRK6b2Vec2($3,$16,$d);
  $45 = (__ZNK15b2DistanceProxy10GetSupportERK6b2Vec2($11,$3)|0);
  $46 = ((($simplex) + (($30*36)|0)|0) + 32|0);
  HEAP32[$46>>2] = $45;
  $47 = ((($simplex) + (($30*36)|0)|0) + 8|0);
  $48 = (__ZNK15b2DistanceProxy9GetVertexEi($11,$45)|0);
  __Z5b2MulRK11b2TransformRK6b2Vec2($4,$transformB,$48);
  $49 = $4;
  $50 = $49;
  $51 = HEAP32[$50>>2]|0;
  $52 = (($49) + 4)|0;
  $53 = $52;
  $54 = HEAP32[$53>>2]|0;
  $55 = $47;
  $56 = $55;
  HEAP32[$56>>2] = $51;
  $57 = (($55) + 4)|0;
  $58 = $57;
  HEAP32[$58>>2] = $54;
  $59 = ((($simplex) + (($30*36)|0)|0) + 16|0);
  __ZmiRK6b2Vec2S1_($5,$47,$31);
  $60 = $5;
  $61 = $60;
  $62 = HEAP32[$61>>2]|0;
  $63 = (($60) + 4)|0;
  $64 = $63;
  $65 = HEAP32[$64>>2]|0;
  $66 = $59;
  $67 = $66;
  HEAP32[$67>>2] = $62;
  $68 = (($66) + 4)|0;
  $69 = $68;
  HEAP32[$69>>2] = $65;
  $70 = (($iter$010) + 1)|0;
  $71 = HEAP32[1912>>2]|0;
  $72 = (($71) + 1)|0;
  HEAP32[1912>>2] = $72;
  $73 = ($17|0)>(0);
  if ($73) {
   $74 = HEAP32[$33>>2]|0;
   $i1$05 = 0;
   while(1) {
    $75 = (($saveA) + ($i1$05<<2)|0);
    $76 = HEAP32[$75>>2]|0;
    $77 = ($74|0)==($76|0);
    if ($77) {
     $78 = HEAP32[$46>>2]|0;
     $79 = (($saveB) + ($i1$05<<2)|0);
     $80 = HEAP32[$79>>2]|0;
     $81 = ($78|0)==($80|0);
     if ($81) {
      $iter$1 = $70;
      break L1;
     }
    }
    $82 = (($i1$05) + 1)|0;
    $83 = ($82|0)<($17|0);
    if ($83) {
     $i1$05 = $82;
    } else {
     break;
    }
   }
  }
  $84 = HEAP32[$14>>2]|0;
  $85 = (($84) + 1)|0;
  HEAP32[$14>>2] = $85;
  $86 = ($70|0)<(20);
  if ($86) {
   $17 = $85;$iter$010 = $70;
  } else {
   $iter$1 = $70;
   break;
  }
 }
 $87 = HEAP32[1920>>2]|0;
 $88 = (__Z5b2MaxIiET_S0_S0_($87,$iter$1)|0);
 HEAP32[1920>>2] = $88;
 $89 = (($output) + 8|0);
 __ZNK9b2Simplex16GetWitnessPointsEP6b2Vec2S1_($simplex,$output,$89);
 $90 = (+__Z10b2DistanceRK6b2Vec2S1_($output,$89));
 $91 = (($output) + 16|0);
 HEAPF32[$91>>2] = $90;
 $92 = (($output) + 20|0);
 HEAP32[$92>>2] = $iter$1;
 __ZNK9b2Simplex10WriteCacheEP14b2SimplexCache($simplex,$cache);
 $93 = (($input) + 88|0);
 $94 = HEAP8[$93>>0]|0;
 $95 = ($94<<24>>24)==(0);
 if ($95) {
  STACKTOP = sp;return;
 }
 $96 = (($input) + 24|0);
 $97 = +HEAPF32[$96>>2];
 $98 = (($input) + 52|0);
 $99 = +HEAPF32[$98>>2];
 $100 = +HEAPF32[$91>>2];
 $101 = $97 + $99;
 $102 = $100 > $101;
 $103 = $100 > 1.1920928955078125E-7;
 $or$cond = $102 & $103;
 if ($or$cond) {
  $104 = $100 - $101;
  HEAPF32[$91>>2] = $104;
  __ZmiRK6b2Vec2S1_($normal,$89,$output);
  (+__ZN6b2Vec29NormalizeEv($normal));
  __ZmlfRK6b2Vec2($6,$97,$normal);
  __ZN6b2Vec2pLERKS_($output,$6);
  __ZmlfRK6b2Vec2($7,$99,$normal);
  __ZN6b2Vec2mIERKS_($89,$7);
  STACKTOP = sp;return;
 } else {
  __ZplRK6b2Vec2S1_($8,$output,$89);
  __ZmlfRK6b2Vec2($p2,0.5,$8);
  $105 = $p2;
  $106 = $105;
  $107 = HEAP32[$106>>2]|0;
  $108 = (($105) + 4)|0;
  $109 = $108;
  $110 = HEAP32[$109>>2]|0;
  $111 = $output;
  $112 = $111;
  HEAP32[$112>>2] = $107;
  $113 = (($111) + 4)|0;
  $114 = $113;
  HEAP32[$114>>2] = $110;
  $115 = $p2;
  $116 = $115;
  $117 = HEAP32[$116>>2]|0;
  $118 = (($115) + 4)|0;
  $119 = $118;
  $120 = HEAP32[$119>>2]|0;
  $121 = $89;
  $122 = $121;
  HEAP32[$122>>2] = $117;
  $123 = (($121) + 4)|0;
  $124 = $123;
  HEAP32[$124>>2] = $120;
  HEAPF32[$91>>2] = 0.0;
  STACKTOP = sp;return;
 }
}
function __ZNK7b2Shape7GetTypeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN9b2Simplex9ReadCacheEPK14b2SimplexCachePK15b2DistanceProxyRK11b2TransformS5_S8_($this,$cache,$proxyA,$transformA,$proxyB,$transformB) {
 $this = $this|0;
 $cache = $cache|0;
 $proxyA = $proxyA|0;
 $transformA = $transformA|0;
 $proxyB = $proxyB|0;
 $transformB = $transformB|0;
 var $$lcssa = 0, $$pr = 0, $$pr11 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0, $84 = 0.0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$012 = 0, $or$cond = 0, $wALocal = 0, $wALocal2 = 0, $wBLocal = 0, $wBLocal3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $wALocal = sp + 72|0;
 $wBLocal = sp + 64|0;
 $0 = sp + 56|0;
 $1 = sp + 48|0;
 $2 = sp + 40|0;
 $wALocal2 = sp + 32|0;
 $wBLocal3 = sp + 24|0;
 $3 = sp + 16|0;
 $4 = sp + 8|0;
 $5 = sp;
 $6 = (($cache) + 4|0);
 $7 = HEAP16[$6>>1]|0;
 $8 = $7&65535;
 $9 = (($this) + 108|0);
 HEAP32[$9>>2] = $8;
 $10 = ($7<<16>>16)==(0);
 if ($10) {
  $$lcssa = $8;
 } else {
  $i$012 = 0;
  while(1) {
   $11 = (($this) + (($i$012*36)|0)|0);
   $12 = ((($cache) + ($i$012)|0) + 6|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = $13&255;
   $15 = ((($this) + (($i$012*36)|0)|0) + 28|0);
   HEAP32[$15>>2] = $14;
   $16 = ((($cache) + ($i$012)|0) + 9|0);
   $17 = HEAP8[$16>>0]|0;
   $18 = $17&255;
   $19 = ((($this) + (($i$012*36)|0)|0) + 32|0);
   HEAP32[$19>>2] = $18;
   $20 = HEAP32[$15>>2]|0;
   $21 = (__ZNK15b2DistanceProxy9GetVertexEi($proxyA,$20)|0);
   $22 = $21;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = (($22) + 4)|0;
   $26 = $25;
   $27 = HEAP32[$26>>2]|0;
   $28 = $wALocal;
   $29 = $28;
   HEAP32[$29>>2] = $24;
   $30 = (($28) + 4)|0;
   $31 = $30;
   HEAP32[$31>>2] = $27;
   $32 = HEAP32[$19>>2]|0;
   $33 = (__ZNK15b2DistanceProxy9GetVertexEi($proxyB,$32)|0);
   $34 = $33;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $wBLocal;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   __Z5b2MulRK11b2TransformRK6b2Vec2($0,$transformA,$wALocal);
   $44 = $0;
   $45 = $44;
   $46 = HEAP32[$45>>2]|0;
   $47 = (($44) + 4)|0;
   $48 = $47;
   $49 = HEAP32[$48>>2]|0;
   $50 = $11;
   $51 = $50;
   HEAP32[$51>>2] = $46;
   $52 = (($50) + 4)|0;
   $53 = $52;
   HEAP32[$53>>2] = $49;
   $54 = ((($this) + (($i$012*36)|0)|0) + 8|0);
   __Z5b2MulRK11b2TransformRK6b2Vec2($1,$transformB,$wBLocal);
   $55 = $1;
   $56 = $55;
   $57 = HEAP32[$56>>2]|0;
   $58 = (($55) + 4)|0;
   $59 = $58;
   $60 = HEAP32[$59>>2]|0;
   $61 = $54;
   $62 = $61;
   HEAP32[$62>>2] = $57;
   $63 = (($61) + 4)|0;
   $64 = $63;
   HEAP32[$64>>2] = $60;
   $65 = ((($this) + (($i$012*36)|0)|0) + 16|0);
   __ZmiRK6b2Vec2S1_($2,$54,$11);
   $66 = $2;
   $67 = $66;
   $68 = HEAP32[$67>>2]|0;
   $69 = (($66) + 4)|0;
   $70 = $69;
   $71 = HEAP32[$70>>2]|0;
   $72 = $65;
   $73 = $72;
   HEAP32[$73>>2] = $68;
   $74 = (($72) + 4)|0;
   $75 = $74;
   HEAP32[$75>>2] = $71;
   $76 = ((($this) + (($i$012*36)|0)|0) + 24|0);
   HEAPF32[$76>>2] = 0.0;
   $77 = (($i$012) + 1)|0;
   $$pr = HEAP32[$9>>2]|0;
   $78 = ($77|0)<($$pr|0);
   if ($78) {
    $i$012 = $77;
   } else {
    $$lcssa = $$pr;
    break;
   }
  }
 }
 $79 = ($$lcssa|0)>(1);
 do {
  if ($79) {
   $80 = +HEAPF32[$cache>>2];
   $81 = (+__ZNK9b2Simplex9GetMetricEv($this));
   $82 = $80 * 0.5;
   $83 = $81 < $82;
   if (!($83)) {
    $84 = $80 * 2.0;
    $85 = $84 < $81;
    $86 = $81 < 1.1920928955078125E-7;
    $or$cond = $85 | $86;
    if (!($or$cond)) {
     label = 7;
     break;
    }
   }
   HEAP32[$9>>2] = 0;
  } else {
   label = 7;
  }
 } while(0);
 if ((label|0) == 7) {
  $$pr11 = HEAP32[$9>>2]|0;
  $87 = ($$pr11|0)==(0);
  if (!($87)) {
   STACKTOP = sp;return;
  }
 }
 $88 = (($this) + 28|0);
 HEAP32[$88>>2] = 0;
 $89 = (($this) + 32|0);
 HEAP32[$89>>2] = 0;
 $90 = (__ZNK15b2DistanceProxy9GetVertexEi($proxyA,0)|0);
 $91 = $90;
 $92 = $91;
 $93 = HEAP32[$92>>2]|0;
 $94 = (($91) + 4)|0;
 $95 = $94;
 $96 = HEAP32[$95>>2]|0;
 $97 = $wALocal2;
 $98 = $97;
 HEAP32[$98>>2] = $93;
 $99 = (($97) + 4)|0;
 $100 = $99;
 HEAP32[$100>>2] = $96;
 $101 = (__ZNK15b2DistanceProxy9GetVertexEi($proxyB,0)|0);
 $102 = $101;
 $103 = $102;
 $104 = HEAP32[$103>>2]|0;
 $105 = (($102) + 4)|0;
 $106 = $105;
 $107 = HEAP32[$106>>2]|0;
 $108 = $wBLocal3;
 $109 = $108;
 HEAP32[$109>>2] = $104;
 $110 = (($108) + 4)|0;
 $111 = $110;
 HEAP32[$111>>2] = $107;
 __Z5b2MulRK11b2TransformRK6b2Vec2($3,$transformA,$wALocal2);
 $112 = $3;
 $113 = $112;
 $114 = HEAP32[$113>>2]|0;
 $115 = (($112) + 4)|0;
 $116 = $115;
 $117 = HEAP32[$116>>2]|0;
 $118 = $this;
 $119 = $118;
 HEAP32[$119>>2] = $114;
 $120 = (($118) + 4)|0;
 $121 = $120;
 HEAP32[$121>>2] = $117;
 $122 = (($this) + 8|0);
 __Z5b2MulRK11b2TransformRK6b2Vec2($4,$transformB,$wBLocal3);
 $123 = $4;
 $124 = $123;
 $125 = HEAP32[$124>>2]|0;
 $126 = (($123) + 4)|0;
 $127 = $126;
 $128 = HEAP32[$127>>2]|0;
 $129 = $122;
 $130 = $129;
 HEAP32[$130>>2] = $125;
 $131 = (($129) + 4)|0;
 $132 = $131;
 HEAP32[$132>>2] = $128;
 $133 = (($this) + 16|0);
 __ZmiRK6b2Vec2S1_($5,$122,$this);
 $134 = $5;
 $135 = $134;
 $136 = HEAP32[$135>>2]|0;
 $137 = (($134) + 4)|0;
 $138 = $137;
 $139 = HEAP32[$138>>2]|0;
 $140 = $133;
 $141 = $140;
 HEAP32[$141>>2] = $136;
 $142 = (($140) + 4)|0;
 $143 = $142;
 HEAP32[$143>>2] = $139;
 $144 = (($this) + 24|0);
 HEAPF32[$144>>2] = 1.0;
 HEAP32[$9>>2] = 1;
 STACKTOP = sp;return;
}
function __ZNK9b2Simplex15GetClosestPointEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0.0;
 var $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = (($this) + 108|0);
 $3 = HEAP32[$2>>2]|0;
 if ((($3|0) == 3)) {
  $31 = 10224;
  $32 = $31;
  $33 = HEAP32[$32>>2]|0;
  $34 = (($31) + 4)|0;
  $35 = $34;
  $36 = HEAP32[$35>>2]|0;
  $37 = $agg$result;
  $38 = $37;
  HEAP32[$38>>2] = $33;
  $39 = (($37) + 4)|0;
  $40 = $39;
  HEAP32[$40>>2] = $36;
  STACKTOP = sp;return;
 } else if ((($3|0) == 2)) {
  $25 = (($this) + 24|0);
  $26 = +HEAPF32[$25>>2];
  $27 = (($this) + 16|0);
  __ZmlfRK6b2Vec2($0,$26,$27);
  $28 = (($this) + 60|0);
  $29 = +HEAPF32[$28>>2];
  $30 = (($this) + 52|0);
  __ZmlfRK6b2Vec2($1,$29,$30);
  __ZplRK6b2Vec2S1_($agg$result,$0,$1);
  STACKTOP = sp;return;
 } else if ((($3|0) == 1)) {
  $14 = (($this) + 16|0);
  $15 = $14;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  $18 = (($15) + 4)|0;
  $19 = $18;
  $20 = HEAP32[$19>>2]|0;
  $21 = $agg$result;
  $22 = $21;
  HEAP32[$22>>2] = $17;
  $23 = (($21) + 4)|0;
  $24 = $23;
  HEAP32[$24>>2] = $20;
  STACKTOP = sp;return;
 } else if ((($3|0) == 0)) {
  $4 = 10224;
  $5 = $4;
  $6 = HEAP32[$5>>2]|0;
  $7 = (($4) + 4)|0;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = $agg$result;
  $11 = $10;
  HEAP32[$11>>2] = $6;
  $12 = (($10) + 4)|0;
  $13 = $12;
  HEAP32[$13>>2] = $9;
  STACKTOP = sp;return;
 } else {
  $41 = 10224;
  $42 = $41;
  $43 = HEAP32[$42>>2]|0;
  $44 = (($41) + 4)|0;
  $45 = $44;
  $46 = HEAP32[$45>>2]|0;
  $47 = $agg$result;
  $48 = $47;
  HEAP32[$48>>2] = $43;
  $49 = (($47) + 4)|0;
  $50 = $49;
  HEAP32[$50>>2] = $46;
  STACKTOP = sp;return;
 }
}
function __ZNK9b2Simplex18GetSearchDirectionEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0, $e12 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $e12 = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 108|0);
 $2 = HEAP32[$1>>2]|0;
 if ((($2|0) == 2)) {
  $4 = (($this) + 52|0);
  $5 = (($this) + 16|0);
  __ZmiRK6b2Vec2S1_($e12,$4,$5);
  __ZNK6b2Vec2ngEv($0,$5);
  $6 = (+__Z7b2CrossRK6b2Vec2S1_($e12,$0));
  $7 = $6 > 0.0;
  if ($7) {
   __Z7b2CrossfRK6b2Vec2($agg$result,1.0,$e12);
   STACKTOP = sp;return;
  } else {
   __Z7b2CrossRK6b2Vec2f($agg$result,$e12,1.0);
   STACKTOP = sp;return;
  }
 } else if ((($2|0) == 1)) {
  $3 = (($this) + 16|0);
  __ZNK6b2Vec2ngEv($agg$result,$3);
  STACKTOP = sp;return;
 } else {
  $8 = 10224;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($8) + 4)|0;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = $agg$result;
  $15 = $14;
  HEAP32[$15>>2] = $10;
  $16 = (($14) + 4)|0;
  $17 = $16;
  HEAP32[$17>>2] = $13;
  STACKTOP = sp;return;
 }
}
function __ZNK9b2Simplex16GetWitnessPointsEP6b2Vec2S1_($this,$pA,$pB) {
 $this = $this|0;
 $pA = $pA|0;
 $pB = $pB|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0.0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $0 = sp + 16|0;
 $1 = sp + 80|0;
 $2 = sp + 72|0;
 $3 = sp + 8|0;
 $4 = sp + 64|0;
 $5 = sp + 56|0;
 $6 = sp;
 $7 = sp + 48|0;
 $8 = sp + 40|0;
 $9 = sp + 32|0;
 $10 = sp + 24|0;
 $11 = (($this) + 108|0);
 $12 = HEAP32[$11>>2]|0;
 if ((($12|0) == 2)) {
  $34 = (($this) + 24|0);
  $35 = +HEAPF32[$34>>2];
  __ZmlfRK6b2Vec2($1,$35,$this);
  $36 = (($this) + 60|0);
  $37 = +HEAPF32[$36>>2];
  $38 = (($this) + 36|0);
  __ZmlfRK6b2Vec2($2,$37,$38);
  __ZplRK6b2Vec2S1_($0,$1,$2);
  $39 = $0;
  $40 = $39;
  $41 = HEAP32[$40>>2]|0;
  $42 = (($39) + 4)|0;
  $43 = $42;
  $44 = HEAP32[$43>>2]|0;
  $45 = $pA;
  $46 = $45;
  HEAP32[$46>>2] = $41;
  $47 = (($45) + 4)|0;
  $48 = $47;
  HEAP32[$48>>2] = $44;
  $49 = +HEAPF32[$34>>2];
  $50 = (($this) + 8|0);
  __ZmlfRK6b2Vec2($4,$49,$50);
  $51 = +HEAPF32[$36>>2];
  $52 = (($this) + 44|0);
  __ZmlfRK6b2Vec2($5,$51,$52);
  __ZplRK6b2Vec2S1_($3,$4,$5);
  $53 = $3;
  $54 = $53;
  $55 = HEAP32[$54>>2]|0;
  $56 = (($53) + 4)|0;
  $57 = $56;
  $58 = HEAP32[$57>>2]|0;
  $59 = $pB;
  $60 = $59;
  HEAP32[$60>>2] = $55;
  $61 = (($59) + 4)|0;
  $62 = $61;
  HEAP32[$62>>2] = $58;
  STACKTOP = sp;return;
 } else if ((($12|0) == 1)) {
  $13 = $this;
  $14 = $13;
  $15 = HEAP32[$14>>2]|0;
  $16 = (($13) + 4)|0;
  $17 = $16;
  $18 = HEAP32[$17>>2]|0;
  $19 = $pA;
  $20 = $19;
  HEAP32[$20>>2] = $15;
  $21 = (($19) + 4)|0;
  $22 = $21;
  HEAP32[$22>>2] = $18;
  $23 = (($this) + 8|0);
  $24 = $23;
  $25 = $24;
  $26 = HEAP32[$25>>2]|0;
  $27 = (($24) + 4)|0;
  $28 = $27;
  $29 = HEAP32[$28>>2]|0;
  $30 = $pB;
  $31 = $30;
  HEAP32[$31>>2] = $26;
  $32 = (($30) + 4)|0;
  $33 = $32;
  HEAP32[$33>>2] = $29;
  STACKTOP = sp;return;
 } else if ((($12|0) == 3)) {
  $63 = (($this) + 24|0);
  $64 = +HEAPF32[$63>>2];
  __ZmlfRK6b2Vec2($8,$64,$this);
  $65 = (($this) + 60|0);
  $66 = +HEAPF32[$65>>2];
  $67 = (($this) + 36|0);
  __ZmlfRK6b2Vec2($9,$66,$67);
  __ZplRK6b2Vec2S1_($7,$8,$9);
  $68 = (($this) + 96|0);
  $69 = +HEAPF32[$68>>2];
  $70 = (($this) + 72|0);
  __ZmlfRK6b2Vec2($10,$69,$70);
  __ZplRK6b2Vec2S1_($6,$7,$10);
  $71 = $6;
  $72 = $71;
  $73 = HEAP32[$72>>2]|0;
  $74 = (($71) + 4)|0;
  $75 = $74;
  $76 = HEAP32[$75>>2]|0;
  $77 = $pA;
  $78 = $77;
  HEAP32[$78>>2] = $73;
  $79 = (($77) + 4)|0;
  $80 = $79;
  HEAP32[$80>>2] = $76;
  $81 = $pB;
  $82 = $81;
  HEAP32[$82>>2] = $73;
  $83 = (($81) + 4)|0;
  $84 = $83;
  HEAP32[$84>>2] = $76;
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZNK9b2Simplex10WriteCacheEP14b2SimplexCache($this,$cache) {
 $this = $this|0;
 $cache = $cache|0;
 var $0 = 0.0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (+__ZNK9b2Simplex9GetMetricEv($this));
 HEAPF32[$cache>>2] = $0;
 $1 = (($this) + 108|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2&65535;
 $4 = (($cache) + 4|0);
 HEAP16[$4>>1] = $3;
 $5 = HEAP32[$1>>2]|0;
 $6 = ($5|0)>(0);
 if ($6) {
  $i$01 = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $7 = ((($this) + (($i$01*36)|0)|0) + 28|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $8&255;
  $10 = ((($cache) + ($i$01)|0) + 6|0);
  HEAP8[$10>>0] = $9;
  $11 = ((($this) + (($i$01*36)|0)|0) + 32|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = $12&255;
  $14 = ((($cache) + ($i$01)|0) + 9|0);
  HEAP8[$14>>0] = $13;
  $15 = (($i$01) + 1)|0;
  $16 = HEAP32[$1>>2]|0;
  $17 = ($15|0)<($16|0);
  if ($17) {
   $i$01 = $15;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK9b2Simplex9GetMetricEv($this) {
 $this = $this|0;
 var $$0 = 0.0, $0 = 0, $1 = 0, $10 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = (($this) + 108|0);
 $3 = HEAP32[$2>>2]|0;
 if ((($3|0) == 2)) {
  $4 = (($this) + 16|0);
  $5 = (($this) + 52|0);
  $6 = (+__Z10b2DistanceRK6b2Vec2S1_($4,$5));
  $$0 = $6;
  STACKTOP = sp;return (+$$0);
 } else if ((($3|0) == 3)) {
  $7 = (($this) + 52|0);
  $8 = (($this) + 16|0);
  __ZmiRK6b2Vec2S1_($0,$7,$8);
  $9 = (($this) + 88|0);
  __ZmiRK6b2Vec2S1_($1,$9,$8);
  $10 = (+__Z7b2CrossRK6b2Vec2S1_($0,$1));
  $$0 = $10;
  STACKTOP = sp;return (+$$0);
 } else {
  $$0 = 0.0;
  STACKTOP = sp;return (+$$0);
 }
 return +(0.0);
}
function __Z7b2CrossfRK6b2Vec2($agg$result,$s,$a) {
 $agg$result = $agg$result|0;
 $s = +$s;
 $a = $a|0;
 var $0 = 0, $1 = 0.0, $2 = 0.0, $3 = 0.0, $4 = 0.0, $5 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($a) + 4|0);
 $1 = +HEAPF32[$0>>2];
 $2 = $1 * $s;
 $3 = -$2;
 $4 = +HEAPF32[$a>>2];
 $5 = $4 * $s;
 __ZN6b2Vec2C2Eff($agg$result,$3,$5);
 STACKTOP = sp;return;
}
function __ZNK11b2EdgeShape5CloneEP16b2BlockAllocator($this,$allocator) {
 $this = $this|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN16b2BlockAllocator8AllocateEi($allocator,48)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = 0;
 } else {
  __ZN11b2EdgeShapeC2Ev($0);
  $2 = $0;
 }
 (__ZN11b2EdgeShapeaSERKS_($2,$this)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZNK11b2EdgeShape13GetChildCountEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZNK11b2EdgeShape9TestPointERK11b2TransformRK6b2Vec2($this,$xf,$p) {
 $this = $this|0;
 $xf = $xf|0;
 $p = $p|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK11b2EdgeShape15ComputeDistanceERK11b2TransformRK6b2Vec2PfPS3_i($this,$xf,$p,$distance,$normal,$childIndex) {
 $this = $this|0;
 $xf = $xf|0;
 $p = $p|0;
 $distance = $distance|0;
 $normal = $normal|0;
 $childIndex = $childIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, $d = 0, $s = 0, $v1 = 0, $v2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $v1 = sp + 40|0;
 $v2 = sp + 32|0;
 $d = sp + 8|0;
 $s = sp + 24|0;
 $0 = sp + 16|0;
 $1 = sp;
 $2 = (($this) + 12|0);
 __Z5b2MulRK11b2TransformRK6b2Vec2($v1,$xf,$2);
 $3 = (($this) + 20|0);
 __Z5b2MulRK11b2TransformRK6b2Vec2($v2,$xf,$3);
 __ZmiRK6b2Vec2S1_($d,$p,$v1);
 __ZmiRK6b2Vec2S1_($s,$v2,$v1);
 $4 = (+__Z5b2DotRK6b2Vec2S1_($d,$s));
 $5 = $4 > 0.0;
 do {
  if ($5) {
   $6 = (+__Z5b2DotRK6b2Vec2S1_($s,$s));
   $7 = $4 > $6;
   if ($7) {
    __ZmiRK6b2Vec2S1_($d,$p,$v2);
    break;
   } else {
    $8 = $4 / $6;
    __ZmlfRK6b2Vec2($0,$8,$s);
    __ZN6b2Vec2mIERKS_($d,$0);
    break;
   }
  }
 } while(0);
 $9 = (+__ZNK6b2Vec26LengthEv($d));
 HEAPF32[$distance>>2] = $9;
 $10 = $9 > 0.0;
 if ($10) {
  $11 = 1.0 / $9;
  __ZmlfRK6b2Vec2($1,$11,$d);
 } else {
  $12 = 10224;
  $13 = $12;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 4)|0;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  $18 = $1;
  $19 = $18;
  HEAP32[$19>>2] = $14;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $17;
 }
 $22 = $1;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 $25 = (($22) + 4)|0;
 $26 = $25;
 $27 = HEAP32[$26>>2]|0;
 $28 = $normal;
 $29 = $28;
 HEAP32[$29>>2] = $24;
 $30 = (($28) + 4)|0;
 $31 = $30;
 HEAP32[$31>>2] = $27;
 STACKTOP = sp;return;
}
function __ZNK11b2EdgeShape7RayCastEP15b2RayCastOutputRK14b2RayCastInputRK11b2Transformi($this,$output,$input,$xf,$childIndex) {
 $this = $this|0;
 $output = $output|0;
 $input = $input|0;
 $xf = $xf|0;
 $childIndex = $childIndex|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0;
 var $44 = 0.0, $45 = 0, $46 = 0.0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $d = 0, $e = 0, $normal = 0, $or$cond = 0, $p1 = 0, $p2 = 0, $q = 0;
 var $r = 0, $v1 = 0, $v2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $p1 = sp + 128|0;
 $0 = sp + 120|0;
 $p2 = sp + 112|0;
 $1 = sp + 104|0;
 $d = sp + 96|0;
 $v1 = sp + 24|0;
 $v2 = sp + 16|0;
 $e = sp + 88|0;
 $normal = sp + 80|0;
 $2 = sp + 72|0;
 $q = sp + 64|0;
 $3 = sp + 56|0;
 $r = sp + 48|0;
 $4 = sp + 40|0;
 $5 = sp + 8|0;
 $6 = sp + 32|0;
 $7 = sp;
 $8 = (($xf) + 8|0);
 __ZmiRK6b2Vec2S1_($0,$input,$xf);
 __Z6b2MulTRK5b2RotRK6b2Vec2($p1,$8,$0);
 $9 = (($input) + 8|0);
 __ZmiRK6b2Vec2S1_($1,$9,$xf);
 __Z6b2MulTRK5b2RotRK6b2Vec2($p2,$8,$1);
 __ZmiRK6b2Vec2S1_($d,$p2,$p1);
 $10 = (($this) + 12|0);
 $11 = $10;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + 4)|0;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = $v1;
 $18 = $17;
 HEAP32[$18>>2] = $13;
 $19 = (($17) + 4)|0;
 $20 = $19;
 HEAP32[$20>>2] = $16;
 $21 = (($this) + 20|0);
 $22 = $21;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 $25 = (($22) + 4)|0;
 $26 = $25;
 $27 = HEAP32[$26>>2]|0;
 $28 = $v2;
 $29 = $28;
 HEAP32[$29>>2] = $24;
 $30 = (($28) + 4)|0;
 $31 = $30;
 HEAP32[$31>>2] = $27;
 __ZmiRK6b2Vec2S1_($e,$v2,$v1);
 $32 = (($e) + 4|0);
 $33 = +HEAPF32[$32>>2];
 $34 = +HEAPF32[$e>>2];
 $35 = -$34;
 __ZN6b2Vec2C2Eff($normal,$33,$35);
 (+__ZN6b2Vec29NormalizeEv($normal));
 __ZmiRK6b2Vec2S1_($2,$v1,$p1);
 $36 = (+__Z5b2DotRK6b2Vec2S1_($normal,$2));
 $37 = (+__Z5b2DotRK6b2Vec2S1_($normal,$d));
 $38 = $37 == 0.0;
 if ($38) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $39 = $36 / $37;
 $40 = $39 < 0.0;
 if ($40) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $41 = (($input) + 16|0);
 $42 = +HEAPF32[$41>>2];
 $43 = $42 < $39;
 if ($43) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 __ZmlfRK6b2Vec2($3,$39,$d);
 __ZplRK6b2Vec2S1_($q,$p1,$3);
 __ZmiRK6b2Vec2S1_($r,$v2,$v1);
 $44 = (+__Z5b2DotRK6b2Vec2S1_($r,$r));
 $45 = $44 == 0.0;
 if ($45) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 __ZmiRK6b2Vec2S1_($4,$q,$v1);
 $46 = (+__Z5b2DotRK6b2Vec2S1_($4,$r));
 $47 = $46 / $44;
 $48 = $47 < 0.0;
 $49 = $47 > 1.0;
 $or$cond = $48 | $49;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $50 = (($output) + 8|0);
 HEAPF32[$50>>2] = $39;
 $51 = $36 > 0.0;
 if ($51) {
  __Z5b2MulRK5b2RotRK6b2Vec2($6,$8,$normal);
  __ZNK6b2Vec2ngEv($5,$6);
  $52 = $5;
  $53 = $52;
  $54 = HEAP32[$53>>2]|0;
  $55 = (($52) + 4)|0;
  $56 = $55;
  $57 = HEAP32[$56>>2]|0;
  $58 = $output;
  $59 = $58;
  HEAP32[$59>>2] = $54;
  $60 = (($58) + 4)|0;
  $61 = $60;
  HEAP32[$61>>2] = $57;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  __Z5b2MulRK5b2RotRK6b2Vec2($7,$8,$normal);
  $62 = $7;
  $63 = $62;
  $64 = HEAP32[$63>>2]|0;
  $65 = (($62) + 4)|0;
  $66 = $65;
  $67 = HEAP32[$66>>2]|0;
  $68 = $output;
  $69 = $68;
  HEAP32[$69>>2] = $64;
  $70 = (($68) + 4)|0;
  $71 = $70;
  HEAP32[$71>>2] = $67;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function __ZNK11b2EdgeShape11ComputeAABBEP6b2AABBRK11b2Transformi($this,$aabb,$xf,$childIndex) {
 $this = $this|0;
 $aabb = $aabb|0;
 $xf = $xf|0;
 $childIndex = $childIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0.0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $lower = 0, $r = 0, $upper = 0, $v1 = 0, $v2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $v1 = sp + 48|0;
 $v2 = sp + 40|0;
 $lower = sp + 32|0;
 $upper = sp + 24|0;
 $r = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = (($this) + 12|0);
 __Z5b2MulRK11b2TransformRK6b2Vec2($v1,$xf,$2);
 $3 = (($this) + 20|0);
 __Z5b2MulRK11b2TransformRK6b2Vec2($v2,$xf,$3);
 __Z5b2MinRK6b2Vec2S1_($lower,$v1,$v2);
 __Z5b2MaxRK6b2Vec2S1_($upper,$v1,$v2);
 $4 = (($this) + 8|0);
 $5 = +HEAPF32[$4>>2];
 __ZN6b2Vec2C2Eff($r,$5,$5);
 __ZmiRK6b2Vec2S1_($0,$lower,$r);
 $6 = $0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $aabb;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 $16 = (($aabb) + 8|0);
 __ZplRK6b2Vec2S1_($1,$upper,$r);
 $17 = $1;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) + 4)|0;
 $21 = $20;
 $22 = HEAP32[$21>>2]|0;
 $23 = $16;
 $24 = $23;
 HEAP32[$24>>2] = $19;
 $25 = (($23) + 4)|0;
 $26 = $25;
 HEAP32[$26>>2] = $22;
 STACKTOP = sp;return;
}
function __ZNK11b2EdgeShape11ComputeMassEP10b2MassDataf($this,$massData,$density) {
 $this = $this|0;
 $massData = $massData|0;
 $density = +$density;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = sp + 8|0;
 HEAPF32[$massData>>2] = 0.0;
 $2 = (($massData) + 4|0);
 $3 = (($this) + 12|0);
 $4 = (($this) + 20|0);
 __ZplRK6b2Vec2S1_($1,$3,$4);
 __ZmlfRK6b2Vec2($0,0.5,$1);
 $5 = $0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $2;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 $15 = (($massData) + 12|0);
 HEAPF32[$15>>2] = 0.0;
 STACKTOP = sp;return;
}
function __ZN11b2EdgeShapeD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN11b2EdgeShapeaSERKS_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN7b2ShapeaSERKS_($this,$0)|0);
 $1 = (($this) + 12|0);
 $2 = (($0) + 12|0);
 ;HEAP32[$1+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$2+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$2+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$2+24>>2]|0;HEAP32[$1+28>>2]=HEAP32[$2+28>>2]|0;HEAP16[$1+32>>1]=HEAP16[$2+32>>1]|0;
 STACKTOP = sp;return ($this|0);
}
function __Z5b2MinRK6b2Vec2S1_($agg$result,$a,$b) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = 0.0, $1 = 0.0, $2 = 0.0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$a>>2];
 $1 = +HEAPF32[$b>>2];
 $2 = (+__Z5b2MinIfET_S0_S0_($0,$1));
 $3 = (($a) + 4|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($b) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = (+__Z5b2MinIfET_S0_S0_($4,$6));
 __ZN6b2Vec2C2Eff($agg$result,$2,$7);
 STACKTOP = sp;return;
}
function __Z5b2MaxRK6b2Vec2S1_($agg$result,$a,$b) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = 0.0, $1 = 0.0, $2 = 0.0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$a>>2];
 $1 = +HEAPF32[$b>>2];
 $2 = (+__Z5b2MaxIfET_S0_S0_($0,$1));
 $3 = (($a) + 4|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($b) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = (+__Z5b2MaxIfET_S0_S0_($4,$6));
 __ZN6b2Vec2C2Eff($agg$result,$2,$7);
 STACKTOP = sp;return;
}
function __ZN7b2ShapeaSERKS_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (($this) + 4|0);
 $2 = (($0) + 4|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $1;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 STACKTOP = sp;return ($this|0);
}
function __Z5b2MinIfET_S0_S0_($a,$b) {
 $a = +$a;
 $b = +$b;
 var $0 = 0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $a < $b;
 $1 = $0 ? $a : $b;
 STACKTOP = sp;return (+$1);
}
function __ZNK14b2PolygonShape5CloneEP16b2BlockAllocator($this,$allocator) {
 $this = $this|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN16b2BlockAllocator8AllocateEi($allocator,152)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = 0;
 } else {
  __ZN14b2PolygonShapeC2Ev($0);
  $2 = $0;
 }
 (__ZN14b2PolygonShapeaSERKS_($2,$this)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN14b2PolygonShape8SetAsBoxEff($this,$hx,$hy) {
 $this = $this|0;
 $hx = +$hx;
 $hy = +$hy;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0.0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 148|0);
 HEAP32[$0>>2] = 4;
 $1 = (($this) + 20|0);
 $2 = -$hx;
 $3 = -$hy;
 __ZN6b2Vec23SetEff($1,$2,$3);
 $4 = (($this) + 28|0);
 __ZN6b2Vec23SetEff($4,$hx,$3);
 $5 = (($this) + 36|0);
 __ZN6b2Vec23SetEff($5,$hx,$hy);
 $6 = (($this) + 44|0);
 __ZN6b2Vec23SetEff($6,$2,$hy);
 $7 = (($this) + 84|0);
 __ZN6b2Vec23SetEff($7,0.0,-1.0);
 $8 = (($this) + 92|0);
 __ZN6b2Vec23SetEff($8,1.0,0.0);
 $9 = (($this) + 100|0);
 __ZN6b2Vec23SetEff($9,0.0,1.0);
 $10 = (($this) + 108|0);
 __ZN6b2Vec23SetEff($10,-1.0,0.0);
 $11 = (($this) + 12|0);
 __ZN6b2Vec27SetZeroEv($11);
 STACKTOP = sp;return;
}
function __ZNK14b2PolygonShape13GetChildCountEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN14b2PolygonShape3SetEPK6b2Vec2i($this,$vertices,$count) {
 $this = $this|0;
 $vertices = $vertices|0;
 $count = $count|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0.0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $edge = 0, $exitcond = 0, $exitcond29 = 0, $exitcond30 = 0, $hull = 0, $i$023 = 0, $i0$013 = 0;
 var $i0$1 = 0, $i1$015 = 0, $i4$04 = 0, $i5$03 = 0, $ie$0$lcssa = 0, $ie$07 = 0, $ie$1 = 0, $ie$2 = 0, $ih$0 = 0, $j$019 = 0, $j2$08 = 0, $m$0 = 0, $ps = 0, $r = 0, $tempCount$024 = 0, $tempCount$1 = 0, $v = 0, $v3 = 0, $x0$014 = 0.0, $x0$1 = 0.0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $ps = sp + 80|0;
 $v = sp + 16|0;
 $hull = sp + 48|0;
 $r = sp + 40|0;
 $v3 = sp + 32|0;
 $edge = sp + 24|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = ($count|0)<(3);
 if ($2) {
  __ZN14b2PolygonShape8SetAsBoxEff($this,1.0,1.0);
  STACKTOP = sp;return;
 }
 $3 = (__Z5b2MinIiET_S0_S0_($count,8)|0);
 $4 = ($3|0)>(0);
 if ($4) {
  $i$023 = 0;$tempCount$024 = 0;
  while(1) {
   $5 = (($vertices) + ($i$023<<3)|0);
   $6 = $5;
   $7 = $6;
   $8 = HEAP32[$7>>2]|0;
   $9 = (($6) + 4)|0;
   $10 = $9;
   $11 = HEAP32[$10>>2]|0;
   $12 = $v;
   $13 = $12;
   HEAP32[$13>>2] = $8;
   $14 = (($12) + 4)|0;
   $15 = $14;
   HEAP32[$15>>2] = $11;
   $16 = ($tempCount$024|0)>(0);
   L8: do {
    if ($16) {
     $j$019 = 0;
     while(1) {
      $19 = (($ps) + ($j$019<<3)|0);
      $20 = (+__Z17b2DistanceSquaredRK6b2Vec2S1_($v,$19));
      $21 = $20 < 0.0024999999441206455;
      $17 = (($j$019) + 1)|0;
      if ($21) {
       $tempCount$1 = $tempCount$024;
       break L8;
      }
      $18 = ($17|0)<($tempCount$024|0);
      if ($18) {
       $j$019 = $17;
      } else {
       label = 7;
       break;
      }
     }
    } else {
     label = 7;
    }
   } while(0);
   if ((label|0) == 7) {
    label = 0;
    $22 = (($tempCount$024) + 1)|0;
    $23 = (($ps) + ($tempCount$024<<3)|0);
    $24 = $v;
    $25 = $24;
    $26 = HEAP32[$25>>2]|0;
    $27 = (($24) + 4)|0;
    $28 = $27;
    $29 = HEAP32[$28>>2]|0;
    $30 = $23;
    $31 = $30;
    HEAP32[$31>>2] = $26;
    $32 = (($30) + 4)|0;
    $33 = $32;
    HEAP32[$33>>2] = $29;
    $tempCount$1 = $22;
   }
   $34 = (($i$023) + 1)|0;
   $exitcond30 = ($34|0)==($3|0);
   if ($exitcond30) {
    break;
   } else {
    $i$023 = $34;$tempCount$024 = $tempCount$1;
   }
  }
  $35 = ($tempCount$1|0)<(3);
  if (!($35)) {
   $36 = +HEAPF32[$ps>>2];
   $i0$013 = 0;$i1$015 = 1;$x0$014 = $36;
   while(1) {
    $38 = (($ps) + ($i1$015<<3)|0);
    $39 = +HEAPF32[$38>>2];
    $40 = $39 > $x0$014;
    if ($40) {
     label = 16;
    } else {
     $41 = $39 == $x0$014;
     if ($41) {
      $42 = ((($ps) + ($i1$015<<3)|0) + 4|0);
      $43 = +HEAPF32[$42>>2];
      $44 = ((($ps) + ($i0$013<<3)|0) + 4|0);
      $45 = +HEAPF32[$44>>2];
      $46 = $43 < $45;
      if ($46) {
       label = 16;
      } else {
       $i0$1 = $i0$013;$x0$1 = $x0$014;
      }
     } else {
      $i0$1 = $i0$013;$x0$1 = $x0$014;
     }
    }
    if ((label|0) == 16) {
     label = 0;
     $i0$1 = $i1$015;$x0$1 = $39;
    }
    $47 = (($i1$015) + 1)|0;
    $exitcond29 = ($47|0)==($tempCount$1|0);
    if ($exitcond29) {
     break;
    } else {
     $i0$013 = $i0$1;$i1$015 = $47;$x0$014 = $x0$1;
    }
   }
   $37 = ($tempCount$1|0)>(1);
   $ih$0 = $i0$1;$m$0 = 0;
   while(1) {
    $48 = (($hull) + ($m$0<<2)|0);
    HEAP32[$48>>2] = $ih$0;
    if ($37) {
     $ie$07 = 0;$j2$08 = 1;
     while(1) {
      $49 = ($ie$07|0)==($ih$0|0);
      if ($49) {
       $ie$2 = $j2$08;
      } else {
       $50 = (($ps) + ($ie$07<<3)|0);
       $51 = HEAP32[$48>>2]|0;
       $52 = (($ps) + ($51<<3)|0);
       __ZmiRK6b2Vec2S1_($r,$50,$52);
       $53 = (($ps) + ($j2$08<<3)|0);
       $54 = HEAP32[$48>>2]|0;
       $55 = (($ps) + ($54<<3)|0);
       __ZmiRK6b2Vec2S1_($v3,$53,$55);
       $56 = (+__Z7b2CrossRK6b2Vec2S1_($r,$v3));
       $57 = $56 < 0.0;
       $ie$1 = $57 ? $j2$08 : $ie$07;
       $58 = $56 == 0.0;
       if ($58) {
        $59 = (+__ZNK6b2Vec213LengthSquaredEv($v3));
        $60 = (+__ZNK6b2Vec213LengthSquaredEv($r));
        $61 = $59 > $60;
        if ($61) {
         $ie$2 = $j2$08;
        } else {
         $ie$2 = $ie$1;
        }
       } else {
        $ie$2 = $ie$1;
       }
      }
      $62 = (($j2$08) + 1)|0;
      $exitcond = ($62|0)==($tempCount$1|0);
      if ($exitcond) {
       $ie$0$lcssa = $ie$2;
       break;
      } else {
       $ie$07 = $ie$2;$j2$08 = $62;
      }
     }
    } else {
     $ie$0$lcssa = 0;
    }
    $63 = (($m$0) + 1)|0;
    $64 = ($ie$0$lcssa|0)==($i0$1|0);
    if ($64) {
     break;
    } else {
     $ih$0 = $ie$0$lcssa;$m$0 = $63;
    }
   }
   $65 = (($this) + 148|0);
   HEAP32[$65>>2] = $63;
   $66 = ($m$0|0)>(-1);
   if ($66) {
    $i4$04 = 0;
    while(1) {
     $68 = ((($this) + ($i4$04<<3)|0) + 20|0);
     $69 = (($hull) + ($i4$04<<2)|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = (($ps) + ($70<<3)|0);
     $72 = $71;
     $73 = $72;
     $74 = HEAP32[$73>>2]|0;
     $75 = (($72) + 4)|0;
     $76 = $75;
     $77 = HEAP32[$76>>2]|0;
     $78 = $68;
     $79 = $78;
     HEAP32[$79>>2] = $74;
     $80 = (($78) + 4)|0;
     $81 = $80;
     HEAP32[$81>>2] = $77;
     $82 = (($i4$04) + 1)|0;
     $83 = ($82|0)<($63|0);
     if ($83) {
      $i4$04 = $82;
     } else {
      break;
     }
    }
    $67 = ($m$0|0)>(-1);
    if ($67) {
     $i5$03 = 0;
     while(1) {
      $84 = (($i5$03) + 1)|0;
      $85 = ($84|0)<($63|0);
      $$ = $85 ? $84 : 0;
      $86 = ((($this) + ($$<<3)|0) + 20|0);
      $87 = ((($this) + ($i5$03<<3)|0) + 20|0);
      __ZmiRK6b2Vec2S1_($edge,$86,$87);
      $88 = ((($this) + ($i5$03<<3)|0) + 84|0);
      __Z7b2CrossRK6b2Vec2f($0,$edge,1.0);
      $89 = $0;
      $90 = $89;
      $91 = HEAP32[$90>>2]|0;
      $92 = (($89) + 4)|0;
      $93 = $92;
      $94 = HEAP32[$93>>2]|0;
      $95 = $88;
      $96 = $95;
      HEAP32[$96>>2] = $91;
      $97 = (($95) + 4)|0;
      $98 = $97;
      HEAP32[$98>>2] = $94;
      (+__ZN6b2Vec29NormalizeEv($88));
      $99 = ($84|0)<($63|0);
      if ($99) {
       $i5$03 = $84;
      } else {
       break;
      }
     }
    }
   }
   $100 = (($this) + 12|0);
   $101 = (($this) + 20|0);
   __ZL15ComputeCentroidPK6b2Vec2i($1,$101,$63);
   $102 = $1;
   $103 = $102;
   $104 = HEAP32[$103>>2]|0;
   $105 = (($102) + 4)|0;
   $106 = $105;
   $107 = HEAP32[$106>>2]|0;
   $108 = $100;
   $109 = $108;
   HEAP32[$109>>2] = $104;
   $110 = (($108) + 4)|0;
   $111 = $110;
   HEAP32[$111>>2] = $107;
   STACKTOP = sp;return;
  }
 }
 __ZN14b2PolygonShape8SetAsBoxEff($this,1.0,1.0);
 STACKTOP = sp;return;
}
function __ZNK14b2PolygonShape9TestPointERK11b2TransformRK6b2Vec2($this,$xf,$p) {
 $this = $this|0;
 $xf = $xf|0;
 $p = $p|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $pLocal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pLocal = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = (($xf) + 8|0);
 __ZmiRK6b2Vec2S1_($0,$p,$xf);
 __Z6b2MulTRK5b2RotRK6b2Vec2($pLocal,$2,$0);
 $3 = (($this) + 148|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(0);
 if ($5) {
  $i$01 = 0;
 } else {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  $9 = ((($this) + ($i$01<<3)|0) + 84|0);
  $10 = ((($this) + ($i$01<<3)|0) + 20|0);
  __ZmiRK6b2Vec2S1_($1,$pLocal,$10);
  $11 = (+__Z5b2DotRK6b2Vec2S1_($9,$1));
  $12 = $11 > 0.0;
  $7 = (($i$01) + 1)|0;
  if ($12) {
   $$0 = 0;
   label = 4;
   break;
  }
  $6 = HEAP32[$3>>2]|0;
  $8 = ($7|0)<($6|0);
  if ($8) {
   $i$01 = $7;
  } else {
   $$0 = 1;
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function __ZNK14b2PolygonShape15ComputeDistanceERK11b2TransformRK6b2Vec2PfPS3_i($this,$xf,$p,$distance,$normal,$childIndex) {
 $this = $this|0;
 $xf = $xf|0;
 $p = $p|0;
 $distance = $distance|0;
 $normal = $normal|0;
 $childIndex = $childIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0.0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0.0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $distance2 = 0, $i$08 = 0, $i1$07 = 0, $maxDistance$0$lcssa15 = 0.0, $maxDistance$09 = 0.0, $maxDistance$1 = 0.0, $minDistance = 0, $minDistance2$0$lcssa = 0.0, $minDistance2$06 = 0.0, $minDistance2$1 = 0.0, $normalForMaxDistance = 0, $pLocal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $pLocal = sp + 40|0;
 $0 = sp + 56|0;
 $normalForMaxDistance = sp + 32|0;
 $1 = sp + 48|0;
 $minDistance = sp + 24|0;
 $distance2 = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp;
 $4 = (($xf) + 8|0);
 __ZmiRK6b2Vec2S1_($0,$p,$xf);
 __Z6b2MulTRK5b2RotRK6b2Vec2($pLocal,$4,$0);
 $5 = $pLocal;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $normalForMaxDistance;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 $15 = (($this) + 148|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)>(0);
 if ($17) {
  $i$08 = 0;$maxDistance$09 = -3.4028234663852886E+38;
  while(1) {
   $18 = ((($this) + ($i$08<<3)|0) + 84|0);
   $19 = ((($this) + ($i$08<<3)|0) + 20|0);
   __ZmiRK6b2Vec2S1_($1,$pLocal,$19);
   $20 = (+__Z5b2DotRK6b2Vec2S1_($18,$1));
   $21 = $20 > $maxDistance$09;
   if ($21) {
    $22 = $18;
    $23 = $22;
    $24 = HEAP32[$23>>2]|0;
    $25 = (($22) + 4)|0;
    $26 = $25;
    $27 = HEAP32[$26>>2]|0;
    $28 = $normalForMaxDistance;
    $29 = $28;
    HEAP32[$29>>2] = $24;
    $30 = (($28) + 4)|0;
    $31 = $30;
    HEAP32[$31>>2] = $27;
    $maxDistance$1 = $20;
   } else {
    $maxDistance$1 = $maxDistance$09;
   }
   $32 = (($i$08) + 1)|0;
   $33 = HEAP32[$15>>2]|0;
   $34 = ($32|0)<($33|0);
   if ($34) {
    $i$08 = $32;$maxDistance$09 = $maxDistance$1;
   } else {
    break;
   }
  }
  $35 = $maxDistance$1 > 0.0;
  if ($35) {
   $36 = $normalForMaxDistance;
   $37 = $36;
   $38 = HEAP32[$37>>2]|0;
   $39 = (($36) + 4)|0;
   $40 = $39;
   $41 = HEAP32[$40>>2]|0;
   $42 = $minDistance;
   $43 = $42;
   HEAP32[$43>>2] = $38;
   $44 = (($42) + 4)|0;
   $45 = $44;
   HEAP32[$45>>2] = $41;
   $46 = $maxDistance$1 * $maxDistance$1;
   $47 = HEAP32[$15>>2]|0;
   $48 = ($47|0)>(0);
   if ($48) {
    $i1$07 = 0;$minDistance2$06 = $46;
    while(1) {
     $49 = ((($this) + ($i1$07<<3)|0) + 20|0);
     __ZmiRK6b2Vec2S1_($distance2,$pLocal,$49);
     $50 = (+__ZNK6b2Vec213LengthSquaredEv($distance2));
     $51 = $minDistance2$06 > $50;
     if ($51) {
      $52 = $distance2;
      $53 = $52;
      $54 = HEAP32[$53>>2]|0;
      $55 = (($52) + 4)|0;
      $56 = $55;
      $57 = HEAP32[$56>>2]|0;
      $58 = $minDistance;
      $59 = $58;
      HEAP32[$59>>2] = $54;
      $60 = (($58) + 4)|0;
      $61 = $60;
      HEAP32[$61>>2] = $57;
      $minDistance2$1 = $50;
     } else {
      $minDistance2$1 = $minDistance2$06;
     }
     $62 = (($i1$07) + 1)|0;
     $63 = HEAP32[$15>>2]|0;
     $64 = ($62|0)<($63|0);
     if ($64) {
      $i1$07 = $62;$minDistance2$06 = $minDistance2$1;
     } else {
      $minDistance2$0$lcssa = $minDistance2$1;
      break;
     }
    }
   } else {
    $minDistance2$0$lcssa = $46;
   }
   $65 = (+Math_sqrt((+$minDistance2$0$lcssa)));
   HEAPF32[$distance>>2] = $65;
   __Z5b2MulRK5b2RotRK6b2Vec2($2,$4,$minDistance);
   $66 = $2;
   $67 = $66;
   $68 = HEAP32[$67>>2]|0;
   $69 = (($66) + 4)|0;
   $70 = $69;
   $71 = HEAP32[$70>>2]|0;
   $72 = $normal;
   $73 = $72;
   HEAP32[$73>>2] = $68;
   $74 = (($72) + 4)|0;
   $75 = $74;
   HEAP32[$75>>2] = $71;
   (+__ZN6b2Vec29NormalizeEv($normal));
   STACKTOP = sp;return;
  } else {
   $maxDistance$0$lcssa15 = $maxDistance$1;
  }
 } else {
  $maxDistance$0$lcssa15 = -3.4028234663852886E+38;
 }
 HEAPF32[$distance>>2] = $maxDistance$0$lcssa15;
 __Z5b2MulRK5b2RotRK6b2Vec2($3,$4,$normalForMaxDistance);
 $76 = $3;
 $77 = $76;
 $78 = HEAP32[$77>>2]|0;
 $79 = (($76) + 4)|0;
 $80 = $79;
 $81 = HEAP32[$80>>2]|0;
 $82 = $normal;
 $83 = $82;
 HEAP32[$83>>2] = $78;
 $84 = (($82) + 4)|0;
 $85 = $84;
 HEAP32[$85>>2] = $81;
 STACKTOP = sp;return;
}
function __ZNK14b2PolygonShape7RayCastEP15b2RayCastOutputRK14b2RayCastInputRK11b2Transformi($this,$output,$input,$xf,$childIndex) {
 $this = $this|0;
 $output = $output|0;
 $input = $input|0;
 $xf = $xf|0;
 $childIndex = $childIndex|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0.0;
 var $26 = 0, $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $d = 0, $i$08 = 0, $index$07 = 0, $index$1 = 0, $lower$09 = 0.0, $lower$1 = 0.0, $or$cond = 0, $or$cond3 = 0, $p1 = 0, $p2 = 0, $upper$06 = 0.0, $upper$1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $p1 = sp + 48|0;
 $0 = sp + 40|0;
 $p2 = sp + 32|0;
 $1 = sp + 24|0;
 $d = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp;
 $4 = (($xf) + 8|0);
 __ZmiRK6b2Vec2S1_($0,$input,$xf);
 __Z6b2MulTRK5b2RotRK6b2Vec2($p1,$4,$0);
 $5 = (($input) + 8|0);
 __ZmiRK6b2Vec2S1_($1,$5,$xf);
 __Z6b2MulTRK5b2RotRK6b2Vec2($p2,$4,$1);
 __ZmiRK6b2Vec2S1_($d,$p2,$p1);
 $6 = (($this) + 148|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)>(0);
 if (!($8)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (($input) + 16|0);
 $10 = +HEAPF32[$9>>2];
 $i$08 = 0;$index$07 = -1;$lower$09 = 0.0;$upper$06 = $10;
 L4: while(1) {
  $14 = ((($this) + ($i$08<<3)|0) + 84|0);
  $15 = ((($this) + ($i$08<<3)|0) + 20|0);
  __ZmiRK6b2Vec2S1_($2,$15,$p1);
  $16 = (+__Z5b2DotRK6b2Vec2S1_($14,$2));
  $17 = (+__Z5b2DotRK6b2Vec2S1_($14,$d));
  $18 = $17 == 0.0;
  do {
   if ($18) {
    $19 = $16 < 0.0;
    if ($19) {
     $$0 = 0;
     label = 13;
     break L4;
    } else {
     $index$1 = $index$07;$lower$1 = $lower$09;$upper$1 = $upper$06;
    }
   } else {
    $20 = $17 < 0.0;
    $21 = $lower$09 * $17;
    $22 = $16 < $21;
    $or$cond = $20 & $22;
    if ($or$cond) {
     $23 = $16 / $17;
     $index$1 = $i$08;$lower$1 = $23;$upper$1 = $upper$06;
     break;
    }
    $24 = $17 > 0.0;
    $25 = $upper$06 * $17;
    $26 = $16 < $25;
    $or$cond3 = $24 & $26;
    if ($or$cond3) {
     $27 = $16 / $17;
     $index$1 = $index$07;$lower$1 = $lower$09;$upper$1 = $27;
    } else {
     $index$1 = $index$07;$lower$1 = $lower$09;$upper$1 = $upper$06;
    }
   }
  } while(0);
  $28 = $upper$1 < $lower$1;
  $12 = (($i$08) + 1)|0;
  if ($28) {
   $$0 = 0;
   label = 13;
   break;
  }
  $11 = HEAP32[$6>>2]|0;
  $13 = ($12|0)<($11|0);
  if ($13) {
   $i$08 = $12;$index$07 = $index$1;$lower$09 = $lower$1;$upper$06 = $upper$1;
  } else {
   label = 11;
   break;
  }
 }
 if ((label|0) == 11) {
  $29 = ($index$1|0)>(-1);
  if (!($29)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $30 = (($output) + 8|0);
  HEAPF32[$30>>2] = $lower$1;
  $31 = ((($this) + ($index$1<<3)|0) + 84|0);
  __Z5b2MulRK5b2RotRK6b2Vec2($3,$4,$31);
  $32 = $3;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = (($32) + 4)|0;
  $36 = $35;
  $37 = HEAP32[$36>>2]|0;
  $38 = $output;
  $39 = $38;
  HEAP32[$39>>2] = $34;
  $40 = (($38) + 4)|0;
  $41 = $40;
  HEAP32[$41>>2] = $37;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 13) {
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function __ZNK14b2PolygonShape11ComputeAABBEP6b2AABBRK11b2Transformi($this,$aabb,$xf,$childIndex) {
 $this = $this|0;
 $aabb = $aabb|0;
 $xf = $xf|0;
 $childIndex = $childIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $i$06 = 0, $lower = 0, $r = 0, $upper = 0, $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $lower = sp + 40|0;
 $upper = sp + 32|0;
 $v = sp + 56|0;
 $0 = sp + 24|0;
 $1 = sp + 16|0;
 $r = sp + 48|0;
 $2 = sp + 8|0;
 $3 = sp;
 $4 = (($this) + 20|0);
 __Z5b2MulRK11b2TransformRK6b2Vec2($lower,$xf,$4);
 $5 = $lower;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $upper;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 $15 = (($this) + 148|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)>(1);
 if ($17) {
  $i$06 = 1;
  while(1) {
   $18 = ((($this) + ($i$06<<3)|0) + 20|0);
   __Z5b2MulRK11b2TransformRK6b2Vec2($v,$xf,$18);
   __Z5b2MinRK6b2Vec2S1_($0,$lower,$v);
   $19 = $0;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($19) + 4)|0;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = $lower;
   $26 = $25;
   HEAP32[$26>>2] = $21;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $24;
   __Z5b2MaxRK6b2Vec2S1_($1,$upper,$v);
   $29 = $1;
   $30 = $29;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($29) + 4)|0;
   $33 = $32;
   $34 = HEAP32[$33>>2]|0;
   $35 = $upper;
   $36 = $35;
   HEAP32[$36>>2] = $31;
   $37 = (($35) + 4)|0;
   $38 = $37;
   HEAP32[$38>>2] = $34;
   $39 = (($i$06) + 1)|0;
   $40 = HEAP32[$15>>2]|0;
   $41 = ($39|0)<($40|0);
   if ($41) {
    $i$06 = $39;
   } else {
    break;
   }
  }
 }
 $42 = (($this) + 8|0);
 $43 = +HEAPF32[$42>>2];
 __ZN6b2Vec2C2Eff($r,$43,$43);
 __ZmiRK6b2Vec2S1_($2,$lower,$r);
 $44 = $2;
 $45 = $44;
 $46 = HEAP32[$45>>2]|0;
 $47 = (($44) + 4)|0;
 $48 = $47;
 $49 = HEAP32[$48>>2]|0;
 $50 = $aabb;
 $51 = $50;
 HEAP32[$51>>2] = $46;
 $52 = (($50) + 4)|0;
 $53 = $52;
 HEAP32[$53>>2] = $49;
 $54 = (($aabb) + 8|0);
 __ZplRK6b2Vec2S1_($3,$upper,$r);
 $55 = $3;
 $56 = $55;
 $57 = HEAP32[$56>>2]|0;
 $58 = (($55) + 4)|0;
 $59 = $58;
 $60 = HEAP32[$59>>2]|0;
 $61 = $54;
 $62 = $61;
 HEAP32[$62>>2] = $57;
 $63 = (($61) + 4)|0;
 $64 = $63;
 HEAP32[$64>>2] = $60;
 STACKTOP = sp;return;
}
function __ZNK14b2PolygonShape11ComputeMassEP10b2MassDataf($this,$massData,$density) {
 $this = $this|0;
 $massData = $massData|0;
 $density = +$density;
 var $$lcssa5 = 0, $0 = 0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0;
 var $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0;
 var $44 = 0, $45 = 0, $46 = 0.0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0.0;
 var $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $7 = 0, $8 = 0, $9 = 0, $I$0$lcssa = 0.0, $I$02 = 0.0, $area$0$lcssa = 0.0, $area$03 = 0.0, $center = 0, $e1 = 0, $e2 = 0, $i$06 = 0, $i1$01 = 0, $s = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $center = sp + 48|0;
 $s = sp + 40|0;
 $e1 = sp + 32|0;
 $e2 = sp + 24|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 $2 = sp;
 __ZN6b2Vec23SetEff($center,0.0,0.0);
 __ZN6b2Vec2C2Eff($s,0.0,0.0);
 $3 = (($this) + 148|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(0);
 if ($5) {
  $i$06 = 0;
  while(1) {
   $6 = ((($this) + ($i$06<<3)|0) + 20|0);
   __ZN6b2Vec2pLERKS_($s,$6);
   $7 = (($i$06) + 1)|0;
   $8 = HEAP32[$3>>2]|0;
   $9 = ($7|0)<($8|0);
   if ($9) {
    $i$06 = $7;
   } else {
    $$lcssa5 = $8;
    break;
   }
  }
 } else {
  $$lcssa5 = $4;
 }
 $10 = (+($$lcssa5|0));
 $11 = 1.0 / $10;
 __ZN6b2Vec2mLEf($s,$11);
 $12 = HEAP32[$3>>2]|0;
 $13 = ($12|0)>(0);
 if ($13) {
  $14 = (($e1) + 4|0);
  $15 = (($e2) + 4|0);
  $16 = (($this) + 20|0);
  $I$02 = 0.0;$area$03 = 0.0;$i1$01 = 0;
  while(1) {
   $17 = ((($this) + ($i1$01<<3)|0) + 20|0);
   __ZmiRK6b2Vec2S1_($e1,$17,$s);
   $18 = (($i1$01) + 1)|0;
   $19 = HEAP32[$3>>2]|0;
   $20 = ($18|0)<($19|0);
   if ($20) {
    $21 = ((($this) + ($18<<3)|0) + 20|0);
    __ZmiRK6b2Vec2S1_($e2,$21,$s);
   } else {
    __ZmiRK6b2Vec2S1_($e2,$16,$s);
   }
   $22 = (+__Z7b2CrossRK6b2Vec2S1_($e1,$e2));
   $23 = $22 * 0.5;
   $24 = $area$03 + $23;
   $25 = $23 * 0.3333333432674408;
   __ZplRK6b2Vec2S1_($1,$e1,$e2);
   __ZmlfRK6b2Vec2($0,$25,$1);
   __ZN6b2Vec2pLERKS_($center,$0);
   $26 = +HEAPF32[$e1>>2];
   $27 = +HEAPF32[$14>>2];
   $28 = +HEAPF32[$e2>>2];
   $29 = +HEAPF32[$15>>2];
   $30 = $26 * $26;
   $31 = $26 * $28;
   $32 = $30 + $31;
   $33 = $28 * $28;
   $34 = $33 + $32;
   $35 = $27 * $27;
   $36 = $27 * $29;
   $37 = $35 + $36;
   $38 = $29 * $29;
   $39 = $38 + $37;
   $40 = $22 * 0.083333335816860198;
   $41 = $34 + $39;
   $42 = $40 * $41;
   $43 = $I$02 + $42;
   $44 = HEAP32[$3>>2]|0;
   $45 = ($18|0)<($44|0);
   if ($45) {
    $I$02 = $43;$area$03 = $24;$i1$01 = $18;
   } else {
    $I$0$lcssa = $43;$area$0$lcssa = $24;
    break;
   }
  }
 } else {
  $I$0$lcssa = 0.0;$area$0$lcssa = 0.0;
 }
 $46 = $area$0$lcssa * $density;
 HEAPF32[$massData>>2] = $46;
 $47 = 1.0 / $area$0$lcssa;
 __ZN6b2Vec2mLEf($center,$47);
 $48 = (($massData) + 4|0);
 __ZplRK6b2Vec2S1_($2,$center,$s);
 $49 = $2;
 $50 = $49;
 $51 = HEAP32[$50>>2]|0;
 $52 = (($49) + 4)|0;
 $53 = $52;
 $54 = HEAP32[$53>>2]|0;
 $55 = $48;
 $56 = $55;
 HEAP32[$56>>2] = $51;
 $57 = (($55) + 4)|0;
 $58 = $57;
 HEAP32[$58>>2] = $54;
 $59 = $I$0$lcssa * $density;
 $60 = (($massData) + 12|0);
 HEAPF32[$60>>2] = $59;
 $61 = +HEAPF32[$massData>>2];
 $62 = (+__Z5b2DotRK6b2Vec2S1_($48,$48));
 $63 = (+__Z5b2DotRK6b2Vec2S1_($center,$center));
 $64 = $62 - $63;
 $65 = $61 * $64;
 $66 = $59 + $65;
 HEAPF32[$60>>2] = $66;
 STACKTOP = sp;return;
}
function __ZN14b2PolygonShapeD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN14b2PolygonShapeaSERKS_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN7b2ShapeaSERKS_($this,$0)|0);
 $1 = (($this) + 12|0);
 $2 = (($0) + 12|0);
 _memcpy(($1|0),($2|0),140)|0;
 STACKTOP = sp;return ($this|0);
}
function __Z5b2MinIiET_S0_S0_($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($a|0)<($b|0);
 $1 = $0 ? $a : $b;
 STACKTOP = sp;return ($1|0);
}
function __Z17b2DistanceSquaredRK6b2Vec2S1_($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0.0, $c = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $c = sp;
 __ZmiRK6b2Vec2S1_($c,$a,$b);
 $0 = (+__Z5b2DotRK6b2Vec2S1_($c,$c));
 STACKTOP = sp;return (+$0);
}
function __ZL15ComputeCentroidPK6b2Vec2i($agg$result,$vs,$count) {
 $agg$result = $agg$result|0;
 $vs = $vs|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $area$0$lcssa = 0.0, $area$05 = 0.0, $e1 = 0, $e2 = 0, $exitcond = 0, $i$04 = 0, $p1 = 0, $p2 = 0, $p3 = 0, $pRef = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $pRef = sp + 24|0;
 $p1 = sp + 16|0;
 $p2 = sp + 8|0;
 $p3 = sp;
 $e1 = sp + 64|0;
 $e2 = sp + 56|0;
 $0 = sp + 48|0;
 $1 = sp + 40|0;
 $2 = sp + 32|0;
 __ZN6b2Vec23SetEff($agg$result,0.0,0.0);
 __ZN6b2Vec2C2Eff($pRef,0.0,0.0);
 $3 = ($count|0)>(0);
 if (!($3)) {
  $area$0$lcssa = 0.0;
  $43 = 1.0 / $area$0$lcssa;
  __ZN6b2Vec2mLEf($agg$result,$43);
  STACKTOP = sp;return;
 }
 $4 = $pRef;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $area$05 = 0.0;$i$04 = 0;
 while(1) {
  $10 = $p1;
  $11 = $10;
  HEAP32[$11>>2] = $6;
  $12 = (($10) + 4)|0;
  $13 = $12;
  HEAP32[$13>>2] = $9;
  $14 = (($vs) + ($i$04<<3)|0);
  $15 = $14;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  $18 = (($15) + 4)|0;
  $19 = $18;
  $20 = HEAP32[$19>>2]|0;
  $21 = $p2;
  $22 = $21;
  HEAP32[$22>>2] = $17;
  $23 = (($21) + 4)|0;
  $24 = $23;
  HEAP32[$24>>2] = $20;
  $25 = (($i$04) + 1)|0;
  $26 = ($25|0)<($count|0);
  if ($26) {
   $27 = (($vs) + ($25<<3)|0);
   $28 = $27;
  } else {
   $28 = $vs;
  }
  $29 = $28;
  $30 = $29;
  $31 = HEAP32[$30>>2]|0;
  $32 = (($29) + 4)|0;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = $p3;
  $36 = $35;
  HEAP32[$36>>2] = $31;
  $37 = (($35) + 4)|0;
  $38 = $37;
  HEAP32[$38>>2] = $34;
  __ZmiRK6b2Vec2S1_($e1,$p2,$p1);
  __ZmiRK6b2Vec2S1_($e2,$p3,$p1);
  $39 = (+__Z7b2CrossRK6b2Vec2S1_($e1,$e2));
  $40 = $39 * 0.5;
  $41 = $area$05 + $40;
  $42 = $40 * 0.3333333432674408;
  __ZplRK6b2Vec2S1_($2,$p1,$p2);
  __ZplRK6b2Vec2S1_($1,$2,$p3);
  __ZmlfRK6b2Vec2($0,$42,$1);
  __ZN6b2Vec2pLERKS_($agg$result,$0);
  $exitcond = ($25|0)==($count|0);
  if ($exitcond) {
   $area$0$lcssa = $41;
   break;
  } else {
   $area$05 = $41;$i$04 = $25;
  }
 }
 $43 = 1.0 / $area$0$lcssa;
 __ZN6b2Vec2mLEf($agg$result,$43);
 STACKTOP = sp;return;
}
function __ZNK13b2CircleShape5CloneEP16b2BlockAllocator($this,$allocator) {
 $this = $this|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN16b2BlockAllocator8AllocateEi($allocator,20)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = 0;
 } else {
  __ZN13b2CircleShapeC2Ev($0);
  $2 = $0;
 }
 (__ZN13b2CircleShapeaSERKS_($2,$this)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZNK13b2CircleShape13GetChildCountEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZNK13b2CircleShape9TestPointERK11b2TransformRK6b2Vec2($this,$transform,$p) {
 $this = $this|0;
 $transform = $transform|0;
 $p = $p|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0.0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0, $center = 0, $d = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $center = sp + 16|0;
 $0 = sp + 8|0;
 $d = sp;
 $1 = (($transform) + 8|0);
 $2 = (($this) + 12|0);
 __Z5b2MulRK5b2RotRK6b2Vec2($0,$1,$2);
 __ZplRK6b2Vec2S1_($center,$transform,$0);
 __ZmiRK6b2Vec2S1_($d,$p,$center);
 $3 = (+__Z5b2DotRK6b2Vec2S1_($d,$d));
 $4 = (($this) + 8|0);
 $5 = +HEAPF32[$4>>2];
 $6 = $5 * $5;
 $7 = $3 <= $6;
 STACKTOP = sp;return ($7|0);
}
function __ZNK13b2CircleShape15ComputeDistanceERK11b2TransformRK6b2Vec2PfPS3_i($this,$transform,$p,$distance,$normal,$childIndex) {
 $this = $this|0;
 $transform = $transform|0;
 $p = $p|0;
 $distance = $distance|0;
 $normal = $normal|0;
 $childIndex = $childIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0, $center = 0;
 var $d = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $center = sp + 24|0;
 $0 = sp + 16|0;
 $d = sp + 8|0;
 $1 = sp;
 $2 = (($transform) + 8|0);
 $3 = (($this) + 12|0);
 __Z5b2MulRK5b2RotRK6b2Vec2($0,$2,$3);
 __ZplRK6b2Vec2S1_($center,$transform,$0);
 __ZmiRK6b2Vec2S1_($d,$p,$center);
 $4 = (+__ZNK6b2Vec26LengthEv($d));
 $5 = (($this) + 8|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $4 - $6;
 HEAPF32[$distance>>2] = $7;
 $8 = 1.0 / $4;
 __ZmlfRK6b2Vec2($1,$8,$d);
 $9 = $1;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = $normal;
 $16 = $15;
 HEAP32[$16>>2] = $11;
 $17 = (($15) + 4)|0;
 $18 = $17;
 HEAP32[$18>>2] = $14;
 STACKTOP = sp;return;
}
function __ZNK13b2CircleShape7RayCastEP15b2RayCastOutputRK14b2RayCastInputRK11b2Transformi($this,$output,$input,$transform,$childIndex) {
 $this = $this|0;
 $output = $output|0;
 $input = $input|0;
 $transform = $transform|0;
 $childIndex = $childIndex|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0;
 var $26 = 0.0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0.0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, $or$cond = 0;
 var $position = 0, $r = 0, $s = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $position = sp + 40|0;
 $0 = sp + 32|0;
 $s = sp + 24|0;
 $r = sp + 16|0;
 $1 = sp;
 $2 = sp + 8|0;
 $3 = (($transform) + 8|0);
 $4 = (($this) + 12|0);
 __Z5b2MulRK5b2RotRK6b2Vec2($0,$3,$4);
 __ZplRK6b2Vec2S1_($position,$transform,$0);
 __ZmiRK6b2Vec2S1_($s,$input,$position);
 $5 = (+__Z5b2DotRK6b2Vec2S1_($s,$s));
 $6 = (($this) + 8|0);
 $7 = +HEAPF32[$6>>2];
 $8 = $7 * $7;
 $9 = $5 - $8;
 $10 = (($input) + 8|0);
 __ZmiRK6b2Vec2S1_($r,$10,$input);
 $11 = (+__Z5b2DotRK6b2Vec2S1_($s,$r));
 $12 = (+__Z5b2DotRK6b2Vec2S1_($r,$r));
 $13 = $11 * $11;
 $14 = $9 * $12;
 $15 = $13 - $14;
 $16 = $15 < 0.0;
 $17 = $12 < 1.1920928955078125E-7;
 $or$cond = $16 | $17;
 if ($or$cond) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (+Math_sqrt((+$15)));
 $19 = $11 + $18;
 $20 = -$19;
 $21 = !($19 <= -0.0);
 if ($21) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $22 = (($input) + 16|0);
 $23 = +HEAPF32[$22>>2];
 $24 = $12 * $23;
 $25 = !($24 >= $20);
 if ($25) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $26 = $20 / $12;
 $27 = (($output) + 8|0);
 HEAPF32[$27>>2] = $26;
 __ZmlfRK6b2Vec2($2,$26,$r);
 __ZplRK6b2Vec2S1_($1,$s,$2);
 $28 = $1;
 $29 = $28;
 $30 = HEAP32[$29>>2]|0;
 $31 = (($28) + 4)|0;
 $32 = $31;
 $33 = HEAP32[$32>>2]|0;
 $34 = $output;
 $35 = $34;
 HEAP32[$35>>2] = $30;
 $36 = (($34) + 4)|0;
 $37 = $36;
 HEAP32[$37>>2] = $33;
 (+__ZN6b2Vec29NormalizeEv($output));
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK13b2CircleShape11ComputeAABBEP6b2AABBRK11b2Transformi($this,$aabb,$transform,$childIndex) {
 $this = $this|0;
 $aabb = $aabb|0;
 $transform = $transform|0;
 $childIndex = $childIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $2 = 0, $3 = 0.0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, $p = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $p = sp + 8|0;
 $0 = sp;
 $1 = (($transform) + 8|0);
 $2 = (($this) + 12|0);
 __Z5b2MulRK5b2RotRK6b2Vec2($0,$1,$2);
 __ZplRK6b2Vec2S1_($p,$transform,$0);
 $3 = +HEAPF32[$p>>2];
 $4 = (($this) + 8|0);
 $5 = +HEAPF32[$4>>2];
 $6 = $3 - $5;
 $7 = (($p) + 4|0);
 $8 = +HEAPF32[$7>>2];
 $9 = $8 - $5;
 __ZN6b2Vec23SetEff($aabb,$6,$9);
 $10 = (($aabb) + 8|0);
 $11 = +HEAPF32[$p>>2];
 $12 = +HEAPF32[$4>>2];
 $13 = $11 + $12;
 $14 = +HEAPF32[$7>>2];
 $15 = $12 + $14;
 __ZN6b2Vec23SetEff($10,$13,$15);
 STACKTOP = sp;return;
}
function __ZNK13b2CircleShape11ComputeMassEP10b2MassDataf($this,$massData,$density) {
 $this = $this|0;
 $massData = $massData|0;
 $density = +$density;
 var $0 = 0.0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0, $3 = 0.0, $4 = 0.0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $density * 3.1415927410125732;
 $1 = (($this) + 8|0);
 $2 = +HEAPF32[$1>>2];
 $3 = $0 * $2;
 $4 = $2 * $3;
 HEAPF32[$massData>>2] = $4;
 $5 = (($massData) + 4|0);
 $6 = (($this) + 12|0);
 $7 = $6;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 4)|0;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = $5;
 $14 = $13;
 HEAP32[$14>>2] = $9;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = $12;
 $17 = +HEAPF32[$massData>>2];
 $18 = +HEAPF32[$1>>2];
 $19 = $18 * 0.5;
 $20 = $18 * $19;
 $21 = (+__Z5b2DotRK6b2Vec2S1_($6,$6));
 $22 = $21 + $20;
 $23 = $17 * $22;
 $24 = (($massData) + 12|0);
 HEAPF32[$24>>2] = $23;
 STACKTOP = sp;return;
}
function __ZN13b2CircleShapeD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN13b2CircleShapeaSERKS_($this,$0) {
 $this = $this|0;
 $0 = $0|0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN7b2ShapeaSERKS_($this,$0)|0);
 $1 = (($this) + 12|0);
 $2 = (($0) + 12|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $1;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 STACKTOP = sp;return ($this|0);
}
function __ZN12b2ChainShapeD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12b2ChainShapeD2Ev($this);
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN12b2ChainShapeD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((2176 + 8|0));
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 __Z6b2FreePv($1);
 HEAP32[$0>>2] = 0;
 $2 = (($this) + 16|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN12b2ChainShape11CreateChainEPK6b2Vec2i($this,$vertices,$count) {
 $this = $this|0;
 $vertices = $vertices|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 HEAP32[$0>>2] = $count;
 $1 = $count << 3;
 $2 = (__Z7b2Alloci($1)|0);
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = $2;
 $4 = HEAP32[$0>>2]|0;
 $5 = $4 << 3;
 _memcpy(($2|0),($vertices|0),($5|0))|0;
 $6 = (($this) + 36|0);
 HEAP8[$6>>0] = 0;
 $7 = (($this) + 37|0);
 HEAP8[$7>>0] = 0;
 $8 = (($this) + 20|0);
 __ZN6b2Vec27SetZeroEv($8);
 $9 = (($this) + 28|0);
 __ZN6b2Vec27SetZeroEv($9);
 STACKTOP = sp;return;
}
function __ZNK12b2ChainShape5CloneEP16b2BlockAllocator($this,$allocator) {
 $this = $this|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN16b2BlockAllocator8AllocateEi($allocator,40)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $6 = 0;
 } else {
  __ZN12b2ChainShapeC2Ev($0);
  $6 = $0;
 }
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 __ZN12b2ChainShape11CreateChainEPK6b2Vec2i($6,$3,$5);
 $7 = (($6) + 20|0);
 $8 = (($this) + 20|0);
 $9 = $8;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = $7;
 $16 = $15;
 HEAP32[$16>>2] = $11;
 $17 = (($15) + 4)|0;
 $18 = $17;
 HEAP32[$18>>2] = $14;
 $19 = (($6) + 28|0);
 $20 = (($this) + 28|0);
 $21 = $20;
 $22 = $21;
 $23 = HEAP32[$22>>2]|0;
 $24 = (($21) + 4)|0;
 $25 = $24;
 $26 = HEAP32[$25>>2]|0;
 $27 = $19;
 $28 = $27;
 HEAP32[$28>>2] = $23;
 $29 = (($27) + 4)|0;
 $30 = $29;
 HEAP32[$30>>2] = $26;
 $31 = (($this) + 36|0);
 $32 = HEAP8[$31>>0]|0;
 $33 = (($6) + 36|0);
 HEAP8[$33>>0] = $32;
 $34 = (($this) + 37|0);
 $35 = HEAP8[$34>>0]|0;
 $36 = (($6) + 37|0);
 HEAP8[$36>>0] = $35;
 STACKTOP = sp;return ($6|0);
}
function __ZNK12b2ChainShape13GetChildCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 STACKTOP = sp;return ($2|0);
}
function __ZNK12b2ChainShape12GetChildEdgeEP11b2EdgeShapei($this,$edge,$index) {
 $this = $this|0;
 $edge = $edge|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0.0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($edge) + 4|0);
 HEAP32[$0>>2] = 1;
 $1 = (($this) + 8|0);
 $2 = +HEAPF32[$1>>2];
 $3 = (($edge) + 8|0);
 HEAPF32[$3>>2] = $2;
 $4 = (($edge) + 12|0);
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($index<<3)|0);
 $8 = $7;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = $4;
 $15 = $14;
 HEAP32[$15>>2] = $10;
 $16 = (($14) + 4)|0;
 $17 = $16;
 HEAP32[$17>>2] = $13;
 $18 = (($edge) + 20|0);
 $19 = (($index) + 1)|0;
 $20 = HEAP32[$5>>2]|0;
 $21 = (($20) + ($19<<3)|0);
 $22 = $21;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 $25 = (($22) + 4)|0;
 $26 = $25;
 $27 = HEAP32[$26>>2]|0;
 $28 = $18;
 $29 = $28;
 HEAP32[$29>>2] = $24;
 $30 = (($28) + 4)|0;
 $31 = $30;
 HEAP32[$31>>2] = $27;
 $32 = ($index|0)>(0);
 $33 = (($edge) + 28|0);
 if ($32) {
  $34 = (($index) + -1)|0;
  $35 = HEAP32[$5>>2]|0;
  $36 = (($35) + ($34<<3)|0);
  $37 = $36;
  $38 = $37;
  $39 = HEAP32[$38>>2]|0;
  $40 = (($37) + 4)|0;
  $41 = $40;
  $42 = HEAP32[$41>>2]|0;
  $43 = $33;
  $44 = $43;
  HEAP32[$44>>2] = $39;
  $45 = (($43) + 4)|0;
  $46 = $45;
  HEAP32[$46>>2] = $42;
  $47 = (($edge) + 44|0);
  HEAP8[$47>>0] = 1;
 } else {
  $48 = (($this) + 20|0);
  $49 = $48;
  $50 = $49;
  $51 = HEAP32[$50>>2]|0;
  $52 = (($49) + 4)|0;
  $53 = $52;
  $54 = HEAP32[$53>>2]|0;
  $55 = $33;
  $56 = $55;
  HEAP32[$56>>2] = $51;
  $57 = (($55) + 4)|0;
  $58 = $57;
  HEAP32[$58>>2] = $54;
  $59 = (($this) + 36|0);
  $60 = HEAP8[$59>>0]|0;
  $61 = (($edge) + 44|0);
  HEAP8[$61>>0] = $60;
 }
 $62 = (($this) + 16|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($63) + -2)|0;
 $65 = ($64|0)>($index|0);
 $66 = (($edge) + 36|0);
 if ($65) {
  $67 = (($index) + 2)|0;
  $68 = HEAP32[$5>>2]|0;
  $69 = (($68) + ($67<<3)|0);
  $70 = $69;
  $71 = $70;
  $72 = HEAP32[$71>>2]|0;
  $73 = (($70) + 4)|0;
  $74 = $73;
  $75 = HEAP32[$74>>2]|0;
  $76 = $66;
  $77 = $76;
  HEAP32[$77>>2] = $72;
  $78 = (($76) + 4)|0;
  $79 = $78;
  HEAP32[$79>>2] = $75;
  $80 = (($edge) + 45|0);
  HEAP8[$80>>0] = 1;
  STACKTOP = sp;return;
 } else {
  $81 = (($this) + 28|0);
  $82 = $81;
  $83 = $82;
  $84 = HEAP32[$83>>2]|0;
  $85 = (($82) + 4)|0;
  $86 = $85;
  $87 = HEAP32[$86>>2]|0;
  $88 = $66;
  $89 = $88;
  HEAP32[$89>>2] = $84;
  $90 = (($88) + 4)|0;
  $91 = $90;
  HEAP32[$91>>2] = $87;
  $92 = (($this) + 37|0);
  $93 = HEAP8[$92>>0]|0;
  $94 = (($edge) + 45|0);
  HEAP8[$94>>0] = $93;
  STACKTOP = sp;return;
 }
}
function __ZNK12b2ChainShape15ComputeDistanceERK11b2TransformRK6b2Vec2PfPS3_i($this,$xf,$p,$distance,$normal,$childIndex) {
 $this = $this|0;
 $xf = $xf|0;
 $p = $p|0;
 $distance = $distance|0;
 $normal = $normal|0;
 $childIndex = $childIndex|0;
 var $edge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $edge = sp;
 __ZN11b2EdgeShapeC2Ev($edge);
 __ZNK12b2ChainShape12GetChildEdgeEP11b2EdgeShapei($this,$edge,$childIndex);
 __ZNK11b2EdgeShape15ComputeDistanceERK11b2TransformRK6b2Vec2PfPS3_i($edge,$xf,$p,$distance,$normal,0);
 STACKTOP = sp;return;
}
function __ZNK12b2ChainShape9TestPointERK11b2TransformRK6b2Vec2($this,$xf,$p) {
 $this = $this|0;
 $xf = $xf|0;
 $p = $p|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZNK12b2ChainShape7RayCastEP15b2RayCastOutputRK14b2RayCastInputRK11b2Transformi($this,$output,$input,$xf,$childIndex) {
 $this = $this|0;
 $output = $output|0;
 $input = $input|0;
 $xf = $xf|0;
 $childIndex = $childIndex|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $edgeShape = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $edgeShape = sp;
 __ZN11b2EdgeShapeC2Ev($edgeShape);
 $0 = (($childIndex) + 1)|0;
 $1 = (($this) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0|0)==($2|0);
 $$ = $3 ? 0 : $0;
 $4 = (($edgeShape) + 12|0);
 $5 = (($this) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($childIndex<<3)|0);
 $8 = $7;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = $4;
 $15 = $14;
 HEAP32[$15>>2] = $10;
 $16 = (($14) + 4)|0;
 $17 = $16;
 HEAP32[$17>>2] = $13;
 $18 = (($edgeShape) + 20|0);
 $19 = HEAP32[$5>>2]|0;
 $20 = (($19) + ($$<<3)|0);
 $21 = $20;
 $22 = $21;
 $23 = HEAP32[$22>>2]|0;
 $24 = (($21) + 4)|0;
 $25 = $24;
 $26 = HEAP32[$25>>2]|0;
 $27 = $18;
 $28 = $27;
 HEAP32[$28>>2] = $23;
 $29 = (($27) + 4)|0;
 $30 = $29;
 HEAP32[$30>>2] = $26;
 $31 = (__ZNK11b2EdgeShape7RayCastEP15b2RayCastOutputRK14b2RayCastInputRK11b2Transformi($edgeShape,$output,$input,$xf,0)|0);
 STACKTOP = sp;return ($31|0);
}
function __ZNK12b2ChainShape11ComputeAABBEP6b2AABBRK11b2Transformi($this,$aabb,$xf,$childIndex) {
 $this = $this|0;
 $aabb = $aabb|0;
 $xf = $xf|0;
 $childIndex = $childIndex|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $v1 = 0, $v2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $v1 = sp + 24|0;
 $v2 = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = (($childIndex) + 1)|0;
 $3 = (($this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==($4|0);
 $$ = $5 ? 0 : $2;
 $6 = (($this) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($childIndex<<3)|0);
 __Z5b2MulRK11b2TransformRK6b2Vec2($v1,$xf,$8);
 $9 = HEAP32[$6>>2]|0;
 $10 = (($9) + ($$<<3)|0);
 __Z5b2MulRK11b2TransformRK6b2Vec2($v2,$xf,$10);
 __Z5b2MinRK6b2Vec2S1_($0,$v1,$v2);
 $11 = $0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + 4)|0;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = $aabb;
 $18 = $17;
 HEAP32[$18>>2] = $13;
 $19 = (($17) + 4)|0;
 $20 = $19;
 HEAP32[$20>>2] = $16;
 $21 = (($aabb) + 8|0);
 __Z5b2MaxRK6b2Vec2S1_($1,$v1,$v2);
 $22 = $1;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 $25 = (($22) + 4)|0;
 $26 = $25;
 $27 = HEAP32[$26>>2]|0;
 $28 = $21;
 $29 = $28;
 HEAP32[$29>>2] = $24;
 $30 = (($28) + 4)|0;
 $31 = $30;
 HEAP32[$31>>2] = $27;
 STACKTOP = sp;return;
}
function __ZNK12b2ChainShape11ComputeMassEP10b2MassDataf($this,$massData,$density) {
 $this = $this|0;
 $massData = $massData|0;
 $density = +$density;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$massData>>2] = 0.0;
 $0 = (($massData) + 4|0);
 __ZN6b2Vec27SetZeroEv($0);
 $1 = (($massData) + 12|0);
 HEAPF32[$1>>2] = 0.0;
 STACKTOP = sp;return;
}
function __ZN12b2BroadPhaseC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13b2DynamicTreeC2Ev($this);
 $0 = (($this) + 28|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 48|0);
 HEAP32[$1>>2] = 16;
 $2 = (($this) + 52|0);
 HEAP32[$2>>2] = 0;
 $3 = HEAP32[$1>>2]|0;
 $4 = $3 << 3;
 $5 = (__Z7b2Alloci($4)|0);
 $6 = (($this) + 44|0);
 HEAP32[$6>>2] = $5;
 $7 = (($this) + 36|0);
 HEAP32[$7>>2] = 16;
 $8 = (($this) + 40|0);
 HEAP32[$8>>2] = 0;
 $9 = HEAP32[$7>>2]|0;
 $10 = $9 << 2;
 $11 = (__Z7b2Alloci($10)|0);
 $12 = (($this) + 32|0);
 HEAP32[$12>>2] = $11;
 STACKTOP = sp;return;
}
function __ZN12b2BroadPhaseD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 __Z6b2FreePv($1);
 $2 = (($this) + 44|0);
 $3 = HEAP32[$2>>2]|0;
 __Z6b2FreePv($3);
 __ZN13b2DynamicTreeD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN12b2BroadPhase11CreateProxyERK6b2AABBPv($this,$aabb,$userData) {
 $this = $this|0;
 $aabb = $aabb|0;
 $userData = $userData|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN13b2DynamicTree11CreateProxyERK6b2AABBPv($this,$aabb,$userData)|0);
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[$1>>2] = $3;
 __ZN12b2BroadPhase10BufferMoveEi($this,$0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12b2BroadPhase10BufferMoveEi($this,$proxyId) {
 $this = $this|0;
 $proxyId = $proxyId|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 36|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  $5 = (($this) + 32|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $3 << 1;
  HEAP32[$2>>2] = $7;
  $8 = $3 << 3;
  $9 = (__Z7b2Alloci($8)|0);
  HEAP32[$5>>2] = $9;
  $10 = HEAP32[$0>>2]|0;
  $11 = $10 << 2;
  _memcpy(($9|0),($6|0),($11|0))|0;
  __Z6b2FreePv($6);
 }
 $12 = HEAP32[$0>>2]|0;
 $13 = (($this) + 32|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($14) + ($12<<2)|0);
 HEAP32[$15>>2] = $proxyId;
 $16 = HEAP32[$0>>2]|0;
 $17 = (($16) + 1)|0;
 HEAP32[$0>>2] = $17;
 STACKTOP = sp;return;
}
function __ZN12b2BroadPhase12DestroyProxyEi($this,$proxyId) {
 $this = $this|0;
 $proxyId = $proxyId|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12b2BroadPhase12UnBufferMoveEi($this,$proxyId);
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 HEAP32[$0>>2] = $2;
 __ZN13b2DynamicTree12DestroyProxyEi($this,$proxyId);
 STACKTOP = sp;return;
}
function __ZN12b2BroadPhase12UnBufferMoveEi($this,$proxyId) {
 $this = $this|0;
 $proxyId = $proxyId|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $i$01 = 0;
 while(1) {
  $5 = (($4) + ($i$01<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==($proxyId|0);
  if ($7) {
   HEAP32[$5>>2] = -1;
  }
  $8 = (($i$01) + 1)|0;
  $9 = HEAP32[$0>>2]|0;
  $10 = ($8|0)<($9|0);
  if ($10) {
   $i$01 = $8;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12b2BroadPhase9MoveProxyEiRK6b2AABBRK6b2Vec2($this,$proxyId,$aabb,$displacement) {
 $this = $this|0;
 $proxyId = $proxyId|0;
 $aabb = $aabb|0;
 $displacement = $displacement|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN13b2DynamicTree9MoveProxyEiRK6b2AABBRK6b2Vec2($this,$proxyId,$aabb,$displacement)|0);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 __ZN12b2BroadPhase10BufferMoveEi($this,$proxyId);
 STACKTOP = sp;return;
}
function __ZN12b2BroadPhase10TouchProxyEi($this,$proxyId) {
 $this = $this|0;
 $proxyId = $proxyId|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12b2BroadPhase10BufferMoveEi($this,$proxyId);
 STACKTOP = sp;return;
}
function __ZN12b2BroadPhase13QueryCallbackEi($this,$proxyId) {
 $this = $this|0;
 $proxyId = $proxyId|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($proxyId|0);
 if ($2) {
  STACKTOP = sp;return 1;
 }
 $3 = (($this) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 48|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 if ($7) {
  $8 = (($this) + 44|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $6 << 1;
  HEAP32[$5>>2] = $10;
  $11 = $6 << 4;
  $12 = (__Z7b2Alloci($11)|0);
  HEAP32[$8>>2] = $12;
  $13 = HEAP32[$3>>2]|0;
  $14 = $13 << 3;
  _memcpy(($12|0),($9|0),($14|0))|0;
  __Z6b2FreePv($9);
 }
 $15 = HEAP32[$0>>2]|0;
 $16 = (__Z5b2MinIiET_S0_S0_($proxyId,$15)|0);
 $17 = HEAP32[$3>>2]|0;
 $18 = (($this) + 44|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + ($17<<3)|0);
 HEAP32[$20>>2] = $16;
 $21 = HEAP32[$0>>2]|0;
 $22 = (__Z5b2MaxIiET_S0_S0_($proxyId,$21)|0);
 $23 = HEAP32[$3>>2]|0;
 $24 = HEAP32[$18>>2]|0;
 $25 = ((($24) + ($23<<3)|0) + 4|0);
 HEAP32[$25>>2] = $22;
 $26 = HEAP32[$3>>2]|0;
 $27 = (($26) + 1)|0;
 HEAP32[$3>>2] = $27;
 STACKTOP = sp;return 1;
}
function __Z16b2CollideCirclesP10b2ManifoldPK13b2CircleShapeRK11b2TransformS3_S6_($manifold,$circleA,$xfA,$circleB,$xfB) {
 $manifold = $manifold|0;
 $circleA = $circleA|0;
 $xfA = $xfA|0;
 $circleB = $circleB|0;
 $xfB = $xfB|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0.0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0.0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, $d = 0, $pA = 0, $pB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pA = sp + 16|0;
 $pB = sp + 8|0;
 $d = sp;
 $0 = (($manifold) + 60|0);
 HEAP32[$0>>2] = 0;
 $1 = (($circleA) + 12|0);
 __Z5b2MulRK11b2TransformRK6b2Vec2($pA,$xfA,$1);
 $2 = (($circleB) + 12|0);
 __Z5b2MulRK11b2TransformRK6b2Vec2($pB,$xfB,$2);
 __ZmiRK6b2Vec2S1_($d,$pB,$pA);
 $3 = (+__Z5b2DotRK6b2Vec2S1_($d,$d));
 $4 = (($circleA) + 8|0);
 $5 = +HEAPF32[$4>>2];
 $6 = (($circleB) + 8|0);
 $7 = +HEAPF32[$6>>2];
 $8 = $5 + $7;
 $9 = $8 * $8;
 $10 = $3 > $9;
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (($manifold) + 56|0);
 HEAP32[$11>>2] = 0;
 $12 = (($manifold) + 48|0);
 $13 = $1;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 4)|0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = $12;
 $20 = $19;
 HEAP32[$20>>2] = $15;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $18;
 $23 = (($manifold) + 40|0);
 __ZN6b2Vec27SetZeroEv($23);
 HEAP32[$0>>2] = 1;
 $24 = $2;
 $25 = $24;
 $26 = HEAP32[$25>>2]|0;
 $27 = (($24) + 4)|0;
 $28 = $27;
 $29 = HEAP32[$28>>2]|0;
 $30 = $manifold;
 $31 = $30;
 HEAP32[$31>>2] = $26;
 $32 = (($30) + 4)|0;
 $33 = $32;
 HEAP32[$33>>2] = $29;
 $34 = (($manifold) + 16|0);
 HEAP32[$34>>2] = 0;
 STACKTOP = sp;return;
}
function __Z25b2CollidePolygonAndCircleP10b2ManifoldPK14b2PolygonShapeRK11b2TransformPK13b2CircleShapeS6_($manifold,$polygonA,$xfA,$circleB,$xfB) {
 $manifold = $manifold|0;
 $polygonA = $polygonA|0;
 $xfA = $xfA|0;
 $circleB = $circleB|0;
 $xfB = $xfB|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0.0, $127 = 0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0.0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0.0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0.0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0.0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $21 = 0, $22 = 0, $23 = 0.0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0.0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $c = 0, $cLocal = 0, $faceCenter = 0, $i$08 = 0, $normalIndex$0$lcssa = 0, $normalIndex$010 = 0, $normalIndex$1 = 0, $phitmp = 0, $separation$0$lcssa = 0, $separation$09 = 0.0, $separation$1 = 0.0, $v1 = 0, $v2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $c = sp + 120|0;
 $cLocal = sp + 112|0;
 $0 = sp + 104|0;
 $v1 = sp + 40|0;
 $v2 = sp + 32|0;
 $1 = sp + 24|0;
 $2 = sp + 96|0;
 $3 = sp + 88|0;
 $4 = sp + 80|0;
 $5 = sp + 72|0;
 $6 = sp + 64|0;
 $7 = sp + 16|0;
 $8 = sp + 8|0;
 $faceCenter = sp;
 $9 = sp + 56|0;
 $10 = sp + 48|0;
 $11 = (($manifold) + 60|0);
 HEAP32[$11>>2] = 0;
 $12 = (($circleB) + 12|0);
 __Z5b2MulRK11b2TransformRK6b2Vec2($c,$xfB,$12);
 __Z6b2MulTRK11b2TransformRK6b2Vec2($cLocal,$xfA,$c);
 $13 = (($polygonA) + 8|0);
 $14 = +HEAPF32[$13>>2];
 $15 = (($circleB) + 8|0);
 $16 = +HEAPF32[$15>>2];
 $17 = $14 + $16;
 $18 = (($polygonA) + 148|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)>(0);
 do {
  if ($20) {
   $i$08 = 0;$normalIndex$010 = 0;$separation$09 = -3.4028234663852886E+38;
   while(1) {
    $21 = ((($polygonA) + ($i$08<<3)|0) + 84|0);
    $22 = ((($polygonA) + ($i$08<<3)|0) + 20|0);
    __ZmiRK6b2Vec2S1_($0,$cLocal,$22);
    $23 = (+__Z5b2DotRK6b2Vec2S1_($21,$0));
    $24 = $23 > $17;
    if ($24) {
     label = 15;
     break;
    }
    $25 = $23 > $separation$09;
    $separation$1 = $25 ? $23 : $separation$09;
    $normalIndex$1 = $25 ? $i$08 : $normalIndex$010;
    $26 = (($i$08) + 1)|0;
    $27 = ($26|0)<($19|0);
    if ($27) {
     $i$08 = $26;$normalIndex$010 = $normalIndex$1;$separation$09 = $separation$1;
    } else {
     label = 4;
     break;
    }
   }
   if ((label|0) == 4) {
    $phitmp = $separation$1 < 1.1920928955078125E-7;
    $normalIndex$0$lcssa = $normalIndex$1;$separation$0$lcssa = $phitmp;
    break;
   }
   else if ((label|0) == 15) {
    STACKTOP = sp;return;
   }
  } else {
   $normalIndex$0$lcssa = 0;$separation$0$lcssa = 1;
  }
 } while(0);
 $28 = (($normalIndex$0$lcssa) + 1)|0;
 $29 = ($28|0)<($19|0);
 $$ = $29 ? $28 : 0;
 $30 = ((($polygonA) + ($normalIndex$0$lcssa<<3)|0) + 20|0);
 $31 = $30;
 $32 = $31;
 $33 = HEAP32[$32>>2]|0;
 $34 = (($31) + 4)|0;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = $v1;
 $38 = $37;
 HEAP32[$38>>2] = $33;
 $39 = (($37) + 4)|0;
 $40 = $39;
 HEAP32[$40>>2] = $36;
 $41 = ((($polygonA) + ($$<<3)|0) + 20|0);
 $42 = $41;
 $43 = $42;
 $44 = HEAP32[$43>>2]|0;
 $45 = (($42) + 4)|0;
 $46 = $45;
 $47 = HEAP32[$46>>2]|0;
 $48 = $v2;
 $49 = $48;
 HEAP32[$49>>2] = $44;
 $50 = (($48) + 4)|0;
 $51 = $50;
 HEAP32[$51>>2] = $47;
 if ($separation$0$lcssa) {
  HEAP32[$11>>2] = 1;
  $52 = (($manifold) + 56|0);
  HEAP32[$52>>2] = 1;
  $53 = (($manifold) + 40|0);
  $54 = ((($polygonA) + ($normalIndex$0$lcssa<<3)|0) + 84|0);
  $55 = $54;
  $56 = $55;
  $57 = HEAP32[$56>>2]|0;
  $58 = (($55) + 4)|0;
  $59 = $58;
  $60 = HEAP32[$59>>2]|0;
  $61 = $53;
  $62 = $61;
  HEAP32[$62>>2] = $57;
  $63 = (($61) + 4)|0;
  $64 = $63;
  HEAP32[$64>>2] = $60;
  $65 = (($manifold) + 48|0);
  __ZplRK6b2Vec2S1_($2,$v1,$v2);
  __ZmlfRK6b2Vec2($1,0.5,$2);
  $66 = $1;
  $67 = $66;
  $68 = HEAP32[$67>>2]|0;
  $69 = (($66) + 4)|0;
  $70 = $69;
  $71 = HEAP32[$70>>2]|0;
  $72 = $65;
  $73 = $72;
  HEAP32[$73>>2] = $68;
  $74 = (($72) + 4)|0;
  $75 = $74;
  HEAP32[$75>>2] = $71;
  $76 = $12;
  $77 = $76;
  $78 = HEAP32[$77>>2]|0;
  $79 = (($76) + 4)|0;
  $80 = $79;
  $81 = HEAP32[$80>>2]|0;
  $82 = $manifold;
  $83 = $82;
  HEAP32[$83>>2] = $78;
  $84 = (($82) + 4)|0;
  $85 = $84;
  HEAP32[$85>>2] = $81;
  $86 = (($manifold) + 16|0);
  HEAP32[$86>>2] = 0;
  STACKTOP = sp;return;
 }
 __ZmiRK6b2Vec2S1_($3,$cLocal,$v1);
 __ZmiRK6b2Vec2S1_($4,$v2,$v1);
 $87 = (+__Z5b2DotRK6b2Vec2S1_($3,$4));
 __ZmiRK6b2Vec2S1_($5,$cLocal,$v2);
 __ZmiRK6b2Vec2S1_($6,$v1,$v2);
 $88 = !($87 <= 0.0);
 if (!($88)) {
  $89 = (+__Z17b2DistanceSquaredRK6b2Vec2S1_($cLocal,$v1));
  $90 = $17 * $17;
  $91 = $89 > $90;
  if ($91) {
   STACKTOP = sp;return;
  }
  HEAP32[$11>>2] = 1;
  $92 = (($manifold) + 56|0);
  HEAP32[$92>>2] = 1;
  $93 = (($manifold) + 40|0);
  __ZmiRK6b2Vec2S1_($7,$cLocal,$v1);
  $94 = $7;
  $95 = $94;
  $96 = HEAP32[$95>>2]|0;
  $97 = (($94) + 4)|0;
  $98 = $97;
  $99 = HEAP32[$98>>2]|0;
  $100 = $93;
  $101 = $100;
  HEAP32[$101>>2] = $96;
  $102 = (($100) + 4)|0;
  $103 = $102;
  HEAP32[$103>>2] = $99;
  (+__ZN6b2Vec29NormalizeEv($93));
  $104 = (($manifold) + 48|0);
  $105 = $v1;
  $106 = $105;
  $107 = HEAP32[$106>>2]|0;
  $108 = (($105) + 4)|0;
  $109 = $108;
  $110 = HEAP32[$109>>2]|0;
  $111 = $104;
  $112 = $111;
  HEAP32[$112>>2] = $107;
  $113 = (($111) + 4)|0;
  $114 = $113;
  HEAP32[$114>>2] = $110;
  $115 = $12;
  $116 = $115;
  $117 = HEAP32[$116>>2]|0;
  $118 = (($115) + 4)|0;
  $119 = $118;
  $120 = HEAP32[$119>>2]|0;
  $121 = $manifold;
  $122 = $121;
  HEAP32[$122>>2] = $117;
  $123 = (($121) + 4)|0;
  $124 = $123;
  HEAP32[$124>>2] = $120;
  $125 = (($manifold) + 16|0);
  HEAP32[$125>>2] = 0;
  STACKTOP = sp;return;
 }
 $126 = (+__Z5b2DotRK6b2Vec2S1_($5,$6));
 $127 = !($126 <= 0.0);
 if ($127) {
  __ZplRK6b2Vec2S1_($9,$v1,$v2);
  __ZmlfRK6b2Vec2($faceCenter,0.5,$9);
  __ZmiRK6b2Vec2S1_($10,$cLocal,$faceCenter);
  $165 = ((($polygonA) + ($normalIndex$0$lcssa<<3)|0) + 84|0);
  $166 = (+__Z5b2DotRK6b2Vec2S1_($10,$165));
  $167 = $166 > $17;
  if ($167) {
   STACKTOP = sp;return;
  }
  HEAP32[$11>>2] = 1;
  $168 = (($manifold) + 56|0);
  HEAP32[$168>>2] = 1;
  $169 = (($manifold) + 40|0);
  $170 = $165;
  $171 = $170;
  $172 = HEAP32[$171>>2]|0;
  $173 = (($170) + 4)|0;
  $174 = $173;
  $175 = HEAP32[$174>>2]|0;
  $176 = $169;
  $177 = $176;
  HEAP32[$177>>2] = $172;
  $178 = (($176) + 4)|0;
  $179 = $178;
  HEAP32[$179>>2] = $175;
  $180 = (($manifold) + 48|0);
  $181 = $faceCenter;
  $182 = $181;
  $183 = HEAP32[$182>>2]|0;
  $184 = (($181) + 4)|0;
  $185 = $184;
  $186 = HEAP32[$185>>2]|0;
  $187 = $180;
  $188 = $187;
  HEAP32[$188>>2] = $183;
  $189 = (($187) + 4)|0;
  $190 = $189;
  HEAP32[$190>>2] = $186;
  $191 = $12;
  $192 = $191;
  $193 = HEAP32[$192>>2]|0;
  $194 = (($191) + 4)|0;
  $195 = $194;
  $196 = HEAP32[$195>>2]|0;
  $197 = $manifold;
  $198 = $197;
  HEAP32[$198>>2] = $193;
  $199 = (($197) + 4)|0;
  $200 = $199;
  HEAP32[$200>>2] = $196;
  $201 = (($manifold) + 16|0);
  HEAP32[$201>>2] = 0;
  STACKTOP = sp;return;
 } else {
  $128 = (+__Z17b2DistanceSquaredRK6b2Vec2S1_($cLocal,$v2));
  $129 = $17 * $17;
  $130 = $128 > $129;
  if ($130) {
   STACKTOP = sp;return;
  }
  HEAP32[$11>>2] = 1;
  $131 = (($manifold) + 56|0);
  HEAP32[$131>>2] = 1;
  $132 = (($manifold) + 40|0);
  __ZmiRK6b2Vec2S1_($8,$cLocal,$v2);
  $133 = $8;
  $134 = $133;
  $135 = HEAP32[$134>>2]|0;
  $136 = (($133) + 4)|0;
  $137 = $136;
  $138 = HEAP32[$137>>2]|0;
  $139 = $132;
  $140 = $139;
  HEAP32[$140>>2] = $135;
  $141 = (($139) + 4)|0;
  $142 = $141;
  HEAP32[$142>>2] = $138;
  (+__ZN6b2Vec29NormalizeEv($132));
  $143 = (($manifold) + 48|0);
  $144 = $v2;
  $145 = $144;
  $146 = HEAP32[$145>>2]|0;
  $147 = (($144) + 4)|0;
  $148 = $147;
  $149 = HEAP32[$148>>2]|0;
  $150 = $143;
  $151 = $150;
  HEAP32[$151>>2] = $146;
  $152 = (($150) + 4)|0;
  $153 = $152;
  HEAP32[$153>>2] = $149;
  $154 = $12;
  $155 = $154;
  $156 = HEAP32[$155>>2]|0;
  $157 = (($154) + 4)|0;
  $158 = $157;
  $159 = HEAP32[$158>>2]|0;
  $160 = $manifold;
  $161 = $160;
  HEAP32[$161>>2] = $156;
  $162 = (($160) + 4)|0;
  $163 = $162;
  HEAP32[$163>>2] = $159;
  $164 = (($manifold) + 16|0);
  HEAP32[$164>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN13b2DynamicTreeC2Ev($this) {
 $this = $this|0;
 var $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = -1;
 $0 = (($this) + 12|0);
 HEAP32[$0>>2] = 16;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = HEAP32[$0>>2]|0;
 $3 = ($2*36)|0;
 $4 = (__Z7b2Alloci($3)|0);
 $5 = (($this) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = HEAP32[$0>>2]|0;
 $7 = ($6*36)|0;
 _memset(($4|0),0,($7|0))|0;
 $8 = HEAP32[$0>>2]|0;
 $9 = (($8) + -1)|0;
 $10 = ($9|0)>(0);
 if ($10) {
  $11 = HEAP32[$5>>2]|0;
  $i$01 = 0;
  while(1) {
   $12 = (($i$01) + 1)|0;
   $13 = ((($11) + (($i$01*36)|0)|0) + 20|0);
   HEAP32[$13>>2] = $12;
   $14 = ((($11) + (($i$01*36)|0)|0) + 32|0);
   HEAP32[$14>>2] = -1;
   $15 = HEAP32[$0>>2]|0;
   $16 = (($15) + -1)|0;
   $17 = ($12|0)<($16|0);
   if ($17) {
    $i$01 = $12;
   } else {
    $$lcssa = $16;
    break;
   }
  }
 } else {
  $$lcssa = $9;
 }
 $18 = HEAP32[$5>>2]|0;
 $19 = ((($18) + (($$lcssa*36)|0)|0) + 20|0);
 HEAP32[$19>>2] = -1;
 $20 = HEAP32[$0>>2]|0;
 $21 = (($20) + -1)|0;
 $22 = HEAP32[$5>>2]|0;
 $23 = ((($22) + (($21*36)|0)|0) + 32|0);
 HEAP32[$23>>2] = -1;
 $24 = (($this) + 16|0);
 HEAP32[$24>>2] = 0;
 $25 = (($this) + 20|0);
 HEAP32[$25>>2] = 0;
 $26 = (($this) + 24|0);
 HEAP32[$26>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN13b2DynamicTreeD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 __Z6b2FreePv($1);
 STACKTOP = sp;return;
}
function __ZN13b2DynamicTree12AllocateNodeEv($this) {
 $this = $this|0;
 var $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 if ($2) {
  $3 = (($this) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = (($this) + 12|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $6 << 1;
  HEAP32[$5>>2] = $7;
  $8 = ($6*72)|0;
  $9 = (__Z7b2Alloci($8)|0);
  HEAP32[$3>>2] = $9;
  $10 = (($this) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11*36)|0;
  _memcpy(($9|0),($4|0),($12|0))|0;
  __Z6b2FreePv($4);
  $13 = HEAP32[$10>>2]|0;
  $14 = HEAP32[$5>>2]|0;
  $15 = (($14) + -1)|0;
  $16 = ($13|0)<($15|0);
  if ($16) {
   $17 = HEAP32[$3>>2]|0;
   $i$01 = $13;
   while(1) {
    $18 = (($i$01) + 1)|0;
    $19 = ((($17) + (($i$01*36)|0)|0) + 20|0);
    HEAP32[$19>>2] = $18;
    $20 = ((($17) + (($i$01*36)|0)|0) + 32|0);
    HEAP32[$20>>2] = -1;
    $21 = HEAP32[$5>>2]|0;
    $22 = (($21) + -1)|0;
    $23 = ($18|0)<($22|0);
    if ($23) {
     $i$01 = $18;
    } else {
     $$lcssa = $22;
     break;
    }
   }
  } else {
   $$lcssa = $15;
  }
  $24 = HEAP32[$3>>2]|0;
  $25 = ((($24) + (($$lcssa*36)|0)|0) + 20|0);
  HEAP32[$25>>2] = -1;
  $26 = HEAP32[$5>>2]|0;
  $27 = (($26) + -1)|0;
  $28 = HEAP32[$3>>2]|0;
  $29 = ((($28) + (($27*36)|0)|0) + 32|0);
  HEAP32[$29>>2] = -1;
  $30 = HEAP32[$10>>2]|0;
  HEAP32[$0>>2] = $30;
 }
 $31 = HEAP32[$0>>2]|0;
 $32 = (($this) + 4|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ((($33) + (($31*36)|0)|0) + 20|0);
 $35 = HEAP32[$34>>2]|0;
 HEAP32[$0>>2] = $35;
 $36 = HEAP32[$32>>2]|0;
 $37 = ((($36) + (($31*36)|0)|0) + 20|0);
 HEAP32[$37>>2] = -1;
 $38 = HEAP32[$32>>2]|0;
 $39 = ((($38) + (($31*36)|0)|0) + 24|0);
 HEAP32[$39>>2] = -1;
 $40 = HEAP32[$32>>2]|0;
 $41 = ((($40) + (($31*36)|0)|0) + 28|0);
 HEAP32[$41>>2] = -1;
 $42 = HEAP32[$32>>2]|0;
 $43 = ((($42) + (($31*36)|0)|0) + 32|0);
 HEAP32[$43>>2] = 0;
 $44 = HEAP32[$32>>2]|0;
 $45 = ((($44) + (($31*36)|0)|0) + 16|0);
 HEAP32[$45>>2] = 0;
 $46 = (($this) + 8|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = (($47) + 1)|0;
 HEAP32[$46>>2] = $48;
 STACKTOP = sp;return ($31|0);
}
function __ZN13b2DynamicTree8FreeNodeEi($this,$nodeId) {
 $this = $this|0;
 $nodeId = $nodeId|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3) + (($nodeId*36)|0)|0) + 20|0);
 HEAP32[$4>>2] = $1;
 $5 = HEAP32[$2>>2]|0;
 $6 = ((($5) + (($nodeId*36)|0)|0) + 32|0);
 HEAP32[$6>>2] = -1;
 HEAP32[$0>>2] = $nodeId;
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + -1)|0;
 HEAP32[$7>>2] = $9;
 STACKTOP = sp;return;
}
function __ZN13b2DynamicTree11CreateProxyERK6b2AABBPv($this,$aabb,$userData) {
 $this = $this|0;
 $aabb = $aabb|0;
 $userData = $userData|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $r = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $r = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = (__ZN13b2DynamicTree12AllocateNodeEv($this)|0);
 __ZN6b2Vec2C2Eff($r,0.10000000149011612,0.10000000149011612);
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + (($2*36)|0)|0);
 __ZmiRK6b2Vec2S1_($0,$aabb,$r);
 $6 = $0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $5;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 $16 = HEAP32[$3>>2]|0;
 $17 = ((($16) + (($2*36)|0)|0) + 8|0);
 $18 = (($aabb) + 8|0);
 __ZplRK6b2Vec2S1_($1,$18,$r);
 $19 = $1;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) + 4)|0;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 $25 = $17;
 $26 = $25;
 HEAP32[$26>>2] = $21;
 $27 = (($25) + 4)|0;
 $28 = $27;
 HEAP32[$28>>2] = $24;
 $29 = HEAP32[$3>>2]|0;
 $30 = ((($29) + (($2*36)|0)|0) + 16|0);
 HEAP32[$30>>2] = $userData;
 $31 = HEAP32[$3>>2]|0;
 $32 = ((($31) + (($2*36)|0)|0) + 32|0);
 HEAP32[$32>>2] = 0;
 __ZN13b2DynamicTree10InsertLeafEi($this,$2);
 STACKTOP = sp;return ($2|0);
}
function __ZN13b2DynamicTree10InsertLeafEi($this,$leaf) {
 $this = $this|0;
 $leaf = $leaf|0;
 var $$ = 0, $$pn = 0.0, $$pn1 = 0.0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0.0;
 var $31 = 0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $aabb = 0, $aabb1 = 0, $aabb2 = 0, $aabb3 = 0, $combinedAABB = 0;
 var $cost1$0 = 0.0, $cost2$0 = 0.0, $index$0$lcssa = 0, $index$04 = 0, $index$1 = 0, $index$12 = 0, $index$13 = 0, $leafAABB = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $leafAABB = sp + 80|0;
 $combinedAABB = sp + 64|0;
 $aabb = sp + 48|0;
 $aabb1 = sp + 32|0;
 $aabb2 = sp + 16|0;
 $aabb3 = sp;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1)|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$this>>2]|0;
 $4 = ($3|0)==(-1);
 if ($4) {
  HEAP32[$this>>2] = $leaf;
  $5 = (($this) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ((($6) + (($leaf*36)|0)|0) + 20|0);
  HEAP32[$7>>2] = -1;
  STACKTOP = sp;return;
 }
 $8 = (($this) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + (($leaf*36)|0)|0);
 ;HEAP32[$leafAABB+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$leafAABB+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$leafAABB+8>>2]=HEAP32[$10+8>>2]|0;HEAP32[$leafAABB+12>>2]=HEAP32[$10+12>>2]|0;
 $11 = HEAP32[$this>>2]|0;
 $12 = HEAP32[$8>>2]|0;
 $13 = (($12) + (($11*36)|0)|0);
 $14 = (__ZNK10b2TreeNode6IsLeafEv($13)|0);
 L5: do {
  if ($14) {
   $index$0$lcssa = $11;
  } else {
   $16 = $12;$index$04 = $11;
   while(1) {
    $15 = ((($16) + (($index$04*36)|0)|0) + 24|0);
    $17 = HEAP32[$15>>2]|0;
    $18 = ((($16) + (($index$04*36)|0)|0) + 28|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($16) + (($index$04*36)|0)|0);
    $21 = (+__ZNK6b2AABB12GetPerimeterEv($20));
    __ZN6b2AABB7CombineERKS_S1_($combinedAABB,$20,$leafAABB);
    $22 = (+__ZNK6b2AABB12GetPerimeterEv($combinedAABB));
    $23 = $22 * 2.0;
    $24 = $22 - $21;
    $25 = $24 * 2.0;
    $26 = HEAP32[$8>>2]|0;
    $27 = (($26) + (($17*36)|0)|0);
    $28 = (__ZNK10b2TreeNode6IsLeafEv($27)|0);
    $29 = (($26) + (($17*36)|0)|0);
    if ($28) {
     __ZN6b2AABB7CombineERKS_S1_($aabb,$leafAABB,$29);
     $30 = (+__ZNK6b2AABB12GetPerimeterEv($aabb));
     $$pn = $30;
    } else {
     __ZN6b2AABB7CombineERKS_S1_($aabb1,$leafAABB,$29);
     $31 = HEAP32[$8>>2]|0;
     $32 = (($31) + (($17*36)|0)|0);
     $33 = (+__ZNK6b2AABB12GetPerimeterEv($32));
     $34 = (+__ZNK6b2AABB12GetPerimeterEv($aabb1));
     $35 = $34 - $33;
     $$pn = $35;
    }
    $cost1$0 = $25 + $$pn;
    $36 = HEAP32[$8>>2]|0;
    $37 = (($36) + (($19*36)|0)|0);
    $38 = (__ZNK10b2TreeNode6IsLeafEv($37)|0);
    $39 = (($36) + (($19*36)|0)|0);
    if ($38) {
     __ZN6b2AABB7CombineERKS_S1_($aabb2,$leafAABB,$39);
     $40 = (+__ZNK6b2AABB12GetPerimeterEv($aabb2));
     $$pn1 = $40;
    } else {
     __ZN6b2AABB7CombineERKS_S1_($aabb3,$leafAABB,$39);
     $41 = HEAP32[$8>>2]|0;
     $42 = (($41) + (($19*36)|0)|0);
     $43 = (+__ZNK6b2AABB12GetPerimeterEv($42));
     $44 = (+__ZNK6b2AABB12GetPerimeterEv($aabb3));
     $45 = $44 - $43;
     $$pn1 = $45;
    }
    $cost2$0 = $25 + $$pn1;
    $46 = $23 < $cost1$0;
    $47 = $23 < $cost2$0;
    $or$cond = $46 & $47;
    if ($or$cond) {
     $index$0$lcssa = $index$04;
     break L5;
    }
    $48 = $cost1$0 < $cost2$0;
    $$ = $48 ? $17 : $19;
    $49 = HEAP32[$8>>2]|0;
    $50 = (($49) + (($$*36)|0)|0);
    $51 = (__ZNK10b2TreeNode6IsLeafEv($50)|0);
    if ($51) {
     $index$0$lcssa = $$;
     break;
    } else {
     $16 = $49;$index$04 = $$;
    }
   }
  }
 } while(0);
 $52 = HEAP32[$8>>2]|0;
 $53 = ((($52) + (($index$0$lcssa*36)|0)|0) + 20|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = (__ZN13b2DynamicTree12AllocateNodeEv($this)|0);
 $56 = HEAP32[$8>>2]|0;
 $57 = ((($56) + (($55*36)|0)|0) + 20|0);
 HEAP32[$57>>2] = $54;
 $58 = HEAP32[$8>>2]|0;
 $59 = ((($58) + (($55*36)|0)|0) + 16|0);
 HEAP32[$59>>2] = 0;
 $60 = HEAP32[$8>>2]|0;
 $61 = (($60) + (($55*36)|0)|0);
 $62 = (($60) + (($index$0$lcssa*36)|0)|0);
 __ZN6b2AABB7CombineERKS_S1_($61,$leafAABB,$62);
 $63 = HEAP32[$8>>2]|0;
 $64 = ((($63) + (($index$0$lcssa*36)|0)|0) + 32|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($65) + 1)|0;
 $67 = ((($63) + (($55*36)|0)|0) + 32|0);
 HEAP32[$67>>2] = $66;
 $68 = ($54|0)==(-1);
 $69 = HEAP32[$8>>2]|0;
 if ($68) {
  $82 = ((($69) + (($55*36)|0)|0) + 24|0);
  HEAP32[$82>>2] = $index$0$lcssa;
  $83 = HEAP32[$8>>2]|0;
  $84 = ((($83) + (($55*36)|0)|0) + 28|0);
  HEAP32[$84>>2] = $leaf;
  $85 = HEAP32[$8>>2]|0;
  $86 = ((($85) + (($index$0$lcssa*36)|0)|0) + 20|0);
  HEAP32[$86>>2] = $55;
  $87 = HEAP32[$8>>2]|0;
  $88 = ((($87) + (($leaf*36)|0)|0) + 20|0);
  HEAP32[$88>>2] = $55;
  HEAP32[$this>>2] = $55;
 } else {
  $70 = ((($69) + (($54*36)|0)|0) + 24|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = ($71|0)==($index$0$lcssa|0);
  if ($72) {
   HEAP32[$70>>2] = $55;
  } else {
   $73 = ((($69) + (($54*36)|0)|0) + 28|0);
   HEAP32[$73>>2] = $55;
  }
  $74 = HEAP32[$8>>2]|0;
  $75 = ((($74) + (($55*36)|0)|0) + 24|0);
  HEAP32[$75>>2] = $index$0$lcssa;
  $76 = HEAP32[$8>>2]|0;
  $77 = ((($76) + (($55*36)|0)|0) + 28|0);
  HEAP32[$77>>2] = $leaf;
  $78 = HEAP32[$8>>2]|0;
  $79 = ((($78) + (($index$0$lcssa*36)|0)|0) + 20|0);
  HEAP32[$79>>2] = $55;
  $80 = HEAP32[$8>>2]|0;
  $81 = ((($80) + (($leaf*36)|0)|0) + 20|0);
  HEAP32[$81>>2] = $55;
 }
 $89 = HEAP32[$8>>2]|0;
 $90 = ((($89) + (($leaf*36)|0)|0) + 20|0);
 $index$12 = HEAP32[$90>>2]|0;
 $91 = ($index$12|0)==(-1);
 if ($91) {
  STACKTOP = sp;return;
 } else {
  $index$13 = $index$12;
 }
 while(1) {
  $92 = (__ZN13b2DynamicTree7BalanceEi($this,$index$13)|0);
  $93 = HEAP32[$8>>2]|0;
  $94 = ((($93) + (($92*36)|0)|0) + 24|0);
  $95 = HEAP32[$94>>2]|0;
  $96 = ((($93) + (($92*36)|0)|0) + 28|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = ((($93) + (($95*36)|0)|0) + 32|0);
  $99 = HEAP32[$98>>2]|0;
  $100 = ((($93) + (($97*36)|0)|0) + 32|0);
  $101 = HEAP32[$100>>2]|0;
  $102 = (__Z5b2MaxIiET_S0_S0_($99,$101)|0);
  $103 = (($102) + 1)|0;
  $104 = ((($93) + (($92*36)|0)|0) + 32|0);
  HEAP32[$104>>2] = $103;
  $105 = HEAP32[$8>>2]|0;
  $106 = (($105) + (($92*36)|0)|0);
  $107 = (($105) + (($95*36)|0)|0);
  $108 = (($105) + (($97*36)|0)|0);
  __ZN6b2AABB7CombineERKS_S1_($106,$107,$108);
  $109 = HEAP32[$8>>2]|0;
  $110 = ((($109) + (($92*36)|0)|0) + 20|0);
  $index$1 = HEAP32[$110>>2]|0;
  $111 = ($index$1|0)==(-1);
  if ($111) {
   break;
  } else {
   $index$13 = $index$1;
  }
 }
 STACKTOP = sp;return;
}
function __ZN13b2DynamicTree12DestroyProxyEi($this,$proxyId) {
 $this = $this|0;
 $proxyId = $proxyId|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN13b2DynamicTree10RemoveLeafEi($this,$proxyId);
 __ZN13b2DynamicTree8FreeNodeEi($this,$proxyId);
 STACKTOP = sp;return;
}
function __ZN13b2DynamicTree10RemoveLeafEi($this,$leaf) {
 $this = $this|0;
 $leaf = $leaf|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $index$01 = 0, $sibling$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==($leaf|0);
 if ($1) {
  HEAP32[$this>>2] = -1;
  STACKTOP = sp;return;
 }
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3) + (($leaf*36)|0)|0) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($3) + (($5*36)|0)|0) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($3) + (($5*36)|0)|0) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==($leaf|0);
 if ($10) {
  $11 = ((($3) + (($5*36)|0)|0) + 28|0);
  $12 = HEAP32[$11>>2]|0;
  $sibling$0 = $12;
 } else {
  $sibling$0 = $9;
 }
 $13 = ($7|0)==(-1);
 if ($13) {
  HEAP32[$this>>2] = $sibling$0;
  $43 = HEAP32[$2>>2]|0;
  $44 = ((($43) + (($sibling$0*36)|0)|0) + 20|0);
  HEAP32[$44>>2] = -1;
  __ZN13b2DynamicTree8FreeNodeEi($this,$5);
  STACKTOP = sp;return;
 }
 $14 = HEAP32[$2>>2]|0;
 $15 = ((($14) + (($7*36)|0)|0) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==($5|0);
 if ($17) {
  HEAP32[$15>>2] = $sibling$0;
 } else {
  $18 = ((($14) + (($7*36)|0)|0) + 28|0);
  HEAP32[$18>>2] = $sibling$0;
 }
 $19 = HEAP32[$2>>2]|0;
 $20 = ((($19) + (($sibling$0*36)|0)|0) + 20|0);
 HEAP32[$20>>2] = $7;
 __ZN13b2DynamicTree8FreeNodeEi($this,$5);
 $21 = ($7|0)==(-1);
 if ($21) {
  STACKTOP = sp;return;
 } else {
  $index$01 = $7;
 }
 while(1) {
  $22 = (__ZN13b2DynamicTree7BalanceEi($this,$index$01)|0);
  $23 = HEAP32[$2>>2]|0;
  $24 = ((($23) + (($22*36)|0)|0) + 24|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ((($23) + (($22*36)|0)|0) + 28|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($23) + (($22*36)|0)|0);
  $29 = (($23) + (($25*36)|0)|0);
  $30 = (($23) + (($27*36)|0)|0);
  __ZN6b2AABB7CombineERKS_S1_($28,$29,$30);
  $31 = HEAP32[$2>>2]|0;
  $32 = ((($31) + (($25*36)|0)|0) + 32|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ((($31) + (($27*36)|0)|0) + 32|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (__Z5b2MaxIiET_S0_S0_($33,$35)|0);
  $37 = (($36) + 1)|0;
  $38 = ((($31) + (($22*36)|0)|0) + 32|0);
  HEAP32[$38>>2] = $37;
  $39 = HEAP32[$2>>2]|0;
  $40 = ((($39) + (($22*36)|0)|0) + 20|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)==(-1);
  if ($42) {
   break;
  } else {
   $index$01 = $41;
  }
 }
 STACKTOP = sp;return;
}
function __ZN13b2DynamicTree9MoveProxyEiRK6b2AABBRK6b2Vec2($this,$proxyId,$aabb,$displacement) {
 $this = $this|0;
 $proxyId = $proxyId|0;
 $aabb = $aabb|0;
 $displacement = $displacement|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0.0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $b = 0, $d = 0, $r = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $b = sp + 16|0;
 $r = sp + 40|0;
 $0 = sp + 8|0;
 $1 = sp;
 $d = sp + 32|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + (($proxyId*36)|0)|0);
 $5 = (__ZNK6b2AABB8ContainsERKS_($4,$aabb)|0);
 if ($5) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 __ZN13b2DynamicTree10RemoveLeafEi($this,$proxyId);
 ;HEAP32[$b+0>>2]=HEAP32[$aabb+0>>2]|0;HEAP32[$b+4>>2]=HEAP32[$aabb+4>>2]|0;HEAP32[$b+8>>2]=HEAP32[$aabb+8>>2]|0;HEAP32[$b+12>>2]=HEAP32[$aabb+12>>2]|0;
 __ZN6b2Vec2C2Eff($r,0.10000000149011612,0.10000000149011612);
 __ZmiRK6b2Vec2S1_($0,$b,$r);
 $6 = $0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $b;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 $16 = (($b) + 8|0);
 __ZplRK6b2Vec2S1_($1,$16,$r);
 $17 = $1;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) + 4)|0;
 $21 = $20;
 $22 = HEAP32[$21>>2]|0;
 $23 = $16;
 $24 = $23;
 HEAP32[$24>>2] = $19;
 $25 = (($23) + 4)|0;
 $26 = $25;
 HEAP32[$26>>2] = $22;
 __ZmlfRK6b2Vec2($d,2.0,$displacement);
 $27 = +HEAPF32[$d>>2];
 $28 = $27 < 0.0;
 if ($28) {
  $29 = +HEAPF32[$b>>2];
  $30 = $27 + $29;
  HEAPF32[$b>>2] = $30;
 } else {
  $31 = +HEAPF32[$16>>2];
  $32 = $27 + $31;
  HEAPF32[$16>>2] = $32;
 }
 $33 = (($d) + 4|0);
 $34 = +HEAPF32[$33>>2];
 $35 = $34 < 0.0;
 if ($35) {
  $36 = (($b) + 4|0);
  $37 = +HEAPF32[$36>>2];
  $38 = $34 + $37;
  HEAPF32[$36>>2] = $38;
 } else {
  $39 = (($b) + 12|0);
  $40 = +HEAPF32[$39>>2];
  $41 = $34 + $40;
  HEAPF32[$39>>2] = $41;
 }
 $42 = HEAP32[$2>>2]|0;
 $43 = (($42) + (($proxyId*36)|0)|0);
 ;HEAP32[$43+0>>2]=HEAP32[$b+0>>2]|0;HEAP32[$43+4>>2]=HEAP32[$b+4>>2]|0;HEAP32[$43+8>>2]=HEAP32[$b+8>>2]|0;HEAP32[$43+12>>2]=HEAP32[$b+12>>2]|0;
 __ZN13b2DynamicTree10InsertLeafEi($this,$proxyId);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN13b2DynamicTree7BalanceEi($this,$iA) {
 $this = $this|0;
 $iA = $iA|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $storemerge = 0, $storemerge$in = 0, $storemerge1 = 0, $storemerge1$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + (($iA*36)|0)|0);
 $3 = (__ZNK10b2TreeNode6IsLeafEv($2)|0);
 if ($3) {
  $$0 = $iA;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = ((($1) + (($iA*36)|0)|0) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)<(2);
 if ($6) {
  $$0 = $iA;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = ((($1) + (($iA*36)|0)|0) + 24|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($1) + (($iA*36)|0)|0) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($1) + (($8*36)|0)|0);
 $12 = (($1) + (($10*36)|0)|0);
 $13 = ((($1) + (($10*36)|0)|0) + 32|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($1) + (($8*36)|0)|0) + 32|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14) - ($16))|0;
 $18 = ($17|0)>(1);
 if ($18) {
  $19 = ((($1) + (($10*36)|0)|0) + 24|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ((($1) + (($10*36)|0)|0) + 28|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = (($1) + (($20*36)|0)|0);
  $24 = (($1) + (($22*36)|0)|0);
  HEAP32[$19>>2] = $iA;
  $25 = ((($1) + (($iA*36)|0)|0) + 20|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ((($1) + (($10*36)|0)|0) + 20|0);
  HEAP32[$27>>2] = $26;
  HEAP32[$25>>2] = $10;
  $28 = HEAP32[$27>>2]|0;
  $29 = ($28|0)==(-1);
  do {
   if ($29) {
    HEAP32[$this>>2] = $10;
   } else {
    $30 = HEAP32[$0>>2]|0;
    $31 = ((($30) + (($28*36)|0)|0) + 24|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = ($32|0)==($iA|0);
    if ($33) {
     HEAP32[$31>>2] = $10;
     break;
    } else {
     $34 = ((($30) + (($28*36)|0)|0) + 28|0);
     HEAP32[$34>>2] = $10;
     break;
    }
   }
  } while(0);
  $35 = ((($1) + (($20*36)|0)|0) + 32|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ((($1) + (($22*36)|0)|0) + 32|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = ($36|0)>($38|0);
  if ($39) {
   HEAP32[$21>>2] = $20;
   HEAP32[$9>>2] = $22;
   $40 = ((($1) + (($22*36)|0)|0) + 20|0);
   HEAP32[$40>>2] = $iA;
   __ZN6b2AABB7CombineERKS_S1_($2,$11,$24);
   __ZN6b2AABB7CombineERKS_S1_($12,$2,$23);
   $41 = HEAP32[$15>>2]|0;
   $42 = HEAP32[$37>>2]|0;
   $43 = (__Z5b2MaxIiET_S0_S0_($41,$42)|0);
   $44 = (($43) + 1)|0;
   HEAP32[$4>>2] = $44;
   $45 = HEAP32[$35>>2]|0;
   $46 = (__Z5b2MaxIiET_S0_S0_($44,$45)|0);
   $storemerge1$in = $46;
  } else {
   HEAP32[$21>>2] = $22;
   HEAP32[$9>>2] = $20;
   $47 = ((($1) + (($20*36)|0)|0) + 20|0);
   HEAP32[$47>>2] = $iA;
   __ZN6b2AABB7CombineERKS_S1_($2,$11,$23);
   __ZN6b2AABB7CombineERKS_S1_($12,$2,$24);
   $48 = HEAP32[$15>>2]|0;
   $49 = HEAP32[$35>>2]|0;
   $50 = (__Z5b2MaxIiET_S0_S0_($48,$49)|0);
   $51 = (($50) + 1)|0;
   HEAP32[$4>>2] = $51;
   $52 = HEAP32[$37>>2]|0;
   $53 = (__Z5b2MaxIiET_S0_S0_($51,$52)|0);
   $storemerge1$in = $53;
  }
  $storemerge1 = (($storemerge1$in) + 1)|0;
  HEAP32[$13>>2] = $storemerge1;
  $$0 = $10;
  STACKTOP = sp;return ($$0|0);
 }
 $54 = ($17|0)<(-1);
 if (!($54)) {
  $$0 = $iA;
  STACKTOP = sp;return ($$0|0);
 }
 $55 = ((($1) + (($8*36)|0)|0) + 24|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ((($1) + (($8*36)|0)|0) + 28|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = (($1) + (($56*36)|0)|0);
 $60 = (($1) + (($58*36)|0)|0);
 HEAP32[$55>>2] = $iA;
 $61 = ((($1) + (($iA*36)|0)|0) + 20|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ((($1) + (($8*36)|0)|0) + 20|0);
 HEAP32[$63>>2] = $62;
 HEAP32[$61>>2] = $8;
 $64 = HEAP32[$63>>2]|0;
 $65 = ($64|0)==(-1);
 do {
  if ($65) {
   HEAP32[$this>>2] = $8;
  } else {
   $66 = HEAP32[$0>>2]|0;
   $67 = ((($66) + (($64*36)|0)|0) + 24|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = ($68|0)==($iA|0);
   if ($69) {
    HEAP32[$67>>2] = $8;
    break;
   } else {
    $70 = ((($66) + (($64*36)|0)|0) + 28|0);
    HEAP32[$70>>2] = $8;
    break;
   }
  }
 } while(0);
 $71 = ((($1) + (($56*36)|0)|0) + 32|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ((($1) + (($58*36)|0)|0) + 32|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ($72|0)>($74|0);
 if ($75) {
  HEAP32[$57>>2] = $56;
  HEAP32[$7>>2] = $58;
  $76 = ((($1) + (($58*36)|0)|0) + 20|0);
  HEAP32[$76>>2] = $iA;
  __ZN6b2AABB7CombineERKS_S1_($2,$12,$60);
  __ZN6b2AABB7CombineERKS_S1_($11,$2,$59);
  $77 = HEAP32[$13>>2]|0;
  $78 = HEAP32[$73>>2]|0;
  $79 = (__Z5b2MaxIiET_S0_S0_($77,$78)|0);
  $80 = (($79) + 1)|0;
  HEAP32[$4>>2] = $80;
  $81 = HEAP32[$71>>2]|0;
  $82 = (__Z5b2MaxIiET_S0_S0_($80,$81)|0);
  $storemerge$in = $82;
 } else {
  HEAP32[$57>>2] = $58;
  HEAP32[$7>>2] = $56;
  $83 = ((($1) + (($56*36)|0)|0) + 20|0);
  HEAP32[$83>>2] = $iA;
  __ZN6b2AABB7CombineERKS_S1_($2,$12,$59);
  __ZN6b2AABB7CombineERKS_S1_($11,$2,$60);
  $84 = HEAP32[$13>>2]|0;
  $85 = HEAP32[$71>>2]|0;
  $86 = (__Z5b2MaxIiET_S0_S0_($84,$85)|0);
  $87 = (($86) + 1)|0;
  HEAP32[$4>>2] = $87;
  $88 = HEAP32[$73>>2]|0;
  $89 = (__Z5b2MaxIiET_S0_S0_($87,$88)|0);
  $storemerge$in = $89;
 }
 $storemerge = (($storemerge$in) + 1)|0;
 HEAP32[$15>>2] = $storemerge;
 $$0 = $8;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK10b2TreeNode6IsLeafEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(-1);
 STACKTOP = sp;return ($2|0);
}
function __ZNK6b2AABB12GetPerimeterEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0.0, $10 = 0.0, $2 = 0.0, $3 = 0.0, $4 = 0, $5 = 0.0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = +HEAPF32[$0>>2];
 $2 = +HEAPF32[$this>>2];
 $3 = $1 - $2;
 $4 = (($this) + 12|0);
 $5 = +HEAPF32[$4>>2];
 $6 = (($this) + 4|0);
 $7 = +HEAPF32[$6>>2];
 $8 = $5 - $7;
 $9 = $3 + $8;
 $10 = $9 * 2.0;
 STACKTOP = sp;return (+$10);
}
function __ZN6b2AABB7CombineERKS_S1_($this,$aabb1,$aabb2) {
 $this = $this|0;
 $aabb1 = $aabb1|0;
 $aabb2 = $aabb2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 __Z5b2MinRK6b2Vec2S1_($0,$aabb1,$aabb2);
 $2 = $0;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $this;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 $12 = (($this) + 8|0);
 $13 = (($aabb1) + 8|0);
 $14 = (($aabb2) + 8|0);
 __Z5b2MaxRK6b2Vec2S1_($1,$13,$14);
 $15 = $1;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = $12;
 $22 = $21;
 HEAP32[$22>>2] = $17;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = $20;
 STACKTOP = sp;return;
}
function __ZNK6b2AABB8ContainsERKS_($this,$aabb) {
 $this = $this|0;
 $aabb = $aabb|0;
 var $0 = 0.0, $1 = 0.0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0.0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$this>>2];
 $1 = +HEAPF32[$aabb>>2];
 $2 = !($0 <= $1);
 if ($2) {
  $18 = 0;
 } else {
  $3 = (($this) + 4|0);
  $4 = +HEAPF32[$3>>2];
  $5 = (($aabb) + 4|0);
  $6 = +HEAPF32[$5>>2];
  $7 = !($4 <= $6);
  if ($7) {
   $18 = 0;
  } else {
   $8 = (($aabb) + 8|0);
   $9 = +HEAPF32[$8>>2];
   $10 = (($this) + 8|0);
   $11 = +HEAPF32[$10>>2];
   $12 = !($9 <= $11);
   if ($12) {
    $18 = 0;
   } else {
    $13 = (($aabb) + 12|0);
    $14 = +HEAPF32[$13>>2];
    $15 = (($this) + 12|0);
    $16 = +HEAPF32[$15>>2];
    $17 = $14 <= $16;
    $18 = $17;
   }
  }
 }
 STACKTOP = sp;return ($18|0);
}
function __Z22b2CollideEdgeAndCircleP10b2ManifoldPK11b2EdgeShapeRK11b2TransformPK13b2CircleShapeS6_($manifold,$edgeA,$xfA,$circleB,$xfB) {
 $manifold = $manifold|0;
 $edgeA = $edgeA|0;
 $xfA = $xfA|0;
 $circleB = $circleB|0;
 $xfB = $xfB|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0.0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0, $179 = 0, $18 = 0, $180 = 0.0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0, $185 = 0.0, $186 = 0.0, $187 = 0, $188 = 0.0;
 var $189 = 0.0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0.0;
 var $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0.0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0.0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $A = 0, $A1 = 0, $A2 = 0, $B = 0, $B1 = 0, $B2 = 0, $P = 0, $P1 = 0, $P4 = 0, $Q = 0, $d = 0, $d2 = 0, $d5 = 0;
 var $e = 0, $e1 = 0, $e2 = 0, $n = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $Q = sp + 200|0;
 $0 = sp + 192|0;
 $A = sp + 64|0;
 $B = sp + 56|0;
 $e = sp + 184|0;
 $1 = sp + 176|0;
 $2 = sp + 168|0;
 $P = sp + 48|0;
 $d = sp + 160|0;
 $A1 = sp + 40|0;
 $B1 = sp + 32|0;
 $e1 = sp + 152|0;
 $3 = sp + 144|0;
 $P1 = sp + 24|0;
 $d2 = sp + 136|0;
 $B2 = sp + 16|0;
 $A2 = sp + 8|0;
 $e2 = sp + 128|0;
 $4 = sp + 120|0;
 $P4 = sp + 112|0;
 $5 = sp + 104|0;
 $6 = sp + 96|0;
 $7 = sp + 88|0;
 $d5 = sp + 80|0;
 $n = sp;
 $8 = sp + 72|0;
 $9 = (($manifold) + 60|0);
 HEAP32[$9>>2] = 0;
 $10 = (($circleB) + 12|0);
 __Z5b2MulRK11b2TransformRK6b2Vec2($0,$xfB,$10);
 __Z6b2MulTRK11b2TransformRK6b2Vec2($Q,$xfA,$0);
 $11 = (($edgeA) + 12|0);
 $12 = $11;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($12) + 4)|0;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = $A;
 $19 = $18;
 HEAP32[$19>>2] = $14;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = $17;
 $22 = (($edgeA) + 20|0);
 $23 = $22;
 $24 = $23;
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23) + 4)|0;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = $B;
 $30 = $29;
 HEAP32[$30>>2] = $25;
 $31 = (($29) + 4)|0;
 $32 = $31;
 HEAP32[$32>>2] = $28;
 __ZmiRK6b2Vec2S1_($e,$B,$A);
 __ZmiRK6b2Vec2S1_($1,$B,$Q);
 $33 = (+__Z5b2DotRK6b2Vec2S1_($e,$1));
 __ZmiRK6b2Vec2S1_($2,$Q,$A);
 $34 = (+__Z5b2DotRK6b2Vec2S1_($e,$2));
 $35 = (($edgeA) + 8|0);
 $36 = +HEAPF32[$35>>2];
 $37 = (($circleB) + 8|0);
 $38 = +HEAPF32[$37>>2];
 $39 = $36 + $38;
 $40 = !($34 <= 0.0);
 if (!($40)) {
  $41 = $A;
  $42 = $41;
  $43 = HEAP32[$42>>2]|0;
  $44 = (($41) + 4)|0;
  $45 = $44;
  $46 = HEAP32[$45>>2]|0;
  $47 = $P;
  $48 = $47;
  HEAP32[$48>>2] = $43;
  $49 = (($47) + 4)|0;
  $50 = $49;
  HEAP32[$50>>2] = $46;
  __ZmiRK6b2Vec2S1_($d,$Q,$P);
  $51 = (+__Z5b2DotRK6b2Vec2S1_($d,$d));
  $52 = $39 * $39;
  $53 = $51 > $52;
  if ($53) {
   STACKTOP = sp;return;
  }
  $54 = (($edgeA) + 44|0);
  $55 = HEAP8[$54>>0]|0;
  $56 = ($55<<24>>24)==(0);
  if (!($56)) {
   $57 = (($edgeA) + 28|0);
   $58 = $57;
   $59 = $58;
   $60 = HEAP32[$59>>2]|0;
   $61 = (($58) + 4)|0;
   $62 = $61;
   $63 = HEAP32[$62>>2]|0;
   $64 = $A1;
   $65 = $64;
   HEAP32[$65>>2] = $60;
   $66 = (($64) + 4)|0;
   $67 = $66;
   HEAP32[$67>>2] = $63;
   $68 = $A;
   $69 = $68;
   $70 = HEAP32[$69>>2]|0;
   $71 = (($68) + 4)|0;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = $B1;
   $75 = $74;
   HEAP32[$75>>2] = $70;
   $76 = (($74) + 4)|0;
   $77 = $76;
   HEAP32[$77>>2] = $73;
   __ZmiRK6b2Vec2S1_($e1,$B1,$A1);
   __ZmiRK6b2Vec2S1_($3,$B1,$Q);
   $78 = (+__Z5b2DotRK6b2Vec2S1_($e1,$3));
   $79 = $78 > 0.0;
   if ($79) {
    STACKTOP = sp;return;
   }
  }
  HEAP32[$9>>2] = 1;
  $80 = (($manifold) + 56|0);
  HEAP32[$80>>2] = 0;
  $81 = (($manifold) + 40|0);
  __ZN6b2Vec27SetZeroEv($81);
  $82 = (($manifold) + 48|0);
  $83 = $P;
  $84 = $83;
  $85 = HEAP32[$84>>2]|0;
  $86 = (($83) + 4)|0;
  $87 = $86;
  $88 = HEAP32[$87>>2]|0;
  $89 = $82;
  $90 = $89;
  HEAP32[$90>>2] = $85;
  $91 = (($89) + 4)|0;
  $92 = $91;
  HEAP32[$92>>2] = $88;
  $93 = (($manifold) + 16|0);
  HEAP32[$93>>2] = 0;
  HEAP8[$93>>0] = 0;
  $94 = (($93) + 1|0);
  HEAP8[$94>>0] = 0;
  $95 = (($93) + 2|0);
  HEAP8[$95>>0] = 0;
  $96 = (($93) + 3|0);
  HEAP8[$96>>0] = 0;
  $97 = $10;
  $98 = $97;
  $99 = HEAP32[$98>>2]|0;
  $100 = (($97) + 4)|0;
  $101 = $100;
  $102 = HEAP32[$101>>2]|0;
  $103 = $manifold;
  $104 = $103;
  HEAP32[$104>>2] = $99;
  $105 = (($103) + 4)|0;
  $106 = $105;
  HEAP32[$106>>2] = $102;
  STACKTOP = sp;return;
 }
 $107 = !($33 <= 0.0);
 if ($107) {
  $174 = (+__Z5b2DotRK6b2Vec2S1_($e,$e));
  $175 = 1.0 / $174;
  __ZmlfRK6b2Vec2($6,$33,$A);
  __ZmlfRK6b2Vec2($7,$34,$B);
  __ZplRK6b2Vec2S1_($5,$6,$7);
  __ZmlfRK6b2Vec2($P4,$175,$5);
  __ZmiRK6b2Vec2S1_($d5,$Q,$P4);
  $176 = (+__Z5b2DotRK6b2Vec2S1_($d5,$d5));
  $177 = $39 * $39;
  $178 = $176 > $177;
  if ($178) {
   STACKTOP = sp;return;
  }
  $179 = (($e) + 4|0);
  $180 = +HEAPF32[$179>>2];
  $181 = -$180;
  $182 = +HEAPF32[$e>>2];
  __ZN6b2Vec2C2Eff($n,$181,$182);
  __ZmiRK6b2Vec2S1_($8,$Q,$A);
  $183 = (+__Z5b2DotRK6b2Vec2S1_($n,$8));
  $184 = $183 < 0.0;
  if ($184) {
   $185 = +HEAPF32[$n>>2];
   $186 = -$185;
   $187 = (($n) + 4|0);
   $188 = +HEAPF32[$187>>2];
   $189 = -$188;
   __ZN6b2Vec23SetEff($n,$186,$189);
  }
  (+__ZN6b2Vec29NormalizeEv($n));
  HEAP32[$9>>2] = 1;
  $190 = (($manifold) + 56|0);
  HEAP32[$190>>2] = 1;
  $191 = (($manifold) + 40|0);
  $192 = $n;
  $193 = $192;
  $194 = HEAP32[$193>>2]|0;
  $195 = (($192) + 4)|0;
  $196 = $195;
  $197 = HEAP32[$196>>2]|0;
  $198 = $191;
  $199 = $198;
  HEAP32[$199>>2] = $194;
  $200 = (($198) + 4)|0;
  $201 = $200;
  HEAP32[$201>>2] = $197;
  $202 = (($manifold) + 48|0);
  $203 = $A;
  $204 = $203;
  $205 = HEAP32[$204>>2]|0;
  $206 = (($203) + 4)|0;
  $207 = $206;
  $208 = HEAP32[$207>>2]|0;
  $209 = $202;
  $210 = $209;
  HEAP32[$210>>2] = $205;
  $211 = (($209) + 4)|0;
  $212 = $211;
  HEAP32[$212>>2] = $208;
  $213 = (($manifold) + 16|0);
  HEAP32[$213>>2] = 0;
  HEAP8[$213>>0] = 0;
  $214 = (($213) + 1|0);
  HEAP8[$214>>0] = 0;
  $215 = (($213) + 2|0);
  HEAP8[$215>>0] = 1;
  $216 = (($213) + 3|0);
  HEAP8[$216>>0] = 0;
  $217 = $10;
  $218 = $217;
  $219 = HEAP32[$218>>2]|0;
  $220 = (($217) + 4)|0;
  $221 = $220;
  $222 = HEAP32[$221>>2]|0;
  $223 = $manifold;
  $224 = $223;
  HEAP32[$224>>2] = $219;
  $225 = (($223) + 4)|0;
  $226 = $225;
  HEAP32[$226>>2] = $222;
  STACKTOP = sp;return;
 }
 $108 = $B;
 $109 = $108;
 $110 = HEAP32[$109>>2]|0;
 $111 = (($108) + 4)|0;
 $112 = $111;
 $113 = HEAP32[$112>>2]|0;
 $114 = $P1;
 $115 = $114;
 HEAP32[$115>>2] = $110;
 $116 = (($114) + 4)|0;
 $117 = $116;
 HEAP32[$117>>2] = $113;
 __ZmiRK6b2Vec2S1_($d2,$Q,$P1);
 $118 = (+__Z5b2DotRK6b2Vec2S1_($d2,$d2));
 $119 = $39 * $39;
 $120 = $118 > $119;
 if ($120) {
  STACKTOP = sp;return;
 }
 $121 = (($edgeA) + 45|0);
 $122 = HEAP8[$121>>0]|0;
 $123 = ($122<<24>>24)==(0);
 if (!($123)) {
  $124 = (($edgeA) + 36|0);
  $125 = $124;
  $126 = $125;
  $127 = HEAP32[$126>>2]|0;
  $128 = (($125) + 4)|0;
  $129 = $128;
  $130 = HEAP32[$129>>2]|0;
  $131 = $B2;
  $132 = $131;
  HEAP32[$132>>2] = $127;
  $133 = (($131) + 4)|0;
  $134 = $133;
  HEAP32[$134>>2] = $130;
  $135 = $B;
  $136 = $135;
  $137 = HEAP32[$136>>2]|0;
  $138 = (($135) + 4)|0;
  $139 = $138;
  $140 = HEAP32[$139>>2]|0;
  $141 = $A2;
  $142 = $141;
  HEAP32[$142>>2] = $137;
  $143 = (($141) + 4)|0;
  $144 = $143;
  HEAP32[$144>>2] = $140;
  __ZmiRK6b2Vec2S1_($e2,$B2,$A2);
  __ZmiRK6b2Vec2S1_($4,$Q,$A2);
  $145 = (+__Z5b2DotRK6b2Vec2S1_($e2,$4));
  $146 = $145 > 0.0;
  if ($146) {
   STACKTOP = sp;return;
  }
 }
 HEAP32[$9>>2] = 1;
 $147 = (($manifold) + 56|0);
 HEAP32[$147>>2] = 0;
 $148 = (($manifold) + 40|0);
 __ZN6b2Vec27SetZeroEv($148);
 $149 = (($manifold) + 48|0);
 $150 = $P1;
 $151 = $150;
 $152 = HEAP32[$151>>2]|0;
 $153 = (($150) + 4)|0;
 $154 = $153;
 $155 = HEAP32[$154>>2]|0;
 $156 = $149;
 $157 = $156;
 HEAP32[$157>>2] = $152;
 $158 = (($156) + 4)|0;
 $159 = $158;
 HEAP32[$159>>2] = $155;
 $160 = (($manifold) + 16|0);
 HEAP32[$160>>2] = 0;
 HEAP8[$160>>0] = 1;
 $161 = (($160) + 1|0);
 HEAP8[$161>>0] = 0;
 $162 = (($160) + 2|0);
 HEAP8[$162>>0] = 0;
 $163 = (($160) + 3|0);
 HEAP8[$163>>0] = 0;
 $164 = $10;
 $165 = $164;
 $166 = HEAP32[$165>>2]|0;
 $167 = (($164) + 4)|0;
 $168 = $167;
 $169 = HEAP32[$168>>2]|0;
 $170 = $manifold;
 $171 = $170;
 HEAP32[$171>>2] = $166;
 $172 = (($170) + 4)|0;
 $173 = $172;
 HEAP32[$173>>2] = $169;
 STACKTOP = sp;return;
}
function __ZN12b2EPCollider7CollideEP10b2ManifoldPK11b2EdgeShapeRK11b2TransformPK14b2PolygonShapeS7_($this,$manifold,$edgeA,$xfA,$polygonB,$xfB) {
 $this = $this|0;
 $manifold = $manifold|0;
 $edgeA = $edgeA|0;
 $xfA = $xfA|0;
 $polygonB = $polygonB|0;
 $xfB = $xfB|0;
 var $$ = 0, $$45 = 0, $$lcssa = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0;
 var $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0;
 var $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0.0, $104 = 0, $1040 = 0.0, $1041 = 0.0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0;
 var $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0.0, $1055 = 0, $1056 = 0, $1057 = 0.0, $1058 = 0, $1059 = 0.0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0.0, $1064 = 0, $1065 = 0;
 var $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0.0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0.0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0;
 var $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0.0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0.0, $1100 = 0;
 var $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0.0, $1116 = 0.0, $1117 = 0, $1118 = 0, $1119 = 0;
 var $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0.0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0;
 var $1138 = 0, $1139 = 0, $114 = 0.0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0.0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0.0, $1155 = 0.0;
 var $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0.0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0, $1173 = 0;
 var $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0.0, $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0, $119 = 0, $1190 = 0, $1191 = 0;
 var $1192 = 0, $1193 = 0, $12 = 0, $120 = 0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0, $126 = 0.0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0;
 var $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0;
 var $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0;
 var $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0;
 var $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0;
 var $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0;
 var $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0;
 var $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0;
 var $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0;
 var $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0;
 var $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0;
 var $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0;
 var $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0;
 var $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0;
 var $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0;
 var $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0;
 var $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0;
 var $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0;
 var $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0;
 var $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0;
 var $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0;
 var $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0;
 var $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0;
 var $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0;
 var $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0;
 var $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0;
 var $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0;
 var $820 = 0.0, $821 = 0.0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0.0, $827 = 0.0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0.0, $835 = 0.0, $836 = 0.0, $837 = 0.0, $838 = 0;
 var $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0.0, $851 = 0, $852 = 0, $853 = 0.0, $854 = 0, $855 = 0, $856 = 0;
 var $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0;
 var $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0;
 var $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0;
 var $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0;
 var $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0;
 var $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0;
 var $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0;
 var $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $bestIndex$0$lcssa = 0, $bestIndex$064 = 0;
 var $bestIndex$1 = 0, $bestValue$065 = 0.0, $bestValue$1 = 0.0, $brmerge$demorgan = 0, $brmerge44$demorgan = 0, $clipPoints1 = 0, $clipPoints2 = 0, $convex1$0$off0 = 0, $convex2$0$off049 = 0, $edge0 = 0, $edge1 = 0, $edge2 = 0, $edgeAxis = 0, $i$068 = 0, $i1$066 = 0, $ie = 0, $offset0$0 = 0.0, $offset2$050 = 0.0, $or$cond = 0, $or$cond3 = 0;
 var $phitmp = 0, $phitmp15 = 0, $phitmp19 = 0, $phitmp23 = 0, $phitmp27 = 0, $phitmp31 = 0, $phitmp35 = 0, $phitmp39 = 0, $pointCount$1 = 0, $pointCount$1$1 = 0, $polygonAxis = 0, $primaryAxis$sroa$0$0 = 0, $primaryAxis$sroa$6$0 = 0, $rf = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 496|0;
 $0 = sp + 472|0;
 $1 = sp + 304|0;
 $edge1 = sp + 464|0;
 $2 = sp + 456|0;
 $edge0 = sp + 448|0;
 $3 = sp + 440|0;
 $edge2 = sp + 432|0;
 $4 = sp + 424|0;
 $5 = sp + 296|0;
 $6 = sp + 288|0;
 $7 = sp + 280|0;
 $8 = sp + 272|0;
 $9 = sp + 264|0;
 $10 = sp + 256|0;
 $11 = sp + 248|0;
 $12 = sp + 240|0;
 $13 = sp + 232|0;
 $14 = sp + 224|0;
 $15 = sp + 216|0;
 $16 = sp + 208|0;
 $17 = sp + 200|0;
 $18 = sp + 192|0;
 $19 = sp + 184|0;
 $20 = sp + 176|0;
 $21 = sp + 168|0;
 $22 = sp + 160|0;
 $23 = sp + 152|0;
 $24 = sp + 144|0;
 $25 = sp + 136|0;
 $26 = sp + 128|0;
 $27 = sp + 120|0;
 $28 = sp + 112|0;
 $29 = sp + 104|0;
 $30 = sp + 96|0;
 $31 = sp + 88|0;
 $32 = sp + 80|0;
 $33 = sp + 72|0;
 $edgeAxis = sp + 412|0;
 $polygonAxis = sp + 400|0;
 $ie = sp + 48|0;
 $rf = sp + 344|0;
 $34 = sp + 40|0;
 $35 = sp + 32|0;
 $clipPoints1 = sp + 320|0;
 $clipPoints2 = sp + 8|0;
 $36 = sp + 312|0;
 $37 = sp;
 $38 = (($this) + 132|0);
 __Z6b2MulTRK11b2TransformS1_($0,$xfA,$xfB);
 ;HEAP32[$38+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$38+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$38+12>>2]=HEAP32[$0+12>>2]|0;
 $39 = (($this) + 148|0);
 $40 = (($polygonB) + 12|0);
 __Z5b2MulRK11b2TransformRK6b2Vec2($1,$38,$40);
 $41 = $1;
 $42 = $41;
 $43 = HEAP32[$42>>2]|0;
 $44 = (($41) + 4)|0;
 $45 = $44;
 $46 = HEAP32[$45>>2]|0;
 $47 = $39;
 $48 = $47;
 HEAP32[$48>>2] = $43;
 $49 = (($47) + 4)|0;
 $50 = $49;
 HEAP32[$50>>2] = $46;
 $51 = (($this) + 156|0);
 $52 = (($edgeA) + 28|0);
 $53 = $52;
 $54 = $53;
 $55 = HEAP32[$54>>2]|0;
 $56 = (($53) + 4)|0;
 $57 = $56;
 $58 = HEAP32[$57>>2]|0;
 $59 = $51;
 $60 = $59;
 HEAP32[$60>>2] = $55;
 $61 = (($59) + 4)|0;
 $62 = $61;
 HEAP32[$62>>2] = $58;
 $63 = (($this) + 164|0);
 $64 = (($edgeA) + 12|0);
 $65 = $64;
 $66 = $65;
 $67 = HEAP32[$66>>2]|0;
 $68 = (($65) + 4)|0;
 $69 = $68;
 $70 = HEAP32[$69>>2]|0;
 $71 = $63;
 $72 = $71;
 HEAP32[$72>>2] = $67;
 $73 = (($71) + 4)|0;
 $74 = $73;
 HEAP32[$74>>2] = $70;
 $75 = (($this) + 172|0);
 $76 = (($edgeA) + 20|0);
 $77 = $76;
 $78 = $77;
 $79 = HEAP32[$78>>2]|0;
 $80 = (($77) + 4)|0;
 $81 = $80;
 $82 = HEAP32[$81>>2]|0;
 $83 = $75;
 $84 = $83;
 HEAP32[$84>>2] = $79;
 $85 = (($83) + 4)|0;
 $86 = $85;
 HEAP32[$86>>2] = $82;
 $87 = (($this) + 180|0);
 $88 = (($edgeA) + 36|0);
 $89 = $88;
 $90 = $89;
 $91 = HEAP32[$90>>2]|0;
 $92 = (($89) + 4)|0;
 $93 = $92;
 $94 = HEAP32[$93>>2]|0;
 $95 = $87;
 $96 = $95;
 HEAP32[$96>>2] = $91;
 $97 = (($95) + 4)|0;
 $98 = $97;
 HEAP32[$98>>2] = $94;
 $99 = (($edgeA) + 44|0);
 $100 = HEAP8[$99>>0]|0;
 $101 = ($100<<24>>24)!=(0);
 $102 = (($edgeA) + 45|0);
 $103 = HEAP8[$102>>0]|0;
 $104 = ($103<<24>>24)!=(0);
 __ZmiRK6b2Vec2S1_($edge1,$75,$63);
 (+__ZN6b2Vec29NormalizeEv($edge1));
 $105 = (($this) + 196|0);
 $106 = (($edge1) + 4|0);
 $107 = +HEAPF32[$106>>2];
 $108 = +HEAPF32[$edge1>>2];
 $109 = -$108;
 __ZN6b2Vec23SetEff($105,$107,$109);
 __ZmiRK6b2Vec2S1_($2,$39,$63);
 $110 = (+__Z5b2DotRK6b2Vec2S1_($105,$2));
 if ($101) {
  __ZmiRK6b2Vec2S1_($edge0,$63,$51);
  (+__ZN6b2Vec29NormalizeEv($edge0));
  $111 = (($this) + 188|0);
  $112 = (($edge0) + 4|0);
  $113 = +HEAPF32[$112>>2];
  $114 = +HEAPF32[$edge0>>2];
  $115 = -$114;
  __ZN6b2Vec23SetEff($111,$113,$115);
  $116 = (+__Z7b2CrossRK6b2Vec2S1_($edge0,$edge1));
  $117 = $116 >= 0.0;
  __ZmiRK6b2Vec2S1_($3,$39,$51);
  $118 = (+__Z5b2DotRK6b2Vec2S1_($111,$3));
  $convex1$0$off0 = $117;$offset0$0 = $118;
 } else {
  $convex1$0$off0 = 0;$offset0$0 = 0.0;
 }
 L4: do {
  if ($104) {
   __ZmiRK6b2Vec2S1_($edge2,$87,$75);
   (+__ZN6b2Vec29NormalizeEv($edge2));
   $119 = (($this) + 204|0);
   $120 = (($edge2) + 4|0);
   $121 = +HEAPF32[$120>>2];
   $122 = +HEAPF32[$edge2>>2];
   $123 = -$122;
   __ZN6b2Vec23SetEff($119,$121,$123);
   $124 = (+__Z7b2CrossRK6b2Vec2S1_($edge1,$edge2));
   $125 = $124 > 0.0;
   __ZmiRK6b2Vec2S1_($4,$39,$75);
   $126 = (+__Z5b2DotRK6b2Vec2S1_($119,$4));
   $brmerge$demorgan = $101 & $104;
   if ($brmerge$demorgan) {
    $brmerge44$demorgan = $convex1$0$off0 & $125;
    if ($brmerge44$demorgan) {
     $127 = $offset0$0 >= 0.0;
     $128 = $110 >= 0.0;
     $or$cond = $127 | $128;
     if ($or$cond) {
      $129 = (($this) + 248|0);
      HEAP8[$129>>0] = 1;
      $130 = (($this) + 212|0);
      $140 = $130;
     } else {
      $131 = $126 >= 0.0;
      $phitmp39 = $131&1;
      $132 = (($this) + 248|0);
      HEAP8[$132>>0] = $phitmp39;
      $133 = (($this) + 212|0);
      if ($131) {
       $140 = $133;
      } else {
       __ZNK6b2Vec2ngEv($5,$105);
       $169 = $5;
       $170 = $169;
       $171 = HEAP32[$170>>2]|0;
       $172 = (($169) + 4)|0;
       $173 = $172;
       $174 = HEAP32[$173>>2]|0;
       $175 = $133;
       $176 = $175;
       HEAP32[$176>>2] = $171;
       $177 = (($175) + 4)|0;
       $178 = $177;
       HEAP32[$178>>2] = $174;
       $179 = (($this) + 228|0);
       __ZNK6b2Vec2ngEv($6,$105);
       $180 = $6;
       $181 = $180;
       $182 = HEAP32[$181>>2]|0;
       $183 = (($180) + 4)|0;
       $184 = $183;
       $185 = HEAP32[$184>>2]|0;
       $186 = $179;
       $187 = $186;
       HEAP32[$187>>2] = $182;
       $188 = (($186) + 4)|0;
       $189 = $188;
       HEAP32[$189>>2] = $185;
       $190 = (($this) + 236|0);
       __ZNK6b2Vec2ngEv($7,$105);
       $191 = $7;
       $192 = $191;
       $193 = HEAP32[$192>>2]|0;
       $194 = (($191) + 4)|0;
       $195 = $194;
       $196 = HEAP32[$195>>2]|0;
       $197 = $190;
       $198 = $197;
       HEAP32[$198>>2] = $193;
       $199 = (($197) + 4)|0;
       $200 = $199;
       HEAP32[$200>>2] = $196;
       break;
      }
     }
     $134 = $105;
     $135 = $134;
     $136 = HEAP32[$135>>2]|0;
     $137 = (($134) + 4)|0;
     $138 = $137;
     $139 = HEAP32[$138>>2]|0;
     $141 = $140;
     $142 = $141;
     HEAP32[$142>>2] = $136;
     $143 = (($141) + 4)|0;
     $144 = $143;
     HEAP32[$144>>2] = $139;
     $145 = (($this) + 228|0);
     $146 = (($this) + 188|0);
     $147 = $146;
     $148 = $147;
     $149 = HEAP32[$148>>2]|0;
     $150 = (($147) + 4)|0;
     $151 = $150;
     $152 = HEAP32[$151>>2]|0;
     $153 = $145;
     $154 = $153;
     HEAP32[$154>>2] = $149;
     $155 = (($153) + 4)|0;
     $156 = $155;
     HEAP32[$156>>2] = $152;
     $157 = (($this) + 236|0);
     $158 = (($this) + 204|0);
     $159 = $158;
     $160 = $159;
     $161 = HEAP32[$160>>2]|0;
     $162 = (($159) + 4)|0;
     $163 = $162;
     $164 = HEAP32[$163>>2]|0;
     $165 = $157;
     $166 = $165;
     HEAP32[$166>>2] = $161;
     $167 = (($165) + 4)|0;
     $168 = $167;
     HEAP32[$168>>2] = $164;
     break;
    }
    if ($convex1$0$off0) {
     $201 = !($offset0$0 >= 0.0);
     do {
      if ($201) {
       $204 = !($110 >= 0.0);
       if ($204) {
        $205 = (($this) + 248|0);
        HEAP8[$205>>0] = 0;
        $206 = (($this) + 212|0);
        $250 = $206;
       } else {
        $207 = $126 >= 0.0;
        $phitmp35 = $207&1;
        $208 = (($this) + 248|0);
        HEAP8[$208>>0] = $phitmp35;
        $209 = (($this) + 212|0);
        if ($207) {
         $216 = $209;
         break;
        } else {
         $250 = $209;
        }
       }
       __ZNK6b2Vec2ngEv($8,$105);
       $244 = $8;
       $245 = $244;
       $246 = HEAP32[$245>>2]|0;
       $247 = (($244) + 4)|0;
       $248 = $247;
       $249 = HEAP32[$248>>2]|0;
       $251 = $250;
       $252 = $251;
       HEAP32[$252>>2] = $246;
       $253 = (($251) + 4)|0;
       $254 = $253;
       HEAP32[$254>>2] = $249;
       $255 = (($this) + 228|0);
       $256 = (($this) + 204|0);
       __ZNK6b2Vec2ngEv($9,$256);
       $257 = $9;
       $258 = $257;
       $259 = HEAP32[$258>>2]|0;
       $260 = (($257) + 4)|0;
       $261 = $260;
       $262 = HEAP32[$261>>2]|0;
       $263 = $255;
       $264 = $263;
       HEAP32[$264>>2] = $259;
       $265 = (($263) + 4)|0;
       $266 = $265;
       HEAP32[$266>>2] = $262;
       $267 = (($this) + 236|0);
       __ZNK6b2Vec2ngEv($10,$105);
       $268 = $10;
       $269 = $268;
       $270 = HEAP32[$269>>2]|0;
       $271 = (($268) + 4)|0;
       $272 = $271;
       $273 = HEAP32[$272>>2]|0;
       $274 = $267;
       $275 = $274;
       HEAP32[$275>>2] = $270;
       $276 = (($274) + 4)|0;
       $277 = $276;
       HEAP32[$277>>2] = $273;
       break L4;
      } else {
       $202 = (($this) + 248|0);
       HEAP8[$202>>0] = 1;
       $203 = (($this) + 212|0);
       $216 = $203;
      }
     } while(0);
     $210 = $105;
     $211 = $210;
     $212 = HEAP32[$211>>2]|0;
     $213 = (($210) + 4)|0;
     $214 = $213;
     $215 = HEAP32[$214>>2]|0;
     $217 = $216;
     $218 = $217;
     HEAP32[$218>>2] = $212;
     $219 = (($217) + 4)|0;
     $220 = $219;
     HEAP32[$220>>2] = $215;
     $221 = (($this) + 228|0);
     $222 = (($this) + 188|0);
     $223 = $222;
     $224 = $223;
     $225 = HEAP32[$224>>2]|0;
     $226 = (($223) + 4)|0;
     $227 = $226;
     $228 = HEAP32[$227>>2]|0;
     $229 = $221;
     $230 = $229;
     HEAP32[$230>>2] = $225;
     $231 = (($229) + 4)|0;
     $232 = $231;
     HEAP32[$232>>2] = $228;
     $233 = (($this) + 236|0);
     $234 = $105;
     $235 = $234;
     $236 = HEAP32[$235>>2]|0;
     $237 = (($234) + 4)|0;
     $238 = $237;
     $239 = HEAP32[$238>>2]|0;
     $240 = $233;
     $241 = $240;
     HEAP32[$241>>2] = $236;
     $242 = (($240) + 4)|0;
     $243 = $242;
     HEAP32[$243>>2] = $239;
     break;
    }
    if (!($125)) {
     $355 = $offset0$0 >= 0.0;
     $356 = $110 >= 0.0;
     $or$cond3 = $355 & $356;
     if ($or$cond3) {
      $359 = $126 >= 0.0;
      $phitmp27 = $359&1;
      $360 = (($this) + 248|0);
      HEAP8[$360>>0] = $phitmp27;
      $361 = (($this) + 212|0);
      if ($359) {
       $362 = $105;
       $363 = $362;
       $364 = HEAP32[$363>>2]|0;
       $365 = (($362) + 4)|0;
       $366 = $365;
       $367 = HEAP32[$366>>2]|0;
       $368 = $361;
       $369 = $368;
       HEAP32[$369>>2] = $364;
       $370 = (($368) + 4)|0;
       $371 = $370;
       HEAP32[$371>>2] = $367;
       $372 = (($this) + 228|0);
       $373 = $105;
       $374 = $373;
       $375 = HEAP32[$374>>2]|0;
       $376 = (($373) + 4)|0;
       $377 = $376;
       $378 = HEAP32[$377>>2]|0;
       $379 = $372;
       $380 = $379;
       HEAP32[$380>>2] = $375;
       $381 = (($379) + 4)|0;
       $382 = $381;
       HEAP32[$382>>2] = $378;
       $383 = (($this) + 236|0);
       $384 = $105;
       $385 = $384;
       $386 = HEAP32[$385>>2]|0;
       $387 = (($384) + 4)|0;
       $388 = $387;
       $389 = HEAP32[$388>>2]|0;
       $390 = $383;
       $391 = $390;
       HEAP32[$391>>2] = $386;
       $392 = (($390) + 4)|0;
       $393 = $392;
       HEAP32[$393>>2] = $389;
       break;
      } else {
       $400 = $361;
      }
     } else {
      $357 = (($this) + 248|0);
      HEAP8[$357>>0] = 0;
      $358 = (($this) + 212|0);
      $400 = $358;
     }
     __ZNK6b2Vec2ngEv($14,$105);
     $394 = $14;
     $395 = $394;
     $396 = HEAP32[$395>>2]|0;
     $397 = (($394) + 4)|0;
     $398 = $397;
     $399 = HEAP32[$398>>2]|0;
     $401 = $400;
     $402 = $401;
     HEAP32[$402>>2] = $396;
     $403 = (($401) + 4)|0;
     $404 = $403;
     HEAP32[$404>>2] = $399;
     $405 = (($this) + 228|0);
     $406 = (($this) + 204|0);
     __ZNK6b2Vec2ngEv($15,$406);
     $407 = $15;
     $408 = $407;
     $409 = HEAP32[$408>>2]|0;
     $410 = (($407) + 4)|0;
     $411 = $410;
     $412 = HEAP32[$411>>2]|0;
     $413 = $405;
     $414 = $413;
     HEAP32[$414>>2] = $409;
     $415 = (($413) + 4)|0;
     $416 = $415;
     HEAP32[$416>>2] = $412;
     $417 = (($this) + 236|0);
     $418 = (($this) + 188|0);
     __ZNK6b2Vec2ngEv($16,$418);
     $419 = $16;
     $420 = $419;
     $421 = HEAP32[$420>>2]|0;
     $422 = (($419) + 4)|0;
     $423 = $422;
     $424 = HEAP32[$423>>2]|0;
     $425 = $417;
     $426 = $425;
     HEAP32[$426>>2] = $421;
     $427 = (($425) + 4)|0;
     $428 = $427;
     HEAP32[$428>>2] = $424;
     break;
    }
    $278 = !($126 >= 0.0);
    do {
     if ($278) {
      $281 = !($offset0$0 >= 0.0);
      if ($281) {
       $282 = (($this) + 248|0);
       HEAP8[$282>>0] = 0;
       $283 = (($this) + 212|0);
       $327 = $283;
      } else {
       $284 = $110 >= 0.0;
       $phitmp31 = $284&1;
       $285 = (($this) + 248|0);
       HEAP8[$285>>0] = $phitmp31;
       $286 = (($this) + 212|0);
       if ($284) {
        $293 = $286;
        break;
       } else {
        $327 = $286;
       }
      }
      __ZNK6b2Vec2ngEv($11,$105);
      $321 = $11;
      $322 = $321;
      $323 = HEAP32[$322>>2]|0;
      $324 = (($321) + 4)|0;
      $325 = $324;
      $326 = HEAP32[$325>>2]|0;
      $328 = $327;
      $329 = $328;
      HEAP32[$329>>2] = $323;
      $330 = (($328) + 4)|0;
      $331 = $330;
      HEAP32[$331>>2] = $326;
      $332 = (($this) + 228|0);
      __ZNK6b2Vec2ngEv($12,$105);
      $333 = $12;
      $334 = $333;
      $335 = HEAP32[$334>>2]|0;
      $336 = (($333) + 4)|0;
      $337 = $336;
      $338 = HEAP32[$337>>2]|0;
      $339 = $332;
      $340 = $339;
      HEAP32[$340>>2] = $335;
      $341 = (($339) + 4)|0;
      $342 = $341;
      HEAP32[$342>>2] = $338;
      $343 = (($this) + 236|0);
      $344 = (($this) + 188|0);
      __ZNK6b2Vec2ngEv($13,$344);
      $345 = $13;
      $346 = $345;
      $347 = HEAP32[$346>>2]|0;
      $348 = (($345) + 4)|0;
      $349 = $348;
      $350 = HEAP32[$349>>2]|0;
      $351 = $343;
      $352 = $351;
      HEAP32[$352>>2] = $347;
      $353 = (($351) + 4)|0;
      $354 = $353;
      HEAP32[$354>>2] = $350;
      break L4;
     } else {
      $279 = (($this) + 248|0);
      HEAP8[$279>>0] = 1;
      $280 = (($this) + 212|0);
      $293 = $280;
     }
    } while(0);
    $287 = $105;
    $288 = $287;
    $289 = HEAP32[$288>>2]|0;
    $290 = (($287) + 4)|0;
    $291 = $290;
    $292 = HEAP32[$291>>2]|0;
    $294 = $293;
    $295 = $294;
    HEAP32[$295>>2] = $289;
    $296 = (($294) + 4)|0;
    $297 = $296;
    HEAP32[$297>>2] = $292;
    $298 = (($this) + 228|0);
    $299 = $105;
    $300 = $299;
    $301 = HEAP32[$300>>2]|0;
    $302 = (($299) + 4)|0;
    $303 = $302;
    $304 = HEAP32[$303>>2]|0;
    $305 = $298;
    $306 = $305;
    HEAP32[$306>>2] = $301;
    $307 = (($305) + 4)|0;
    $308 = $307;
    HEAP32[$308>>2] = $304;
    $309 = (($this) + 236|0);
    $310 = (($this) + 204|0);
    $311 = $310;
    $312 = $311;
    $313 = HEAP32[$312>>2]|0;
    $314 = (($311) + 4)|0;
    $315 = $314;
    $316 = HEAP32[$315>>2]|0;
    $317 = $309;
    $318 = $317;
    HEAP32[$318>>2] = $313;
    $319 = (($317) + 4)|0;
    $320 = $319;
    HEAP32[$320>>2] = $316;
   } else {
    $convex2$0$off049 = $125;$offset2$050 = $126;
    label = 32;
   }
  } else {
   $convex2$0$off049 = 0;$offset2$050 = 0.0;
   label = 32;
  }
 } while(0);
 do {
  if ((label|0) == 32) {
   if ($101) {
    $429 = $offset0$0 >= 0.0;
    if ($convex1$0$off0) {
     if ($429) {
      $430 = (($this) + 248|0);
      HEAP8[$430>>0] = 1;
      $431 = (($this) + 212|0);
      $441 = $431;
     } else {
      $432 = $110 >= 0.0;
      $phitmp23 = $432&1;
      $433 = (($this) + 248|0);
      HEAP8[$433>>0] = $phitmp23;
      $434 = (($this) + 212|0);
      if ($432) {
       $441 = $434;
      } else {
       __ZNK6b2Vec2ngEv($18,$105);
       $469 = $18;
       $470 = $469;
       $471 = HEAP32[$470>>2]|0;
       $472 = (($469) + 4)|0;
       $473 = $472;
       $474 = HEAP32[$473>>2]|0;
       $475 = $434;
       $476 = $475;
       HEAP32[$476>>2] = $471;
       $477 = (($475) + 4)|0;
       $478 = $477;
       HEAP32[$478>>2] = $474;
       $479 = (($this) + 228|0);
       $480 = $105;
       $481 = $480;
       $482 = HEAP32[$481>>2]|0;
       $483 = (($480) + 4)|0;
       $484 = $483;
       $485 = HEAP32[$484>>2]|0;
       $486 = $479;
       $487 = $486;
       HEAP32[$487>>2] = $482;
       $488 = (($486) + 4)|0;
       $489 = $488;
       HEAP32[$489>>2] = $485;
       $490 = (($this) + 236|0);
       __ZNK6b2Vec2ngEv($19,$105);
       $491 = $19;
       $492 = $491;
       $493 = HEAP32[$492>>2]|0;
       $494 = (($491) + 4)|0;
       $495 = $494;
       $496 = HEAP32[$495>>2]|0;
       $497 = $490;
       $498 = $497;
       HEAP32[$498>>2] = $493;
       $499 = (($497) + 4)|0;
       $500 = $499;
       HEAP32[$500>>2] = $496;
       break;
      }
     }
     $435 = $105;
     $436 = $435;
     $437 = HEAP32[$436>>2]|0;
     $438 = (($435) + 4)|0;
     $439 = $438;
     $440 = HEAP32[$439>>2]|0;
     $442 = $441;
     $443 = $442;
     HEAP32[$443>>2] = $437;
     $444 = (($442) + 4)|0;
     $445 = $444;
     HEAP32[$445>>2] = $440;
     $446 = (($this) + 228|0);
     $447 = (($this) + 188|0);
     $448 = $447;
     $449 = $448;
     $450 = HEAP32[$449>>2]|0;
     $451 = (($448) + 4)|0;
     $452 = $451;
     $453 = HEAP32[$452>>2]|0;
     $454 = $446;
     $455 = $454;
     HEAP32[$455>>2] = $450;
     $456 = (($454) + 4)|0;
     $457 = $456;
     HEAP32[$457>>2] = $453;
     $458 = (($this) + 236|0);
     __ZNK6b2Vec2ngEv($17,$105);
     $459 = $17;
     $460 = $459;
     $461 = HEAP32[$460>>2]|0;
     $462 = (($459) + 4)|0;
     $463 = $462;
     $464 = HEAP32[$463>>2]|0;
     $465 = $458;
     $466 = $465;
     HEAP32[$466>>2] = $461;
     $467 = (($465) + 4)|0;
     $468 = $467;
     HEAP32[$468>>2] = $464;
     break;
    } else {
     if ($429) {
      $503 = $110 >= 0.0;
      $phitmp19 = $503&1;
      $504 = (($this) + 248|0);
      HEAP8[$504>>0] = $phitmp19;
      $505 = (($this) + 212|0);
      if ($503) {
       $506 = $105;
       $507 = $506;
       $508 = HEAP32[$507>>2]|0;
       $509 = (($506) + 4)|0;
       $510 = $509;
       $511 = HEAP32[$510>>2]|0;
       $512 = $505;
       $513 = $512;
       HEAP32[$513>>2] = $508;
       $514 = (($512) + 4)|0;
       $515 = $514;
       HEAP32[$515>>2] = $511;
       $516 = (($this) + 228|0);
       $517 = $105;
       $518 = $517;
       $519 = HEAP32[$518>>2]|0;
       $520 = (($517) + 4)|0;
       $521 = $520;
       $522 = HEAP32[$521>>2]|0;
       $523 = $516;
       $524 = $523;
       HEAP32[$524>>2] = $519;
       $525 = (($523) + 4)|0;
       $526 = $525;
       HEAP32[$526>>2] = $522;
       $527 = (($this) + 236|0);
       __ZNK6b2Vec2ngEv($20,$105);
       $528 = $20;
       $529 = $528;
       $530 = HEAP32[$529>>2]|0;
       $531 = (($528) + 4)|0;
       $532 = $531;
       $533 = HEAP32[$532>>2]|0;
       $534 = $527;
       $535 = $534;
       HEAP32[$535>>2] = $530;
       $536 = (($534) + 4)|0;
       $537 = $536;
       HEAP32[$537>>2] = $533;
       break;
      } else {
       $544 = $505;
      }
     } else {
      $501 = (($this) + 248|0);
      HEAP8[$501>>0] = 0;
      $502 = (($this) + 212|0);
      $544 = $502;
     }
     __ZNK6b2Vec2ngEv($21,$105);
     $538 = $21;
     $539 = $538;
     $540 = HEAP32[$539>>2]|0;
     $541 = (($538) + 4)|0;
     $542 = $541;
     $543 = HEAP32[$542>>2]|0;
     $545 = $544;
     $546 = $545;
     HEAP32[$546>>2] = $540;
     $547 = (($545) + 4)|0;
     $548 = $547;
     HEAP32[$548>>2] = $543;
     $549 = (($this) + 228|0);
     $550 = $105;
     $551 = $550;
     $552 = HEAP32[$551>>2]|0;
     $553 = (($550) + 4)|0;
     $554 = $553;
     $555 = HEAP32[$554>>2]|0;
     $556 = $549;
     $557 = $556;
     HEAP32[$557>>2] = $552;
     $558 = (($556) + 4)|0;
     $559 = $558;
     HEAP32[$559>>2] = $555;
     $560 = (($this) + 236|0);
     $561 = (($this) + 188|0);
     __ZNK6b2Vec2ngEv($22,$561);
     $562 = $22;
     $563 = $562;
     $564 = HEAP32[$563>>2]|0;
     $565 = (($562) + 4)|0;
     $566 = $565;
     $567 = HEAP32[$566>>2]|0;
     $568 = $560;
     $569 = $568;
     HEAP32[$569>>2] = $564;
     $570 = (($568) + 4)|0;
     $571 = $570;
     HEAP32[$571>>2] = $567;
     break;
    }
   }
   $572 = $110 >= 0.0;
   if (!($104)) {
    $715 = (($this) + 248|0);
    $716 = $572&1;
    HEAP8[$715>>0] = $716;
    $717 = (($this) + 212|0);
    if ($572) {
     $718 = $105;
     $719 = $718;
     $720 = HEAP32[$719>>2]|0;
     $721 = (($718) + 4)|0;
     $722 = $721;
     $723 = HEAP32[$722>>2]|0;
     $724 = $717;
     $725 = $724;
     HEAP32[$725>>2] = $720;
     $726 = (($724) + 4)|0;
     $727 = $726;
     HEAP32[$727>>2] = $723;
     $728 = (($this) + 228|0);
     __ZNK6b2Vec2ngEv($29,$105);
     $729 = $29;
     $730 = $729;
     $731 = HEAP32[$730>>2]|0;
     $732 = (($729) + 4)|0;
     $733 = $732;
     $734 = HEAP32[$733>>2]|0;
     $735 = $728;
     $736 = $735;
     HEAP32[$736>>2] = $731;
     $737 = (($735) + 4)|0;
     $738 = $737;
     HEAP32[$738>>2] = $734;
     $739 = (($this) + 236|0);
     __ZNK6b2Vec2ngEv($30,$105);
     $740 = $30;
     $741 = $740;
     $742 = HEAP32[$741>>2]|0;
     $743 = (($740) + 4)|0;
     $744 = $743;
     $745 = HEAP32[$744>>2]|0;
     $746 = $739;
     $747 = $746;
     HEAP32[$747>>2] = $742;
     $748 = (($746) + 4)|0;
     $749 = $748;
     HEAP32[$749>>2] = $745;
     break;
    } else {
     __ZNK6b2Vec2ngEv($31,$105);
     $750 = $31;
     $751 = $750;
     $752 = HEAP32[$751>>2]|0;
     $753 = (($750) + 4)|0;
     $754 = $753;
     $755 = HEAP32[$754>>2]|0;
     $756 = $717;
     $757 = $756;
     HEAP32[$757>>2] = $752;
     $758 = (($756) + 4)|0;
     $759 = $758;
     HEAP32[$759>>2] = $755;
     $760 = (($this) + 228|0);
     $761 = $105;
     $762 = $761;
     $763 = HEAP32[$762>>2]|0;
     $764 = (($761) + 4)|0;
     $765 = $764;
     $766 = HEAP32[$765>>2]|0;
     $767 = $760;
     $768 = $767;
     HEAP32[$768>>2] = $763;
     $769 = (($767) + 4)|0;
     $770 = $769;
     HEAP32[$770>>2] = $766;
     $771 = (($this) + 236|0);
     $772 = $105;
     $773 = $772;
     $774 = HEAP32[$773>>2]|0;
     $775 = (($772) + 4)|0;
     $776 = $775;
     $777 = HEAP32[$776>>2]|0;
     $778 = $771;
     $779 = $778;
     HEAP32[$779>>2] = $774;
     $780 = (($778) + 4)|0;
     $781 = $780;
     HEAP32[$781>>2] = $777;
     break;
    }
   }
   if ($convex2$0$off049) {
    if ($572) {
     $573 = (($this) + 248|0);
     HEAP8[$573>>0] = 1;
     $574 = (($this) + 212|0);
     $584 = $574;
    } else {
     $575 = $offset2$050 >= 0.0;
     $phitmp15 = $575&1;
     $576 = (($this) + 248|0);
     HEAP8[$576>>0] = $phitmp15;
     $577 = (($this) + 212|0);
     if ($575) {
      $584 = $577;
     } else {
      __ZNK6b2Vec2ngEv($24,$105);
      $612 = $24;
      $613 = $612;
      $614 = HEAP32[$613>>2]|0;
      $615 = (($612) + 4)|0;
      $616 = $615;
      $617 = HEAP32[$616>>2]|0;
      $618 = $577;
      $619 = $618;
      HEAP32[$619>>2] = $614;
      $620 = (($618) + 4)|0;
      $621 = $620;
      HEAP32[$621>>2] = $617;
      $622 = (($this) + 228|0);
      __ZNK6b2Vec2ngEv($25,$105);
      $623 = $25;
      $624 = $623;
      $625 = HEAP32[$624>>2]|0;
      $626 = (($623) + 4)|0;
      $627 = $626;
      $628 = HEAP32[$627>>2]|0;
      $629 = $622;
      $630 = $629;
      HEAP32[$630>>2] = $625;
      $631 = (($629) + 4)|0;
      $632 = $631;
      HEAP32[$632>>2] = $628;
      $633 = (($this) + 236|0);
      $634 = $105;
      $635 = $634;
      $636 = HEAP32[$635>>2]|0;
      $637 = (($634) + 4)|0;
      $638 = $637;
      $639 = HEAP32[$638>>2]|0;
      $640 = $633;
      $641 = $640;
      HEAP32[$641>>2] = $636;
      $642 = (($640) + 4)|0;
      $643 = $642;
      HEAP32[$643>>2] = $639;
      break;
     }
    }
    $578 = $105;
    $579 = $578;
    $580 = HEAP32[$579>>2]|0;
    $581 = (($578) + 4)|0;
    $582 = $581;
    $583 = HEAP32[$582>>2]|0;
    $585 = $584;
    $586 = $585;
    HEAP32[$586>>2] = $580;
    $587 = (($585) + 4)|0;
    $588 = $587;
    HEAP32[$588>>2] = $583;
    $589 = (($this) + 228|0);
    __ZNK6b2Vec2ngEv($23,$105);
    $590 = $23;
    $591 = $590;
    $592 = HEAP32[$591>>2]|0;
    $593 = (($590) + 4)|0;
    $594 = $593;
    $595 = HEAP32[$594>>2]|0;
    $596 = $589;
    $597 = $596;
    HEAP32[$597>>2] = $592;
    $598 = (($596) + 4)|0;
    $599 = $598;
    HEAP32[$599>>2] = $595;
    $600 = (($this) + 236|0);
    $601 = (($this) + 204|0);
    $602 = $601;
    $603 = $602;
    $604 = HEAP32[$603>>2]|0;
    $605 = (($602) + 4)|0;
    $606 = $605;
    $607 = HEAP32[$606>>2]|0;
    $608 = $600;
    $609 = $608;
    HEAP32[$609>>2] = $604;
    $610 = (($608) + 4)|0;
    $611 = $610;
    HEAP32[$611>>2] = $607;
    break;
   } else {
    if ($572) {
     $646 = $offset2$050 >= 0.0;
     $phitmp = $646&1;
     $647 = (($this) + 248|0);
     HEAP8[$647>>0] = $phitmp;
     $648 = (($this) + 212|0);
     if ($646) {
      $649 = $105;
      $650 = $649;
      $651 = HEAP32[$650>>2]|0;
      $652 = (($649) + 4)|0;
      $653 = $652;
      $654 = HEAP32[$653>>2]|0;
      $655 = $648;
      $656 = $655;
      HEAP32[$656>>2] = $651;
      $657 = (($655) + 4)|0;
      $658 = $657;
      HEAP32[$658>>2] = $654;
      $659 = (($this) + 228|0);
      __ZNK6b2Vec2ngEv($26,$105);
      $660 = $26;
      $661 = $660;
      $662 = HEAP32[$661>>2]|0;
      $663 = (($660) + 4)|0;
      $664 = $663;
      $665 = HEAP32[$664>>2]|0;
      $666 = $659;
      $667 = $666;
      HEAP32[$667>>2] = $662;
      $668 = (($666) + 4)|0;
      $669 = $668;
      HEAP32[$669>>2] = $665;
      $670 = (($this) + 236|0);
      $671 = $105;
      $672 = $671;
      $673 = HEAP32[$672>>2]|0;
      $674 = (($671) + 4)|0;
      $675 = $674;
      $676 = HEAP32[$675>>2]|0;
      $677 = $670;
      $678 = $677;
      HEAP32[$678>>2] = $673;
      $679 = (($677) + 4)|0;
      $680 = $679;
      HEAP32[$680>>2] = $676;
      break;
     } else {
      $687 = $648;
     }
    } else {
     $644 = (($this) + 248|0);
     HEAP8[$644>>0] = 0;
     $645 = (($this) + 212|0);
     $687 = $645;
    }
    __ZNK6b2Vec2ngEv($27,$105);
    $681 = $27;
    $682 = $681;
    $683 = HEAP32[$682>>2]|0;
    $684 = (($681) + 4)|0;
    $685 = $684;
    $686 = HEAP32[$685>>2]|0;
    $688 = $687;
    $689 = $688;
    HEAP32[$689>>2] = $683;
    $690 = (($688) + 4)|0;
    $691 = $690;
    HEAP32[$691>>2] = $686;
    $692 = (($this) + 228|0);
    $693 = (($this) + 204|0);
    __ZNK6b2Vec2ngEv($28,$693);
    $694 = $28;
    $695 = $694;
    $696 = HEAP32[$695>>2]|0;
    $697 = (($694) + 4)|0;
    $698 = $697;
    $699 = HEAP32[$698>>2]|0;
    $700 = $692;
    $701 = $700;
    HEAP32[$701>>2] = $696;
    $702 = (($700) + 4)|0;
    $703 = $702;
    HEAP32[$703>>2] = $699;
    $704 = (($this) + 236|0);
    $705 = $105;
    $706 = $705;
    $707 = HEAP32[$706>>2]|0;
    $708 = (($705) + 4)|0;
    $709 = $708;
    $710 = HEAP32[$709>>2]|0;
    $711 = $704;
    $712 = $711;
    HEAP32[$712>>2] = $707;
    $713 = (($711) + 4)|0;
    $714 = $713;
    HEAP32[$714>>2] = $710;
    break;
   }
  }
 } while(0);
 $782 = (($polygonB) + 148|0);
 $783 = HEAP32[$782>>2]|0;
 $784 = (($this) + 128|0);
 HEAP32[$784>>2] = $783;
 $785 = HEAP32[$782>>2]|0;
 $786 = ($785|0)>(0);
 if ($786) {
  $787 = (($this) + 140|0);
  $i$068 = 0;
  while(1) {
   $788 = (($this) + ($i$068<<3)|0);
   $789 = ((($polygonB) + ($i$068<<3)|0) + 20|0);
   __Z5b2MulRK11b2TransformRK6b2Vec2($32,$38,$789);
   $790 = $32;
   $791 = $790;
   $792 = HEAP32[$791>>2]|0;
   $793 = (($790) + 4)|0;
   $794 = $793;
   $795 = HEAP32[$794>>2]|0;
   $796 = $788;
   $797 = $796;
   HEAP32[$797>>2] = $792;
   $798 = (($796) + 4)|0;
   $799 = $798;
   HEAP32[$799>>2] = $795;
   $800 = ((($this) + ($i$068<<3)|0) + 64|0);
   $801 = ((($polygonB) + ($i$068<<3)|0) + 84|0);
   __Z5b2MulRK5b2RotRK6b2Vec2($33,$787,$801);
   $802 = $33;
   $803 = $802;
   $804 = HEAP32[$803>>2]|0;
   $805 = (($802) + 4)|0;
   $806 = $805;
   $807 = HEAP32[$806>>2]|0;
   $808 = $800;
   $809 = $808;
   HEAP32[$809>>2] = $804;
   $810 = (($808) + 4)|0;
   $811 = $810;
   HEAP32[$811>>2] = $807;
   $812 = (($i$068) + 1)|0;
   $813 = HEAP32[$782>>2]|0;
   $814 = ($812|0)<($813|0);
   if ($814) {
    $i$068 = $812;
   } else {
    break;
   }
  }
 }
 $815 = (($this) + 244|0);
 HEAPF32[$815>>2] = 0.019999999552965164;
 $816 = (($manifold) + 60|0);
 HEAP32[$816>>2] = 0;
 __ZN12b2EPCollider21ComputeEdgeSeparationEv($edgeAxis,$this);
 $817 = HEAP32[$edgeAxis>>2]|0;
 $818 = ($817|0)==(0);
 if ($818) {
  STACKTOP = sp;return;
 }
 $819 = (($edgeAxis) + 8|0);
 $820 = +HEAPF32[$819>>2];
 $821 = +HEAPF32[$815>>2];
 $822 = $820 > $821;
 if ($822) {
  STACKTOP = sp;return;
 }
 __ZN12b2EPCollider24ComputePolygonSeparationEv($polygonAxis,$this);
 $823 = HEAP32[$polygonAxis>>2]|0;
 $824 = ($823|0)==(0);
 do {
  if ($824) {
   label = 67;
  } else {
   $825 = (($polygonAxis) + 8|0);
   $826 = +HEAPF32[$825>>2];
   $827 = +HEAPF32[$815>>2];
   $828 = $826 > $827;
   if ($828) {
    STACKTOP = sp;return;
   }
   $$pr = HEAP32[$polygonAxis>>2]|0;
   $829 = ($$pr|0)==(0);
   if ($829) {
    label = 67;
   } else {
    $833 = (($polygonAxis) + 8|0);
    $834 = +HEAPF32[$833>>2];
    $835 = +HEAPF32[$819>>2];
    $836 = $835 * 0.98000001907348633;
    $837 = $836 + 0.0010000000474974513;
    $838 = $834 > $837;
    if ($838) {
     $839 = (($polygonAxis) + 4|0);
     $840 = HEAP32[$839>>2]|0;
     $primaryAxis$sroa$0$0 = $$pr;$primaryAxis$sroa$6$0 = $840;
     break;
    } else {
     $841 = HEAP32[$edgeAxis>>2]|0;
     $842 = (($edgeAxis) + 4|0);
     $843 = HEAP32[$842>>2]|0;
     $primaryAxis$sroa$0$0 = $841;$primaryAxis$sroa$6$0 = $843;
     break;
    }
   }
  }
 } while(0);
 if ((label|0) == 67) {
  $830 = HEAP32[$edgeAxis>>2]|0;
  $831 = (($edgeAxis) + 4|0);
  $832 = HEAP32[$831>>2]|0;
  $primaryAxis$sroa$0$0 = $830;$primaryAxis$sroa$6$0 = $832;
 }
 $844 = ($primaryAxis$sroa$0$0|0)==(1);
 $845 = (($manifold) + 56|0);
 do {
  if ($844) {
   HEAP32[$845>>2] = 1;
   $846 = (($this) + 212|0);
   $847 = HEAP32[$784>>2]|0;
   $848 = ($847|0)>(1);
   if ($848) {
    $849 = (($this) + 64|0);
    $850 = (+__Z5b2DotRK6b2Vec2S1_($846,$849));
    $851 = HEAP32[$784>>2]|0;
    $bestIndex$064 = 0;$bestValue$065 = $850;$i1$066 = 1;
    while(1) {
     $852 = ((($this) + ($i1$066<<3)|0) + 64|0);
     $853 = (+__Z5b2DotRK6b2Vec2S1_($846,$852));
     $854 = $853 < $bestValue$065;
     $bestIndex$1 = $854 ? $i1$066 : $bestIndex$064;
     $bestValue$1 = $854 ? $853 : $bestValue$065;
     $855 = (($i1$066) + 1)|0;
     $856 = ($855|0)<($851|0);
     if ($856) {
      $bestIndex$064 = $bestIndex$1;$bestValue$065 = $bestValue$1;$i1$066 = $855;
     } else {
      $$lcssa = $851;$bestIndex$0$lcssa = $bestIndex$1;
      break;
     }
    }
   } else {
    $$lcssa = $847;$bestIndex$0$lcssa = 0;
   }
   $857 = (($bestIndex$0$lcssa) + 1)|0;
   $858 = ($857|0)<($$lcssa|0);
   $$ = $858 ? $857 : 0;
   $859 = (($this) + ($bestIndex$0$lcssa<<3)|0);
   $860 = $859;
   $861 = $860;
   $862 = HEAP32[$861>>2]|0;
   $863 = (($860) + 4)|0;
   $864 = $863;
   $865 = HEAP32[$864>>2]|0;
   $866 = $ie;
   $867 = $866;
   HEAP32[$867>>2] = $862;
   $868 = (($866) + 4)|0;
   $869 = $868;
   HEAP32[$869>>2] = $865;
   $870 = (($ie) + 8|0);
   HEAP8[$870>>0] = 0;
   $871 = $bestIndex$0$lcssa&255;
   $872 = (($870) + 1|0);
   HEAP8[$872>>0] = $871;
   $873 = (($870) + 2|0);
   HEAP8[$873>>0] = 1;
   $874 = (($870) + 3|0);
   HEAP8[$874>>0] = 0;
   $875 = (($ie) + 12|0);
   $876 = (($this) + ($$<<3)|0);
   $877 = $876;
   $878 = $877;
   $879 = HEAP32[$878>>2]|0;
   $880 = (($877) + 4)|0;
   $881 = $880;
   $882 = HEAP32[$881>>2]|0;
   $883 = $875;
   $884 = $883;
   HEAP32[$884>>2] = $879;
   $885 = (($883) + 4)|0;
   $886 = $885;
   HEAP32[$886>>2] = $882;
   $887 = (($ie) + 20|0);
   HEAP8[$887>>0] = 0;
   $888 = $$&255;
   $889 = (($887) + 1|0);
   HEAP8[$889>>0] = $888;
   $890 = (($887) + 2|0);
   HEAP8[$890>>0] = 1;
   $891 = (($887) + 3|0);
   HEAP8[$891>>0] = 0;
   $892 = (($this) + 248|0);
   $893 = HEAP8[$892>>0]|0;
   $894 = ($893<<24>>24)==(0);
   if ($894) {
    HEAP32[$rf>>2] = 1;
    $929 = (($rf) + 4|0);
    HEAP32[$929>>2] = 0;
    $930 = (($rf) + 8|0);
    $931 = $75;
    $932 = $931;
    $933 = HEAP32[$932>>2]|0;
    $934 = (($931) + 4)|0;
    $935 = $934;
    $936 = HEAP32[$935>>2]|0;
    $937 = $930;
    $938 = $937;
    HEAP32[$938>>2] = $933;
    $939 = (($937) + 4)|0;
    $940 = $939;
    HEAP32[$940>>2] = $936;
    $941 = (($rf) + 16|0);
    $942 = $63;
    $943 = $942;
    $944 = HEAP32[$943>>2]|0;
    $945 = (($942) + 4)|0;
    $946 = $945;
    $947 = HEAP32[$946>>2]|0;
    $948 = $941;
    $949 = $948;
    HEAP32[$949>>2] = $944;
    $950 = (($948) + 4)|0;
    $951 = $950;
    HEAP32[$951>>2] = $947;
    $952 = (($rf) + 24|0);
    __ZNK6b2Vec2ngEv($34,$105);
    $953 = $34;
    $954 = $953;
    $955 = HEAP32[$954>>2]|0;
    $956 = (($953) + 4)|0;
    $957 = $956;
    $958 = HEAP32[$957>>2]|0;
    $959 = $952;
    $960 = $959;
    HEAP32[$960>>2] = $955;
    $961 = (($959) + 4)|0;
    $962 = $961;
    HEAP32[$962>>2] = $958;
    break;
   } else {
    HEAP32[$rf>>2] = 0;
    $895 = (($rf) + 4|0);
    HEAP32[$895>>2] = 1;
    $896 = (($rf) + 8|0);
    $897 = $63;
    $898 = $897;
    $899 = HEAP32[$898>>2]|0;
    $900 = (($897) + 4)|0;
    $901 = $900;
    $902 = HEAP32[$901>>2]|0;
    $903 = $896;
    $904 = $903;
    HEAP32[$904>>2] = $899;
    $905 = (($903) + 4)|0;
    $906 = $905;
    HEAP32[$906>>2] = $902;
    $907 = (($rf) + 16|0);
    $908 = $75;
    $909 = $908;
    $910 = HEAP32[$909>>2]|0;
    $911 = (($908) + 4)|0;
    $912 = $911;
    $913 = HEAP32[$912>>2]|0;
    $914 = $907;
    $915 = $914;
    HEAP32[$915>>2] = $910;
    $916 = (($914) + 4)|0;
    $917 = $916;
    HEAP32[$917>>2] = $913;
    $918 = (($rf) + 24|0);
    $919 = $105;
    $920 = $919;
    $921 = HEAP32[$920>>2]|0;
    $922 = (($919) + 4)|0;
    $923 = $922;
    $924 = HEAP32[$923>>2]|0;
    $925 = $918;
    $926 = $925;
    HEAP32[$926>>2] = $921;
    $927 = (($925) + 4)|0;
    $928 = $927;
    HEAP32[$928>>2] = $924;
    break;
   }
  } else {
   HEAP32[$845>>2] = 2;
   $963 = $63;
   $964 = $963;
   $965 = HEAP32[$964>>2]|0;
   $966 = (($963) + 4)|0;
   $967 = $966;
   $968 = HEAP32[$967>>2]|0;
   $969 = $ie;
   $970 = $969;
   HEAP32[$970>>2] = $965;
   $971 = (($969) + 4)|0;
   $972 = $971;
   HEAP32[$972>>2] = $968;
   $973 = (($ie) + 8|0);
   HEAP8[$973>>0] = 0;
   $974 = $primaryAxis$sroa$6$0&255;
   $975 = (($973) + 1|0);
   HEAP8[$975>>0] = $974;
   $976 = (($973) + 2|0);
   HEAP8[$976>>0] = 0;
   $977 = (($973) + 3|0);
   HEAP8[$977>>0] = 1;
   $978 = (($ie) + 12|0);
   $979 = $75;
   $980 = $979;
   $981 = HEAP32[$980>>2]|0;
   $982 = (($979) + 4)|0;
   $983 = $982;
   $984 = HEAP32[$983>>2]|0;
   $985 = $978;
   $986 = $985;
   HEAP32[$986>>2] = $981;
   $987 = (($985) + 4)|0;
   $988 = $987;
   HEAP32[$988>>2] = $984;
   $989 = (($ie) + 20|0);
   HEAP8[$989>>0] = 0;
   $990 = (($989) + 1|0);
   HEAP8[$990>>0] = $974;
   $991 = (($989) + 2|0);
   HEAP8[$991>>0] = 0;
   $992 = (($989) + 3|0);
   HEAP8[$992>>0] = 1;
   HEAP32[$rf>>2] = $primaryAxis$sroa$6$0;
   $993 = (($primaryAxis$sroa$6$0) + 1)|0;
   $994 = HEAP32[$784>>2]|0;
   $995 = ($993|0)<($994|0);
   $$45 = $995 ? $993 : 0;
   $996 = (($rf) + 4|0);
   HEAP32[$996>>2] = $$45;
   $997 = (($rf) + 8|0);
   $998 = HEAP32[$rf>>2]|0;
   $999 = (($this) + ($998<<3)|0);
   $1000 = $999;
   $1001 = $1000;
   $1002 = HEAP32[$1001>>2]|0;
   $1003 = (($1000) + 4)|0;
   $1004 = $1003;
   $1005 = HEAP32[$1004>>2]|0;
   $1006 = $997;
   $1007 = $1006;
   HEAP32[$1007>>2] = $1002;
   $1008 = (($1006) + 4)|0;
   $1009 = $1008;
   HEAP32[$1009>>2] = $1005;
   $1010 = (($rf) + 16|0);
   $1011 = HEAP32[$996>>2]|0;
   $1012 = (($this) + ($1011<<3)|0);
   $1013 = $1012;
   $1014 = $1013;
   $1015 = HEAP32[$1014>>2]|0;
   $1016 = (($1013) + 4)|0;
   $1017 = $1016;
   $1018 = HEAP32[$1017>>2]|0;
   $1019 = $1010;
   $1020 = $1019;
   HEAP32[$1020>>2] = $1015;
   $1021 = (($1019) + 4)|0;
   $1022 = $1021;
   HEAP32[$1022>>2] = $1018;
   $1023 = (($rf) + 24|0);
   $1024 = HEAP32[$rf>>2]|0;
   $1025 = ((($this) + ($1024<<3)|0) + 64|0);
   $1026 = $1025;
   $1027 = $1026;
   $1028 = HEAP32[$1027>>2]|0;
   $1029 = (($1026) + 4)|0;
   $1030 = $1029;
   $1031 = HEAP32[$1030>>2]|0;
   $1032 = $1023;
   $1033 = $1032;
   HEAP32[$1033>>2] = $1028;
   $1034 = (($1032) + 4)|0;
   $1035 = $1034;
   HEAP32[$1035>>2] = $1031;
  }
 } while(0);
 $1036 = (($rf) + 32|0);
 $1037 = (($rf) + 24|0);
 $1038 = (($rf) + 28|0);
 $1039 = +HEAPF32[$1038>>2];
 $1040 = +HEAPF32[$1037>>2];
 $1041 = -$1040;
 __ZN6b2Vec23SetEff($1036,$1039,$1041);
 $1042 = (($rf) + 44|0);
 __ZNK6b2Vec2ngEv($35,$1036);
 $1043 = $35;
 $1044 = $1043;
 $1045 = HEAP32[$1044>>2]|0;
 $1046 = (($1043) + 4)|0;
 $1047 = $1046;
 $1048 = HEAP32[$1047>>2]|0;
 $1049 = $1042;
 $1050 = $1049;
 HEAP32[$1050>>2] = $1045;
 $1051 = (($1049) + 4)|0;
 $1052 = $1051;
 HEAP32[$1052>>2] = $1048;
 $1053 = (($rf) + 8|0);
 $1054 = (+__Z5b2DotRK6b2Vec2S1_($1036,$1053));
 $1055 = (($rf) + 40|0);
 HEAPF32[$1055>>2] = $1054;
 $1056 = (($rf) + 16|0);
 $1057 = (+__Z5b2DotRK6b2Vec2S1_($1042,$1056));
 $1058 = (($rf) + 52|0);
 HEAPF32[$1058>>2] = $1057;
 $1059 = +HEAPF32[$1055>>2];
 $1060 = HEAP32[$rf>>2]|0;
 $1061 = (__Z19b2ClipSegmentToLineP12b2ClipVertexPKS_RK6b2Vec2fi($clipPoints1,$ie,$1036,$1059,$1060)|0);
 $1062 = ($1061|0)<(2);
 if ($1062) {
  STACKTOP = sp;return;
 }
 $1063 = +HEAPF32[$1058>>2];
 $1064 = (($rf) + 4|0);
 $1065 = HEAP32[$1064>>2]|0;
 $1066 = (__Z19b2ClipSegmentToLineP12b2ClipVertexPKS_RK6b2Vec2fi($clipPoints2,$clipPoints1,$1042,$1063,$1065)|0);
 $1067 = ($1066|0)<(2);
 if ($1067) {
  STACKTOP = sp;return;
 }
 $1068 = (($manifold) + 40|0);
 if ($844) {
  $1069 = $1037;
  $1070 = $1069;
  $1071 = HEAP32[$1070>>2]|0;
  $1072 = (($1069) + 4)|0;
  $1073 = $1072;
  $1074 = HEAP32[$1073>>2]|0;
  $1075 = $1068;
  $1076 = $1075;
  HEAP32[$1076>>2] = $1071;
  $1077 = (($1075) + 4)|0;
  $1078 = $1077;
  HEAP32[$1078>>2] = $1074;
  $1079 = (($manifold) + 48|0);
  $1080 = $1053;
  $1081 = $1080;
  $1082 = HEAP32[$1081>>2]|0;
  $1083 = (($1080) + 4)|0;
  $1084 = $1083;
  $1085 = HEAP32[$1084>>2]|0;
  $1086 = $1079;
  $1087 = $1086;
  HEAP32[$1087>>2] = $1082;
  $1088 = (($1086) + 4)|0;
  $1089 = $1088;
  HEAP32[$1089>>2] = $1085;
 } else {
  $1090 = HEAP32[$rf>>2]|0;
  $1091 = ((($polygonB) + ($1090<<3)|0) + 84|0);
  $1092 = $1091;
  $1093 = $1092;
  $1094 = HEAP32[$1093>>2]|0;
  $1095 = (($1092) + 4)|0;
  $1096 = $1095;
  $1097 = HEAP32[$1096>>2]|0;
  $1098 = $1068;
  $1099 = $1098;
  HEAP32[$1099>>2] = $1094;
  $1100 = (($1098) + 4)|0;
  $1101 = $1100;
  HEAP32[$1101>>2] = $1097;
  $1102 = (($manifold) + 48|0);
  $1103 = HEAP32[$rf>>2]|0;
  $1104 = ((($polygonB) + ($1103<<3)|0) + 20|0);
  $1105 = $1104;
  $1106 = $1105;
  $1107 = HEAP32[$1106>>2]|0;
  $1108 = (($1105) + 4)|0;
  $1109 = $1108;
  $1110 = HEAP32[$1109>>2]|0;
  $1111 = $1102;
  $1112 = $1111;
  HEAP32[$1112>>2] = $1107;
  $1113 = (($1111) + 4)|0;
  $1114 = $1113;
  HEAP32[$1114>>2] = $1110;
 }
 __ZmiRK6b2Vec2S1_($36,$clipPoints2,$1053);
 $1115 = (+__Z5b2DotRK6b2Vec2S1_($1037,$36));
 $1116 = +HEAPF32[$815>>2];
 $1117 = !($1115 <= $1116);
 do {
  if ($1117) {
   $pointCount$1 = 0;
  } else {
   if ($844) {
    __Z6b2MulTRK11b2TransformRK6b2Vec2($37,$38,$clipPoints2);
    $1118 = $37;
    $1119 = $1118;
    $1120 = HEAP32[$1119>>2]|0;
    $1121 = (($1118) + 4)|0;
    $1122 = $1121;
    $1123 = HEAP32[$1122>>2]|0;
    $1124 = $manifold;
    $1125 = $1124;
    HEAP32[$1125>>2] = $1120;
    $1126 = (($1124) + 4)|0;
    $1127 = $1126;
    HEAP32[$1127>>2] = $1123;
    $1128 = (($clipPoints2) + 8|0);
    $1129 = HEAP32[$1128>>2]|0;
    $1130 = (($manifold) + 16|0);
    HEAP32[$1130>>2] = $1129;
    $pointCount$1 = 1;
    break;
   } else {
    $1131 = $clipPoints2;
    $1132 = $1131;
    $1133 = HEAP32[$1132>>2]|0;
    $1134 = (($1131) + 4)|0;
    $1135 = $1134;
    $1136 = HEAP32[$1135>>2]|0;
    $1137 = $manifold;
    $1138 = $1137;
    HEAP32[$1138>>2] = $1133;
    $1139 = (($1137) + 4)|0;
    $1140 = $1139;
    HEAP32[$1140>>2] = $1136;
    $1141 = (($clipPoints2) + 8|0);
    $1142 = (($1141) + 3|0);
    $1143 = HEAP8[$1142>>0]|0;
    $1144 = (($manifold) + 16|0);
    $1145 = (($1144) + 2|0);
    HEAP8[$1145>>0] = $1143;
    $1146 = (($1141) + 2|0);
    $1147 = HEAP8[$1146>>0]|0;
    $1148 = (($1144) + 3|0);
    HEAP8[$1148>>0] = $1147;
    $1149 = (($1141) + 1|0);
    $1150 = HEAP8[$1149>>0]|0;
    HEAP8[$1144>>0] = $1150;
    $1151 = HEAP8[$1141>>0]|0;
    $1152 = (($1144) + 1|0);
    HEAP8[$1152>>0] = $1151;
    $pointCount$1 = 1;
    break;
   }
  }
 } while(0);
 $1153 = (($clipPoints2) + 12|0);
 __ZmiRK6b2Vec2S1_($36,$1153,$1053);
 $1154 = (+__Z5b2DotRK6b2Vec2S1_($1037,$36));
 $1155 = +HEAPF32[$815>>2];
 $1156 = !($1154 <= $1155);
 if ($1156) {
  $pointCount$1$1 = $pointCount$1;
 } else {
  $1157 = (($manifold) + (($pointCount$1*20)|0)|0);
  if ($844) {
   __Z6b2MulTRK11b2TransformRK6b2Vec2($37,$38,$1153);
   $1180 = $37;
   $1181 = $1180;
   $1182 = HEAP32[$1181>>2]|0;
   $1183 = (($1180) + 4)|0;
   $1184 = $1183;
   $1185 = HEAP32[$1184>>2]|0;
   $1186 = $1157;
   $1187 = $1186;
   HEAP32[$1187>>2] = $1182;
   $1188 = (($1186) + 4)|0;
   $1189 = $1188;
   HEAP32[$1189>>2] = $1185;
   $1190 = (($clipPoints2) + 20|0);
   $1191 = HEAP32[$1190>>2]|0;
   $1192 = ((($manifold) + (($pointCount$1*20)|0)|0) + 16|0);
   HEAP32[$1192>>2] = $1191;
  } else {
   $1158 = $1153;
   $1159 = $1158;
   $1160 = HEAP32[$1159>>2]|0;
   $1161 = (($1158) + 4)|0;
   $1162 = $1161;
   $1163 = HEAP32[$1162>>2]|0;
   $1164 = $1157;
   $1165 = $1164;
   HEAP32[$1165>>2] = $1160;
   $1166 = (($1164) + 4)|0;
   $1167 = $1166;
   HEAP32[$1167>>2] = $1163;
   $1168 = (($clipPoints2) + 20|0);
   $1169 = (($1168) + 3|0);
   $1170 = HEAP8[$1169>>0]|0;
   $1171 = ((($manifold) + (($pointCount$1*20)|0)|0) + 16|0);
   $1172 = (($1171) + 2|0);
   HEAP8[$1172>>0] = $1170;
   $1173 = (($1168) + 2|0);
   $1174 = HEAP8[$1173>>0]|0;
   $1175 = (($1171) + 3|0);
   HEAP8[$1175>>0] = $1174;
   $1176 = (($1168) + 1|0);
   $1177 = HEAP8[$1176>>0]|0;
   HEAP8[$1171>>0] = $1177;
   $1178 = HEAP8[$1168>>0]|0;
   $1179 = (($1171) + 1|0);
   HEAP8[$1179>>0] = $1178;
  }
  $1193 = (($pointCount$1) + 1)|0;
  $pointCount$1$1 = $1193;
 }
 HEAP32[$816>>2] = $pointCount$1$1;
 STACKTOP = sp;return;
}
function __ZN12b2EPCollider21ComputeEdgeSeparationEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 HEAP32[$agg$result>>2] = 1;
 $1 = (($this) + 248|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2 ^ 1;
 $4 = $3&255;
 $5 = (($agg$result) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = (($agg$result) + 8|0);
 HEAPF32[$6>>2] = 3.4028234663852886E+38;
 $7 = (($this) + 128|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)>(0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = (($this) + 212|0);
 $11 = (($this) + 164|0);
 $i$01 = 0;
 while(1) {
  $12 = (($this) + ($i$01<<3)|0);
  __ZmiRK6b2Vec2S1_($0,$12,$11);
  $13 = (+__Z5b2DotRK6b2Vec2S1_($10,$0));
  $14 = +HEAPF32[$6>>2];
  $15 = $13 < $14;
  if ($15) {
   HEAPF32[$6>>2] = $13;
  }
  $16 = (($i$01) + 1)|0;
  $17 = HEAP32[$7>>2]|0;
  $18 = ($16|0)<($17|0);
  if ($18) {
   $i$01 = $16;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12b2EPCollider24ComputePolygonSeparationEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0.0;
 var $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0.0, $i$02 = 0, $n = 0, $perp = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $perp = sp + 40|0;
 $n = sp + 32|0;
 $0 = sp + 24|0;
 $1 = sp + 16|0;
 $2 = sp + 8|0;
 $3 = sp;
 HEAP32[$agg$result>>2] = 0;
 $4 = (($agg$result) + 4|0);
 HEAP32[$4>>2] = -1;
 $5 = (($agg$result) + 8|0);
 HEAPF32[$5>>2] = -3.4028234663852886E+38;
 $6 = (($this) + 212|0);
 $7 = (($this) + 216|0);
 $8 = +HEAPF32[$7>>2];
 $9 = -$8;
 $10 = +HEAPF32[$6>>2];
 __ZN6b2Vec2C2Eff($perp,$9,$10);
 $11 = (($this) + 128|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)>(0);
 if (!($13)) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 164|0);
 $15 = (($this) + 172|0);
 $16 = (($this) + 244|0);
 $17 = (($this) + 228|0);
 $18 = (($this) + 236|0);
 $i$02 = 0;
 while(1) {
  $19 = ((($this) + ($i$02<<3)|0) + 64|0);
  __ZNK6b2Vec2ngEv($n,$19);
  $20 = (($this) + ($i$02<<3)|0);
  __ZmiRK6b2Vec2S1_($0,$20,$14);
  $21 = (+__Z5b2DotRK6b2Vec2S1_($n,$0));
  __ZmiRK6b2Vec2S1_($1,$20,$15);
  $22 = (+__Z5b2DotRK6b2Vec2S1_($n,$1));
  $23 = (+__Z5b2MinIfET_S0_S0_($21,$22));
  $24 = +HEAPF32[$16>>2];
  $25 = $23 > $24;
  if ($25) {
   break;
  }
  $26 = (+__Z5b2DotRK6b2Vec2S1_($n,$perp));
  $27 = !($26 >= 0.0);
  if ($27) {
   __ZmiRK6b2Vec2S1_($3,$n,$17);
   $30 = (+__Z5b2DotRK6b2Vec2S1_($3,$6));
   $31 = $30 < -0.034906588494777679;
   if (!($31)) {
    label = 8;
   }
  } else {
   __ZmiRK6b2Vec2S1_($2,$n,$18);
   $28 = (+__Z5b2DotRK6b2Vec2S1_($2,$6));
   $29 = $28 < -0.034906588494777679;
   if (!($29)) {
    label = 8;
   }
  }
  if ((label|0) == 8) {
   label = 0;
   $32 = +HEAPF32[$5>>2];
   $33 = $23 > $32;
   if ($33) {
    HEAP32[$agg$result>>2] = 2;
    HEAP32[$4>>2] = $i$02;
    HEAPF32[$5>>2] = $23;
   }
  }
  $34 = (($i$02) + 1)|0;
  $35 = HEAP32[$11>>2]|0;
  $36 = ($34|0)<($35|0);
  if ($36) {
   $i$02 = $34;
  } else {
   label = 11;
   break;
  }
 }
 if ((label|0) == 11) {
  STACKTOP = sp;return;
 }
 HEAP32[$agg$result>>2] = 2;
 HEAP32[$4>>2] = $i$02;
 HEAPF32[$5>>2] = $23;
 STACKTOP = sp;return;
}
function __Z23b2CollideEdgeAndPolygonP10b2ManifoldPK11b2EdgeShapeRK11b2TransformPK14b2PolygonShapeS6_($manifold,$edgeA,$xfA,$polygonB,$xfB) {
 $manifold = $manifold|0;
 $edgeA = $edgeA|0;
 $xfA = $xfA|0;
 $polygonB = $polygonB|0;
 $xfB = $xfB|0;
 var $collider = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $collider = sp;
 __ZN12b2EPCollider7CollideEP10b2ManifoldPK11b2EdgeShapeRK11b2TransformPK14b2PolygonShapeS7_($collider,$manifold,$edgeA,$xfA,$polygonB,$xfB);
 STACKTOP = sp;return;
}
function __Z6b2MulTRK11b2TransformS1_($agg$result,$A,$B) {
 $agg$result = $agg$result|0;
 $A = $A|0;
 $B = $B|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = (($agg$result) + 8|0);
 $4 = (($A) + 8|0);
 $5 = (($B) + 8|0);
 __Z6b2MulTRK5b2RotS1_($0,$4,$5);
 $6 = $0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $3;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 __ZmiRK6b2Vec2S1_($2,$B,$A);
 __Z6b2MulTRK5b2RotRK6b2Vec2($1,$4,$2);
 $16 = $1;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16) + 4)|0;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = $agg$result;
 $23 = $22;
 HEAP32[$23>>2] = $18;
 $24 = (($22) + 4)|0;
 $25 = $24;
 HEAP32[$25>>2] = $21;
 STACKTOP = sp;return;
}
function __Z6b2MulTRK5b2RotS1_($agg$result,$q,$r) {
 $agg$result = $agg$result|0;
 $q = $q|0;
 $r = $r|0;
 var $0 = 0, $1 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0, $2 = 0.0, $3 = 0.0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($q) + 4|0);
 $1 = +HEAPF32[$0>>2];
 $2 = +HEAPF32[$r>>2];
 $3 = $1 * $2;
 $4 = +HEAPF32[$q>>2];
 $5 = (($r) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $4 * $6;
 $8 = $3 - $7;
 HEAPF32[$agg$result>>2] = $8;
 $9 = +HEAPF32[$0>>2];
 $10 = +HEAPF32[$5>>2];
 $11 = $9 * $10;
 $12 = +HEAPF32[$q>>2];
 $13 = +HEAPF32[$r>>2];
 $14 = $12 * $13;
 $15 = $11 + $14;
 $16 = (($agg$result) + 4|0);
 HEAPF32[$16>>2] = $15;
 STACKTOP = sp;return;
}
function __Z17b2CollidePolygonsP10b2ManifoldPK14b2PolygonShapeRK11b2TransformS3_S6_($manifold,$polyA,$xfA,$polyB,$xfB) {
 $manifold = $manifold|0;
 $polyA = $polyA|0;
 $xfA = $xfA|0;
 $polyB = $polyB|0;
 $xfB = $xfB|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0.0, $100 = 0.0, $101 = 0.0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0.0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0.0, $125 = 0.0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0.0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $15 = 0.0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0.0, $69 = 0.0, $7 = 0.0, $70 = 0.0, $71 = 0.0;
 var $72 = 0, $73 = 0, $74 = 0.0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0.0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $clipPoints1 = 0, $clipPoints2 = 0, $edge1$0 = 0, $edgeA = 0, $edgeB = 0, $flip$0 = 0, $incidentEdge = 0, $localNormal = 0, $localTangent = 0, $normal = 0;
 var $planePoint = 0, $pointCount$1 = 0, $pointCount$1$1 = 0, $poly1$0 = 0, $poly2$0 = 0, $tangent = 0, $v11 = 0, $v12 = 0, $xf1 = 0, $xf2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $edgeA = sp + 204|0;
 $edgeB = sp + 200|0;
 $xf1 = sp + 184|0;
 $xf2 = sp + 168|0;
 $incidentEdge = sp + 144|0;
 $v11 = sp + 48|0;
 $v12 = sp + 40|0;
 $localTangent = sp + 136|0;
 $localNormal = sp + 32|0;
 $planePoint = sp + 24|0;
 $0 = sp + 128|0;
 $tangent = sp + 120|0;
 $normal = sp + 112|0;
 $1 = sp + 16|0;
 $2 = sp + 8|0;
 $clipPoints1 = sp + 88|0;
 $clipPoints2 = sp + 64|0;
 $3 = sp + 56|0;
 $4 = sp;
 $5 = (($manifold) + 60|0);
 HEAP32[$5>>2] = 0;
 $6 = (($polyA) + 8|0);
 $7 = +HEAPF32[$6>>2];
 $8 = (($polyB) + 8|0);
 $9 = +HEAPF32[$8>>2];
 $10 = $7 + $9;
 HEAP32[$edgeA>>2] = 0;
 $11 = (+__ZL19b2FindMaxSeparationPiPK14b2PolygonShapeRK11b2TransformS2_S5_($edgeA,$polyA,$xfA,$polyB,$xfB));
 $12 = $11 > $10;
 if ($12) {
  STACKTOP = sp;return;
 }
 HEAP32[$edgeB>>2] = 0;
 $13 = (+__ZL19b2FindMaxSeparationPiPK14b2PolygonShapeRK11b2TransformS2_S5_($edgeB,$polyB,$xfB,$polyA,$xfA));
 $14 = $13 > $10;
 if ($14) {
  STACKTOP = sp;return;
 }
 $15 = $11 + 5.0000002374872565E-4;
 $16 = $13 > $15;
 if ($16) {
  ;HEAP32[$xf1+0>>2]=HEAP32[$xfB+0>>2]|0;HEAP32[$xf1+4>>2]=HEAP32[$xfB+4>>2]|0;HEAP32[$xf1+8>>2]=HEAP32[$xfB+8>>2]|0;HEAP32[$xf1+12>>2]=HEAP32[$xfB+12>>2]|0;
  ;HEAP32[$xf2+0>>2]=HEAP32[$xfA+0>>2]|0;HEAP32[$xf2+4>>2]=HEAP32[$xfA+4>>2]|0;HEAP32[$xf2+8>>2]=HEAP32[$xfA+8>>2]|0;HEAP32[$xf2+12>>2]=HEAP32[$xfA+12>>2]|0;
  $17 = HEAP32[$edgeB>>2]|0;
  $18 = (($manifold) + 56|0);
  HEAP32[$18>>2] = 2;
  $edge1$0 = $17;$flip$0 = 1;$poly1$0 = $polyB;$poly2$0 = $polyA;
 } else {
  ;HEAP32[$xf1+0>>2]=HEAP32[$xfA+0>>2]|0;HEAP32[$xf1+4>>2]=HEAP32[$xfA+4>>2]|0;HEAP32[$xf1+8>>2]=HEAP32[$xfA+8>>2]|0;HEAP32[$xf1+12>>2]=HEAP32[$xfA+12>>2]|0;
  ;HEAP32[$xf2+0>>2]=HEAP32[$xfB+0>>2]|0;HEAP32[$xf2+4>>2]=HEAP32[$xfB+4>>2]|0;HEAP32[$xf2+8>>2]=HEAP32[$xfB+8>>2]|0;HEAP32[$xf2+12>>2]=HEAP32[$xfB+12>>2]|0;
  $19 = HEAP32[$edgeA>>2]|0;
  $20 = (($manifold) + 56|0);
  HEAP32[$20>>2] = 1;
  $edge1$0 = $19;$flip$0 = 0;$poly1$0 = $polyA;$poly2$0 = $polyB;
 }
 __ZL18b2FindIncidentEdgeP12b2ClipVertexPK14b2PolygonShapeRK11b2TransformiS3_S6_($incidentEdge,$poly1$0,$xf1,$edge1$0,$poly2$0,$xf2);
 $21 = (($poly1$0) + 148|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($edge1$0) + 1)|0;
 $24 = ($23|0)<($22|0);
 $$ = $24 ? $23 : 0;
 $25 = ((($poly1$0) + ($edge1$0<<3)|0) + 20|0);
 $26 = $25;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($26) + 4)|0;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = $v11;
 $33 = $32;
 HEAP32[$33>>2] = $28;
 $34 = (($32) + 4)|0;
 $35 = $34;
 HEAP32[$35>>2] = $31;
 $36 = ((($poly1$0) + ($$<<3)|0) + 20|0);
 $37 = $36;
 $38 = $37;
 $39 = HEAP32[$38>>2]|0;
 $40 = (($37) + 4)|0;
 $41 = $40;
 $42 = HEAP32[$41>>2]|0;
 $43 = $v12;
 $44 = $43;
 HEAP32[$44>>2] = $39;
 $45 = (($43) + 4)|0;
 $46 = $45;
 HEAP32[$46>>2] = $42;
 __ZmiRK6b2Vec2S1_($localTangent,$v12,$v11);
 (+__ZN6b2Vec29NormalizeEv($localTangent));
 __Z7b2CrossRK6b2Vec2f($localNormal,$localTangent,1.0);
 __ZplRK6b2Vec2S1_($0,$v11,$v12);
 __ZmlfRK6b2Vec2($planePoint,0.5,$0);
 $47 = (($xf1) + 8|0);
 __Z5b2MulRK5b2RotRK6b2Vec2($tangent,$47,$localTangent);
 __Z7b2CrossRK6b2Vec2f($normal,$tangent,1.0);
 __Z5b2MulRK11b2TransformRK6b2Vec2($1,$xf1,$v11);
 $48 = $1;
 $49 = $48;
 $50 = HEAP32[$49>>2]|0;
 $51 = (($48) + 4)|0;
 $52 = $51;
 $53 = HEAP32[$52>>2]|0;
 $54 = $v11;
 $55 = $54;
 HEAP32[$55>>2] = $50;
 $56 = (($54) + 4)|0;
 $57 = $56;
 HEAP32[$57>>2] = $53;
 __Z5b2MulRK11b2TransformRK6b2Vec2($2,$xf1,$v12);
 $58 = $2;
 $59 = $58;
 $60 = HEAP32[$59>>2]|0;
 $61 = (($58) + 4)|0;
 $62 = $61;
 $63 = HEAP32[$62>>2]|0;
 $64 = $v12;
 $65 = $64;
 HEAP32[$65>>2] = $60;
 $66 = (($64) + 4)|0;
 $67 = $66;
 HEAP32[$67>>2] = $63;
 $68 = (+__Z5b2DotRK6b2Vec2S1_($normal,$v11));
 $69 = (+__Z5b2DotRK6b2Vec2S1_($tangent,$v12));
 $70 = (+__Z5b2DotRK6b2Vec2S1_($tangent,$v11));
 $71 = $10 - $70;
 __ZNK6b2Vec2ngEv($3,$tangent);
 $72 = (__Z19b2ClipSegmentToLineP12b2ClipVertexPKS_RK6b2Vec2fi($clipPoints1,$incidentEdge,$3,$71,$edge1$0)|0);
 $73 = ($72|0)<(2);
 if ($73) {
  STACKTOP = sp;return;
 }
 $74 = $10 + $69;
 $75 = (__Z19b2ClipSegmentToLineP12b2ClipVertexPKS_RK6b2Vec2fi($clipPoints2,$clipPoints1,$tangent,$74,$$)|0);
 $76 = ($75|0)<(2);
 if ($76) {
  STACKTOP = sp;return;
 }
 $77 = (($manifold) + 40|0);
 $78 = $localNormal;
 $79 = $78;
 $80 = HEAP32[$79>>2]|0;
 $81 = (($78) + 4)|0;
 $82 = $81;
 $83 = HEAP32[$82>>2]|0;
 $84 = $77;
 $85 = $84;
 HEAP32[$85>>2] = $80;
 $86 = (($84) + 4)|0;
 $87 = $86;
 HEAP32[$87>>2] = $83;
 $88 = (($manifold) + 48|0);
 $89 = $planePoint;
 $90 = $89;
 $91 = HEAP32[$90>>2]|0;
 $92 = (($89) + 4)|0;
 $93 = $92;
 $94 = HEAP32[$93>>2]|0;
 $95 = $88;
 $96 = $95;
 HEAP32[$96>>2] = $91;
 $97 = (($95) + 4)|0;
 $98 = $97;
 HEAP32[$98>>2] = $94;
 $99 = ($flip$0<<24>>24)==(0);
 $100 = (+__Z5b2DotRK6b2Vec2S1_($normal,$clipPoints2));
 $101 = $100 - $68;
 $102 = !($101 <= $10);
 if ($102) {
  $pointCount$1 = 0;
 } else {
  __Z6b2MulTRK11b2TransformRK6b2Vec2($4,$xf2,$clipPoints2);
  $103 = $4;
  $104 = $103;
  $105 = HEAP32[$104>>2]|0;
  $106 = (($103) + 4)|0;
  $107 = $106;
  $108 = HEAP32[$107>>2]|0;
  $109 = $manifold;
  $110 = $109;
  HEAP32[$110>>2] = $105;
  $111 = (($109) + 4)|0;
  $112 = $111;
  HEAP32[$112>>2] = $108;
  $113 = (($manifold) + 16|0);
  $114 = (($clipPoints2) + 8|0);
  $115 = HEAP32[$114>>2]|0;
  HEAP32[$113>>2] = $115;
  if ($99) {
   $pointCount$1 = 1;
  } else {
   $116 = HEAP8[$113>>0]|0;
   $117 = (($113) + 1|0);
   $118 = HEAP8[$117>>0]|0;
   $119 = (($113) + 2|0);
   $120 = HEAP8[$119>>0]|0;
   $121 = (($113) + 3|0);
   $122 = HEAP8[$121>>0]|0;
   HEAP8[$113>>0] = $118;
   HEAP8[$117>>0] = $116;
   HEAP8[$119>>0] = $122;
   HEAP8[$121>>0] = $120;
   $pointCount$1 = 1;
  }
 }
 $123 = (($clipPoints2) + 12|0);
 $124 = (+__Z5b2DotRK6b2Vec2S1_($normal,$123));
 $125 = $124 - $68;
 $126 = !($125 <= $10);
 if ($126) {
  $pointCount$1$1 = $pointCount$1;
 } else {
  $127 = (($manifold) + (($pointCount$1*20)|0)|0);
  __Z6b2MulTRK11b2TransformRK6b2Vec2($4,$xf2,$123);
  $128 = $4;
  $129 = $128;
  $130 = HEAP32[$129>>2]|0;
  $131 = (($128) + 4)|0;
  $132 = $131;
  $133 = HEAP32[$132>>2]|0;
  $134 = $127;
  $135 = $134;
  HEAP32[$135>>2] = $130;
  $136 = (($134) + 4)|0;
  $137 = $136;
  HEAP32[$137>>2] = $133;
  $138 = ((($manifold) + (($pointCount$1*20)|0)|0) + 16|0);
  $139 = (($clipPoints2) + 20|0);
  $140 = HEAP32[$139>>2]|0;
  HEAP32[$138>>2] = $140;
  if (!($99)) {
   $141 = HEAP8[$138>>0]|0;
   $142 = (($138) + 1|0);
   $143 = HEAP8[$142>>0]|0;
   $144 = (($138) + 2|0);
   $145 = HEAP8[$144>>0]|0;
   $146 = (($138) + 3|0);
   $147 = HEAP8[$146>>0]|0;
   HEAP8[$138>>0] = $143;
   HEAP8[$142>>0] = $141;
   HEAP8[$144>>0] = $147;
   HEAP8[$146>>0] = $145;
  }
  $148 = (($pointCount$1) + 1)|0;
  $pointCount$1$1 = $148;
 }
 HEAP32[$5>>2] = $pointCount$1$1;
 STACKTOP = sp;return;
}
function __ZL19b2FindMaxSeparationPiPK14b2PolygonShapeRK11b2TransformS2_S5_($edgeIndex,$poly1,$xf1,$poly2,$xf2) {
 $edgeIndex = $edgeIndex|0;
 $poly1 = $poly1|0;
 $xf1 = $xf1|0;
 $poly2 = $poly2|0;
 $xf2 = $xf2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bestIndex$0$lcssa = 0, $bestIndex$05 = 0, $bestIndex$1 = 0, $exitcond = 0;
 var $exitcond11 = 0, $i$04 = 0, $j$02 = 0, $maxSeparation$0$lcssa = 0.0, $maxSeparation$03 = 0.0, $maxSeparation$1 = 0.0, $n = 0, $si$0$lcssa = 0.0, $si$01 = 0.0, $si$1 = 0.0, $v1 = 0, $xf = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $xf = sp + 24|0;
 $n = sp + 16|0;
 $v1 = sp + 8|0;
 $0 = sp;
 $1 = (($poly1) + 148|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($poly2) + 148|0);
 $4 = HEAP32[$3>>2]|0;
 __Z6b2MulTRK11b2TransformS1_($xf,$xf2,$xf1);
 $5 = ($2|0)>(0);
 if (!($5)) {
  $bestIndex$0$lcssa = 0;$maxSeparation$0$lcssa = -3.4028234663852886E+38;
  HEAP32[$edgeIndex>>2] = $bestIndex$0$lcssa;
  STACKTOP = sp;return (+$maxSeparation$0$lcssa);
 }
 $6 = (($xf) + 8|0);
 $7 = ($4|0)>(0);
 $bestIndex$05 = 0;$i$04 = 0;$maxSeparation$03 = -3.4028234663852886E+38;
 while(1) {
  $8 = ((($poly1) + ($i$04<<3)|0) + 84|0);
  __Z5b2MulRK5b2RotRK6b2Vec2($n,$6,$8);
  $9 = ((($poly1) + ($i$04<<3)|0) + 20|0);
  __Z5b2MulRK11b2TransformRK6b2Vec2($v1,$xf,$9);
  if ($7) {
   $j$02 = 0;$si$01 = 3.4028234663852886E+38;
   while(1) {
    $10 = ((($poly2) + ($j$02<<3)|0) + 20|0);
    __ZmiRK6b2Vec2S1_($0,$10,$v1);
    $11 = (+__Z5b2DotRK6b2Vec2S1_($n,$0));
    $12 = $11 < $si$01;
    $si$1 = $12 ? $11 : $si$01;
    $13 = (($j$02) + 1)|0;
    $exitcond = ($13|0)==($4|0);
    if ($exitcond) {
     $si$0$lcssa = $si$1;
     break;
    } else {
     $j$02 = $13;$si$01 = $si$1;
    }
   }
  } else {
   $si$0$lcssa = 3.4028234663852886E+38;
  }
  $14 = $si$0$lcssa > $maxSeparation$03;
  $maxSeparation$1 = $14 ? $si$0$lcssa : $maxSeparation$03;
  $bestIndex$1 = $14 ? $i$04 : $bestIndex$05;
  $15 = (($i$04) + 1)|0;
  $exitcond11 = ($15|0)==($2|0);
  if ($exitcond11) {
   $bestIndex$0$lcssa = $bestIndex$1;$maxSeparation$0$lcssa = $maxSeparation$1;
   break;
  } else {
   $bestIndex$05 = $bestIndex$1;$i$04 = $15;$maxSeparation$03 = $maxSeparation$1;
  }
 }
 HEAP32[$edgeIndex>>2] = $bestIndex$0$lcssa;
 STACKTOP = sp;return (+$maxSeparation$0$lcssa);
}
function __ZL18b2FindIncidentEdgeP12b2ClipVertexPK14b2PolygonShapeRK11b2TransformiS3_S6_($c,$poly1,$xf1,$edge1,$poly2,$xf2) {
 $c = $c|0;
 $poly1 = $poly1|0;
 $xf1 = $xf1|0;
 $edge1 = $edge1|0;
 $poly2 = $poly2|0;
 $xf2 = $xf2|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$02 = 0, $index$0$lcssa = 0, $index$04 = 0, $index$1 = 0, $minDot$03 = 0.0, $minDot$1 = 0.0, $normal1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $normal1 = sp + 24|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($poly2) + 148|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($xf2) + 8|0);
 $6 = (($xf1) + 8|0);
 $7 = ((($poly1) + ($edge1<<3)|0) + 84|0);
 __Z5b2MulRK5b2RotRK6b2Vec2($0,$6,$7);
 __Z6b2MulTRK5b2RotRK6b2Vec2($normal1,$5,$0);
 $8 = ($4|0)>(0);
 if ($8) {
  $i$02 = 0;$index$04 = 0;$minDot$03 = 3.4028234663852886E+38;
  while(1) {
   $9 = ((($poly2) + ($i$02<<3)|0) + 84|0);
   $10 = (+__Z5b2DotRK6b2Vec2S1_($normal1,$9));
   $11 = $10 < $minDot$03;
   $minDot$1 = $11 ? $10 : $minDot$03;
   $index$1 = $11 ? $i$02 : $index$04;
   $12 = (($i$02) + 1)|0;
   $exitcond = ($12|0)==($4|0);
   if ($exitcond) {
    $index$0$lcssa = $index$1;
    break;
   } else {
    $i$02 = $12;$index$04 = $index$1;$minDot$03 = $minDot$1;
   }
  }
 } else {
  $index$0$lcssa = 0;
 }
 $13 = (($index$0$lcssa) + 1)|0;
 $14 = ($13|0)<($4|0);
 $$ = $14 ? $13 : 0;
 $15 = ((($poly2) + ($index$0$lcssa<<3)|0) + 20|0);
 __Z5b2MulRK11b2TransformRK6b2Vec2($1,$xf2,$15);
 $16 = $1;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16) + 4)|0;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = $c;
 $23 = $22;
 HEAP32[$23>>2] = $18;
 $24 = (($22) + 4)|0;
 $25 = $24;
 HEAP32[$25>>2] = $21;
 $26 = $edge1&255;
 $27 = (($c) + 8|0);
 HEAP8[$27>>0] = $26;
 $28 = $index$0$lcssa&255;
 $29 = (($27) + 1|0);
 HEAP8[$29>>0] = $28;
 $30 = (($27) + 2|0);
 HEAP8[$30>>0] = 1;
 $31 = (($27) + 3|0);
 HEAP8[$31>>0] = 0;
 $32 = (($c) + 12|0);
 $33 = ((($poly2) + ($$<<3)|0) + 20|0);
 __Z5b2MulRK11b2TransformRK6b2Vec2($2,$xf2,$33);
 $34 = $2;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = (($34) + 4)|0;
 $38 = $37;
 $39 = HEAP32[$38>>2]|0;
 $40 = $32;
 $41 = $40;
 HEAP32[$41>>2] = $36;
 $42 = (($40) + 4)|0;
 $43 = $42;
 HEAP32[$43>>2] = $39;
 $44 = (($c) + 20|0);
 HEAP8[$44>>0] = $26;
 $45 = $$&255;
 $46 = (($44) + 1|0);
 HEAP8[$46>>0] = $45;
 $47 = (($44) + 2|0);
 HEAP8[$47>>0] = 1;
 $48 = (($44) + 3|0);
 HEAP8[$48>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN15b2WorldManifold10InitializeEPK10b2ManifoldRK11b2TransformfS5_f($this,$manifold,$xfA,$radiusA,$xfB,$radiusB) {
 $this = $this|0;
 $manifold = $manifold|0;
 $xfA = $xfA|0;
 $radiusA = +$radiusA;
 $xfB = $xfB|0;
 $radiusB = +$radiusB;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0.0, $103 = 0.0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0.0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0.0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cA = 0, $cA1 = 0, $cA7 = 0, $cB = 0, $cB2 = 0, $cB6 = 0, $clipPoint = 0, $clipPoint5 = 0, $i$07 = 0, $i4$08 = 0;
 var $planePoint = 0, $planePoint3 = 0, $pointA = 0, $pointB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $pointA = sp + 256|0;
 $pointB = sp + 248|0;
 $0 = sp + 48|0;
 $cA = sp + 240|0;
 $1 = sp + 232|0;
 $cB = sp + 224|0;
 $2 = sp + 216|0;
 $3 = sp + 40|0;
 $4 = sp + 208|0;
 $5 = sp + 200|0;
 $6 = sp + 32|0;
 $planePoint = sp + 192|0;
 $clipPoint = sp + 184|0;
 $cA1 = sp + 176|0;
 $7 = sp + 168|0;
 $8 = sp + 160|0;
 $cB2 = sp + 152|0;
 $9 = sp + 144|0;
 $10 = sp + 24|0;
 $11 = sp + 136|0;
 $12 = sp + 128|0;
 $13 = sp + 16|0;
 $planePoint3 = sp + 120|0;
 $clipPoint5 = sp + 112|0;
 $cB6 = sp + 104|0;
 $14 = sp + 96|0;
 $15 = sp + 88|0;
 $cA7 = sp + 80|0;
 $16 = sp + 72|0;
 $17 = sp + 8|0;
 $18 = sp + 64|0;
 $19 = sp + 56|0;
 $20 = sp;
 $21 = (($manifold) + 60|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  STACKTOP = sp;return;
 }
 $24 = (($manifold) + 56|0);
 $25 = HEAP32[$24>>2]|0;
 if ((($25|0) == 0)) {
  __ZN6b2Vec23SetEff($this,1.0,0.0);
  $26 = (($manifold) + 48|0);
  __Z5b2MulRK11b2TransformRK6b2Vec2($pointA,$xfA,$26);
  __Z5b2MulRK11b2TransformRK6b2Vec2($pointB,$xfB,$manifold);
  $27 = (+__Z17b2DistanceSquaredRK6b2Vec2S1_($pointA,$pointB));
  $28 = $27 > 1.4210854715202004E-14;
  if ($28) {
   __ZmiRK6b2Vec2S1_($0,$pointB,$pointA);
   $29 = $0;
   $30 = $29;
   $31 = HEAP32[$30>>2]|0;
   $32 = (($29) + 4)|0;
   $33 = $32;
   $34 = HEAP32[$33>>2]|0;
   $35 = $this;
   $36 = $35;
   HEAP32[$36>>2] = $31;
   $37 = (($35) + 4)|0;
   $38 = $37;
   HEAP32[$38>>2] = $34;
   (+__ZN6b2Vec29NormalizeEv($this));
  }
  __ZmlfRK6b2Vec2($1,$radiusA,$this);
  __ZplRK6b2Vec2S1_($cA,$pointA,$1);
  __ZmlfRK6b2Vec2($2,$radiusB,$this);
  __ZmiRK6b2Vec2S1_($cB,$pointB,$2);
  $39 = (($this) + 8|0);
  __ZplRK6b2Vec2S1_($4,$cA,$cB);
  __ZmlfRK6b2Vec2($3,0.5,$4);
  $40 = $3;
  $41 = $40;
  $42 = HEAP32[$41>>2]|0;
  $43 = (($40) + 4)|0;
  $44 = $43;
  $45 = HEAP32[$44>>2]|0;
  $46 = $39;
  $47 = $46;
  HEAP32[$47>>2] = $42;
  $48 = (($46) + 4)|0;
  $49 = $48;
  HEAP32[$49>>2] = $45;
  __ZmiRK6b2Vec2S1_($5,$cB,$cA);
  $50 = (+__Z5b2DotRK6b2Vec2S1_($5,$this));
  $51 = (($this) + 24|0);
  HEAPF32[$51>>2] = $50;
  STACKTOP = sp;return;
 } else if ((($25|0) == 2)) {
  $86 = (($xfB) + 8|0);
  $87 = (($manifold) + 40|0);
  __Z5b2MulRK5b2RotRK6b2Vec2($13,$86,$87);
  $88 = $13;
  $89 = $88;
  $90 = HEAP32[$89>>2]|0;
  $91 = (($88) + 4)|0;
  $92 = $91;
  $93 = HEAP32[$92>>2]|0;
  $94 = $this;
  $95 = $94;
  HEAP32[$95>>2] = $90;
  $96 = (($94) + 4)|0;
  $97 = $96;
  HEAP32[$97>>2] = $93;
  $98 = (($manifold) + 48|0);
  __Z5b2MulRK11b2TransformRK6b2Vec2($planePoint3,$xfB,$98);
  $99 = HEAP32[$21>>2]|0;
  $100 = ($99|0)>(0);
  if ($100) {
   $i4$08 = 0;
   while(1) {
    $101 = (($manifold) + (($i4$08*20)|0)|0);
    __Z5b2MulRK11b2TransformRK6b2Vec2($clipPoint5,$xfA,$101);
    __ZmiRK6b2Vec2S1_($15,$clipPoint5,$planePoint3);
    $102 = (+__Z5b2DotRK6b2Vec2S1_($15,$this));
    $103 = $radiusB - $102;
    __ZmlfRK6b2Vec2($14,$103,$this);
    __ZplRK6b2Vec2S1_($cB6,$clipPoint5,$14);
    __ZmlfRK6b2Vec2($16,$radiusA,$this);
    __ZmiRK6b2Vec2S1_($cA7,$clipPoint5,$16);
    $104 = ((($this) + ($i4$08<<3)|0) + 8|0);
    __ZplRK6b2Vec2S1_($18,$cA7,$cB6);
    __ZmlfRK6b2Vec2($17,0.5,$18);
    $105 = $17;
    $106 = $105;
    $107 = HEAP32[$106>>2]|0;
    $108 = (($105) + 4)|0;
    $109 = $108;
    $110 = HEAP32[$109>>2]|0;
    $111 = $104;
    $112 = $111;
    HEAP32[$112>>2] = $107;
    $113 = (($111) + 4)|0;
    $114 = $113;
    HEAP32[$114>>2] = $110;
    __ZmiRK6b2Vec2S1_($19,$cA7,$cB6);
    $115 = (+__Z5b2DotRK6b2Vec2S1_($19,$this));
    $116 = ((($this) + ($i4$08<<2)|0) + 24|0);
    HEAPF32[$116>>2] = $115;
    $117 = (($i4$08) + 1)|0;
    $118 = HEAP32[$21>>2]|0;
    $119 = ($117|0)<($118|0);
    if ($119) {
     $i4$08 = $117;
    } else {
     break;
    }
   }
  }
  __ZNK6b2Vec2ngEv($20,$this);
  $120 = $20;
  $121 = $120;
  $122 = HEAP32[$121>>2]|0;
  $123 = (($120) + 4)|0;
  $124 = $123;
  $125 = HEAP32[$124>>2]|0;
  $126 = $this;
  $127 = $126;
  HEAP32[$127>>2] = $122;
  $128 = (($126) + 4)|0;
  $129 = $128;
  HEAP32[$129>>2] = $125;
  STACKTOP = sp;return;
 } else if ((($25|0) == 1)) {
  $52 = (($xfA) + 8|0);
  $53 = (($manifold) + 40|0);
  __Z5b2MulRK5b2RotRK6b2Vec2($6,$52,$53);
  $54 = $6;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = (($54) + 4)|0;
  $58 = $57;
  $59 = HEAP32[$58>>2]|0;
  $60 = $this;
  $61 = $60;
  HEAP32[$61>>2] = $56;
  $62 = (($60) + 4)|0;
  $63 = $62;
  HEAP32[$63>>2] = $59;
  $64 = (($manifold) + 48|0);
  __Z5b2MulRK11b2TransformRK6b2Vec2($planePoint,$xfA,$64);
  $65 = HEAP32[$21>>2]|0;
  $66 = ($65|0)>(0);
  if ($66) {
   $i$07 = 0;
  } else {
   STACKTOP = sp;return;
  }
  while(1) {
   $67 = (($manifold) + (($i$07*20)|0)|0);
   __Z5b2MulRK11b2TransformRK6b2Vec2($clipPoint,$xfB,$67);
   __ZmiRK6b2Vec2S1_($8,$clipPoint,$planePoint);
   $68 = (+__Z5b2DotRK6b2Vec2S1_($8,$this));
   $69 = $radiusA - $68;
   __ZmlfRK6b2Vec2($7,$69,$this);
   __ZplRK6b2Vec2S1_($cA1,$clipPoint,$7);
   __ZmlfRK6b2Vec2($9,$radiusB,$this);
   __ZmiRK6b2Vec2S1_($cB2,$clipPoint,$9);
   $70 = ((($this) + ($i$07<<3)|0) + 8|0);
   __ZplRK6b2Vec2S1_($11,$cA1,$cB2);
   __ZmlfRK6b2Vec2($10,0.5,$11);
   $71 = $10;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = (($71) + 4)|0;
   $75 = $74;
   $76 = HEAP32[$75>>2]|0;
   $77 = $70;
   $78 = $77;
   HEAP32[$78>>2] = $73;
   $79 = (($77) + 4)|0;
   $80 = $79;
   HEAP32[$80>>2] = $76;
   __ZmiRK6b2Vec2S1_($12,$cB2,$cA1);
   $81 = (+__Z5b2DotRK6b2Vec2S1_($12,$this));
   $82 = ((($this) + ($i$07<<2)|0) + 24|0);
   HEAPF32[$82>>2] = $81;
   $83 = (($i$07) + 1)|0;
   $84 = HEAP32[$21>>2]|0;
   $85 = ($83|0)<($84|0);
   if ($85) {
    $i$07 = $83;
   } else {
    break;
   }
  }
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __Z19b2ClipSegmentToLineP12b2ClipVertexPKS_RK6b2Vec2fi($vOut,$vIn,$normal,$offset,$vertexIndexA) {
 $vOut = $vOut|0;
 $vIn = $vIn|0;
 $normal = $normal|0;
 $offset = +$offset;
 $vertexIndexA = $vertexIndexA|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0.0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0, $numOut$0 = 0, $numOut$1 = 0, $numOut$2 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp;
 $1 = sp + 16|0;
 $2 = sp + 8|0;
 $3 = (+__Z5b2DotRK6b2Vec2S1_($normal,$vIn));
 $4 = $3 - $offset;
 $5 = (($vIn) + 12|0);
 $6 = (+__Z5b2DotRK6b2Vec2S1_($normal,$5));
 $7 = $6 - $offset;
 $8 = !($4 <= 0.0);
 if ($8) {
  $numOut$0 = 0;
 } else {
  ;HEAP32[$vOut+0>>2]=HEAP32[$vIn+0>>2]|0;HEAP32[$vOut+4>>2]=HEAP32[$vIn+4>>2]|0;HEAP32[$vOut+8>>2]=HEAP32[$vIn+8>>2]|0;
  $numOut$0 = 1;
 }
 $9 = !($7 <= 0.0);
 if ($9) {
  $numOut$1 = $numOut$0;
 } else {
  $10 = (($numOut$0) + 1)|0;
  $11 = (($vOut) + (($numOut$0*12)|0)|0);
  ;HEAP32[$11+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$11+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$5+8>>2]|0;
  $numOut$1 = $10;
 }
 $12 = $4 * $7;
 $13 = $12 < 0.0;
 if (!($13)) {
  $numOut$2 = $numOut$1;
  STACKTOP = sp;return ($numOut$2|0);
 }
 $14 = $4 - $7;
 $15 = $4 / $14;
 $16 = (($vOut) + (($numOut$1*12)|0)|0);
 __ZmiRK6b2Vec2S1_($2,$5,$vIn);
 __ZmlfRK6b2Vec2($1,$15,$2);
 __ZplRK6b2Vec2S1_($0,$vIn,$1);
 $17 = $0;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) + 4)|0;
 $21 = $20;
 $22 = HEAP32[$21>>2]|0;
 $23 = $16;
 $24 = $23;
 HEAP32[$24>>2] = $19;
 $25 = (($23) + 4)|0;
 $26 = $25;
 HEAP32[$26>>2] = $22;
 $27 = $vertexIndexA&255;
 $28 = ((($vOut) + (($numOut$1*12)|0)|0) + 8|0);
 HEAP8[$28>>0] = $27;
 $29 = (($vIn) + 8|0);
 $30 = (($29) + 1|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = (($28) + 1|0);
 HEAP8[$32>>0] = $31;
 $33 = (($28) + 2|0);
 HEAP8[$33>>0] = 0;
 $34 = (($28) + 3|0);
 HEAP8[$34>>0] = 1;
 $35 = (($numOut$1) + 1)|0;
 $numOut$2 = $35;
 STACKTOP = sp;return ($numOut$2|0);
}
function __Z13b2TestOverlapPK7b2ShapeiS1_iRK11b2TransformS4_($shapeA,$indexA,$shapeB,$indexB,$xfA,$xfB) {
 $shapeA = $shapeA|0;
 $indexA = $indexA|0;
 $shapeB = $shapeB|0;
 $indexB = $indexB|0;
 $xfA = $xfA|0;
 $xfB = $xfB|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $cache = 0, $input = 0, $output = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $input = sp + 36|0;
 $cache = sp + 24|0;
 $output = sp;
 __ZN15b2DistanceInputC2Ev($input);
 __ZN15b2DistanceProxy3SetEPK7b2Shapei($input,$shapeA,$indexA);
 $0 = (($input) + 28|0);
 __ZN15b2DistanceProxy3SetEPK7b2Shapei($0,$shapeB,$indexB);
 $1 = (($input) + 56|0);
 ;HEAP32[$1+0>>2]=HEAP32[$xfA+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$xfA+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$xfA+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$xfA+12>>2]|0;
 $2 = (($input) + 72|0);
 ;HEAP32[$2+0>>2]=HEAP32[$xfB+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$xfB+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$xfB+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$xfB+12>>2]|0;
 $3 = (($input) + 88|0);
 HEAP8[$3>>0] = 1;
 $4 = (($cache) + 4|0);
 HEAP16[$4>>1] = 0;
 __Z10b2DistanceP16b2DistanceOutputP14b2SimplexCachePK15b2DistanceInput($output,$cache,$input);
 $5 = (($output) + 16|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $6 < 1.1920928955078125E-6;
 STACKTOP = sp;return ($7|0);
}
function __Z5b2AbsRK6b2Vec2($agg$result,$a) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 var $0 = 0.0, $1 = 0.0, $2 = 0, $3 = 0.0, $4 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$a>>2];
 $1 = (+__Z5b2AbsIfET_S0_($0));
 $2 = (($a) + 4|0);
 $3 = +HEAPF32[$2>>2];
 $4 = (+__Z5b2AbsIfET_S0_($3));
 __ZN6b2Vec2C2Eff($agg$result,$1,$4);
 STACKTOP = sp;return;
}
function __Z6b2SwapIfEvRT_S1_($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$a>>2];
 $1 = +HEAPF32[$b>>2];
 HEAPF32[$a>>2] = $1;
 HEAPF32[$b>>2] = $0;
 STACKTOP = sp;return;
}
function __ZN8b2IslandC2EiiiP16b2StackAllocatorP17b2ContactListener($this,$bodyCapacity,$contactCapacity,$jointCapacity,$allocator,$listener) {
 $this = $this|0;
 $bodyCapacity = $bodyCapacity|0;
 $contactCapacity = $contactCapacity|0;
 $jointCapacity = $jointCapacity|0;
 $allocator = $allocator|0;
 $listener = $listener|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 HEAP32[$0>>2] = $bodyCapacity;
 $1 = (($this) + 44|0);
 HEAP32[$1>>2] = $contactCapacity;
 $2 = (($this) + 48|0);
 HEAP32[$2>>2] = $jointCapacity;
 $3 = (($this) + 28|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 36|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 32|0);
 HEAP32[$5>>2] = 0;
 HEAP32[$this>>2] = $allocator;
 $6 = (($this) + 4|0);
 HEAP32[$6>>2] = $listener;
 $7 = HEAP32[$this>>2]|0;
 $8 = $bodyCapacity << 2;
 $9 = (__ZN16b2StackAllocator8AllocateEi($7,$8)|0);
 $10 = (($this) + 8|0);
 HEAP32[$10>>2] = $9;
 $11 = HEAP32[$this>>2]|0;
 $12 = $contactCapacity << 2;
 $13 = (__ZN16b2StackAllocator8AllocateEi($11,$12)|0);
 $14 = (($this) + 12|0);
 HEAP32[$14>>2] = $13;
 $15 = HEAP32[$this>>2]|0;
 $16 = $jointCapacity << 2;
 $17 = (__ZN16b2StackAllocator8AllocateEi($15,$16)|0);
 $18 = (($this) + 16|0);
 HEAP32[$18>>2] = $17;
 $19 = HEAP32[$this>>2]|0;
 $20 = HEAP32[$0>>2]|0;
 $21 = ($20*12)|0;
 $22 = (__ZN16b2StackAllocator8AllocateEi($19,$21)|0);
 $23 = (($this) + 24|0);
 HEAP32[$23>>2] = $22;
 $24 = HEAP32[$this>>2]|0;
 $25 = HEAP32[$0>>2]|0;
 $26 = ($25*12)|0;
 $27 = (__ZN16b2StackAllocator8AllocateEi($24,$26)|0);
 $28 = (($this) + 20|0);
 HEAP32[$28>>2] = $27;
 STACKTOP = sp;return;
}
function __ZN8b2IslandD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 20|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN16b2StackAllocator4FreeEPv($0,$2);
 $3 = HEAP32[$this>>2]|0;
 $4 = (($this) + 24|0);
 $5 = HEAP32[$4>>2]|0;
 __ZN16b2StackAllocator4FreeEPv($3,$5);
 $6 = HEAP32[$this>>2]|0;
 $7 = (($this) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN16b2StackAllocator4FreeEPv($6,$8);
 $9 = HEAP32[$this>>2]|0;
 $10 = (($this) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 __ZN16b2StackAllocator4FreeEPv($9,$11);
 $12 = HEAP32[$this>>2]|0;
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 __ZN16b2StackAllocator4FreeEPv($12,$14);
 STACKTOP = sp;return;
}
function __ZN8b2Island5SolveEP9b2ProfileRK10b2TimeStepRK6b2Vec2b($this,$profile,$step,$gravity,$allowSleep) {
 $this = $this|0;
 $profile = $profile|0;
 $step = $step|0;
 $gravity = $gravity|0;
 $allowSleep = $allowSleep|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0.0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0.0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0.0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0.0;
 var $188 = 0.0, $189 = 0, $19 = 0, $190 = 0.0, $191 = 0.0, $192 = 0.0, $193 = 0.0, $194 = 0, $195 = 0.0, $196 = 0.0, $197 = 0.0, $198 = 0.0, $199 = 0.0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0.0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0.0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0.0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0.0, $295 = 0;
 var $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0.0, $312 = 0.0;
 var $313 = 0, $314 = 0, $315 = 0.0, $316 = 0, $317 = 0, $318 = 0, $319 = 0.0, $32 = 0, $320 = 0.0, $321 = 0.0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0;
 var $331 = 0, $332 = 0, $333 = 0, $334 = 0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0.0;
 var $49 = 0, $5 = 0.0, $50 = 0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0, $65 = 0.0, $66 = 0.0;
 var $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge$demorgan = 0, $brmerge4 = 0, $c4 = 0, $contactSolver = 0;
 var $contactSolverDef = 0, $i$056 = 0, $i1$051 = 0, $i10$018 = 0, $i11$010 = 0, $i12$08 = 0, $i14$05 = 0, $i2$045 = 0, $i3$031 = 0, $i9$026 = 0, $j$038 = 0, $jointsOkay$0$off0$lcssa = 0, $jointsOkay$0$off017 = 0, $minSleepTime$0$lcssa = 0.0, $minSleepTime$07 = 0.0, $minSleepTime$1 = 0.0, $positionSolved$0$off0 = 0, $solverData = 0, $timer = 0, $translation = 0;
 var $v = 0, $v6 = 0, $w$0 = 0.0, $w7$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $timer = sp + 24|0;
 $v = sp + 16|0;
 $0 = sp + 216|0;
 $1 = sp + 208|0;
 $2 = sp + 200|0;
 $3 = sp + 192|0;
 $solverData = sp + 152|0;
 $contactSolverDef = sp + 104|0;
 $contactSolver = sp + 48|0;
 $c4 = sp + 8|0;
 $v6 = sp;
 $translation = sp + 40|0;
 $4 = sp + 32|0;
 __ZN7b2TimerC2Ev($timer);
 $5 = +HEAPF32[$step>>2];
 $6 = (($this) + 28|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)>(0);
 if ($8) {
  $9 = (($this) + 8|0);
  $10 = (($this) + 20|0);
  $11 = (($this) + 24|0);
  $i$056 = 0;
  while(1) {
   $12 = HEAP32[$9>>2]|0;
   $13 = (($12) + ($i$056<<2)|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (($14) + 60|0);
   $16 = $15;
   $17 = $16;
   $18 = HEAP32[$17>>2]|0;
   $19 = (($16) + 4)|0;
   $20 = $19;
   $21 = HEAP32[$20>>2]|0;
   $22 = (($14) + 72|0);
   $23 = +HEAPF32[$22>>2];
   $24 = (($14) + 80|0);
   $25 = $24;
   $26 = $25;
   $27 = HEAP32[$26>>2]|0;
   $28 = (($25) + 4)|0;
   $29 = $28;
   $30 = HEAP32[$29>>2]|0;
   $31 = $v;
   $32 = $31;
   HEAP32[$32>>2] = $27;
   $33 = (($31) + 4)|0;
   $34 = $33;
   HEAP32[$34>>2] = $30;
   $35 = (($14) + 88|0);
   $36 = +HEAPF32[$35>>2];
   $37 = (($14) + 52|0);
   $38 = $15;
   $39 = $38;
   $40 = HEAP32[$39>>2]|0;
   $41 = (($38) + 4)|0;
   $42 = $41;
   $43 = HEAP32[$42>>2]|0;
   $44 = $37;
   $45 = $44;
   HEAP32[$45>>2] = $40;
   $46 = (($44) + 4)|0;
   $47 = $46;
   HEAP32[$47>>2] = $43;
   $48 = +HEAPF32[$22>>2];
   $49 = (($14) + 68|0);
   HEAPF32[$49>>2] = $48;
   $50 = HEAP32[$14>>2]|0;
   $51 = ($50|0)==(2);
   if ($51) {
    $52 = (($14) + 156|0);
    $53 = +HEAPF32[$52>>2];
    __ZmlfRK6b2Vec2($2,$53,$gravity);
    $54 = (($14) + 136|0);
    $55 = +HEAPF32[$54>>2];
    $56 = (($14) + 92|0);
    __ZmlfRK6b2Vec2($3,$55,$56);
    __ZplRK6b2Vec2S1_($1,$2,$3);
    __ZmlfRK6b2Vec2($0,$5,$1);
    __ZN6b2Vec2pLERKS_($v,$0);
    $57 = (($14) + 144|0);
    $58 = +HEAPF32[$57>>2];
    $59 = $5 * $58;
    $60 = (($14) + 100|0);
    $61 = +HEAPF32[$60>>2];
    $62 = $59 * $61;
    $63 = $36 + $62;
    $64 = (($14) + 148|0);
    $65 = +HEAPF32[$64>>2];
    $66 = $5 * $65;
    $67 = $66 + 1.0;
    $68 = 1.0 / $67;
    __ZN6b2Vec2mLEf($v,$68);
    $69 = (($14) + 152|0);
    $70 = +HEAPF32[$69>>2];
    $71 = $5 * $70;
    $72 = $71 + 1.0;
    $73 = 1.0 / $72;
    $74 = $63 * $73;
    $w$0 = $74;
   } else {
    $w$0 = $36;
   }
   $75 = HEAP32[$10>>2]|0;
   $76 = (($75) + (($i$056*12)|0)|0);
   $77 = $76;
   $78 = $77;
   HEAP32[$78>>2] = $18;
   $79 = (($77) + 4)|0;
   $80 = $79;
   HEAP32[$80>>2] = $21;
   $81 = HEAP32[$10>>2]|0;
   $82 = ((($81) + (($i$056*12)|0)|0) + 8|0);
   HEAPF32[$82>>2] = $23;
   $83 = HEAP32[$11>>2]|0;
   $84 = (($83) + (($i$056*12)|0)|0);
   $85 = $v;
   $86 = $85;
   $87 = HEAP32[$86>>2]|0;
   $88 = (($85) + 4)|0;
   $89 = $88;
   $90 = HEAP32[$89>>2]|0;
   $91 = $84;
   $92 = $91;
   HEAP32[$92>>2] = $87;
   $93 = (($91) + 4)|0;
   $94 = $93;
   HEAP32[$94>>2] = $90;
   $95 = HEAP32[$11>>2]|0;
   $96 = ((($95) + (($i$056*12)|0)|0) + 8|0);
   HEAPF32[$96>>2] = $w$0;
   $97 = (($i$056) + 1)|0;
   $98 = HEAP32[$6>>2]|0;
   $99 = ($97|0)<($98|0);
   if ($99) {
    $i$056 = $97;
   } else {
    break;
   }
  }
 }
 ;HEAP32[$solverData+0>>2]=HEAP32[$step+0>>2]|0;HEAP32[$solverData+4>>2]=HEAP32[$step+4>>2]|0;HEAP32[$solverData+8>>2]=HEAP32[$step+8>>2]|0;HEAP32[$solverData+12>>2]=HEAP32[$step+12>>2]|0;HEAP32[$solverData+16>>2]=HEAP32[$step+16>>2]|0;HEAP32[$solverData+20>>2]=HEAP32[$step+20>>2]|0;HEAP32[$solverData+24>>2]=HEAP32[$step+24>>2]|0;
 $100 = (($this) + 20|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = (($solverData) + 28|0);
 HEAP32[$102>>2] = $101;
 $103 = (($this) + 24|0);
 $104 = HEAP32[$103>>2]|0;
 $105 = (($solverData) + 32|0);
 HEAP32[$105>>2] = $104;
 ;HEAP32[$contactSolverDef+0>>2]=HEAP32[$step+0>>2]|0;HEAP32[$contactSolverDef+4>>2]=HEAP32[$step+4>>2]|0;HEAP32[$contactSolverDef+8>>2]=HEAP32[$step+8>>2]|0;HEAP32[$contactSolverDef+12>>2]=HEAP32[$step+12>>2]|0;HEAP32[$contactSolverDef+16>>2]=HEAP32[$step+16>>2]|0;HEAP32[$contactSolverDef+20>>2]=HEAP32[$step+20>>2]|0;HEAP32[$contactSolverDef+24>>2]=HEAP32[$step+24>>2]|0;
 $106 = (($this) + 12|0);
 $107 = HEAP32[$106>>2]|0;
 $108 = (($contactSolverDef) + 28|0);
 HEAP32[$108>>2] = $107;
 $109 = (($this) + 36|0);
 $110 = HEAP32[$109>>2]|0;
 $111 = (($contactSolverDef) + 32|0);
 HEAP32[$111>>2] = $110;
 $112 = HEAP32[$100>>2]|0;
 $113 = (($contactSolverDef) + 36|0);
 HEAP32[$113>>2] = $112;
 $114 = HEAP32[$103>>2]|0;
 $115 = (($contactSolverDef) + 40|0);
 HEAP32[$115>>2] = $114;
 $116 = HEAP32[$this>>2]|0;
 $117 = (($contactSolverDef) + 44|0);
 HEAP32[$117>>2] = $116;
 __ZN15b2ContactSolverC2EP18b2ContactSolverDef($contactSolver,$contactSolverDef);
 __ZN15b2ContactSolver29InitializeVelocityConstraintsEv($contactSolver);
 $118 = (($step) + 24|0);
 $119 = HEAP8[$118>>0]|0;
 $120 = ($119<<24>>24)==(0);
 if (!($120)) {
  __ZN15b2ContactSolver9WarmStartEv($contactSolver);
 }
 $121 = (($this) + 32|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = ($122|0)>(0);
 if ($123) {
  $124 = (($this) + 16|0);
  $i1$051 = 0;
  while(1) {
   $125 = HEAP32[$124>>2]|0;
   $126 = (($125) + ($i1$051<<2)|0);
   $127 = HEAP32[$126>>2]|0;
   $128 = HEAP32[$127>>2]|0;
   $129 = (($128) + 32|0);
   $130 = HEAP32[$129>>2]|0;
   FUNCTION_TABLE_vii[$130 & 63]($127,$solverData);
   $131 = (($i1$051) + 1)|0;
   $132 = HEAP32[$121>>2]|0;
   $133 = ($131|0)<($132|0);
   if ($133) {
    $i1$051 = $131;
   } else {
    break;
   }
  }
 }
 $134 = (+__ZNK7b2Timer15GetMillisecondsEv($timer));
 $135 = (($profile) + 12|0);
 HEAPF32[$135>>2] = $134;
 $136 = (($step) + 12|0);
 $137 = HEAP32[$136>>2]|0;
 $138 = ($137|0)>(0);
 if ($138) {
  $139 = (($this) + 16|0);
  $i2$045 = 0;
  while(1) {
   $140 = HEAP32[$121>>2]|0;
   $141 = ($140|0)>(0);
   if ($141) {
    $j$038 = 0;
    while(1) {
     $142 = HEAP32[$139>>2]|0;
     $143 = (($142) + ($j$038<<2)|0);
     $144 = HEAP32[$143>>2]|0;
     $145 = HEAP32[$144>>2]|0;
     $146 = (($145) + 36|0);
     $147 = HEAP32[$146>>2]|0;
     FUNCTION_TABLE_vii[$147 & 63]($144,$solverData);
     $148 = (($j$038) + 1)|0;
     $149 = HEAP32[$121>>2]|0;
     $150 = ($148|0)<($149|0);
     if ($150) {
      $j$038 = $148;
     } else {
      break;
     }
    }
   }
   __ZN15b2ContactSolver24SolveVelocityConstraintsEv($contactSolver);
   $151 = (($i2$045) + 1)|0;
   $152 = HEAP32[$136>>2]|0;
   $153 = ($151|0)<($152|0);
   if ($153) {
    $i2$045 = $151;
   } else {
    break;
   }
  }
 }
 __ZN15b2ContactSolver13StoreImpulsesEv($contactSolver);
 $154 = (+__ZNK7b2Timer15GetMillisecondsEv($timer));
 $155 = (($profile) + 16|0);
 HEAPF32[$155>>2] = $154;
 $156 = HEAP32[$6>>2]|0;
 $157 = ($156|0)>(0);
 if ($157) {
  $i3$031 = 0;
  while(1) {
   $158 = HEAP32[$100>>2]|0;
   $159 = (($158) + (($i3$031*12)|0)|0);
   $160 = $159;
   $161 = $160;
   $162 = HEAP32[$161>>2]|0;
   $163 = (($160) + 4)|0;
   $164 = $163;
   $165 = HEAP32[$164>>2]|0;
   $166 = $c4;
   $167 = $166;
   HEAP32[$167>>2] = $162;
   $168 = (($166) + 4)|0;
   $169 = $168;
   HEAP32[$169>>2] = $165;
   $170 = HEAP32[$100>>2]|0;
   $171 = ((($170) + (($i3$031*12)|0)|0) + 8|0);
   $172 = +HEAPF32[$171>>2];
   $173 = HEAP32[$103>>2]|0;
   $174 = (($173) + (($i3$031*12)|0)|0);
   $175 = $174;
   $176 = $175;
   $177 = HEAP32[$176>>2]|0;
   $178 = (($175) + 4)|0;
   $179 = $178;
   $180 = HEAP32[$179>>2]|0;
   $181 = $v6;
   $182 = $181;
   HEAP32[$182>>2] = $177;
   $183 = (($181) + 4)|0;
   $184 = $183;
   HEAP32[$184>>2] = $180;
   $185 = HEAP32[$103>>2]|0;
   $186 = ((($185) + (($i3$031*12)|0)|0) + 8|0);
   $187 = +HEAPF32[$186>>2];
   __ZmlfRK6b2Vec2($translation,$5,$v6);
   $188 = (+__Z5b2DotRK6b2Vec2S1_($translation,$translation));
   $189 = $188 > 4.0;
   if ($189) {
    $190 = (+__ZNK6b2Vec26LengthEv($translation));
    $191 = 2.0 / $190;
    __ZN6b2Vec2mLEf($v6,$191);
   }
   $192 = $5 * $187;
   $193 = $192 * $192;
   $194 = $193 > 2.4674012660980225;
   if ($194) {
    $195 = (+__Z5b2AbsIfET_S0_($192));
    $196 = 1.5707963705062866 / $195;
    $197 = $187 * $196;
    $w7$0 = $197;
   } else {
    $w7$0 = $187;
   }
   __ZmlfRK6b2Vec2($4,$5,$v6);
   __ZN6b2Vec2pLERKS_($c4,$4);
   $198 = $5 * $w7$0;
   $199 = $172 + $198;
   $200 = HEAP32[$100>>2]|0;
   $201 = (($200) + (($i3$031*12)|0)|0);
   $202 = $c4;
   $203 = $202;
   $204 = HEAP32[$203>>2]|0;
   $205 = (($202) + 4)|0;
   $206 = $205;
   $207 = HEAP32[$206>>2]|0;
   $208 = $201;
   $209 = $208;
   HEAP32[$209>>2] = $204;
   $210 = (($208) + 4)|0;
   $211 = $210;
   HEAP32[$211>>2] = $207;
   $212 = HEAP32[$100>>2]|0;
   $213 = ((($212) + (($i3$031*12)|0)|0) + 8|0);
   HEAPF32[$213>>2] = $199;
   $214 = HEAP32[$103>>2]|0;
   $215 = (($214) + (($i3$031*12)|0)|0);
   $216 = $v6;
   $217 = $216;
   $218 = HEAP32[$217>>2]|0;
   $219 = (($216) + 4)|0;
   $220 = $219;
   $221 = HEAP32[$220>>2]|0;
   $222 = $215;
   $223 = $222;
   HEAP32[$223>>2] = $218;
   $224 = (($222) + 4)|0;
   $225 = $224;
   HEAP32[$225>>2] = $221;
   $226 = HEAP32[$103>>2]|0;
   $227 = ((($226) + (($i3$031*12)|0)|0) + 8|0);
   HEAPF32[$227>>2] = $w7$0;
   $228 = (($i3$031) + 1)|0;
   $229 = HEAP32[$6>>2]|0;
   $230 = ($228|0)<($229|0);
   if ($230) {
    $i3$031 = $228;
   } else {
    break;
   }
  }
 }
 $231 = (($step) + 16|0);
 $232 = HEAP32[$231>>2]|0;
 $233 = ($232|0)>(0);
 L36: do {
  if ($233) {
   $234 = (($this) + 16|0);
   $i9$026 = 0;
   while(1) {
    $238 = (__ZN15b2ContactSolver24SolvePositionConstraintsEv($contactSolver)|0);
    $239 = HEAP32[$121>>2]|0;
    $240 = ($239|0)>(0);
    if ($240) {
     $i10$018 = 0;$jointsOkay$0$off017 = 1;
     while(1) {
      $241 = HEAP32[$234>>2]|0;
      $242 = (($241) + ($i10$018<<2)|0);
      $243 = HEAP32[$242>>2]|0;
      $244 = HEAP32[$243>>2]|0;
      $245 = (($244) + 40|0);
      $246 = HEAP32[$245>>2]|0;
      $247 = (FUNCTION_TABLE_iii[$246 & 63]($243,$solverData)|0);
      $$ = $jointsOkay$0$off017 & $247;
      $248 = (($i10$018) + 1)|0;
      $249 = HEAP32[$121>>2]|0;
      $250 = ($248|0)<($249|0);
      if ($250) {
       $i10$018 = $248;$jointsOkay$0$off017 = $$;
      } else {
       $jointsOkay$0$off0$lcssa = $$;
       break;
      }
     }
    } else {
     $jointsOkay$0$off0$lcssa = 1;
    }
    $brmerge$demorgan = $238 & $jointsOkay$0$off0$lcssa;
    $236 = (($i9$026) + 1)|0;
    if ($brmerge$demorgan) {
     $positionSolved$0$off0 = 0;
     break L36;
    }
    $235 = HEAP32[$231>>2]|0;
    $237 = ($236|0)<($235|0);
    if ($237) {
     $i9$026 = $236;
    } else {
     $positionSolved$0$off0 = 1;
     break;
    }
   }
  } else {
   $positionSolved$0$off0 = 1;
  }
 } while(0);
 $251 = HEAP32[$6>>2]|0;
 $252 = ($251|0)>(0);
 if ($252) {
  $253 = (($this) + 8|0);
  $i11$010 = 0;
  while(1) {
   $254 = HEAP32[$253>>2]|0;
   $255 = (($254) + ($i11$010<<2)|0);
   $256 = HEAP32[$255>>2]|0;
   $257 = (($256) + 60|0);
   $258 = HEAP32[$100>>2]|0;
   $259 = (($258) + (($i11$010*12)|0)|0);
   $260 = $259;
   $261 = $260;
   $262 = HEAP32[$261>>2]|0;
   $263 = (($260) + 4)|0;
   $264 = $263;
   $265 = HEAP32[$264>>2]|0;
   $266 = $257;
   $267 = $266;
   HEAP32[$267>>2] = $262;
   $268 = (($266) + 4)|0;
   $269 = $268;
   HEAP32[$269>>2] = $265;
   $270 = HEAP32[$100>>2]|0;
   $271 = ((($270) + (($i11$010*12)|0)|0) + 8|0);
   $272 = +HEAPF32[$271>>2];
   $273 = (($256) + 72|0);
   HEAPF32[$273>>2] = $272;
   $274 = (($256) + 80|0);
   $275 = HEAP32[$103>>2]|0;
   $276 = (($275) + (($i11$010*12)|0)|0);
   $277 = $276;
   $278 = $277;
   $279 = HEAP32[$278>>2]|0;
   $280 = (($277) + 4)|0;
   $281 = $280;
   $282 = HEAP32[$281>>2]|0;
   $283 = $274;
   $284 = $283;
   HEAP32[$284>>2] = $279;
   $285 = (($283) + 4)|0;
   $286 = $285;
   HEAP32[$286>>2] = $282;
   $287 = HEAP32[$103>>2]|0;
   $288 = ((($287) + (($i11$010*12)|0)|0) + 8|0);
   $289 = +HEAPF32[$288>>2];
   $290 = (($256) + 88|0);
   HEAPF32[$290>>2] = $289;
   __ZN6b2Body20SynchronizeTransformEv($256);
   $291 = (($i11$010) + 1)|0;
   $292 = HEAP32[$6>>2]|0;
   $293 = ($291|0)<($292|0);
   if ($293) {
    $i11$010 = $291;
   } else {
    break;
   }
  }
 }
 $294 = (+__ZNK7b2Timer15GetMillisecondsEv($timer));
 $295 = (($profile) + 20|0);
 HEAPF32[$295>>2] = $294;
 $296 = (($contactSolver) + 44|0);
 $297 = HEAP32[$296>>2]|0;
 __ZN8b2Island6ReportEPK27b2ContactVelocityConstraint($this,$297);
 if (!($allowSleep)) {
  __ZN15b2ContactSolverD2Ev($contactSolver);
  STACKTOP = sp;return;
 }
 $298 = HEAP32[$6>>2]|0;
 $299 = ($298|0)>(0);
 if ($299) {
  $300 = (($this) + 8|0);
  $i12$08 = 0;$minSleepTime$07 = 3.4028234663852886E+38;
  while(1) {
   $301 = HEAP32[$300>>2]|0;
   $302 = (($301) + ($i12$08<<2)|0);
   $303 = HEAP32[$302>>2]|0;
   $304 = (__ZNK6b2Body7GetTypeEv($303)|0);
   $305 = ($304|0)==(0);
   do {
    if ($305) {
     $minSleepTime$1 = $minSleepTime$07;
    } else {
     $306 = (($303) + 4|0);
     $307 = HEAP16[$306>>1]|0;
     $308 = $307 & 4;
     $309 = ($308<<16>>16)==(0);
     if (!($309)) {
      $310 = (($303) + 88|0);
      $311 = +HEAPF32[$310>>2];
      $312 = $311 * $311;
      $313 = $312 > 0.0012184699298813939;
      if (!($313)) {
       $314 = (($303) + 80|0);
       $315 = (+__Z5b2DotRK6b2Vec2S1_($314,$314));
       $316 = $315 > 9.9999997473787516E-5;
       if (!($316)) {
        $318 = (($303) + 160|0);
        $319 = +HEAPF32[$318>>2];
        $320 = $5 + $319;
        HEAPF32[$318>>2] = $320;
        $321 = (+__Z5b2MinIfET_S0_S0_($minSleepTime$07,$320));
        $minSleepTime$1 = $321;
        break;
       }
      }
     }
     $317 = (($303) + 160|0);
     HEAPF32[$317>>2] = 0.0;
     $minSleepTime$1 = 0.0;
    }
   } while(0);
   $322 = (($i12$08) + 1)|0;
   $323 = HEAP32[$6>>2]|0;
   $324 = ($322|0)<($323|0);
   if ($324) {
    $i12$08 = $322;$minSleepTime$07 = $minSleepTime$1;
   } else {
    $minSleepTime$0$lcssa = $minSleepTime$1;
    break;
   }
  }
 } else {
  $minSleepTime$0$lcssa = 3.4028234663852886E+38;
 }
 $325 = !($minSleepTime$0$lcssa >= 0.5);
 $brmerge4 = $325 | $positionSolved$0$off0;
 if ($brmerge4) {
  __ZN15b2ContactSolverD2Ev($contactSolver);
  STACKTOP = sp;return;
 }
 $326 = HEAP32[$6>>2]|0;
 $327 = ($326|0)>(0);
 if (!($327)) {
  __ZN15b2ContactSolverD2Ev($contactSolver);
  STACKTOP = sp;return;
 }
 $328 = (($this) + 8|0);
 $i14$05 = 0;
 while(1) {
  $329 = HEAP32[$328>>2]|0;
  $330 = (($329) + ($i14$05<<2)|0);
  $331 = HEAP32[$330>>2]|0;
  __ZN6b2Body8SetAwakeEb($331,0);
  $332 = (($i14$05) + 1)|0;
  $333 = HEAP32[$6>>2]|0;
  $334 = ($332|0)<($333|0);
  if ($334) {
   $i14$05 = $332;
  } else {
   break;
  }
 }
 __ZN15b2ContactSolverD2Ev($contactSolver);
 STACKTOP = sp;return;
}
function __ZN8b2Island6ReportEPK27b2ContactVelocityConstraint($this,$constraints) {
 $this = $this|0;
 $constraints = $constraints|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $impulse = 0, $j$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $impulse = sp;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 36|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 12|0);
 $7 = (($impulse) + 16|0);
 $i$02 = 0;
 while(1) {
  $8 = HEAP32[$6>>2]|0;
  $9 = (($8) + ($i$02<<2)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($constraints) + (($i$02*156)|0)|0) + 148|0);
  $12 = HEAP32[$11>>2]|0;
  HEAP32[$7>>2] = $12;
  $13 = HEAP32[$11>>2]|0;
  $14 = ($13|0)>(0);
  if ($14) {
   $15 = HEAP32[$11>>2]|0;
   $j$01 = 0;
   while(1) {
    $16 = (((($constraints) + (($i$02*156)|0)|0) + (($j$01*36)|0)|0) + 16|0);
    $17 = +HEAPF32[$16>>2];
    $18 = (($impulse) + ($j$01<<2)|0);
    HEAPF32[$18>>2] = $17;
    $19 = (((($constraints) + (($i$02*156)|0)|0) + (($j$01*36)|0)|0) + 20|0);
    $20 = +HEAPF32[$19>>2];
    $21 = ((($impulse) + ($j$01<<2)|0) + 8|0);
    HEAPF32[$21>>2] = $20;
    $22 = (($j$01) + 1)|0;
    $23 = ($22|0)<($15|0);
    if ($23) {
     $j$01 = $22;
    } else {
     break;
    }
   }
  }
  $24 = HEAP32[$0>>2]|0;
  $25 = HEAP32[$24>>2]|0;
  $26 = (($25) + 36|0);
  $27 = HEAP32[$26>>2]|0;
  FUNCTION_TABLE_viii[$27 & 15]($24,$10,$impulse);
  $28 = (($i$02) + 1)|0;
  $29 = HEAP32[$3>>2]|0;
  $30 = ($28|0)<($29|0);
  if ($30) {
   $i$02 = $28;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN8b2Island8SolveTOIERK10b2TimeStepii($this,$subStep,$toiIndexA,$toiIndexB) {
 $this = $this|0;
 $subStep = $subStep|0;
 $toiIndexA = $toiIndexA|0;
 $toiIndexB = $toiIndexB|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0.0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0.0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0.0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0.0, $154 = 0.0, $155 = 0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0.0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0.0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $c = 0, $contactSolver = 0, $contactSolverDef = 0, $i$013 = 0, $i1$09 = 0, $i2$03 = 0, $i3$02 = 0, $translation = 0, $v = 0, $w$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $contactSolverDef = sp + 88|0;
 $contactSolver = sp + 32|0;
 $c = sp + 8|0;
 $v = sp;
 $translation = sp + 24|0;
 $0 = sp + 16|0;
 $1 = (($this) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(0);
 if ($3) {
  $4 = (($this) + 8|0);
  $5 = (($this) + 20|0);
  $6 = (($this) + 24|0);
  $i$013 = 0;
  while(1) {
   $7 = HEAP32[$4>>2]|0;
   $8 = (($7) + ($i$013<<2)|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP32[$5>>2]|0;
   $11 = (($10) + (($i$013*12)|0)|0);
   $12 = (($9) + 60|0);
   $13 = $12;
   $14 = $13;
   $15 = HEAP32[$14>>2]|0;
   $16 = (($13) + 4)|0;
   $17 = $16;
   $18 = HEAP32[$17>>2]|0;
   $19 = $11;
   $20 = $19;
   HEAP32[$20>>2] = $15;
   $21 = (($19) + 4)|0;
   $22 = $21;
   HEAP32[$22>>2] = $18;
   $23 = (($9) + 72|0);
   $24 = +HEAPF32[$23>>2];
   $25 = HEAP32[$5>>2]|0;
   $26 = ((($25) + (($i$013*12)|0)|0) + 8|0);
   HEAPF32[$26>>2] = $24;
   $27 = HEAP32[$6>>2]|0;
   $28 = (($27) + (($i$013*12)|0)|0);
   $29 = (($9) + 80|0);
   $30 = $29;
   $31 = $30;
   $32 = HEAP32[$31>>2]|0;
   $33 = (($30) + 4)|0;
   $34 = $33;
   $35 = HEAP32[$34>>2]|0;
   $36 = $28;
   $37 = $36;
   HEAP32[$37>>2] = $32;
   $38 = (($36) + 4)|0;
   $39 = $38;
   HEAP32[$39>>2] = $35;
   $40 = (($9) + 88|0);
   $41 = +HEAPF32[$40>>2];
   $42 = HEAP32[$6>>2]|0;
   $43 = ((($42) + (($i$013*12)|0)|0) + 8|0);
   HEAPF32[$43>>2] = $41;
   $44 = (($i$013) + 1)|0;
   $45 = HEAP32[$1>>2]|0;
   $46 = ($44|0)<($45|0);
   if ($46) {
    $i$013 = $44;
   } else {
    break;
   }
  }
 }
 $47 = (($this) + 12|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($contactSolverDef) + 28|0);
 HEAP32[$49>>2] = $48;
 $50 = (($this) + 36|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($contactSolverDef) + 32|0);
 HEAP32[$52>>2] = $51;
 $53 = HEAP32[$this>>2]|0;
 $54 = (($contactSolverDef) + 44|0);
 HEAP32[$54>>2] = $53;
 ;HEAP32[$contactSolverDef+0>>2]=HEAP32[$subStep+0>>2]|0;HEAP32[$contactSolverDef+4>>2]=HEAP32[$subStep+4>>2]|0;HEAP32[$contactSolverDef+8>>2]=HEAP32[$subStep+8>>2]|0;HEAP32[$contactSolverDef+12>>2]=HEAP32[$subStep+12>>2]|0;HEAP32[$contactSolverDef+16>>2]=HEAP32[$subStep+16>>2]|0;HEAP32[$contactSolverDef+20>>2]=HEAP32[$subStep+20>>2]|0;HEAP32[$contactSolverDef+24>>2]=HEAP32[$subStep+24>>2]|0;
 $55 = (($this) + 20|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = (($contactSolverDef) + 36|0);
 HEAP32[$57>>2] = $56;
 $58 = (($this) + 24|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($contactSolverDef) + 40|0);
 HEAP32[$60>>2] = $59;
 __ZN15b2ContactSolverC2EP18b2ContactSolverDef($contactSolver,$contactSolverDef);
 $61 = (($subStep) + 16|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = ($62|0)>(0);
 L6: do {
  if ($63) {
   $i1$09 = 0;
   while(1) {
    $67 = (__ZN15b2ContactSolver27SolveTOIPositionConstraintsEii($contactSolver,$toiIndexA,$toiIndexB)|0);
    $65 = (($i1$09) + 1)|0;
    if ($67) {
     break L6;
    }
    $64 = HEAP32[$61>>2]|0;
    $66 = ($65|0)<($64|0);
    if ($66) {
     $i1$09 = $65;
    } else {
     break;
    }
   }
  }
 } while(0);
 $68 = (($this) + 8|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (($69) + ($toiIndexA<<2)|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = (($71) + 52|0);
 $73 = HEAP32[$55>>2]|0;
 $74 = (($73) + (($toiIndexA*12)|0)|0);
 $75 = $74;
 $76 = $75;
 $77 = HEAP32[$76>>2]|0;
 $78 = (($75) + 4)|0;
 $79 = $78;
 $80 = HEAP32[$79>>2]|0;
 $81 = $72;
 $82 = $81;
 HEAP32[$82>>2] = $77;
 $83 = (($81) + 4)|0;
 $84 = $83;
 HEAP32[$84>>2] = $80;
 $85 = HEAP32[$55>>2]|0;
 $86 = ((($85) + (($toiIndexA*12)|0)|0) + 8|0);
 $87 = +HEAPF32[$86>>2];
 $88 = HEAP32[$68>>2]|0;
 $89 = (($88) + ($toiIndexA<<2)|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = (($90) + 68|0);
 HEAPF32[$91>>2] = $87;
 $92 = HEAP32[$68>>2]|0;
 $93 = (($92) + ($toiIndexB<<2)|0);
 $94 = HEAP32[$93>>2]|0;
 $95 = (($94) + 52|0);
 $96 = HEAP32[$55>>2]|0;
 $97 = (($96) + (($toiIndexB*12)|0)|0);
 $98 = $97;
 $99 = $98;
 $100 = HEAP32[$99>>2]|0;
 $101 = (($98) + 4)|0;
 $102 = $101;
 $103 = HEAP32[$102>>2]|0;
 $104 = $95;
 $105 = $104;
 HEAP32[$105>>2] = $100;
 $106 = (($104) + 4)|0;
 $107 = $106;
 HEAP32[$107>>2] = $103;
 $108 = HEAP32[$55>>2]|0;
 $109 = ((($108) + (($toiIndexB*12)|0)|0) + 8|0);
 $110 = +HEAPF32[$109>>2];
 $111 = HEAP32[$68>>2]|0;
 $112 = (($111) + ($toiIndexB<<2)|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = (($113) + 68|0);
 HEAPF32[$114>>2] = $110;
 __ZN15b2ContactSolver29InitializeVelocityConstraintsEv($contactSolver);
 $115 = (($subStep) + 12|0);
 $116 = HEAP32[$115>>2]|0;
 $117 = ($116|0)>(0);
 if ($117) {
  $i2$03 = 0;
  while(1) {
   __ZN15b2ContactSolver24SolveVelocityConstraintsEv($contactSolver);
   $118 = (($i2$03) + 1)|0;
   $119 = HEAP32[$115>>2]|0;
   $120 = ($118|0)<($119|0);
   if ($120) {
    $i2$03 = $118;
   } else {
    break;
   }
  }
 }
 $121 = +HEAPF32[$subStep>>2];
 $122 = HEAP32[$1>>2]|0;
 $123 = ($122|0)>(0);
 if ($123) {
  $i3$02 = 0;
 } else {
  $224 = (($contactSolver) + 44|0);
  $225 = HEAP32[$224>>2]|0;
  __ZN8b2Island6ReportEPK27b2ContactVelocityConstraint($this,$225);
  __ZN15b2ContactSolverD2Ev($contactSolver);
  STACKTOP = sp;return;
 }
 while(1) {
  $124 = HEAP32[$55>>2]|0;
  $125 = (($124) + (($i3$02*12)|0)|0);
  $126 = $125;
  $127 = $126;
  $128 = HEAP32[$127>>2]|0;
  $129 = (($126) + 4)|0;
  $130 = $129;
  $131 = HEAP32[$130>>2]|0;
  $132 = $c;
  $133 = $132;
  HEAP32[$133>>2] = $128;
  $134 = (($132) + 4)|0;
  $135 = $134;
  HEAP32[$135>>2] = $131;
  $136 = HEAP32[$55>>2]|0;
  $137 = ((($136) + (($i3$02*12)|0)|0) + 8|0);
  $138 = +HEAPF32[$137>>2];
  $139 = HEAP32[$58>>2]|0;
  $140 = (($139) + (($i3$02*12)|0)|0);
  $141 = $140;
  $142 = $141;
  $143 = HEAP32[$142>>2]|0;
  $144 = (($141) + 4)|0;
  $145 = $144;
  $146 = HEAP32[$145>>2]|0;
  $147 = $v;
  $148 = $147;
  HEAP32[$148>>2] = $143;
  $149 = (($147) + 4)|0;
  $150 = $149;
  HEAP32[$150>>2] = $146;
  $151 = HEAP32[$58>>2]|0;
  $152 = ((($151) + (($i3$02*12)|0)|0) + 8|0);
  $153 = +HEAPF32[$152>>2];
  __ZmlfRK6b2Vec2($translation,$121,$v);
  $154 = (+__Z5b2DotRK6b2Vec2S1_($translation,$translation));
  $155 = $154 > 4.0;
  if ($155) {
   $156 = (+__ZNK6b2Vec26LengthEv($translation));
   $157 = 2.0 / $156;
   __ZN6b2Vec2mLEf($v,$157);
  }
  $158 = $121 * $153;
  $159 = $158 * $158;
  $160 = $159 > 2.4674012660980225;
  if ($160) {
   $161 = (+__Z5b2AbsIfET_S0_($158));
   $162 = 1.5707963705062866 / $161;
   $163 = $153 * $162;
   $w$0 = $163;
  } else {
   $w$0 = $153;
  }
  __ZmlfRK6b2Vec2($0,$121,$v);
  __ZN6b2Vec2pLERKS_($c,$0);
  $164 = $121 * $w$0;
  $165 = $138 + $164;
  $166 = HEAP32[$55>>2]|0;
  $167 = (($166) + (($i3$02*12)|0)|0);
  $168 = $c;
  $169 = $168;
  $170 = HEAP32[$169>>2]|0;
  $171 = (($168) + 4)|0;
  $172 = $171;
  $173 = HEAP32[$172>>2]|0;
  $174 = $167;
  $175 = $174;
  HEAP32[$175>>2] = $170;
  $176 = (($174) + 4)|0;
  $177 = $176;
  HEAP32[$177>>2] = $173;
  $178 = HEAP32[$55>>2]|0;
  $179 = ((($178) + (($i3$02*12)|0)|0) + 8|0);
  HEAPF32[$179>>2] = $165;
  $180 = HEAP32[$58>>2]|0;
  $181 = (($180) + (($i3$02*12)|0)|0);
  $182 = $v;
  $183 = $182;
  $184 = HEAP32[$183>>2]|0;
  $185 = (($182) + 4)|0;
  $186 = $185;
  $187 = HEAP32[$186>>2]|0;
  $188 = $181;
  $189 = $188;
  HEAP32[$189>>2] = $184;
  $190 = (($188) + 4)|0;
  $191 = $190;
  HEAP32[$191>>2] = $187;
  $192 = HEAP32[$58>>2]|0;
  $193 = ((($192) + (($i3$02*12)|0)|0) + 8|0);
  HEAPF32[$193>>2] = $w$0;
  $194 = HEAP32[$68>>2]|0;
  $195 = (($194) + ($i3$02<<2)|0);
  $196 = HEAP32[$195>>2]|0;
  $197 = (($196) + 60|0);
  $198 = $c;
  $199 = $198;
  $200 = HEAP32[$199>>2]|0;
  $201 = (($198) + 4)|0;
  $202 = $201;
  $203 = HEAP32[$202>>2]|0;
  $204 = $197;
  $205 = $204;
  HEAP32[$205>>2] = $200;
  $206 = (($204) + 4)|0;
  $207 = $206;
  HEAP32[$207>>2] = $203;
  $208 = (($196) + 72|0);
  HEAPF32[$208>>2] = $165;
  $209 = (($196) + 80|0);
  $210 = $v;
  $211 = $210;
  $212 = HEAP32[$211>>2]|0;
  $213 = (($210) + 4)|0;
  $214 = $213;
  $215 = HEAP32[$214>>2]|0;
  $216 = $209;
  $217 = $216;
  HEAP32[$217>>2] = $212;
  $218 = (($216) + 4)|0;
  $219 = $218;
  HEAP32[$219>>2] = $215;
  $220 = (($196) + 88|0);
  HEAPF32[$220>>2] = $w$0;
  __ZN6b2Body20SynchronizeTransformEv($196);
  $221 = (($i3$02) + 1)|0;
  $222 = HEAP32[$1>>2]|0;
  $223 = ($221|0)<($222|0);
  if ($223) {
   $i3$02 = $221;
  } else {
   break;
  }
 }
 $224 = (($contactSolver) + 44|0);
 $225 = HEAP32[$224>>2]|0;
 __ZN8b2Island6ReportEPK27b2ContactVelocityConstraint($this,$225);
 __ZN15b2ContactSolverD2Ev($contactSolver);
 STACKTOP = sp;return;
}
function __ZN6b2Body20SynchronizeTransformEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = (($this) + 20|0);
 $3 = (($this) + 72|0);
 $4 = +HEAPF32[$3>>2];
 __ZN5b2Rot3SetEf($2,$4);
 $5 = (($this) + 12|0);
 $6 = (($this) + 60|0);
 $7 = (($this) + 44|0);
 __Z5b2MulRK5b2RotRK6b2Vec2($1,$2,$7);
 __ZmiRK6b2Vec2S1_($0,$6,$1);
 $8 = $0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = $5;
 $15 = $14;
 HEAP32[$15>>2] = $10;
 $16 = (($14) + 4)|0;
 $17 = $16;
 HEAP32[$17>>2] = $13;
 STACKTOP = sp;return;
}
function __ZN15b2ContactFilter13ShouldCollideEP9b2FixtureS1_($this,$fixtureA,$fixtureB) {
 $this = $this|0;
 $fixtureA = $fixtureA|0;
 $fixtureB = $fixtureB|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK9b2Fixture13GetFilterDataEv($fixtureA)|0);
 $1 = (__ZNK9b2Fixture13GetFilterDataEv($fixtureB)|0);
 $2 = (($0) + 4|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = (($1) + 4|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = ($3<<16>>16)!=($5<<16>>16);
 $7 = ($3<<16>>16)==(0);
 $or$cond = $6 | $7;
 if (!($or$cond)) {
  $8 = ($3<<16>>16)>(0);
  $$0 = $8;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (($0) + 2|0);
 $10 = HEAP16[$9>>1]|0;
 $11 = HEAP16[$1>>1]|0;
 $12 = $11 & $10;
 $13 = ($12<<16>>16)==(0);
 if ($13) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = HEAP16[$0>>1]|0;
 $15 = (($1) + 2|0);
 $16 = HEAP16[$15>>1]|0;
 $17 = $16 & $14;
 $18 = ($17<<16>>16)!=(0);
 $$0 = $18;
 STACKTOP = sp;return ($$0|0);
}
function __ZN15b2ContactFilterD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN15b2ContactFilterD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN15b2ContactFilter13ShouldCollideEP9b2FixtureP16b2ParticleSystemi($this,$fixture,$particleSystem,$particleIndex) {
 $this = $this|0;
 $fixture = $fixture|0;
 $particleSystem = $particleSystem|0;
 $particleIndex = $particleIndex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN15b2ContactFilter13ShouldCollideEP16b2ParticleSystemii($this,$particleSystem,$particleIndexA,$particleIndexB) {
 $this = $this|0;
 $particleSystem = $particleSystem|0;
 $particleIndexA = $particleIndexA|0;
 $particleIndexB = $particleIndexB|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZNK9b2Fixture13GetFilterDataEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12b2MouseJointC2EPK15b2MouseJointDef($this,$def) {
 $this = $this|0;
 $def = $def|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN7b2JointC2EPK10b2JointDef($this,$def);
 HEAP32[$this>>2] = ((2320 + 8|0));
 $1 = (($this) + 68|0);
 $2 = (($this) + 76|0);
 $3 = (($this) + 96|0);
 $4 = (($def) + 20|0);
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $2;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 $15 = (($this) + 52|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (__ZNK6b2Body12GetTransformEv($16)|0);
 __Z6b2MulTRK11b2TransformRK6b2Vec2($0,$17,$2);
 $18 = $0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + 4)|0;
 $22 = $21;
 $23 = HEAP32[$22>>2]|0;
 $24 = $1;
 $25 = $24;
 HEAP32[$25>>2] = $20;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = $23;
 $28 = (($def) + 28|0);
 $29 = +HEAPF32[$28>>2];
 $30 = (($this) + 104|0);
 HEAPF32[$30>>2] = $29;
 __ZN6b2Vec27SetZeroEv($3);
 $31 = (($def) + 32|0);
 $32 = +HEAPF32[$31>>2];
 $33 = (($this) + 84|0);
 HEAPF32[$33>>2] = $32;
 $34 = (($def) + 36|0);
 $35 = +HEAPF32[$34>>2];
 $36 = (($this) + 88|0);
 HEAPF32[$36>>2] = $35;
 $37 = (($this) + 92|0);
 HEAPF32[$37>>2] = 0.0;
 $38 = (($this) + 108|0);
 HEAPF32[$38>>2] = 0.0;
 STACKTOP = sp;return;
}
function __ZN12b2MouseJoint9SetTargetERK6b2Vec2($this,$target) {
 $this = $this|0;
 $target = $target|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK6b2Body7IsAwakeEv($1)|0);
 if (!($2)) {
  __ZN6b2Body8SetAwakeEb($1,1);
 }
 $3 = (($this) + 76|0);
 $4 = $target;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = $3;
 $11 = $10;
 HEAP32[$11>>2] = $6;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = $9;
 STACKTOP = sp;return;
}
function __ZN12b2MouseJoint23InitVelocityConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0;
 var $116 = 0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0.0, $15 = 0, $150 = 0.0, $151 = 0.0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0.0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0;
 var $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0, $84 = 0, $85 = 0.0, $86 = 0.0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $K = 0, $cB = 0, $qB = 0, $storemerge = 0.0, $vB = 0, $wB$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $cB = sp + 24|0;
 $vB = sp + 16|0;
 $qB = sp + 88|0;
 $0 = sp + 8|0;
 $1 = sp + 80|0;
 $K = sp + 64|0;
 $2 = sp + 48|0;
 $3 = sp;
 $4 = sp + 40|0;
 $5 = sp + 32|0;
 $6 = (($this) + 52|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 116|0);
 HEAP32[$10>>2] = $9;
 $11 = (($this) + 128|0);
 $12 = HEAP32[$6>>2]|0;
 $13 = (($12) + 44|0);
 $14 = $13;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14) + 4)|0;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = $11;
 $21 = $20;
 HEAP32[$21>>2] = $16;
 $22 = (($20) + 4)|0;
 $23 = $22;
 HEAP32[$23>>2] = $19;
 $24 = HEAP32[$6>>2]|0;
 $25 = (($24) + 136|0);
 $26 = +HEAPF32[$25>>2];
 $27 = (($this) + 136|0);
 HEAPF32[$27>>2] = $26;
 $28 = HEAP32[$6>>2]|0;
 $29 = (($28) + 144|0);
 $30 = +HEAPF32[$29>>2];
 $31 = (($this) + 140|0);
 HEAPF32[$31>>2] = $30;
 $32 = HEAP32[$10>>2]|0;
 $33 = (($data) + 28|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + (($32*12)|0)|0);
 $36 = $35;
 $37 = $36;
 $38 = HEAP32[$37>>2]|0;
 $39 = (($36) + 4)|0;
 $40 = $39;
 $41 = HEAP32[$40>>2]|0;
 $42 = $cB;
 $43 = $42;
 HEAP32[$43>>2] = $38;
 $44 = (($42) + 4)|0;
 $45 = $44;
 HEAP32[$45>>2] = $41;
 $46 = HEAP32[$10>>2]|0;
 $47 = HEAP32[$33>>2]|0;
 $48 = ((($47) + (($46*12)|0)|0) + 8|0);
 $49 = +HEAPF32[$48>>2];
 $50 = (($data) + 32|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($51) + (($46*12)|0)|0);
 $53 = $52;
 $54 = $53;
 $55 = HEAP32[$54>>2]|0;
 $56 = (($53) + 4)|0;
 $57 = $56;
 $58 = HEAP32[$57>>2]|0;
 $59 = $vB;
 $60 = $59;
 HEAP32[$60>>2] = $55;
 $61 = (($59) + 4)|0;
 $62 = $61;
 HEAP32[$62>>2] = $58;
 $63 = HEAP32[$10>>2]|0;
 $64 = HEAP32[$50>>2]|0;
 $65 = ((($64) + (($63*12)|0)|0) + 8|0);
 $66 = +HEAPF32[$65>>2];
 __ZN5b2RotC2Ef($qB,$49);
 $67 = HEAP32[$6>>2]|0;
 $68 = (+__ZNK6b2Body7GetMassEv($67));
 $69 = (($this) + 84|0);
 $70 = +HEAPF32[$69>>2];
 $71 = $70 * 6.2831854820251465;
 $72 = $68 * 2.0;
 $73 = (($this) + 88|0);
 $74 = +HEAPF32[$73>>2];
 $75 = $72 * $74;
 $76 = $71 * $75;
 $77 = $71 * $71;
 $78 = $68 * $77;
 $79 = +HEAPF32[$data>>2];
 $80 = $79 * $78;
 $81 = $76 + $80;
 $82 = $79 * $81;
 $83 = (($this) + 108|0);
 $84 = $82 != 0.0;
 if ($84) {
  $85 = 1.0 / $82;
  $storemerge = $85;
 } else {
  $storemerge = $82;
 }
 HEAPF32[$83>>2] = $storemerge;
 $86 = $80 * $storemerge;
 $87 = (($this) + 92|0);
 HEAPF32[$87>>2] = $86;
 $88 = (($this) + 120|0);
 $89 = (($this) + 68|0);
 __ZmiRK6b2Vec2S1_($1,$89,$11);
 __Z5b2MulRK5b2RotRK6b2Vec2($0,$qB,$1);
 $90 = $0;
 $91 = $90;
 $92 = HEAP32[$91>>2]|0;
 $93 = (($90) + 4)|0;
 $94 = $93;
 $95 = HEAP32[$94>>2]|0;
 $96 = $88;
 $97 = $96;
 HEAP32[$97>>2] = $92;
 $98 = (($96) + 4)|0;
 $99 = $98;
 HEAP32[$99>>2] = $95;
 $100 = +HEAPF32[$27>>2];
 $101 = +HEAPF32[$31>>2];
 $102 = (($this) + 124|0);
 $103 = +HEAPF32[$102>>2];
 $104 = $101 * $103;
 $105 = $103 * $104;
 $106 = $100 + $105;
 $107 = +HEAPF32[$83>>2];
 $108 = $107 + $106;
 HEAPF32[$K>>2] = $108;
 $109 = +HEAPF32[$31>>2];
 $110 = +HEAPF32[$88>>2];
 $111 = $109 * $110;
 $112 = +HEAPF32[$102>>2];
 $113 = $111 * $112;
 $114 = -$113;
 $115 = (($K) + 4|0);
 HEAPF32[$115>>2] = $114;
 $116 = (($K) + 8|0);
 HEAPF32[$116>>2] = $114;
 $117 = +HEAPF32[$27>>2];
 $118 = +HEAPF32[$31>>2];
 $119 = +HEAPF32[$88>>2];
 $120 = $118 * $119;
 $121 = $119 * $120;
 $122 = $117 + $121;
 $123 = +HEAPF32[$83>>2];
 $124 = $123 + $122;
 $125 = (($K) + 12|0);
 HEAPF32[$125>>2] = $124;
 $126 = (($this) + 144|0);
 __ZNK7b2Mat2210GetInverseEv($2,$K);
 ;HEAP32[$126+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$126+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$126+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$126+12>>2]=HEAP32[$2+12>>2]|0;
 $127 = (($this) + 160|0);
 __ZplRK6b2Vec2S1_($4,$cB,$88);
 $128 = (($this) + 76|0);
 __ZmiRK6b2Vec2S1_($3,$4,$128);
 $129 = $3;
 $130 = $129;
 $131 = HEAP32[$130>>2]|0;
 $132 = (($129) + 4)|0;
 $133 = $132;
 $134 = HEAP32[$133>>2]|0;
 $135 = $127;
 $136 = $135;
 HEAP32[$136>>2] = $131;
 $137 = (($135) + 4)|0;
 $138 = $137;
 HEAP32[$138>>2] = $134;
 $139 = +HEAPF32[$87>>2];
 __ZN6b2Vec2mLEf($127,$139);
 $140 = $66 * 0.98000001907348633;
 $141 = (($data) + 24|0);
 $142 = HEAP8[$141>>0]|0;
 $143 = ($142<<24>>24)==(0);
 $144 = (($this) + 96|0);
 if ($143) {
  __ZN6b2Vec27SetZeroEv($144);
  $wB$0 = $140;
  $152 = HEAP32[$10>>2]|0;
  $153 = HEAP32[$50>>2]|0;
  $154 = (($153) + (($152*12)|0)|0);
  $155 = $vB;
  $156 = $155;
  $157 = HEAP32[$156>>2]|0;
  $158 = (($155) + 4)|0;
  $159 = $158;
  $160 = HEAP32[$159>>2]|0;
  $161 = $154;
  $162 = $161;
  HEAP32[$162>>2] = $157;
  $163 = (($161) + 4)|0;
  $164 = $163;
  HEAP32[$164>>2] = $160;
  $165 = HEAP32[$10>>2]|0;
  $166 = HEAP32[$50>>2]|0;
  $167 = ((($166) + (($165*12)|0)|0) + 8|0);
  HEAPF32[$167>>2] = $wB$0;
  STACKTOP = sp;return;
 } else {
  $145 = (($data) + 8|0);
  $146 = +HEAPF32[$145>>2];
  __ZN6b2Vec2mLEf($144,$146);
  $147 = +HEAPF32[$27>>2];
  __ZmlfRK6b2Vec2($5,$147,$144);
  __ZN6b2Vec2pLERKS_($vB,$5);
  $148 = +HEAPF32[$31>>2];
  $149 = (+__Z7b2CrossRK6b2Vec2S1_($88,$144));
  $150 = $148 * $149;
  $151 = $140 + $150;
  $wB$0 = $151;
  $152 = HEAP32[$10>>2]|0;
  $153 = HEAP32[$50>>2]|0;
  $154 = (($153) + (($152*12)|0)|0);
  $155 = $vB;
  $156 = $155;
  $157 = HEAP32[$156>>2]|0;
  $158 = (($155) + 4)|0;
  $159 = $158;
  $160 = HEAP32[$159>>2]|0;
  $161 = $154;
  $162 = $161;
  HEAP32[$162>>2] = $157;
  $163 = (($161) + 4)|0;
  $164 = $163;
  HEAP32[$164>>2] = $160;
  $165 = HEAP32[$10>>2]|0;
  $166 = HEAP32[$50>>2]|0;
  $167 = ((($166) + (($165*12)|0)|0) + 8|0);
  HEAPF32[$167>>2] = $wB$0;
  STACKTOP = sp;return;
 }
}
function __ZN12b2MouseJoint24SolveVelocityConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0.0;
 var $45 = 0.0, $46 = 0.0, $47 = 0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $Cdot = 0, $impulse = 0, $oldImpulse = 0, $vB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $vB = sp + 16|0;
 $Cdot = sp + 72|0;
 $0 = sp + 64|0;
 $impulse = sp + 8|0;
 $1 = sp + 56|0;
 $2 = sp + 48|0;
 $3 = sp + 40|0;
 $4 = sp + 32|0;
 $oldImpulse = sp;
 $5 = sp + 24|0;
 $6 = (($this) + 116|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($data) + 32|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + (($7*12)|0)|0);
 $11 = $10;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + 4)|0;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = $vB;
 $18 = $17;
 HEAP32[$18>>2] = $13;
 $19 = (($17) + 4)|0;
 $20 = $19;
 HEAP32[$20>>2] = $16;
 $21 = HEAP32[$6>>2]|0;
 $22 = HEAP32[$8>>2]|0;
 $23 = ((($22) + (($21*12)|0)|0) + 8|0);
 $24 = +HEAPF32[$23>>2];
 $25 = (($this) + 120|0);
 __Z7b2CrossfRK6b2Vec2($0,$24,$25);
 __ZplRK6b2Vec2S1_($Cdot,$vB,$0);
 $26 = (($this) + 144|0);
 $27 = (($this) + 160|0);
 __ZplRK6b2Vec2S1_($2,$Cdot,$27);
 $28 = (($this) + 108|0);
 $29 = +HEAPF32[$28>>2];
 $30 = (($this) + 96|0);
 __ZmlfRK6b2Vec2($3,$29,$30);
 __ZplRK6b2Vec2S1_($4,$2,$3);
 __ZNK6b2Vec2ngEv($1,$4);
 __Z5b2MulRK7b2Mat22RK6b2Vec2($impulse,$26,$1);
 $31 = $30;
 $32 = $31;
 $33 = HEAP32[$32>>2]|0;
 $34 = (($31) + 4)|0;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = $oldImpulse;
 $38 = $37;
 HEAP32[$38>>2] = $33;
 $39 = (($37) + 4)|0;
 $40 = $39;
 HEAP32[$40>>2] = $36;
 __ZN6b2Vec2pLERKS_($30,$impulse);
 $41 = +HEAPF32[$data>>2];
 $42 = (($this) + 104|0);
 $43 = +HEAPF32[$42>>2];
 $44 = $41 * $43;
 $45 = (+__ZNK6b2Vec213LengthSquaredEv($30));
 $46 = $44 * $44;
 $47 = $45 > $46;
 if ($47) {
  $48 = (+__ZNK6b2Vec26LengthEv($30));
  $49 = $44 / $48;
  __ZN6b2Vec2mLEf($30,$49);
 }
 __ZmiRK6b2Vec2S1_($impulse,$30,$oldImpulse);
 $50 = (($this) + 136|0);
 $51 = +HEAPF32[$50>>2];
 __ZmlfRK6b2Vec2($5,$51,$impulse);
 __ZN6b2Vec2pLERKS_($vB,$5);
 $52 = (($this) + 140|0);
 $53 = +HEAPF32[$52>>2];
 $54 = (+__Z7b2CrossRK6b2Vec2S1_($25,$impulse));
 $55 = $53 * $54;
 $56 = $24 + $55;
 $57 = HEAP32[$6>>2]|0;
 $58 = HEAP32[$8>>2]|0;
 $59 = (($58) + (($57*12)|0)|0);
 $60 = $vB;
 $61 = $60;
 $62 = HEAP32[$61>>2]|0;
 $63 = (($60) + 4)|0;
 $64 = $63;
 $65 = HEAP32[$64>>2]|0;
 $66 = $59;
 $67 = $66;
 HEAP32[$67>>2] = $62;
 $68 = (($66) + 4)|0;
 $69 = $68;
 HEAP32[$69>>2] = $65;
 $70 = HEAP32[$6>>2]|0;
 $71 = HEAP32[$8>>2]|0;
 $72 = ((($71) + (($70*12)|0)|0) + 8|0);
 HEAPF32[$72>>2] = $56;
 STACKTOP = sp;return;
}
function __ZN12b2MouseJoint24SolvePositionConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZNK12b2MouseJoint10GetAnchorAEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 76|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $agg$result;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 STACKTOP = sp;return;
}
function __ZNK12b2MouseJoint10GetAnchorBEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 68|0);
 __ZNK6b2Body13GetWorldPointERK6b2Vec2($agg$result,$1,$2);
 STACKTOP = sp;return;
}
function __ZNK12b2MouseJoint16GetReactionForceEf($agg$result,$this,$inv_dt) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inv_dt = +$inv_dt;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 96|0);
 __ZmlfRK6b2Vec2($agg$result,$inv_dt,$0);
 STACKTOP = sp;return;
}
function __ZNK12b2MouseJoint17GetReactionTorqueEf($this,$inv_dt) {
 $this = $this|0;
 $inv_dt = +$inv_dt;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $inv_dt * 0.0;
 STACKTOP = sp;return (+$0);
}
function __ZN12b2MouseJoint11ShiftOriginERK6b2Vec2($this,$newOrigin) {
 $this = $this|0;
 $newOrigin = $newOrigin|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 76|0);
 __ZN6b2Vec2mIERKS_($0,$newOrigin);
 STACKTOP = sp;return;
}
function __ZN12b2MouseJoint4DumpEv($this) {
 $this = $this|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 __Z5b2LogPKcz(2432,$vararg_buffer);
 STACKTOP = sp;return;
}
function __ZN7b2JointD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN12b2MouseJointD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK6b2Body7IsAwakeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 & 2;
 $3 = ($2<<16>>16)!=(0);
 STACKTOP = sp;return ($3|0);
}
function __ZN5b2RotC2Ef($this,$angle) {
 $this = $this|0;
 $angle = +$angle;
 var $0 = 0.0, $1 = 0.0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+Math_sin((+$angle)));
 HEAPF32[$this>>2] = $0;
 $1 = (+Math_cos((+$angle)));
 $2 = (($this) + 4|0);
 HEAPF32[$2>>2] = $1;
 STACKTOP = sp;return;
}
function __ZNK7b2Mat2210GetInverseEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0.0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0, $2 = 0.0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0;
 var $det$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$this>>2];
 $1 = (($this) + 8|0);
 $2 = +HEAPF32[$1>>2];
 $3 = (($this) + 4|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($this) + 12|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $0 * $6;
 $8 = $2 * $4;
 $9 = $7 - $8;
 $10 = $9 != 0.0;
 if ($10) {
  $11 = 1.0 / $9;
  $det$0 = $11;
 } else {
  $det$0 = $9;
 }
 $12 = $6 * $det$0;
 HEAPF32[$agg$result>>2] = $12;
 $13 = -$det$0;
 $14 = $2 * $13;
 $15 = (($agg$result) + 8|0);
 HEAPF32[$15>>2] = $14;
 $16 = $4 * $13;
 $17 = (($agg$result) + 4|0);
 HEAPF32[$17>>2] = $16;
 $18 = $0 * $det$0;
 $19 = (($agg$result) + 12|0);
 HEAPF32[$19>>2] = $18;
 STACKTOP = sp;return;
}
function __Z5b2MulRK7b2Mat22RK6b2Vec2($agg$result,$A,$v) {
 $agg$result = $agg$result|0;
 $A = $A|0;
 $v = $v|0;
 var $0 = 0.0, $1 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $2 = 0.0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$A>>2];
 $1 = +HEAPF32[$v>>2];
 $2 = $0 * $1;
 $3 = (($A) + 8|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($v) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $4 * $6;
 $8 = $2 + $7;
 $9 = (($A) + 4|0);
 $10 = +HEAPF32[$9>>2];
 $11 = $1 * $10;
 $12 = (($A) + 12|0);
 $13 = +HEAPF32[$12>>2];
 $14 = $6 * $13;
 $15 = $11 + $14;
 __ZN6b2Vec2C2Eff($agg$result,$8,$15);
 STACKTOP = sp;return;
}
function __ZN15b2MotorJointDef10InitializeEP6b2BodyS1_($this,$bA,$bB) {
 $this = $this|0;
 $bA = $bA|0;
 $bB = $bB|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0.0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $xB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $xB = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $bA;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = $bB;
 $3 = (__ZNK6b2Body11GetPositionEv($bB)|0);
 $4 = $3;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = $xB;
 $11 = $10;
 HEAP32[$11>>2] = $6;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = $9;
 $14 = (($this) + 20|0);
 $15 = HEAP32[$1>>2]|0;
 __ZNK6b2Body13GetLocalPointERK6b2Vec2($0,$15,$xB);
 $16 = $0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16) + 4)|0;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = $14;
 $23 = $22;
 HEAP32[$23>>2] = $18;
 $24 = (($22) + 4)|0;
 $25 = $24;
 HEAP32[$25>>2] = $21;
 $26 = HEAP32[$1>>2]|0;
 $27 = (+__ZNK6b2Body8GetAngleEv($26));
 $28 = HEAP32[$2>>2]|0;
 $29 = (+__ZNK6b2Body8GetAngleEv($28));
 $30 = $29 - $27;
 $31 = (($this) + 28|0);
 HEAPF32[$31>>2] = $30;
 STACKTOP = sp;return;
}
function __ZN12b2MotorJointC2EPK15b2MotorJointDef($this,$def) {
 $this = $this|0;
 $def = $def|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7b2JointC2EPK10b2JointDef($this,$def);
 HEAP32[$this>>2] = ((2472 + 8|0));
 $0 = (($this) + 68|0);
 $1 = (($this) + 80|0);
 $2 = (($def) + 20|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $0;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = (($def) + 28|0);
 $14 = +HEAPF32[$13>>2];
 $15 = (($this) + 76|0);
 HEAPF32[$15>>2] = $14;
 __ZN6b2Vec27SetZeroEv($1);
 $16 = (($this) + 88|0);
 HEAPF32[$16>>2] = 0.0;
 $17 = (($def) + 32|0);
 $18 = +HEAPF32[$17>>2];
 $19 = (($this) + 92|0);
 HEAPF32[$19>>2] = $18;
 $20 = (($def) + 36|0);
 $21 = +HEAPF32[$20>>2];
 $22 = (($this) + 96|0);
 HEAPF32[$22>>2] = $21;
 $23 = (($def) + 40|0);
 $24 = +HEAPF32[$23>>2];
 $25 = (($this) + 100|0);
 HEAPF32[$25>>2] = $24;
 STACKTOP = sp;return;
}
function __ZN12b2MotorJoint23InitVelocityConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0.0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0.0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = 0, $16 = 0, $160 = 0.0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0, $165 = 0.0, $166 = 0.0, $167 = 0.0, $168 = 0.0, $169 = 0.0, $17 = 0;
 var $170 = 0.0, $171 = 0.0, $172 = 0.0, $173 = 0.0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0, $18 = 0, $180 = 0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0.0, $186 = 0.0, $187 = 0.0, $188 = 0.0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0.0, $192 = 0, $193 = 0, $194 = 0.0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0.0, $208 = 0, $209 = 0.0, $21 = 0, $210 = 0.0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0.0, $218 = 0.0, $219 = 0, $22 = 0, $220 = 0.0, $221 = 0.0, $222 = 0.0, $223 = 0;
 var $224 = 0.0, $225 = 0.0, $226 = 0.0, $227 = 0.0, $228 = 0.0, $229 = 0.0, $23 = 0, $230 = 0.0, $231 = 0.0, $232 = 0.0, $233 = 0.0, $234 = 0.0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0.0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0.0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0.0, $99 = 0, $K = 0, $P = 0, $cA = 0, $cB = 0, $qA = 0, $qB = 0, $storemerge = 0.0, $vA = 0, $vB = 0, $wA$0 = 0.0, $wB$0 = 0.0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $cA = sp + 48|0;
 $vA = sp + 40|0;
 $cB = sp + 32|0;
 $vB = sp + 24|0;
 $qA = sp + 168|0;
 $qB = sp + 160|0;
 $0 = sp + 16|0;
 $1 = sp + 152|0;
 $2 = sp + 8|0;
 $3 = sp + 144|0;
 $K = sp + 128|0;
 $4 = sp + 112|0;
 $5 = sp;
 $6 = sp + 104|0;
 $7 = sp + 96|0;
 $8 = sp + 88|0;
 $9 = sp + 80|0;
 $P = sp + 72|0;
 $10 = sp + 64|0;
 $11 = sp + 56|0;
 $12 = (($this) + 48|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 104|0);
 HEAP32[$16>>2] = $15;
 $17 = (($this) + 52|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($this) + 108|0);
 HEAP32[$21>>2] = $20;
 $22 = (($this) + 128|0);
 $23 = HEAP32[$12>>2]|0;
 $24 = (($23) + 44|0);
 $25 = $24;
 $26 = $25;
 $27 = HEAP32[$26>>2]|0;
 $28 = (($25) + 4)|0;
 $29 = $28;
 $30 = HEAP32[$29>>2]|0;
 $31 = $22;
 $32 = $31;
 HEAP32[$32>>2] = $27;
 $33 = (($31) + 4)|0;
 $34 = $33;
 HEAP32[$34>>2] = $30;
 $35 = (($this) + 136|0);
 $36 = HEAP32[$17>>2]|0;
 $37 = (($36) + 44|0);
 $38 = $37;
 $39 = $38;
 $40 = HEAP32[$39>>2]|0;
 $41 = (($38) + 4)|0;
 $42 = $41;
 $43 = HEAP32[$42>>2]|0;
 $44 = $35;
 $45 = $44;
 HEAP32[$45>>2] = $40;
 $46 = (($44) + 4)|0;
 $47 = $46;
 HEAP32[$47>>2] = $43;
 $48 = HEAP32[$12>>2]|0;
 $49 = (($48) + 136|0);
 $50 = +HEAPF32[$49>>2];
 $51 = (($this) + 156|0);
 HEAPF32[$51>>2] = $50;
 $52 = HEAP32[$17>>2]|0;
 $53 = (($52) + 136|0);
 $54 = +HEAPF32[$53>>2];
 $55 = (($this) + 160|0);
 HEAPF32[$55>>2] = $54;
 $56 = HEAP32[$12>>2]|0;
 $57 = (($56) + 144|0);
 $58 = +HEAPF32[$57>>2];
 $59 = (($this) + 164|0);
 HEAPF32[$59>>2] = $58;
 $60 = HEAP32[$17>>2]|0;
 $61 = (($60) + 144|0);
 $62 = +HEAPF32[$61>>2];
 $63 = (($this) + 168|0);
 HEAPF32[$63>>2] = $62;
 $64 = HEAP32[$16>>2]|0;
 $65 = (($data) + 28|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) + (($64*12)|0)|0);
 $68 = $67;
 $69 = $68;
 $70 = HEAP32[$69>>2]|0;
 $71 = (($68) + 4)|0;
 $72 = $71;
 $73 = HEAP32[$72>>2]|0;
 $74 = $cA;
 $75 = $74;
 HEAP32[$75>>2] = $70;
 $76 = (($74) + 4)|0;
 $77 = $76;
 HEAP32[$77>>2] = $73;
 $78 = HEAP32[$16>>2]|0;
 $79 = HEAP32[$65>>2]|0;
 $80 = ((($79) + (($78*12)|0)|0) + 8|0);
 $81 = +HEAPF32[$80>>2];
 $82 = (($data) + 32|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = (($83) + (($78*12)|0)|0);
 $85 = $84;
 $86 = $85;
 $87 = HEAP32[$86>>2]|0;
 $88 = (($85) + 4)|0;
 $89 = $88;
 $90 = HEAP32[$89>>2]|0;
 $91 = $vA;
 $92 = $91;
 HEAP32[$92>>2] = $87;
 $93 = (($91) + 4)|0;
 $94 = $93;
 HEAP32[$94>>2] = $90;
 $95 = HEAP32[$16>>2]|0;
 $96 = HEAP32[$82>>2]|0;
 $97 = ((($96) + (($95*12)|0)|0) + 8|0);
 $98 = +HEAPF32[$97>>2];
 $99 = HEAP32[$21>>2]|0;
 $100 = HEAP32[$65>>2]|0;
 $101 = (($100) + (($99*12)|0)|0);
 $102 = $101;
 $103 = $102;
 $104 = HEAP32[$103>>2]|0;
 $105 = (($102) + 4)|0;
 $106 = $105;
 $107 = HEAP32[$106>>2]|0;
 $108 = $cB;
 $109 = $108;
 HEAP32[$109>>2] = $104;
 $110 = (($108) + 4)|0;
 $111 = $110;
 HEAP32[$111>>2] = $107;
 $112 = HEAP32[$21>>2]|0;
 $113 = HEAP32[$65>>2]|0;
 $114 = ((($113) + (($112*12)|0)|0) + 8|0);
 $115 = +HEAPF32[$114>>2];
 $116 = HEAP32[$82>>2]|0;
 $117 = (($116) + (($112*12)|0)|0);
 $118 = $117;
 $119 = $118;
 $120 = HEAP32[$119>>2]|0;
 $121 = (($118) + 4)|0;
 $122 = $121;
 $123 = HEAP32[$122>>2]|0;
 $124 = $vB;
 $125 = $124;
 HEAP32[$125>>2] = $120;
 $126 = (($124) + 4)|0;
 $127 = $126;
 HEAP32[$127>>2] = $123;
 $128 = HEAP32[$21>>2]|0;
 $129 = HEAP32[$82>>2]|0;
 $130 = ((($129) + (($128*12)|0)|0) + 8|0);
 $131 = +HEAPF32[$130>>2];
 __ZN5b2RotC2Ef($qA,$81);
 __ZN5b2RotC2Ef($qB,$115);
 $132 = (($this) + 112|0);
 __ZNK6b2Vec2ngEv($1,$22);
 __Z5b2MulRK5b2RotRK6b2Vec2($0,$qA,$1);
 $133 = $0;
 $134 = $133;
 $135 = HEAP32[$134>>2]|0;
 $136 = (($133) + 4)|0;
 $137 = $136;
 $138 = HEAP32[$137>>2]|0;
 $139 = $132;
 $140 = $139;
 HEAP32[$140>>2] = $135;
 $141 = (($139) + 4)|0;
 $142 = $141;
 HEAP32[$142>>2] = $138;
 $143 = (($this) + 120|0);
 __ZNK6b2Vec2ngEv($3,$35);
 __Z5b2MulRK5b2RotRK6b2Vec2($2,$qB,$3);
 $144 = $2;
 $145 = $144;
 $146 = HEAP32[$145>>2]|0;
 $147 = (($144) + 4)|0;
 $148 = $147;
 $149 = HEAP32[$148>>2]|0;
 $150 = $143;
 $151 = $150;
 HEAP32[$151>>2] = $146;
 $152 = (($150) + 4)|0;
 $153 = $152;
 HEAP32[$153>>2] = $149;
 $154 = +HEAPF32[$51>>2];
 $155 = +HEAPF32[$55>>2];
 $156 = +HEAPF32[$59>>2];
 $157 = +HEAPF32[$63>>2];
 $158 = $154 + $155;
 $159 = (($this) + 116|0);
 $160 = +HEAPF32[$159>>2];
 $161 = $156 * $160;
 $162 = $160 * $161;
 $163 = $158 + $162;
 $164 = (($this) + 124|0);
 $165 = +HEAPF32[$164>>2];
 $166 = $157 * $165;
 $167 = $165 * $166;
 $168 = $163 + $167;
 HEAPF32[$K>>2] = $168;
 $169 = +HEAPF32[$132>>2];
 $170 = $156 * $169;
 $171 = +HEAPF32[$159>>2];
 $172 = $170 * $171;
 $173 = -$172;
 $174 = +HEAPF32[$143>>2];
 $175 = $157 * $174;
 $176 = +HEAPF32[$164>>2];
 $177 = $175 * $176;
 $178 = $173 - $177;
 $179 = (($K) + 4|0);
 HEAPF32[$179>>2] = $178;
 $180 = (($K) + 8|0);
 HEAPF32[$180>>2] = $178;
 $181 = +HEAPF32[$132>>2];
 $182 = $156 * $181;
 $183 = $181 * $182;
 $184 = $158 + $183;
 $185 = +HEAPF32[$143>>2];
 $186 = $157 * $185;
 $187 = $185 * $186;
 $188 = $184 + $187;
 $189 = (($K) + 12|0);
 HEAPF32[$189>>2] = $188;
 $190 = (($this) + 172|0);
 __ZNK7b2Mat2210GetInverseEv($4,$K);
 ;HEAP32[$190+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$190+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$190+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$190+12>>2]=HEAP32[$4+12>>2]|0;
 $191 = $156 + $157;
 $192 = (($this) + 188|0);
 $193 = $191 > 0.0;
 if ($193) {
  $194 = 1.0 / $191;
  $storemerge = $194;
 } else {
  $storemerge = $191;
 }
 HEAPF32[$192>>2] = $storemerge;
 $195 = (($this) + 144|0);
 __ZplRK6b2Vec2S1_($8,$cB,$143);
 __ZmiRK6b2Vec2S1_($7,$8,$cA);
 __ZmiRK6b2Vec2S1_($6,$7,$132);
 $196 = (($this) + 68|0);
 __Z5b2MulRK5b2RotRK6b2Vec2($9,$qA,$196);
 __ZmiRK6b2Vec2S1_($5,$6,$9);
 $197 = $5;
 $198 = $197;
 $199 = HEAP32[$198>>2]|0;
 $200 = (($197) + 4)|0;
 $201 = $200;
 $202 = HEAP32[$201>>2]|0;
 $203 = $195;
 $204 = $203;
 HEAP32[$204>>2] = $199;
 $205 = (($203) + 4)|0;
 $206 = $205;
 HEAP32[$206>>2] = $202;
 $207 = $115 - $81;
 $208 = (($this) + 76|0);
 $209 = +HEAPF32[$208>>2];
 $210 = $207 - $209;
 $211 = (($this) + 152|0);
 HEAPF32[$211>>2] = $210;
 $212 = (($data) + 24|0);
 $213 = HEAP8[$212>>0]|0;
 $214 = ($213<<24>>24)==(0);
 $215 = (($this) + 80|0);
 if ($214) {
  __ZN6b2Vec27SetZeroEv($215);
  $235 = (($this) + 88|0);
  HEAPF32[$235>>2] = 0.0;
  $wA$0 = $98;$wB$0 = $131;
  $236 = HEAP32[$16>>2]|0;
  $237 = HEAP32[$82>>2]|0;
  $238 = (($237) + (($236*12)|0)|0);
  $239 = $vA;
  $240 = $239;
  $241 = HEAP32[$240>>2]|0;
  $242 = (($239) + 4)|0;
  $243 = $242;
  $244 = HEAP32[$243>>2]|0;
  $245 = $238;
  $246 = $245;
  HEAP32[$246>>2] = $241;
  $247 = (($245) + 4)|0;
  $248 = $247;
  HEAP32[$248>>2] = $244;
  $249 = HEAP32[$16>>2]|0;
  $250 = HEAP32[$82>>2]|0;
  $251 = ((($250) + (($249*12)|0)|0) + 8|0);
  HEAPF32[$251>>2] = $wA$0;
  $252 = HEAP32[$21>>2]|0;
  $253 = HEAP32[$82>>2]|0;
  $254 = (($253) + (($252*12)|0)|0);
  $255 = $vB;
  $256 = $255;
  $257 = HEAP32[$256>>2]|0;
  $258 = (($255) + 4)|0;
  $259 = $258;
  $260 = HEAP32[$259>>2]|0;
  $261 = $254;
  $262 = $261;
  HEAP32[$262>>2] = $257;
  $263 = (($261) + 4)|0;
  $264 = $263;
  HEAP32[$264>>2] = $260;
  $265 = HEAP32[$21>>2]|0;
  $266 = HEAP32[$82>>2]|0;
  $267 = ((($266) + (($265*12)|0)|0) + 8|0);
  HEAPF32[$267>>2] = $wB$0;
  STACKTOP = sp;return;
 } else {
  $216 = (($data) + 8|0);
  $217 = +HEAPF32[$216>>2];
  __ZN6b2Vec2mLEf($215,$217);
  $218 = +HEAPF32[$216>>2];
  $219 = (($this) + 88|0);
  $220 = +HEAPF32[$219>>2];
  $221 = $218 * $220;
  HEAPF32[$219>>2] = $221;
  $222 = +HEAPF32[$215>>2];
  $223 = (($this) + 84|0);
  $224 = +HEAPF32[$223>>2];
  __ZN6b2Vec2C2Eff($P,$222,$224);
  __ZmlfRK6b2Vec2($10,$154,$P);
  __ZN6b2Vec2mIERKS_($vA,$10);
  $225 = (+__Z7b2CrossRK6b2Vec2S1_($132,$P));
  $226 = +HEAPF32[$219>>2];
  $227 = $225 + $226;
  $228 = $156 * $227;
  $229 = $98 - $228;
  __ZmlfRK6b2Vec2($11,$155,$P);
  __ZN6b2Vec2pLERKS_($vB,$11);
  $230 = (+__Z7b2CrossRK6b2Vec2S1_($143,$P));
  $231 = +HEAPF32[$219>>2];
  $232 = $230 + $231;
  $233 = $157 * $232;
  $234 = $131 + $233;
  $wA$0 = $229;$wB$0 = $234;
  $236 = HEAP32[$16>>2]|0;
  $237 = HEAP32[$82>>2]|0;
  $238 = (($237) + (($236*12)|0)|0);
  $239 = $vA;
  $240 = $239;
  $241 = HEAP32[$240>>2]|0;
  $242 = (($239) + 4)|0;
  $243 = $242;
  $244 = HEAP32[$243>>2]|0;
  $245 = $238;
  $246 = $245;
  HEAP32[$246>>2] = $241;
  $247 = (($245) + 4)|0;
  $248 = $247;
  HEAP32[$248>>2] = $244;
  $249 = HEAP32[$16>>2]|0;
  $250 = HEAP32[$82>>2]|0;
  $251 = ((($250) + (($249*12)|0)|0) + 8|0);
  HEAPF32[$251>>2] = $wA$0;
  $252 = HEAP32[$21>>2]|0;
  $253 = HEAP32[$82>>2]|0;
  $254 = (($253) + (($252*12)|0)|0);
  $255 = $vB;
  $256 = $255;
  $257 = HEAP32[$256>>2]|0;
  $258 = (($255) + 4)|0;
  $259 = $258;
  $260 = HEAP32[$259>>2]|0;
  $261 = $254;
  $262 = $261;
  HEAP32[$262>>2] = $257;
  $263 = (($261) + 4)|0;
  $264 = $263;
  HEAP32[$264>>2] = $260;
  $265 = HEAP32[$21>>2]|0;
  $266 = HEAP32[$82>>2]|0;
  $267 = ((($266) + (($265*12)|0)|0) + 8|0);
  HEAPF32[$267>>2] = $wB$0;
  STACKTOP = sp;return;
 }
}
function __ZN12b2MotorJoint24SolveVelocityConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0.0, $45 = 0, $46 = 0.0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0.0, $57 = 0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0.0;
 var $62 = 0.0, $63 = 0.0, $64 = 0, $65 = 0.0, $66 = 0.0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0.0, $83 = 0.0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0.0;
 var $99 = 0.0, $Cdot1 = 0, $impulse2 = 0, $oldImpulse3 = 0, $vA = 0, $vB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $vA = sp + 24|0;
 $vB = sp + 16|0;
 $Cdot1 = sp + 104|0;
 $0 = sp + 96|0;
 $1 = sp + 88|0;
 $2 = sp + 80|0;
 $3 = sp + 72|0;
 $4 = sp + 64|0;
 $5 = sp + 56|0;
 $impulse2 = sp + 8|0;
 $6 = sp + 48|0;
 $oldImpulse3 = sp;
 $7 = sp + 40|0;
 $8 = sp + 32|0;
 $9 = (($this) + 104|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($data) + 32|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + (($10*12)|0)|0);
 $14 = $13;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14) + 4)|0;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = $vA;
 $21 = $20;
 HEAP32[$21>>2] = $16;
 $22 = (($20) + 4)|0;
 $23 = $22;
 HEAP32[$23>>2] = $19;
 $24 = HEAP32[$9>>2]|0;
 $25 = HEAP32[$11>>2]|0;
 $26 = ((($25) + (($24*12)|0)|0) + 8|0);
 $27 = +HEAPF32[$26>>2];
 $28 = (($this) + 108|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($25) + (($29*12)|0)|0);
 $31 = $30;
 $32 = $31;
 $33 = HEAP32[$32>>2]|0;
 $34 = (($31) + 4)|0;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = $vB;
 $38 = $37;
 HEAP32[$38>>2] = $33;
 $39 = (($37) + 4)|0;
 $40 = $39;
 HEAP32[$40>>2] = $36;
 $41 = HEAP32[$28>>2]|0;
 $42 = HEAP32[$11>>2]|0;
 $43 = ((($42) + (($41*12)|0)|0) + 8|0);
 $44 = +HEAPF32[$43>>2];
 $45 = (($this) + 156|0);
 $46 = +HEAPF32[$45>>2];
 $47 = (($this) + 160|0);
 $48 = +HEAPF32[$47>>2];
 $49 = (($this) + 164|0);
 $50 = +HEAPF32[$49>>2];
 $51 = (($this) + 168|0);
 $52 = +HEAPF32[$51>>2];
 $53 = +HEAPF32[$data>>2];
 $54 = (($data) + 4|0);
 $55 = +HEAPF32[$54>>2];
 $56 = $44 - $27;
 $57 = (($this) + 100|0);
 $58 = +HEAPF32[$57>>2];
 $59 = $55 * $58;
 $60 = (($this) + 152|0);
 $61 = +HEAPF32[$60>>2];
 $62 = $59 * $61;
 $63 = $56 + $62;
 $64 = (($this) + 188|0);
 $65 = +HEAPF32[$64>>2];
 $66 = $65 * $63;
 $67 = (($this) + 88|0);
 $68 = +HEAPF32[$67>>2];
 $69 = (($this) + 96|0);
 $70 = +HEAPF32[$69>>2];
 $71 = $53 * $70;
 $72 = $68 - $66;
 $73 = -$71;
 $74 = (+__Z7b2ClampIfET_S0_S0_S0_($72,$73,$71));
 HEAPF32[$67>>2] = $74;
 $75 = $74 - $68;
 $76 = $50 * $75;
 $77 = $27 - $76;
 $78 = $52 * $75;
 $79 = $44 + $78;
 $80 = (($this) + 120|0);
 __Z7b2CrossfRK6b2Vec2($3,$79,$80);
 __ZplRK6b2Vec2S1_($2,$vB,$3);
 __ZmiRK6b2Vec2S1_($1,$2,$vA);
 $81 = (($this) + 112|0);
 __Z7b2CrossfRK6b2Vec2($4,$77,$81);
 __ZmiRK6b2Vec2S1_($0,$1,$4);
 $82 = +HEAPF32[$57>>2];
 $83 = $55 * $82;
 $84 = (($this) + 144|0);
 __ZmlfRK6b2Vec2($5,$83,$84);
 __ZplRK6b2Vec2S1_($Cdot1,$0,$5);
 $85 = (($this) + 172|0);
 __Z5b2MulRK7b2Mat22RK6b2Vec2($6,$85,$Cdot1);
 __ZNK6b2Vec2ngEv($impulse2,$6);
 $86 = (($this) + 80|0);
 $87 = $86;
 $88 = $87;
 $89 = HEAP32[$88>>2]|0;
 $90 = (($87) + 4)|0;
 $91 = $90;
 $92 = HEAP32[$91>>2]|0;
 $93 = $oldImpulse3;
 $94 = $93;
 HEAP32[$94>>2] = $89;
 $95 = (($93) + 4)|0;
 $96 = $95;
 HEAP32[$96>>2] = $92;
 __ZN6b2Vec2pLERKS_($86,$impulse2);
 $97 = (($this) + 92|0);
 $98 = +HEAPF32[$97>>2];
 $99 = $53 * $98;
 $100 = (+__ZNK6b2Vec213LengthSquaredEv($86));
 $101 = $99 * $99;
 $102 = $100 > $101;
 if ($102) {
  (+__ZN6b2Vec29NormalizeEv($86));
  __ZN6b2Vec2mLEf($86,$99);
 }
 __ZmiRK6b2Vec2S1_($impulse2,$86,$oldImpulse3);
 __ZmlfRK6b2Vec2($7,$46,$impulse2);
 __ZN6b2Vec2mIERKS_($vA,$7);
 $103 = (+__Z7b2CrossRK6b2Vec2S1_($81,$impulse2));
 $104 = $50 * $103;
 $105 = $77 - $104;
 __ZmlfRK6b2Vec2($8,$48,$impulse2);
 __ZN6b2Vec2pLERKS_($vB,$8);
 $106 = (+__Z7b2CrossRK6b2Vec2S1_($80,$impulse2));
 $107 = $52 * $106;
 $108 = $79 + $107;
 $109 = HEAP32[$9>>2]|0;
 $110 = HEAP32[$11>>2]|0;
 $111 = (($110) + (($109*12)|0)|0);
 $112 = $vA;
 $113 = $112;
 $114 = HEAP32[$113>>2]|0;
 $115 = (($112) + 4)|0;
 $116 = $115;
 $117 = HEAP32[$116>>2]|0;
 $118 = $111;
 $119 = $118;
 HEAP32[$119>>2] = $114;
 $120 = (($118) + 4)|0;
 $121 = $120;
 HEAP32[$121>>2] = $117;
 $122 = HEAP32[$9>>2]|0;
 $123 = HEAP32[$11>>2]|0;
 $124 = ((($123) + (($122*12)|0)|0) + 8|0);
 HEAPF32[$124>>2] = $105;
 $125 = HEAP32[$28>>2]|0;
 $126 = HEAP32[$11>>2]|0;
 $127 = (($126) + (($125*12)|0)|0);
 $128 = $vB;
 $129 = $128;
 $130 = HEAP32[$129>>2]|0;
 $131 = (($128) + 4)|0;
 $132 = $131;
 $133 = HEAP32[$132>>2]|0;
 $134 = $127;
 $135 = $134;
 HEAP32[$135>>2] = $130;
 $136 = (($134) + 4)|0;
 $137 = $136;
 HEAP32[$137>>2] = $133;
 $138 = HEAP32[$28>>2]|0;
 $139 = HEAP32[$11>>2]|0;
 $140 = ((($139) + (($138*12)|0)|0) + 8|0);
 HEAPF32[$140>>2] = $108;
 STACKTOP = sp;return;
}
function __ZN12b2MotorJoint24SolvePositionConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZNK12b2MotorJoint10GetAnchorAEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK6b2Body11GetPositionEv($1)|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $agg$result;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 STACKTOP = sp;return;
}
function __ZNK12b2MotorJoint10GetAnchorBEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK6b2Body11GetPositionEv($1)|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $agg$result;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 STACKTOP = sp;return;
}
function __ZNK12b2MotorJoint16GetReactionForceEf($agg$result,$this,$inv_dt) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inv_dt = +$inv_dt;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 __ZmlfRK6b2Vec2($agg$result,$inv_dt,$0);
 STACKTOP = sp;return;
}
function __ZNK12b2MotorJoint17GetReactionTorqueEf($this,$inv_dt) {
 $this = $this|0;
 $inv_dt = +$inv_dt;
 var $0 = 0, $1 = 0.0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = +HEAPF32[$0>>2];
 $2 = $1 * $inv_dt;
 STACKTOP = sp;return (+$2);
}
function __ZN12b2MotorJoint15SetLinearOffsetERK6b2Vec2($this,$linearOffset) {
 $this = $this|0;
 $linearOffset = $linearOffset|0;
 var $0 = 0.0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0.0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0;
 var $7 = 0.0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$linearOffset>>2];
 $1 = (($this) + 68|0);
 $2 = +HEAPF32[$1>>2];
 $3 = $0 != $2;
 if (!($3)) {
  $4 = (($linearOffset) + 4|0);
  $5 = +HEAPF32[$4>>2];
  $6 = (($this) + 72|0);
  $7 = +HEAPF32[$6>>2];
  $8 = $5 != $7;
  if (!($8)) {
   STACKTOP = sp;return;
  }
 }
 $9 = (($this) + 48|0);
 $10 = HEAP32[$9>>2]|0;
 __ZN6b2Body8SetAwakeEb($10,1);
 $11 = (($this) + 52|0);
 $12 = HEAP32[$11>>2]|0;
 __ZN6b2Body8SetAwakeEb($12,1);
 $13 = $linearOffset;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = (($13) + 4)|0;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = $1;
 $20 = $19;
 HEAP32[$20>>2] = $15;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $18;
 STACKTOP = sp;return;
}
function __ZN12b2MotorJoint16SetAngularOffsetEf($this,$angularOffset) {
 $this = $this|0;
 $angularOffset = +$angularOffset;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 76|0);
 $1 = +HEAPF32[$0>>2];
 $2 = $1 != $angularOffset;
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN6b2Body8SetAwakeEb($4,1);
 $5 = (($this) + 52|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN6b2Body8SetAwakeEb($6,1);
 HEAPF32[$0>>2] = $angularOffset;
 STACKTOP = sp;return;
}
function __ZN12b2MotorJoint4DumpEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0;
 var $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer25 = 0, $vararg_ptr12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer25 = sp;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 __Z5b2LogPKcz(2528,$vararg_buffer25);
 HEAP32[$vararg_buffer25>>2] = $3;
 __Z5b2LogPKcz(2552,$vararg_buffer25);
 HEAP32[$vararg_buffer25>>2] = $7;
 __Z5b2LogPKcz(2584,$vararg_buffer25);
 $8 = (($this) + 61|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 HEAP32[$vararg_buffer25>>2] = $10;
 __Z5b2LogPKcz(2616,$vararg_buffer25);
 $11 = (($this) + 68|0);
 $12 = +HEAPF32[$11>>2];
 $13 = $12;
 $14 = (($this) + 72|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $15;
 HEAPF64[tempDoublePtr>>3]=$13;HEAP32[$vararg_buffer25>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer25+4>>2]=HEAP32[tempDoublePtr+4>>2];
 $vararg_ptr12 = (($vararg_buffer25) + 8|0);
 HEAPF64[tempDoublePtr>>3]=$16;HEAP32[$vararg_ptr12>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr12+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(2656,$vararg_buffer25);
 $17 = (($this) + 76|0);
 $18 = +HEAPF32[$17>>2];
 $19 = $18;
 HEAPF64[tempDoublePtr>>3]=$19;HEAP32[$vararg_buffer25>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer25+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(2704,$vararg_buffer25);
 $20 = (($this) + 92|0);
 $21 = +HEAPF32[$20>>2];
 $22 = $21;
 HEAPF64[tempDoublePtr>>3]=$22;HEAP32[$vararg_buffer25>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer25+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(2736,$vararg_buffer25);
 $23 = (($this) + 96|0);
 $24 = +HEAPF32[$23>>2];
 $25 = $24;
 HEAPF64[tempDoublePtr>>3]=$25;HEAP32[$vararg_buffer25>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer25+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(2768,$vararg_buffer25);
 $26 = (($this) + 100|0);
 $27 = +HEAPF32[$26>>2];
 $28 = $27;
 HEAPF64[tempDoublePtr>>3]=$28;HEAP32[$vararg_buffer25>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer25+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(2800,$vararg_buffer25);
 $29 = (($this) + 56|0);
 $30 = HEAP32[$29>>2]|0;
 HEAP32[$vararg_buffer25>>2] = $30;
 __Z5b2LogPKcz(2840,$vararg_buffer25);
 STACKTOP = sp;return;
}
function __ZN7b2Joint11ShiftOriginERK6b2Vec2($this,$newOrigin) {
 $this = $this|0;
 $newOrigin = $newOrigin|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN12b2MotorJointD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __Z7b2ClampIfET_S0_S0_S0_($a,$low,$high) {
 $a = +$a;
 $low = +$low;
 $high = +$high;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+__Z5b2MinIfET_S0_S0_($a,$high));
 $1 = (+__Z5b2MaxIfET_S0_S0_($low,$0));
 STACKTOP = sp;return (+$1);
}
function __ZN18b2DistanceJointDef10InitializeEP6b2BodyS1_RK6b2Vec2S4_($this,$b1,$b2,$anchor1,$anchor2) {
 $this = $this|0;
 $b1 = $b1|0;
 $b2 = $b2|0;
 $anchor1 = $anchor1|0;
 $anchor2 = $anchor2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $d = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 8|0;
 $1 = sp;
 $d = sp + 16|0;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = $b1;
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = $b2;
 $4 = (($this) + 20|0);
 $5 = HEAP32[$2>>2]|0;
 __ZNK6b2Body13GetLocalPointERK6b2Vec2($0,$5,$anchor1);
 $6 = $0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $4;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 $16 = (($this) + 28|0);
 $17 = HEAP32[$3>>2]|0;
 __ZNK6b2Body13GetLocalPointERK6b2Vec2($1,$17,$anchor2);
 $18 = $1;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + 4)|0;
 $22 = $21;
 $23 = HEAP32[$22>>2]|0;
 $24 = $16;
 $25 = $24;
 HEAP32[$25>>2] = $20;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = $23;
 __ZmiRK6b2Vec2S1_($d,$anchor2,$anchor1);
 $28 = (+__ZNK6b2Vec26LengthEv($d));
 $29 = (($this) + 36|0);
 HEAPF32[$29>>2] = $28;
 STACKTOP = sp;return;
}
function __ZN15b2DistanceJointC2EPK18b2DistanceJointDef($this,$def) {
 $this = $this|0;
 $def = $def|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0;
 var $27 = 0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7b2JointC2EPK10b2JointDef($this,$def);
 HEAP32[$this>>2] = ((2920 + 8|0));
 $0 = (($this) + 80|0);
 $1 = (($this) + 88|0);
 $2 = (($def) + 20|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $0;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = (($def) + 28|0);
 $14 = $13;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14) + 4)|0;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = $1;
 $21 = $20;
 HEAP32[$21>>2] = $16;
 $22 = (($20) + 4)|0;
 $23 = $22;
 HEAP32[$23>>2] = $19;
 $24 = (($def) + 36|0);
 $25 = +HEAPF32[$24>>2];
 $26 = (($this) + 104|0);
 HEAPF32[$26>>2] = $25;
 $27 = (($def) + 40|0);
 $28 = +HEAPF32[$27>>2];
 $29 = (($this) + 68|0);
 HEAPF32[$29>>2] = $28;
 $30 = (($def) + 44|0);
 $31 = +HEAPF32[$30>>2];
 $32 = (($this) + 72|0);
 HEAPF32[$32>>2] = $31;
 $33 = (($this) + 100|0);
 HEAPF32[$33>>2] = 0.0;
 $34 = (($this) + 96|0);
 HEAPF32[$34>>2] = 0.0;
 $35 = (($this) + 76|0);
 HEAPF32[$35>>2] = 0.0;
 STACKTOP = sp;return;
}
function __ZN15b2DistanceJoint23InitVelocityConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0.0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0.0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0.0, $165 = 0, $166 = 0.0, $167 = 0.0, $168 = 0.0, $169 = 0.0, $17 = 0;
 var $170 = 0.0, $171 = 0.0, $172 = 0.0, $173 = 0.0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0, $180 = 0, $181 = 0.0, $182 = 0, $183 = 0.0, $184 = 0, $185 = 0.0, $186 = 0, $187 = 0, $188 = 0.0;
 var $189 = 0.0, $19 = 0, $190 = 0.0, $191 = 0.0, $192 = 0, $193 = 0.0, $194 = 0.0, $195 = 0.0, $196 = 0.0, $197 = 0.0, $198 = 0.0, $199 = 0.0, $2 = 0, $20 = 0, $200 = 0.0, $201 = 0.0, $202 = 0, $203 = 0, $204 = 0.0, $205 = 0.0;
 var $206 = 0.0, $207 = 0.0, $208 = 0.0, $209 = 0, $21 = 0, $210 = 0.0, $211 = 0.0, $212 = 0, $213 = 0.0, $214 = 0.0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0.0, $222 = 0, $223 = 0.0;
 var $224 = 0.0, $225 = 0.0, $226 = 0.0, $227 = 0.0, $228 = 0.0, $229 = 0.0, $23 = 0, $230 = 0.0, $231 = 0.0, $232 = 0.0, $233 = 0.0, $234 = 0.0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0, $54 = 0, $55 = 0.0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0.0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0.0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $P = 0, $cA = 0, $cB = 0, $qA = 0, $qB = 0, $vA = 0, $vB = 0, $wA$0 = 0.0, $wB$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $cA = sp + 48|0;
 $vA = sp + 40|0;
 $cB = sp + 32|0;
 $vB = sp + 24|0;
 $qA = sp + 120|0;
 $qB = sp + 112|0;
 $0 = sp + 16|0;
 $1 = sp + 104|0;
 $2 = sp + 8|0;
 $3 = sp + 96|0;
 $4 = sp;
 $5 = sp + 88|0;
 $6 = sp + 80|0;
 $P = sp + 72|0;
 $7 = sp + 64|0;
 $8 = sp + 56|0;
 $9 = (($this) + 48|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 108|0);
 HEAP32[$13>>2] = $12;
 $14 = (($this) + 52|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 112|0);
 HEAP32[$18>>2] = $17;
 $19 = (($this) + 140|0);
 $20 = HEAP32[$9>>2]|0;
 $21 = (($20) + 44|0);
 $22 = $21;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 $25 = (($22) + 4)|0;
 $26 = $25;
 $27 = HEAP32[$26>>2]|0;
 $28 = $19;
 $29 = $28;
 HEAP32[$29>>2] = $24;
 $30 = (($28) + 4)|0;
 $31 = $30;
 HEAP32[$31>>2] = $27;
 $32 = (($this) + 148|0);
 $33 = HEAP32[$14>>2]|0;
 $34 = (($33) + 44|0);
 $35 = $34;
 $36 = $35;
 $37 = HEAP32[$36>>2]|0;
 $38 = (($35) + 4)|0;
 $39 = $38;
 $40 = HEAP32[$39>>2]|0;
 $41 = $32;
 $42 = $41;
 HEAP32[$42>>2] = $37;
 $43 = (($41) + 4)|0;
 $44 = $43;
 HEAP32[$44>>2] = $40;
 $45 = HEAP32[$9>>2]|0;
 $46 = (($45) + 136|0);
 $47 = +HEAPF32[$46>>2];
 $48 = (($this) + 156|0);
 HEAPF32[$48>>2] = $47;
 $49 = HEAP32[$14>>2]|0;
 $50 = (($49) + 136|0);
 $51 = +HEAPF32[$50>>2];
 $52 = (($this) + 160|0);
 HEAPF32[$52>>2] = $51;
 $53 = HEAP32[$9>>2]|0;
 $54 = (($53) + 144|0);
 $55 = +HEAPF32[$54>>2];
 $56 = (($this) + 164|0);
 HEAPF32[$56>>2] = $55;
 $57 = HEAP32[$14>>2]|0;
 $58 = (($57) + 144|0);
 $59 = +HEAPF32[$58>>2];
 $60 = (($this) + 168|0);
 HEAPF32[$60>>2] = $59;
 $61 = HEAP32[$13>>2]|0;
 $62 = (($data) + 28|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($63) + (($61*12)|0)|0);
 $65 = $64;
 $66 = $65;
 $67 = HEAP32[$66>>2]|0;
 $68 = (($65) + 4)|0;
 $69 = $68;
 $70 = HEAP32[$69>>2]|0;
 $71 = $cA;
 $72 = $71;
 HEAP32[$72>>2] = $67;
 $73 = (($71) + 4)|0;
 $74 = $73;
 HEAP32[$74>>2] = $70;
 $75 = HEAP32[$13>>2]|0;
 $76 = HEAP32[$62>>2]|0;
 $77 = ((($76) + (($75*12)|0)|0) + 8|0);
 $78 = +HEAPF32[$77>>2];
 $79 = (($data) + 32|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = (($80) + (($75*12)|0)|0);
 $82 = $81;
 $83 = $82;
 $84 = HEAP32[$83>>2]|0;
 $85 = (($82) + 4)|0;
 $86 = $85;
 $87 = HEAP32[$86>>2]|0;
 $88 = $vA;
 $89 = $88;
 HEAP32[$89>>2] = $84;
 $90 = (($88) + 4)|0;
 $91 = $90;
 HEAP32[$91>>2] = $87;
 $92 = HEAP32[$13>>2]|0;
 $93 = HEAP32[$79>>2]|0;
 $94 = ((($93) + (($92*12)|0)|0) + 8|0);
 $95 = +HEAPF32[$94>>2];
 $96 = HEAP32[$18>>2]|0;
 $97 = HEAP32[$62>>2]|0;
 $98 = (($97) + (($96*12)|0)|0);
 $99 = $98;
 $100 = $99;
 $101 = HEAP32[$100>>2]|0;
 $102 = (($99) + 4)|0;
 $103 = $102;
 $104 = HEAP32[$103>>2]|0;
 $105 = $cB;
 $106 = $105;
 HEAP32[$106>>2] = $101;
 $107 = (($105) + 4)|0;
 $108 = $107;
 HEAP32[$108>>2] = $104;
 $109 = HEAP32[$18>>2]|0;
 $110 = HEAP32[$62>>2]|0;
 $111 = ((($110) + (($109*12)|0)|0) + 8|0);
 $112 = +HEAPF32[$111>>2];
 $113 = HEAP32[$79>>2]|0;
 $114 = (($113) + (($109*12)|0)|0);
 $115 = $114;
 $116 = $115;
 $117 = HEAP32[$116>>2]|0;
 $118 = (($115) + 4)|0;
 $119 = $118;
 $120 = HEAP32[$119>>2]|0;
 $121 = $vB;
 $122 = $121;
 HEAP32[$122>>2] = $117;
 $123 = (($121) + 4)|0;
 $124 = $123;
 HEAP32[$124>>2] = $120;
 $125 = HEAP32[$18>>2]|0;
 $126 = HEAP32[$79>>2]|0;
 $127 = ((($126) + (($125*12)|0)|0) + 8|0);
 $128 = +HEAPF32[$127>>2];
 __ZN5b2RotC2Ef($qA,$78);
 __ZN5b2RotC2Ef($qB,$112);
 $129 = (($this) + 124|0);
 $130 = (($this) + 80|0);
 __ZmiRK6b2Vec2S1_($1,$130,$19);
 __Z5b2MulRK5b2RotRK6b2Vec2($0,$qA,$1);
 $131 = $0;
 $132 = $131;
 $133 = HEAP32[$132>>2]|0;
 $134 = (($131) + 4)|0;
 $135 = $134;
 $136 = HEAP32[$135>>2]|0;
 $137 = $129;
 $138 = $137;
 HEAP32[$138>>2] = $133;
 $139 = (($137) + 4)|0;
 $140 = $139;
 HEAP32[$140>>2] = $136;
 $141 = (($this) + 132|0);
 $142 = (($this) + 88|0);
 __ZmiRK6b2Vec2S1_($3,$142,$32);
 __Z5b2MulRK5b2RotRK6b2Vec2($2,$qB,$3);
 $143 = $2;
 $144 = $143;
 $145 = HEAP32[$144>>2]|0;
 $146 = (($143) + 4)|0;
 $147 = $146;
 $148 = HEAP32[$147>>2]|0;
 $149 = $141;
 $150 = $149;
 HEAP32[$150>>2] = $145;
 $151 = (($149) + 4)|0;
 $152 = $151;
 HEAP32[$152>>2] = $148;
 $153 = (($this) + 116|0);
 __ZplRK6b2Vec2S1_($6,$cB,$141);
 __ZmiRK6b2Vec2S1_($5,$6,$cA);
 __ZmiRK6b2Vec2S1_($4,$5,$129);
 $154 = $4;
 $155 = $154;
 $156 = HEAP32[$155>>2]|0;
 $157 = (($154) + 4)|0;
 $158 = $157;
 $159 = HEAP32[$158>>2]|0;
 $160 = $153;
 $161 = $160;
 HEAP32[$161>>2] = $156;
 $162 = (($160) + 4)|0;
 $163 = $162;
 HEAP32[$163>>2] = $159;
 $164 = (+__ZNK6b2Vec26LengthEv($153));
 $165 = $164 > 0.004999999888241291;
 if ($165) {
  $166 = 1.0 / $164;
  __ZN6b2Vec2mLEf($153,$166);
 } else {
  __ZN6b2Vec23SetEff($153,0.0,0.0);
 }
 $167 = (+__Z7b2CrossRK6b2Vec2S1_($129,$153));
 $168 = (+__Z7b2CrossRK6b2Vec2S1_($141,$153));
 $169 = +HEAPF32[$48>>2];
 $170 = +HEAPF32[$56>>2];
 $171 = $167 * $170;
 $172 = $167 * $171;
 $173 = $169 + $172;
 $174 = +HEAPF32[$52>>2];
 $175 = $174 + $173;
 $176 = +HEAPF32[$60>>2];
 $177 = $168 * $176;
 $178 = $168 * $177;
 $179 = $175 + $178;
 $180 = $179 != 0.0;
 if ($180) {
  $181 = 1.0 / $179;
  $183 = $181;
 } else {
  $183 = 0.0;
 }
 $182 = (($this) + 172|0);
 HEAPF32[$182>>2] = $183;
 $184 = (($this) + 68|0);
 $185 = +HEAPF32[$184>>2];
 $186 = $185 > 0.0;
 if ($186) {
  $187 = (($this) + 104|0);
  $188 = +HEAPF32[$187>>2];
  $189 = $164 - $188;
  $190 = $185 * 6.2831854820251465;
  $191 = $183 * 2.0;
  $192 = (($this) + 72|0);
  $193 = +HEAPF32[$192>>2];
  $194 = $191 * $193;
  $195 = $190 * $194;
  $196 = $183 * $190;
  $197 = $190 * $196;
  $198 = +HEAPF32[$data>>2];
  $199 = $197 * $198;
  $200 = $195 + $199;
  $201 = $198 * $200;
  $202 = (($this) + 96|0);
  HEAPF32[$202>>2] = $201;
  $203 = $201 != 0.0;
  if ($203) {
   $204 = 1.0 / $201;
   $205 = $204;
  } else {
   $205 = 0.0;
  }
  HEAPF32[$202>>2] = $205;
  $206 = $189 * $198;
  $207 = $197 * $206;
  $208 = $207 * $205;
  $209 = (($this) + 76|0);
  HEAPF32[$209>>2] = $208;
  $210 = +HEAPF32[$202>>2];
  $211 = $179 + $210;
  $212 = $211 != 0.0;
  if ($212) {
   $213 = 1.0 / $211;
   $214 = $213;
  } else {
   $214 = 0.0;
  }
  HEAPF32[$182>>2] = $214;
 } else {
  $215 = (($this) + 96|0);
  HEAPF32[$215>>2] = 0.0;
  $216 = (($this) + 76|0);
  HEAPF32[$216>>2] = 0.0;
 }
 $217 = (($data) + 24|0);
 $218 = HEAP8[$217>>0]|0;
 $219 = ($218<<24>>24)==(0);
 if ($219) {
  $235 = (($this) + 100|0);
  HEAPF32[$235>>2] = 0.0;
  $wA$0 = $95;$wB$0 = $128;
  $236 = HEAP32[$13>>2]|0;
  $237 = HEAP32[$79>>2]|0;
  $238 = (($237) + (($236*12)|0)|0);
  $239 = $vA;
  $240 = $239;
  $241 = HEAP32[$240>>2]|0;
  $242 = (($239) + 4)|0;
  $243 = $242;
  $244 = HEAP32[$243>>2]|0;
  $245 = $238;
  $246 = $245;
  HEAP32[$246>>2] = $241;
  $247 = (($245) + 4)|0;
  $248 = $247;
  HEAP32[$248>>2] = $244;
  $249 = HEAP32[$13>>2]|0;
  $250 = HEAP32[$79>>2]|0;
  $251 = ((($250) + (($249*12)|0)|0) + 8|0);
  HEAPF32[$251>>2] = $wA$0;
  $252 = HEAP32[$18>>2]|0;
  $253 = HEAP32[$79>>2]|0;
  $254 = (($253) + (($252*12)|0)|0);
  $255 = $vB;
  $256 = $255;
  $257 = HEAP32[$256>>2]|0;
  $258 = (($255) + 4)|0;
  $259 = $258;
  $260 = HEAP32[$259>>2]|0;
  $261 = $254;
  $262 = $261;
  HEAP32[$262>>2] = $257;
  $263 = (($261) + 4)|0;
  $264 = $263;
  HEAP32[$264>>2] = $260;
  $265 = HEAP32[$18>>2]|0;
  $266 = HEAP32[$79>>2]|0;
  $267 = ((($266) + (($265*12)|0)|0) + 8|0);
  HEAPF32[$267>>2] = $wB$0;
  STACKTOP = sp;return;
 } else {
  $220 = (($data) + 8|0);
  $221 = +HEAPF32[$220>>2];
  $222 = (($this) + 100|0);
  $223 = +HEAPF32[$222>>2];
  $224 = $221 * $223;
  HEAPF32[$222>>2] = $224;
  __ZmlfRK6b2Vec2($P,$224,$153);
  $225 = +HEAPF32[$48>>2];
  __ZmlfRK6b2Vec2($7,$225,$P);
  __ZN6b2Vec2mIERKS_($vA,$7);
  $226 = +HEAPF32[$56>>2];
  $227 = (+__Z7b2CrossRK6b2Vec2S1_($129,$P));
  $228 = $226 * $227;
  $229 = $95 - $228;
  $230 = +HEAPF32[$52>>2];
  __ZmlfRK6b2Vec2($8,$230,$P);
  __ZN6b2Vec2pLERKS_($vB,$8);
  $231 = +HEAPF32[$60>>2];
  $232 = (+__Z7b2CrossRK6b2Vec2S1_($141,$P));
  $233 = $231 * $232;
  $234 = $128 + $233;
  $wA$0 = $229;$wB$0 = $234;
  $236 = HEAP32[$13>>2]|0;
  $237 = HEAP32[$79>>2]|0;
  $238 = (($237) + (($236*12)|0)|0);
  $239 = $vA;
  $240 = $239;
  $241 = HEAP32[$240>>2]|0;
  $242 = (($239) + 4)|0;
  $243 = $242;
  $244 = HEAP32[$243>>2]|0;
  $245 = $238;
  $246 = $245;
  HEAP32[$246>>2] = $241;
  $247 = (($245) + 4)|0;
  $248 = $247;
  HEAP32[$248>>2] = $244;
  $249 = HEAP32[$13>>2]|0;
  $250 = HEAP32[$79>>2]|0;
  $251 = ((($250) + (($249*12)|0)|0) + 8|0);
  HEAPF32[$251>>2] = $wA$0;
  $252 = HEAP32[$18>>2]|0;
  $253 = HEAP32[$79>>2]|0;
  $254 = (($253) + (($252*12)|0)|0);
  $255 = $vB;
  $256 = $255;
  $257 = HEAP32[$256>>2]|0;
  $258 = (($255) + 4)|0;
  $259 = $258;
  $260 = HEAP32[$259>>2]|0;
  $261 = $254;
  $262 = $261;
  HEAP32[$262>>2] = $257;
  $263 = (($261) + 4)|0;
  $264 = $263;
  HEAP32[$264>>2] = $260;
  $265 = HEAP32[$18>>2]|0;
  $266 = HEAP32[$79>>2]|0;
  $267 = ((($266) + (($265*12)|0)|0) + 8|0);
  HEAPF32[$267>>2] = $wB$0;
  STACKTOP = sp;return;
 }
}
function __ZN15b2DistanceJoint24SolveVelocityConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0.0, $41 = 0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0.0, $47 = 0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0;
 var $59 = 0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0, $67 = 0.0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $P = 0, $vA = 0, $vB = 0, $vpA = 0, $vpB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $vA = sp + 8|0;
 $vB = sp;
 $vpA = sp + 72|0;
 $0 = sp + 64|0;
 $vpB = sp + 56|0;
 $1 = sp + 48|0;
 $2 = sp + 40|0;
 $P = sp + 32|0;
 $3 = sp + 24|0;
 $4 = sp + 16|0;
 $5 = (($this) + 108|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($data) + 32|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + (($6*12)|0)|0);
 $10 = $9;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 4)|0;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = $vA;
 $17 = $16;
 HEAP32[$17>>2] = $12;
 $18 = (($16) + 4)|0;
 $19 = $18;
 HEAP32[$19>>2] = $15;
 $20 = HEAP32[$5>>2]|0;
 $21 = HEAP32[$7>>2]|0;
 $22 = ((($21) + (($20*12)|0)|0) + 8|0);
 $23 = +HEAPF32[$22>>2];
 $24 = (($this) + 112|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($21) + (($25*12)|0)|0);
 $27 = $26;
 $28 = $27;
 $29 = HEAP32[$28>>2]|0;
 $30 = (($27) + 4)|0;
 $31 = $30;
 $32 = HEAP32[$31>>2]|0;
 $33 = $vB;
 $34 = $33;
 HEAP32[$34>>2] = $29;
 $35 = (($33) + 4)|0;
 $36 = $35;
 HEAP32[$36>>2] = $32;
 $37 = HEAP32[$24>>2]|0;
 $38 = HEAP32[$7>>2]|0;
 $39 = ((($38) + (($37*12)|0)|0) + 8|0);
 $40 = +HEAPF32[$39>>2];
 $41 = (($this) + 124|0);
 __Z7b2CrossfRK6b2Vec2($0,$23,$41);
 __ZplRK6b2Vec2S1_($vpA,$vA,$0);
 $42 = (($this) + 132|0);
 __Z7b2CrossfRK6b2Vec2($1,$40,$42);
 __ZplRK6b2Vec2S1_($vpB,$vB,$1);
 $43 = (($this) + 116|0);
 __ZmiRK6b2Vec2S1_($2,$vpB,$vpA);
 $44 = (+__Z5b2DotRK6b2Vec2S1_($43,$2));
 $45 = (($this) + 172|0);
 $46 = +HEAPF32[$45>>2];
 $47 = (($this) + 76|0);
 $48 = +HEAPF32[$47>>2];
 $49 = $44 + $48;
 $50 = (($this) + 96|0);
 $51 = +HEAPF32[$50>>2];
 $52 = (($this) + 100|0);
 $53 = +HEAPF32[$52>>2];
 $54 = $51 * $53;
 $55 = $49 + $54;
 $56 = $46 * $55;
 $57 = -$56;
 $58 = $53 - $56;
 HEAPF32[$52>>2] = $58;
 __ZmlfRK6b2Vec2($P,$57,$43);
 $59 = (($this) + 156|0);
 $60 = +HEAPF32[$59>>2];
 __ZmlfRK6b2Vec2($3,$60,$P);
 __ZN6b2Vec2mIERKS_($vA,$3);
 $61 = (($this) + 164|0);
 $62 = +HEAPF32[$61>>2];
 $63 = (+__Z7b2CrossRK6b2Vec2S1_($41,$P));
 $64 = $62 * $63;
 $65 = $23 - $64;
 $66 = (($this) + 160|0);
 $67 = +HEAPF32[$66>>2];
 __ZmlfRK6b2Vec2($4,$67,$P);
 __ZN6b2Vec2pLERKS_($vB,$4);
 $68 = (($this) + 168|0);
 $69 = +HEAPF32[$68>>2];
 $70 = (+__Z7b2CrossRK6b2Vec2S1_($42,$P));
 $71 = $69 * $70;
 $72 = $40 + $71;
 $73 = HEAP32[$5>>2]|0;
 $74 = HEAP32[$7>>2]|0;
 $75 = (($74) + (($73*12)|0)|0);
 $76 = $vA;
 $77 = $76;
 $78 = HEAP32[$77>>2]|0;
 $79 = (($76) + 4)|0;
 $80 = $79;
 $81 = HEAP32[$80>>2]|0;
 $82 = $75;
 $83 = $82;
 HEAP32[$83>>2] = $78;
 $84 = (($82) + 4)|0;
 $85 = $84;
 HEAP32[$85>>2] = $81;
 $86 = HEAP32[$5>>2]|0;
 $87 = HEAP32[$7>>2]|0;
 $88 = ((($87) + (($86*12)|0)|0) + 8|0);
 HEAPF32[$88>>2] = $65;
 $89 = HEAP32[$24>>2]|0;
 $90 = HEAP32[$7>>2]|0;
 $91 = (($90) + (($89*12)|0)|0);
 $92 = $vB;
 $93 = $92;
 $94 = HEAP32[$93>>2]|0;
 $95 = (($92) + 4)|0;
 $96 = $95;
 $97 = HEAP32[$96>>2]|0;
 $98 = $91;
 $99 = $98;
 HEAP32[$99>>2] = $94;
 $100 = (($98) + 4)|0;
 $101 = $100;
 HEAP32[$101>>2] = $97;
 $102 = HEAP32[$24>>2]|0;
 $103 = HEAP32[$7>>2]|0;
 $104 = ((($103) + (($102*12)|0)|0) + 8|0);
 HEAPF32[$104>>2] = $72;
 STACKTOP = sp;return;
}
function __ZN15b2DistanceJoint24SolvePositionConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0.0, $105 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0.0;
 var $57 = 0.0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0.0, $69 = 0.0, $7 = 0.0, $70 = 0.0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $P = 0, $cA = 0, $cB = 0, $qA = 0, $qB = 0, $rA = 0, $rB = 0, $u = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $cA = sp + 8|0;
 $cB = sp;
 $qA = sp + 104|0;
 $qB = sp + 96|0;
 $rA = sp + 88|0;
 $0 = sp + 80|0;
 $rB = sp + 72|0;
 $1 = sp + 64|0;
 $u = sp + 56|0;
 $2 = sp + 48|0;
 $3 = sp + 40|0;
 $P = sp + 32|0;
 $4 = sp + 24|0;
 $5 = sp + 16|0;
 $6 = (($this) + 68|0);
 $7 = +HEAPF32[$6>>2];
 $8 = $7 > 0.0;
 if ($8) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = (($this) + 108|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($data) + 28|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + (($10*12)|0)|0);
 $14 = $13;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14) + 4)|0;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = $cA;
 $21 = $20;
 HEAP32[$21>>2] = $16;
 $22 = (($20) + 4)|0;
 $23 = $22;
 HEAP32[$23>>2] = $19;
 $24 = HEAP32[$9>>2]|0;
 $25 = HEAP32[$11>>2]|0;
 $26 = ((($25) + (($24*12)|0)|0) + 8|0);
 $27 = +HEAPF32[$26>>2];
 $28 = (($this) + 112|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($25) + (($29*12)|0)|0);
 $31 = $30;
 $32 = $31;
 $33 = HEAP32[$32>>2]|0;
 $34 = (($31) + 4)|0;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = $cB;
 $38 = $37;
 HEAP32[$38>>2] = $33;
 $39 = (($37) + 4)|0;
 $40 = $39;
 HEAP32[$40>>2] = $36;
 $41 = HEAP32[$28>>2]|0;
 $42 = HEAP32[$11>>2]|0;
 $43 = ((($42) + (($41*12)|0)|0) + 8|0);
 $44 = +HEAPF32[$43>>2];
 __ZN5b2RotC2Ef($qA,$27);
 __ZN5b2RotC2Ef($qB,$44);
 $45 = (($this) + 80|0);
 $46 = (($this) + 140|0);
 __ZmiRK6b2Vec2S1_($0,$45,$46);
 __Z5b2MulRK5b2RotRK6b2Vec2($rA,$qA,$0);
 $47 = (($this) + 88|0);
 $48 = (($this) + 148|0);
 __ZmiRK6b2Vec2S1_($1,$47,$48);
 __Z5b2MulRK5b2RotRK6b2Vec2($rB,$qB,$1);
 __ZplRK6b2Vec2S1_($3,$cB,$rB);
 __ZmiRK6b2Vec2S1_($2,$3,$cA);
 __ZmiRK6b2Vec2S1_($u,$2,$rA);
 $49 = (+__ZN6b2Vec29NormalizeEv($u));
 $50 = (($this) + 104|0);
 $51 = +HEAPF32[$50>>2];
 $52 = $49 - $51;
 $53 = (+__Z7b2ClampIfET_S0_S0_S0_($52,-0.20000000298023224,0.20000000298023224));
 $54 = (($this) + 172|0);
 $55 = +HEAPF32[$54>>2];
 $56 = $53 * $55;
 $57 = -$56;
 __ZmlfRK6b2Vec2($P,$57,$u);
 $58 = (($this) + 156|0);
 $59 = +HEAPF32[$58>>2];
 __ZmlfRK6b2Vec2($4,$59,$P);
 __ZN6b2Vec2mIERKS_($cA,$4);
 $60 = (($this) + 164|0);
 $61 = +HEAPF32[$60>>2];
 $62 = (+__Z7b2CrossRK6b2Vec2S1_($rA,$P));
 $63 = $61 * $62;
 $64 = $27 - $63;
 $65 = (($this) + 160|0);
 $66 = +HEAPF32[$65>>2];
 __ZmlfRK6b2Vec2($5,$66,$P);
 __ZN6b2Vec2pLERKS_($cB,$5);
 $67 = (($this) + 168|0);
 $68 = +HEAPF32[$67>>2];
 $69 = (+__Z7b2CrossRK6b2Vec2S1_($rB,$P));
 $70 = $68 * $69;
 $71 = $44 + $70;
 $72 = HEAP32[$9>>2]|0;
 $73 = HEAP32[$11>>2]|0;
 $74 = (($73) + (($72*12)|0)|0);
 $75 = $cA;
 $76 = $75;
 $77 = HEAP32[$76>>2]|0;
 $78 = (($75) + 4)|0;
 $79 = $78;
 $80 = HEAP32[$79>>2]|0;
 $81 = $74;
 $82 = $81;
 HEAP32[$82>>2] = $77;
 $83 = (($81) + 4)|0;
 $84 = $83;
 HEAP32[$84>>2] = $80;
 $85 = HEAP32[$9>>2]|0;
 $86 = HEAP32[$11>>2]|0;
 $87 = ((($86) + (($85*12)|0)|0) + 8|0);
 HEAPF32[$87>>2] = $64;
 $88 = HEAP32[$28>>2]|0;
 $89 = HEAP32[$11>>2]|0;
 $90 = (($89) + (($88*12)|0)|0);
 $91 = $cB;
 $92 = $91;
 $93 = HEAP32[$92>>2]|0;
 $94 = (($91) + 4)|0;
 $95 = $94;
 $96 = HEAP32[$95>>2]|0;
 $97 = $90;
 $98 = $97;
 HEAP32[$98>>2] = $93;
 $99 = (($97) + 4)|0;
 $100 = $99;
 HEAP32[$100>>2] = $96;
 $101 = HEAP32[$28>>2]|0;
 $102 = HEAP32[$11>>2]|0;
 $103 = ((($102) + (($101*12)|0)|0) + 8|0);
 HEAPF32[$103>>2] = $71;
 $104 = (+__Z5b2AbsIfET_S0_($53));
 $105 = $104 < 0.004999999888241291;
 $$0 = $105;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK15b2DistanceJoint10GetAnchorAEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 80|0);
 __ZNK6b2Body13GetWorldPointERK6b2Vec2($agg$result,$1,$2);
 STACKTOP = sp;return;
}
function __ZNK15b2DistanceJoint10GetAnchorBEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 88|0);
 __ZNK6b2Body13GetWorldPointERK6b2Vec2($agg$result,$1,$2);
 STACKTOP = sp;return;
}
function __ZNK15b2DistanceJoint16GetReactionForceEf($agg$result,$this,$inv_dt) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inv_dt = +$inv_dt;
 var $0 = 0, $1 = 0.0, $2 = 0.0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 100|0);
 $1 = +HEAPF32[$0>>2];
 $2 = $1 * $inv_dt;
 $3 = (($this) + 116|0);
 __ZmlfRK6b2Vec2($agg$result,$2,$3);
 STACKTOP = sp;return;
}
function __ZNK15b2DistanceJoint17GetReactionTorqueEf($this,$inv_dt) {
 $this = $this|0;
 $inv_dt = +$inv_dt;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return +0;
}
function __ZN15b2DistanceJoint4DumpEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0;
 var $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer26 = 0, $vararg_ptr12 = 0, $vararg_ptr16 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer26 = sp;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 __Z5b2LogPKcz(2976,$vararg_buffer26);
 HEAP32[$vararg_buffer26>>2] = $3;
 __Z5b2LogPKcz(3008,$vararg_buffer26);
 HEAP32[$vararg_buffer26>>2] = $7;
 __Z5b2LogPKcz(3040,$vararg_buffer26);
 $8 = (($this) + 61|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 HEAP32[$vararg_buffer26>>2] = $10;
 __Z5b2LogPKcz(3072,$vararg_buffer26);
 $11 = (($this) + 80|0);
 $12 = +HEAPF32[$11>>2];
 $13 = $12;
 $14 = (($this) + 84|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $15;
 HEAPF64[tempDoublePtr>>3]=$13;HEAP32[$vararg_buffer26>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer26+4>>2]=HEAP32[tempDoublePtr+4>>2];
 $vararg_ptr12 = (($vararg_buffer26) + 8|0);
 HEAPF64[tempDoublePtr>>3]=$16;HEAP32[$vararg_ptr12>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr12+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(3112,$vararg_buffer26);
 $17 = (($this) + 88|0);
 $18 = +HEAPF32[$17>>2];
 $19 = $18;
 $20 = (($this) + 92|0);
 $21 = +HEAPF32[$20>>2];
 $22 = $21;
 HEAPF64[tempDoublePtr>>3]=$19;HEAP32[$vararg_buffer26>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer26+4>>2]=HEAP32[tempDoublePtr+4>>2];
 $vararg_ptr16 = (($vararg_buffer26) + 8|0);
 HEAPF64[tempDoublePtr>>3]=$22;HEAP32[$vararg_ptr16>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr16+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(3160,$vararg_buffer26);
 $23 = (($this) + 104|0);
 $24 = +HEAPF32[$23>>2];
 $25 = $24;
 HEAPF64[tempDoublePtr>>3]=$25;HEAP32[$vararg_buffer26>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer26+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(3208,$vararg_buffer26);
 $26 = (($this) + 68|0);
 $27 = +HEAPF32[$26>>2];
 $28 = $27;
 HEAPF64[tempDoublePtr>>3]=$28;HEAP32[$vararg_buffer26>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer26+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(3232,$vararg_buffer26);
 $29 = (($this) + 72|0);
 $30 = +HEAPF32[$29>>2];
 $31 = $30;
 HEAPF64[tempDoublePtr>>3]=$31;HEAP32[$vararg_buffer26>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer26+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(3264,$vararg_buffer26);
 $32 = (($this) + 56|0);
 $33 = HEAP32[$32>>2]|0;
 HEAP32[$vararg_buffer26>>2] = $33;
 __Z5b2LogPKcz(3296,$vararg_buffer26);
 STACKTOP = sp;return;
}
function __ZN15b2DistanceJointD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN18b2FrictionJointDef10InitializeEP6b2BodyS1_RK6b2Vec2($this,$bA,$bB,$anchor) {
 $this = $this|0;
 $bA = $bA|0;
 $bB = $bB|0;
 $anchor = $anchor|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = $bA;
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = $bB;
 $4 = (($this) + 20|0);
 $5 = HEAP32[$2>>2]|0;
 __ZNK6b2Body13GetLocalPointERK6b2Vec2($0,$5,$anchor);
 $6 = $0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $4;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 $16 = (($this) + 28|0);
 $17 = HEAP32[$3>>2]|0;
 __ZNK6b2Body13GetLocalPointERK6b2Vec2($1,$17,$anchor);
 $18 = $1;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + 4)|0;
 $22 = $21;
 $23 = HEAP32[$22>>2]|0;
 $24 = $16;
 $25 = $24;
 HEAP32[$25>>2] = $20;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = $23;
 STACKTOP = sp;return;
}
function __ZN15b2FrictionJointC2EPK18b2FrictionJointDef($this,$def) {
 $this = $this|0;
 $def = $def|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7b2JointC2EPK10b2JointDef($this,$def);
 HEAP32[$this>>2] = ((3384 + 8|0));
 $0 = (($this) + 68|0);
 $1 = (($this) + 76|0);
 $2 = (($this) + 84|0);
 $3 = (($def) + 20|0);
 $4 = $3;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = $0;
 $11 = $10;
 HEAP32[$11>>2] = $6;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = $9;
 $14 = (($def) + 28|0);
 $15 = $14;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = $1;
 $22 = $21;
 HEAP32[$22>>2] = $17;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = $20;
 __ZN6b2Vec27SetZeroEv($2);
 $25 = (($this) + 92|0);
 HEAPF32[$25>>2] = 0.0;
 $26 = (($def) + 36|0);
 $27 = +HEAPF32[$26>>2];
 $28 = (($this) + 96|0);
 HEAPF32[$28>>2] = $27;
 $29 = (($def) + 40|0);
 $30 = +HEAPF32[$29>>2];
 $31 = (($this) + 100|0);
 HEAPF32[$31>>2] = $30;
 STACKTOP = sp;return;
}
function __ZN15b2FrictionJoint23InitVelocityConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0;
 var $134 = 0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0, $15 = 0, $150 = 0, $151 = 0.0;
 var $152 = 0.0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = 0, $16 = 0, $160 = 0, $161 = 0.0, $162 = 0, $163 = 0, $164 = 0.0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0.0, $171 = 0.0, $172 = 0, $173 = 0.0, $174 = 0.0, $175 = 0.0, $176 = 0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0, $180 = 0.0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0.0, $186 = 0.0, $187 = 0.0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0.0, $46 = 0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0.0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0.0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0.0, $K = 0, $P = 0, $qA = 0, $qB = 0, $storemerge = 0.0, $vA = 0, $vB = 0, $wA$0 = 0.0, $wB$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $vA = sp + 24|0;
 $vB = sp + 16|0;
 $qA = sp + 112|0;
 $qB = sp + 104|0;
 $0 = sp + 8|0;
 $1 = sp + 96|0;
 $2 = sp;
 $3 = sp + 88|0;
 $K = sp + 72|0;
 $4 = sp + 56|0;
 $P = sp + 48|0;
 $5 = sp + 40|0;
 $6 = sp + 32|0;
 $7 = (($this) + 48|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 104|0);
 HEAP32[$11>>2] = $10;
 $12 = (($this) + 52|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 108|0);
 HEAP32[$16>>2] = $15;
 $17 = (($this) + 128|0);
 $18 = HEAP32[$7>>2]|0;
 $19 = (($18) + 44|0);
 $20 = $19;
 $21 = $20;
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20) + 4)|0;
 $24 = $23;
 $25 = HEAP32[$24>>2]|0;
 $26 = $17;
 $27 = $26;
 HEAP32[$27>>2] = $22;
 $28 = (($26) + 4)|0;
 $29 = $28;
 HEAP32[$29>>2] = $25;
 $30 = (($this) + 136|0);
 $31 = HEAP32[$12>>2]|0;
 $32 = (($31) + 44|0);
 $33 = $32;
 $34 = $33;
 $35 = HEAP32[$34>>2]|0;
 $36 = (($33) + 4)|0;
 $37 = $36;
 $38 = HEAP32[$37>>2]|0;
 $39 = $30;
 $40 = $39;
 HEAP32[$40>>2] = $35;
 $41 = (($39) + 4)|0;
 $42 = $41;
 HEAP32[$42>>2] = $38;
 $43 = HEAP32[$7>>2]|0;
 $44 = (($43) + 136|0);
 $45 = +HEAPF32[$44>>2];
 $46 = (($this) + 144|0);
 HEAPF32[$46>>2] = $45;
 $47 = HEAP32[$12>>2]|0;
 $48 = (($47) + 136|0);
 $49 = +HEAPF32[$48>>2];
 $50 = (($this) + 148|0);
 HEAPF32[$50>>2] = $49;
 $51 = HEAP32[$7>>2]|0;
 $52 = (($51) + 144|0);
 $53 = +HEAPF32[$52>>2];
 $54 = (($this) + 152|0);
 HEAPF32[$54>>2] = $53;
 $55 = HEAP32[$12>>2]|0;
 $56 = (($55) + 144|0);
 $57 = +HEAPF32[$56>>2];
 $58 = (($this) + 156|0);
 HEAPF32[$58>>2] = $57;
 $59 = HEAP32[$11>>2]|0;
 $60 = (($data) + 28|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = ((($61) + (($59*12)|0)|0) + 8|0);
 $63 = +HEAPF32[$62>>2];
 $64 = (($data) + 32|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($65) + (($59*12)|0)|0);
 $67 = $66;
 $68 = $67;
 $69 = HEAP32[$68>>2]|0;
 $70 = (($67) + 4)|0;
 $71 = $70;
 $72 = HEAP32[$71>>2]|0;
 $73 = $vA;
 $74 = $73;
 HEAP32[$74>>2] = $69;
 $75 = (($73) + 4)|0;
 $76 = $75;
 HEAP32[$76>>2] = $72;
 $77 = HEAP32[$11>>2]|0;
 $78 = HEAP32[$64>>2]|0;
 $79 = ((($78) + (($77*12)|0)|0) + 8|0);
 $80 = +HEAPF32[$79>>2];
 $81 = HEAP32[$16>>2]|0;
 $82 = HEAP32[$60>>2]|0;
 $83 = ((($82) + (($81*12)|0)|0) + 8|0);
 $84 = +HEAPF32[$83>>2];
 $85 = (($78) + (($81*12)|0)|0);
 $86 = $85;
 $87 = $86;
 $88 = HEAP32[$87>>2]|0;
 $89 = (($86) + 4)|0;
 $90 = $89;
 $91 = HEAP32[$90>>2]|0;
 $92 = $vB;
 $93 = $92;
 HEAP32[$93>>2] = $88;
 $94 = (($92) + 4)|0;
 $95 = $94;
 HEAP32[$95>>2] = $91;
 $96 = HEAP32[$16>>2]|0;
 $97 = HEAP32[$64>>2]|0;
 $98 = ((($97) + (($96*12)|0)|0) + 8|0);
 $99 = +HEAPF32[$98>>2];
 __ZN5b2RotC2Ef($qA,$63);
 __ZN5b2RotC2Ef($qB,$84);
 $100 = (($this) + 112|0);
 $101 = (($this) + 68|0);
 __ZmiRK6b2Vec2S1_($1,$101,$17);
 __Z5b2MulRK5b2RotRK6b2Vec2($0,$qA,$1);
 $102 = $0;
 $103 = $102;
 $104 = HEAP32[$103>>2]|0;
 $105 = (($102) + 4)|0;
 $106 = $105;
 $107 = HEAP32[$106>>2]|0;
 $108 = $100;
 $109 = $108;
 HEAP32[$109>>2] = $104;
 $110 = (($108) + 4)|0;
 $111 = $110;
 HEAP32[$111>>2] = $107;
 $112 = (($this) + 120|0);
 $113 = (($this) + 76|0);
 __ZmiRK6b2Vec2S1_($3,$113,$30);
 __Z5b2MulRK5b2RotRK6b2Vec2($2,$qB,$3);
 $114 = $2;
 $115 = $114;
 $116 = HEAP32[$115>>2]|0;
 $117 = (($114) + 4)|0;
 $118 = $117;
 $119 = HEAP32[$118>>2]|0;
 $120 = $112;
 $121 = $120;
 HEAP32[$121>>2] = $116;
 $122 = (($120) + 4)|0;
 $123 = $122;
 HEAP32[$123>>2] = $119;
 $124 = +HEAPF32[$46>>2];
 $125 = +HEAPF32[$50>>2];
 $126 = +HEAPF32[$54>>2];
 $127 = +HEAPF32[$58>>2];
 $128 = $124 + $125;
 $129 = (($this) + 116|0);
 $130 = +HEAPF32[$129>>2];
 $131 = $126 * $130;
 $132 = $130 * $131;
 $133 = $128 + $132;
 $134 = (($this) + 124|0);
 $135 = +HEAPF32[$134>>2];
 $136 = $127 * $135;
 $137 = $135 * $136;
 $138 = $133 + $137;
 HEAPF32[$K>>2] = $138;
 $139 = +HEAPF32[$100>>2];
 $140 = $126 * $139;
 $141 = +HEAPF32[$129>>2];
 $142 = $140 * $141;
 $143 = -$142;
 $144 = +HEAPF32[$112>>2];
 $145 = $127 * $144;
 $146 = +HEAPF32[$134>>2];
 $147 = $145 * $146;
 $148 = $143 - $147;
 $149 = (($K) + 4|0);
 HEAPF32[$149>>2] = $148;
 $150 = (($K) + 8|0);
 HEAPF32[$150>>2] = $148;
 $151 = +HEAPF32[$100>>2];
 $152 = $126 * $151;
 $153 = $151 * $152;
 $154 = $128 + $153;
 $155 = +HEAPF32[$112>>2];
 $156 = $127 * $155;
 $157 = $155 * $156;
 $158 = $154 + $157;
 $159 = (($K) + 12|0);
 HEAPF32[$159>>2] = $158;
 $160 = (($this) + 160|0);
 __ZNK7b2Mat2210GetInverseEv($4,$K);
 ;HEAP32[$160+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$160+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$160+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$160+12>>2]=HEAP32[$4+12>>2]|0;
 $161 = $126 + $127;
 $162 = (($this) + 176|0);
 $163 = $161 > 0.0;
 if ($163) {
  $164 = 1.0 / $161;
  $storemerge = $164;
 } else {
  $storemerge = $161;
 }
 HEAPF32[$162>>2] = $storemerge;
 $165 = (($data) + 24|0);
 $166 = HEAP8[$165>>0]|0;
 $167 = ($166<<24>>24)==(0);
 $168 = (($this) + 84|0);
 if ($167) {
  __ZN6b2Vec27SetZeroEv($168);
  $188 = (($this) + 92|0);
  HEAPF32[$188>>2] = 0.0;
  $wA$0 = $80;$wB$0 = $99;
  $189 = HEAP32[$11>>2]|0;
  $190 = HEAP32[$64>>2]|0;
  $191 = (($190) + (($189*12)|0)|0);
  $192 = $vA;
  $193 = $192;
  $194 = HEAP32[$193>>2]|0;
  $195 = (($192) + 4)|0;
  $196 = $195;
  $197 = HEAP32[$196>>2]|0;
  $198 = $191;
  $199 = $198;
  HEAP32[$199>>2] = $194;
  $200 = (($198) + 4)|0;
  $201 = $200;
  HEAP32[$201>>2] = $197;
  $202 = HEAP32[$11>>2]|0;
  $203 = HEAP32[$64>>2]|0;
  $204 = ((($203) + (($202*12)|0)|0) + 8|0);
  HEAPF32[$204>>2] = $wA$0;
  $205 = HEAP32[$16>>2]|0;
  $206 = HEAP32[$64>>2]|0;
  $207 = (($206) + (($205*12)|0)|0);
  $208 = $vB;
  $209 = $208;
  $210 = HEAP32[$209>>2]|0;
  $211 = (($208) + 4)|0;
  $212 = $211;
  $213 = HEAP32[$212>>2]|0;
  $214 = $207;
  $215 = $214;
  HEAP32[$215>>2] = $210;
  $216 = (($214) + 4)|0;
  $217 = $216;
  HEAP32[$217>>2] = $213;
  $218 = HEAP32[$16>>2]|0;
  $219 = HEAP32[$64>>2]|0;
  $220 = ((($219) + (($218*12)|0)|0) + 8|0);
  HEAPF32[$220>>2] = $wB$0;
  STACKTOP = sp;return;
 } else {
  $169 = (($data) + 8|0);
  $170 = +HEAPF32[$169>>2];
  __ZN6b2Vec2mLEf($168,$170);
  $171 = +HEAPF32[$169>>2];
  $172 = (($this) + 92|0);
  $173 = +HEAPF32[$172>>2];
  $174 = $171 * $173;
  HEAPF32[$172>>2] = $174;
  $175 = +HEAPF32[$168>>2];
  $176 = (($this) + 88|0);
  $177 = +HEAPF32[$176>>2];
  __ZN6b2Vec2C2Eff($P,$175,$177);
  __ZmlfRK6b2Vec2($5,$124,$P);
  __ZN6b2Vec2mIERKS_($vA,$5);
  $178 = (+__Z7b2CrossRK6b2Vec2S1_($100,$P));
  $179 = +HEAPF32[$172>>2];
  $180 = $178 + $179;
  $181 = $126 * $180;
  $182 = $80 - $181;
  __ZmlfRK6b2Vec2($6,$125,$P);
  __ZN6b2Vec2pLERKS_($vB,$6);
  $183 = (+__Z7b2CrossRK6b2Vec2S1_($112,$P));
  $184 = +HEAPF32[$172>>2];
  $185 = $183 + $184;
  $186 = $127 * $185;
  $187 = $99 + $186;
  $wA$0 = $182;$wB$0 = $187;
  $189 = HEAP32[$11>>2]|0;
  $190 = HEAP32[$64>>2]|0;
  $191 = (($190) + (($189*12)|0)|0);
  $192 = $vA;
  $193 = $192;
  $194 = HEAP32[$193>>2]|0;
  $195 = (($192) + 4)|0;
  $196 = $195;
  $197 = HEAP32[$196>>2]|0;
  $198 = $191;
  $199 = $198;
  HEAP32[$199>>2] = $194;
  $200 = (($198) + 4)|0;
  $201 = $200;
  HEAP32[$201>>2] = $197;
  $202 = HEAP32[$11>>2]|0;
  $203 = HEAP32[$64>>2]|0;
  $204 = ((($203) + (($202*12)|0)|0) + 8|0);
  HEAPF32[$204>>2] = $wA$0;
  $205 = HEAP32[$16>>2]|0;
  $206 = HEAP32[$64>>2]|0;
  $207 = (($206) + (($205*12)|0)|0);
  $208 = $vB;
  $209 = $208;
  $210 = HEAP32[$209>>2]|0;
  $211 = (($208) + 4)|0;
  $212 = $211;
  $213 = HEAP32[$212>>2]|0;
  $214 = $207;
  $215 = $214;
  HEAP32[$215>>2] = $210;
  $216 = (($214) + 4)|0;
  $217 = $216;
  HEAP32[$217>>2] = $213;
  $218 = HEAP32[$16>>2]|0;
  $219 = HEAP32[$64>>2]|0;
  $220 = ((($219) + (($218*12)|0)|0) + 8|0);
  HEAPF32[$220>>2] = $wB$0;
  STACKTOP = sp;return;
 }
}
function __ZN15b2FrictionJoint24SolveVelocityConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0.0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0, $54 = 0.0, $55 = 0.0, $56 = 0;
 var $57 = 0.0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0;
 var $93 = 0.0, $94 = 0.0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $Cdot1 = 0, $impulse2 = 0, $oldImpulse3 = 0, $vA = 0, $vB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $vA = sp + 24|0;
 $vB = sp + 16|0;
 $Cdot1 = sp + 88|0;
 $0 = sp + 80|0;
 $1 = sp + 72|0;
 $2 = sp + 64|0;
 $3 = sp + 56|0;
 $impulse2 = sp + 8|0;
 $4 = sp + 48|0;
 $oldImpulse3 = sp;
 $5 = sp + 40|0;
 $6 = sp + 32|0;
 $7 = (($this) + 104|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($data) + 32|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + (($8*12)|0)|0);
 $12 = $11;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($12) + 4)|0;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = $vA;
 $19 = $18;
 HEAP32[$19>>2] = $14;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = $17;
 $22 = HEAP32[$7>>2]|0;
 $23 = HEAP32[$9>>2]|0;
 $24 = ((($23) + (($22*12)|0)|0) + 8|0);
 $25 = +HEAPF32[$24>>2];
 $26 = (($this) + 108|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($23) + (($27*12)|0)|0);
 $29 = $28;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = (($29) + 4)|0;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = $vB;
 $36 = $35;
 HEAP32[$36>>2] = $31;
 $37 = (($35) + 4)|0;
 $38 = $37;
 HEAP32[$38>>2] = $34;
 $39 = HEAP32[$26>>2]|0;
 $40 = HEAP32[$9>>2]|0;
 $41 = ((($40) + (($39*12)|0)|0) + 8|0);
 $42 = +HEAPF32[$41>>2];
 $43 = (($this) + 144|0);
 $44 = +HEAPF32[$43>>2];
 $45 = (($this) + 148|0);
 $46 = +HEAPF32[$45>>2];
 $47 = (($this) + 152|0);
 $48 = +HEAPF32[$47>>2];
 $49 = (($this) + 156|0);
 $50 = +HEAPF32[$49>>2];
 $51 = +HEAPF32[$data>>2];
 $52 = $42 - $25;
 $53 = (($this) + 176|0);
 $54 = +HEAPF32[$53>>2];
 $55 = $52 * $54;
 $56 = (($this) + 92|0);
 $57 = +HEAPF32[$56>>2];
 $58 = (($this) + 100|0);
 $59 = +HEAPF32[$58>>2];
 $60 = $51 * $59;
 $61 = $57 - $55;
 $62 = -$60;
 $63 = (+__Z7b2ClampIfET_S0_S0_S0_($61,$62,$60));
 HEAPF32[$56>>2] = $63;
 $64 = $63 - $57;
 $65 = $48 * $64;
 $66 = $25 - $65;
 $67 = $50 * $64;
 $68 = $42 + $67;
 $69 = (($this) + 120|0);
 __Z7b2CrossfRK6b2Vec2($2,$68,$69);
 __ZplRK6b2Vec2S1_($1,$vB,$2);
 __ZmiRK6b2Vec2S1_($0,$1,$vA);
 $70 = (($this) + 112|0);
 __Z7b2CrossfRK6b2Vec2($3,$66,$70);
 __ZmiRK6b2Vec2S1_($Cdot1,$0,$3);
 $71 = (($this) + 160|0);
 __Z5b2MulRK7b2Mat22RK6b2Vec2($4,$71,$Cdot1);
 __ZNK6b2Vec2ngEv($impulse2,$4);
 $72 = (($this) + 84|0);
 $73 = $72;
 $74 = $73;
 $75 = HEAP32[$74>>2]|0;
 $76 = (($73) + 4)|0;
 $77 = $76;
 $78 = HEAP32[$77>>2]|0;
 $79 = $oldImpulse3;
 $80 = $79;
 HEAP32[$80>>2] = $75;
 $81 = (($79) + 4)|0;
 $82 = $81;
 HEAP32[$82>>2] = $78;
 __ZN6b2Vec2pLERKS_($72,$impulse2);
 $83 = (($this) + 96|0);
 $84 = +HEAPF32[$83>>2];
 $85 = $51 * $84;
 $86 = (+__ZNK6b2Vec213LengthSquaredEv($72));
 $87 = $85 * $85;
 $88 = $86 > $87;
 if ($88) {
  (+__ZN6b2Vec29NormalizeEv($72));
  __ZN6b2Vec2mLEf($72,$85);
 }
 __ZmiRK6b2Vec2S1_($impulse2,$72,$oldImpulse3);
 __ZmlfRK6b2Vec2($5,$44,$impulse2);
 __ZN6b2Vec2mIERKS_($vA,$5);
 $89 = (+__Z7b2CrossRK6b2Vec2S1_($70,$impulse2));
 $90 = $48 * $89;
 $91 = $66 - $90;
 __ZmlfRK6b2Vec2($6,$46,$impulse2);
 __ZN6b2Vec2pLERKS_($vB,$6);
 $92 = (+__Z7b2CrossRK6b2Vec2S1_($69,$impulse2));
 $93 = $50 * $92;
 $94 = $68 + $93;
 $95 = HEAP32[$7>>2]|0;
 $96 = HEAP32[$9>>2]|0;
 $97 = (($96) + (($95*12)|0)|0);
 $98 = $vA;
 $99 = $98;
 $100 = HEAP32[$99>>2]|0;
 $101 = (($98) + 4)|0;
 $102 = $101;
 $103 = HEAP32[$102>>2]|0;
 $104 = $97;
 $105 = $104;
 HEAP32[$105>>2] = $100;
 $106 = (($104) + 4)|0;
 $107 = $106;
 HEAP32[$107>>2] = $103;
 $108 = HEAP32[$7>>2]|0;
 $109 = HEAP32[$9>>2]|0;
 $110 = ((($109) + (($108*12)|0)|0) + 8|0);
 HEAPF32[$110>>2] = $91;
 $111 = HEAP32[$26>>2]|0;
 $112 = HEAP32[$9>>2]|0;
 $113 = (($112) + (($111*12)|0)|0);
 $114 = $vB;
 $115 = $114;
 $116 = HEAP32[$115>>2]|0;
 $117 = (($114) + 4)|0;
 $118 = $117;
 $119 = HEAP32[$118>>2]|0;
 $120 = $113;
 $121 = $120;
 HEAP32[$121>>2] = $116;
 $122 = (($120) + 4)|0;
 $123 = $122;
 HEAP32[$123>>2] = $119;
 $124 = HEAP32[$26>>2]|0;
 $125 = HEAP32[$9>>2]|0;
 $126 = ((($125) + (($124*12)|0)|0) + 8|0);
 HEAPF32[$126>>2] = $94;
 STACKTOP = sp;return;
}
function __ZN15b2FrictionJoint24SolvePositionConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZNK15b2FrictionJoint10GetAnchorAEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 68|0);
 __ZNK6b2Body13GetWorldPointERK6b2Vec2($agg$result,$1,$2);
 STACKTOP = sp;return;
}
function __ZNK15b2FrictionJoint10GetAnchorBEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 76|0);
 __ZNK6b2Body13GetWorldPointERK6b2Vec2($agg$result,$1,$2);
 STACKTOP = sp;return;
}
function __ZNK15b2FrictionJoint16GetReactionForceEf($agg$result,$this,$inv_dt) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inv_dt = +$inv_dt;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 84|0);
 __ZmlfRK6b2Vec2($agg$result,$inv_dt,$0);
 STACKTOP = sp;return;
}
function __ZNK15b2FrictionJoint17GetReactionTorqueEf($this,$inv_dt) {
 $this = $this|0;
 $inv_dt = +$inv_dt;
 var $0 = 0, $1 = 0.0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 $1 = +HEAPF32[$0>>2];
 $2 = $1 * $inv_dt;
 STACKTOP = sp;return (+$2);
}
function __ZN15b2FrictionJoint4DumpEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0;
 var $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer23 = 0, $vararg_ptr12 = 0, $vararg_ptr16 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer23 = sp;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 __Z5b2LogPKcz(3440,$vararg_buffer23);
 HEAP32[$vararg_buffer23>>2] = $3;
 __Z5b2LogPKcz(3472,$vararg_buffer23);
 HEAP32[$vararg_buffer23>>2] = $7;
 __Z5b2LogPKcz(3504,$vararg_buffer23);
 $8 = (($this) + 61|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 HEAP32[$vararg_buffer23>>2] = $10;
 __Z5b2LogPKcz(3536,$vararg_buffer23);
 $11 = (($this) + 68|0);
 $12 = +HEAPF32[$11>>2];
 $13 = $12;
 $14 = (($this) + 72|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $15;
 HEAPF64[tempDoublePtr>>3]=$13;HEAP32[$vararg_buffer23>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer23+4>>2]=HEAP32[tempDoublePtr+4>>2];
 $vararg_ptr12 = (($vararg_buffer23) + 8|0);
 HEAPF64[tempDoublePtr>>3]=$16;HEAP32[$vararg_ptr12>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr12+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(3576,$vararg_buffer23);
 $17 = (($this) + 76|0);
 $18 = +HEAPF32[$17>>2];
 $19 = $18;
 $20 = (($this) + 80|0);
 $21 = +HEAPF32[$20>>2];
 $22 = $21;
 HEAPF64[tempDoublePtr>>3]=$19;HEAP32[$vararg_buffer23>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer23+4>>2]=HEAP32[tempDoublePtr+4>>2];
 $vararg_ptr16 = (($vararg_buffer23) + 8|0);
 HEAPF64[tempDoublePtr>>3]=$22;HEAP32[$vararg_ptr16>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr16+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(3624,$vararg_buffer23);
 $23 = (($this) + 96|0);
 $24 = +HEAPF32[$23>>2];
 $25 = $24;
 HEAPF64[tempDoublePtr>>3]=$25;HEAP32[$vararg_buffer23>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer23+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(3672,$vararg_buffer23);
 $26 = (($this) + 100|0);
 $27 = +HEAPF32[$26>>2];
 $28 = $27;
 HEAPF64[tempDoublePtr>>3]=$28;HEAP32[$vararg_buffer23>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer23+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(3704,$vararg_buffer23);
 $29 = (($this) + 56|0);
 $30 = HEAP32[$29>>2]|0;
 HEAP32[$vararg_buffer23>>2] = $30;
 __Z5b2LogPKcz(3736,$vararg_buffer23);
 STACKTOP = sp;return;
}
function __ZN15b2FrictionJointD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN14b2WeldJointDef10InitializeEP6b2BodyS1_RK6b2Vec2($this,$bA,$bB,$anchor) {
 $this = $this|0;
 $bA = $bA|0;
 $bB = $bB|0;
 $anchor = $anchor|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = $bA;
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = $bB;
 $4 = (($this) + 20|0);
 $5 = HEAP32[$2>>2]|0;
 __ZNK6b2Body13GetLocalPointERK6b2Vec2($0,$5,$anchor);
 $6 = $0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $4;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 $16 = (($this) + 28|0);
 $17 = HEAP32[$3>>2]|0;
 __ZNK6b2Body13GetLocalPointERK6b2Vec2($1,$17,$anchor);
 $18 = $1;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + 4)|0;
 $22 = $21;
 $23 = HEAP32[$22>>2]|0;
 $24 = $16;
 $25 = $24;
 HEAP32[$25>>2] = $20;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = $23;
 $28 = HEAP32[$3>>2]|0;
 $29 = (+__ZNK6b2Body8GetAngleEv($28));
 $30 = HEAP32[$2>>2]|0;
 $31 = (+__ZNK6b2Body8GetAngleEv($30));
 $32 = $29 - $31;
 $33 = (($this) + 36|0);
 HEAPF32[$33>>2] = $32;
 STACKTOP = sp;return;
}
function __ZN11b2WeldJointC2EPK14b2WeldJointDef($this,$def) {
 $this = $this|0;
 $def = $def|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0.0;
 var $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7b2JointC2EPK10b2JointDef($this,$def);
 HEAP32[$this>>2] = ((3824 + 8|0));
 $0 = (($this) + 80|0);
 $1 = (($this) + 88|0);
 $2 = (($this) + 104|0);
 $3 = (($def) + 20|0);
 $4 = $3;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = $0;
 $11 = $10;
 HEAP32[$11>>2] = $6;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = $9;
 $14 = (($def) + 28|0);
 $15 = $14;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = $1;
 $22 = $21;
 HEAP32[$22>>2] = $17;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = $20;
 $25 = (($def) + 36|0);
 $26 = +HEAPF32[$25>>2];
 $27 = (($this) + 96|0);
 HEAPF32[$27>>2] = $26;
 $28 = (($def) + 40|0);
 $29 = +HEAPF32[$28>>2];
 $30 = (($this) + 68|0);
 HEAPF32[$30>>2] = $29;
 $31 = (($def) + 44|0);
 $32 = +HEAPF32[$31>>2];
 $33 = (($this) + 72|0);
 HEAPF32[$33>>2] = $32;
 __ZN6b2Vec37SetZeroEv($2);
 STACKTOP = sp;return;
}
function __ZN11b2WeldJoint23InitVelocityConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0;
 var $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0, $149 = 0.0, $15 = 0, $150 = 0.0, $151 = 0.0;
 var $152 = 0.0, $153 = 0.0, $154 = 0.0, $155 = 0, $156 = 0.0, $157 = 0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0.0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0.0, $166 = 0, $167 = 0.0, $168 = 0.0, $169 = 0.0, $17 = 0;
 var $170 = 0.0, $171 = 0.0, $172 = 0, $173 = 0.0, $174 = 0, $175 = 0.0, $176 = 0, $177 = 0.0, $178 = 0, $179 = 0, $18 = 0, $180 = 0.0, $181 = 0, $182 = 0, $183 = 0, $184 = 0.0, $185 = 0.0, $186 = 0, $187 = 0.0, $188 = 0.0;
 var $189 = 0.0, $19 = 0, $190 = 0.0, $191 = 0.0, $192 = 0.0, $193 = 0, $194 = 0.0, $195 = 0.0, $196 = 0.0, $197 = 0.0, $198 = 0.0, $199 = 0.0, $2 = 0, $20 = 0, $200 = 0.0, $201 = 0.0, $202 = 0.0, $203 = 0, $204 = 0, $205 = 0.0;
 var $206 = 0.0, $207 = 0.0, $208 = 0.0, $209 = 0.0, $21 = 0, $210 = 0, $211 = 0.0, $212 = 0.0, $213 = 0, $214 = 0.0, $215 = 0, $216 = 0.0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0.0, $225 = 0.0, $226 = 0, $227 = 0.0, $228 = 0.0, $229 = 0, $23 = 0, $230 = 0.0, $231 = 0.0, $232 = 0.0, $233 = 0.0, $234 = 0.0, $235 = 0.0, $236 = 0.0, $237 = 0.0, $238 = 0.0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0.0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0.0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0.0, $99 = 0, $K = 0, $P = 0, $qA = 0, $qB = 0, $vA = 0, $vB = 0, $wA$0 = 0.0, $wB$0 = 0.0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $vA = sp + 24|0;
 $vB = sp + 16|0;
 $qA = sp + 120|0;
 $qB = sp + 112|0;
 $0 = sp + 8|0;
 $1 = sp + 104|0;
 $2 = sp;
 $3 = sp + 96|0;
 $K = sp + 56|0;
 $P = sp + 48|0;
 $4 = sp + 40|0;
 $5 = sp + 32|0;
 $6 = (($this) + 48|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 116|0);
 HEAP32[$10>>2] = $9;
 $11 = (($this) + 52|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($this) + 120|0);
 HEAP32[$15>>2] = $14;
 $16 = (($this) + 140|0);
 $17 = HEAP32[$6>>2]|0;
 $18 = (($17) + 44|0);
 $19 = $18;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) + 4)|0;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 $25 = $16;
 $26 = $25;
 HEAP32[$26>>2] = $21;
 $27 = (($25) + 4)|0;
 $28 = $27;
 HEAP32[$28>>2] = $24;
 $29 = (($this) + 148|0);
 $30 = HEAP32[$11>>2]|0;
 $31 = (($30) + 44|0);
 $32 = $31;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = (($32) + 4)|0;
 $36 = $35;
 $37 = HEAP32[$36>>2]|0;
 $38 = $29;
 $39 = $38;
 HEAP32[$39>>2] = $34;
 $40 = (($38) + 4)|0;
 $41 = $40;
 HEAP32[$41>>2] = $37;
 $42 = HEAP32[$6>>2]|0;
 $43 = (($42) + 136|0);
 $44 = +HEAPF32[$43>>2];
 $45 = (($this) + 156|0);
 HEAPF32[$45>>2] = $44;
 $46 = HEAP32[$11>>2]|0;
 $47 = (($46) + 136|0);
 $48 = +HEAPF32[$47>>2];
 $49 = (($this) + 160|0);
 HEAPF32[$49>>2] = $48;
 $50 = HEAP32[$6>>2]|0;
 $51 = (($50) + 144|0);
 $52 = +HEAPF32[$51>>2];
 $53 = (($this) + 164|0);
 HEAPF32[$53>>2] = $52;
 $54 = HEAP32[$11>>2]|0;
 $55 = (($54) + 144|0);
 $56 = +HEAPF32[$55>>2];
 $57 = (($this) + 168|0);
 HEAPF32[$57>>2] = $56;
 $58 = HEAP32[$10>>2]|0;
 $59 = (($data) + 28|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ((($60) + (($58*12)|0)|0) + 8|0);
 $62 = +HEAPF32[$61>>2];
 $63 = (($data) + 32|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($64) + (($58*12)|0)|0);
 $66 = $65;
 $67 = $66;
 $68 = HEAP32[$67>>2]|0;
 $69 = (($66) + 4)|0;
 $70 = $69;
 $71 = HEAP32[$70>>2]|0;
 $72 = $vA;
 $73 = $72;
 HEAP32[$73>>2] = $68;
 $74 = (($72) + 4)|0;
 $75 = $74;
 HEAP32[$75>>2] = $71;
 $76 = HEAP32[$10>>2]|0;
 $77 = HEAP32[$63>>2]|0;
 $78 = ((($77) + (($76*12)|0)|0) + 8|0);
 $79 = +HEAPF32[$78>>2];
 $80 = HEAP32[$15>>2]|0;
 $81 = HEAP32[$59>>2]|0;
 $82 = ((($81) + (($80*12)|0)|0) + 8|0);
 $83 = +HEAPF32[$82>>2];
 $84 = (($77) + (($80*12)|0)|0);
 $85 = $84;
 $86 = $85;
 $87 = HEAP32[$86>>2]|0;
 $88 = (($85) + 4)|0;
 $89 = $88;
 $90 = HEAP32[$89>>2]|0;
 $91 = $vB;
 $92 = $91;
 HEAP32[$92>>2] = $87;
 $93 = (($91) + 4)|0;
 $94 = $93;
 HEAP32[$94>>2] = $90;
 $95 = HEAP32[$15>>2]|0;
 $96 = HEAP32[$63>>2]|0;
 $97 = ((($96) + (($95*12)|0)|0) + 8|0);
 $98 = +HEAPF32[$97>>2];
 __ZN5b2RotC2Ef($qA,$62);
 __ZN5b2RotC2Ef($qB,$83);
 $99 = (($this) + 124|0);
 $100 = (($this) + 80|0);
 __ZmiRK6b2Vec2S1_($1,$100,$16);
 __Z5b2MulRK5b2RotRK6b2Vec2($0,$qA,$1);
 $101 = $0;
 $102 = $101;
 $103 = HEAP32[$102>>2]|0;
 $104 = (($101) + 4)|0;
 $105 = $104;
 $106 = HEAP32[$105>>2]|0;
 $107 = $99;
 $108 = $107;
 HEAP32[$108>>2] = $103;
 $109 = (($107) + 4)|0;
 $110 = $109;
 HEAP32[$110>>2] = $106;
 $111 = (($this) + 132|0);
 $112 = (($this) + 88|0);
 __ZmiRK6b2Vec2S1_($3,$112,$29);
 __Z5b2MulRK5b2RotRK6b2Vec2($2,$qB,$3);
 $113 = $2;
 $114 = $113;
 $115 = HEAP32[$114>>2]|0;
 $116 = (($113) + 4)|0;
 $117 = $116;
 $118 = HEAP32[$117>>2]|0;
 $119 = $111;
 $120 = $119;
 HEAP32[$120>>2] = $115;
 $121 = (($119) + 4)|0;
 $122 = $121;
 HEAP32[$122>>2] = $118;
 $123 = +HEAPF32[$45>>2];
 $124 = +HEAPF32[$49>>2];
 $125 = +HEAPF32[$53>>2];
 $126 = +HEAPF32[$57>>2];
 $127 = $123 + $124;
 $128 = (($this) + 128|0);
 $129 = +HEAPF32[$128>>2];
 $130 = $129 * $129;
 $131 = $125 * $130;
 $132 = $127 + $131;
 $133 = (($this) + 136|0);
 $134 = +HEAPF32[$133>>2];
 $135 = $134 * $134;
 $136 = $126 * $135;
 $137 = $132 + $136;
 HEAPF32[$K>>2] = $137;
 $138 = +HEAPF32[$128>>2];
 $139 = +HEAPF32[$99>>2];
 $140 = $138 * $139;
 $141 = $125 * $140;
 $142 = -$141;
 $143 = +HEAPF32[$133>>2];
 $144 = +HEAPF32[$111>>2];
 $145 = $143 * $144;
 $146 = $126 * $145;
 $147 = $142 - $146;
 $148 = (($K) + 12|0);
 HEAPF32[$148>>2] = $147;
 $149 = +HEAPF32[$128>>2];
 $150 = $125 * $149;
 $151 = -$150;
 $152 = +HEAPF32[$133>>2];
 $153 = $126 * $152;
 $154 = $151 - $153;
 $155 = (($K) + 24|0);
 HEAPF32[$155>>2] = $154;
 $156 = +HEAPF32[$148>>2];
 $157 = (($K) + 4|0);
 HEAPF32[$157>>2] = $156;
 $158 = +HEAPF32[$99>>2];
 $159 = $158 * $158;
 $160 = $125 * $159;
 $161 = $127 + $160;
 $162 = +HEAPF32[$111>>2];
 $163 = $162 * $162;
 $164 = $126 * $163;
 $165 = $161 + $164;
 $166 = (($K) + 16|0);
 HEAPF32[$166>>2] = $165;
 $167 = +HEAPF32[$99>>2];
 $168 = $125 * $167;
 $169 = +HEAPF32[$111>>2];
 $170 = $126 * $169;
 $171 = $168 + $170;
 $172 = (($K) + 28|0);
 HEAPF32[$172>>2] = $171;
 $173 = +HEAPF32[$155>>2];
 $174 = (($K) + 8|0);
 HEAPF32[$174>>2] = $173;
 $175 = +HEAPF32[$172>>2];
 $176 = (($K) + 20|0);
 HEAPF32[$176>>2] = $175;
 $177 = $125 + $126;
 $178 = (($K) + 32|0);
 HEAPF32[$178>>2] = $177;
 $179 = (($this) + 68|0);
 $180 = +HEAPF32[$179>>2];
 $181 = $180 > 0.0;
 $182 = (($this) + 172|0);
 if ($181) {
  __ZNK7b2Mat3312GetInverse22EPS_($K,$182);
  $183 = $177 > 0.0;
  if ($183) {
   $184 = 1.0 / $177;
   $192 = $184;
  } else {
   $192 = 0.0;
  }
  $185 = $83 - $62;
  $186 = (($this) + 96|0);
  $187 = +HEAPF32[$186>>2];
  $188 = $185 - $187;
  $189 = +HEAPF32[$179>>2];
  $190 = $189 * 6.2831854820251465;
  $191 = $192 * 2.0;
  $193 = (($this) + 72|0);
  $194 = +HEAPF32[$193>>2];
  $195 = $191 * $194;
  $196 = $190 * $195;
  $197 = $192 * $190;
  $198 = $190 * $197;
  $199 = +HEAPF32[$data>>2];
  $200 = $199 * $198;
  $201 = $196 + $200;
  $202 = $199 * $201;
  $203 = (($this) + 100|0);
  HEAPF32[$203>>2] = $202;
  $204 = $202 != 0.0;
  if ($204) {
   $205 = 1.0 / $202;
   $206 = $205;
  } else {
   $206 = 0.0;
  }
  HEAPF32[$203>>2] = $206;
  $207 = $188 * $199;
  $208 = $207 * $198;
  $209 = $208 * $206;
  $210 = (($this) + 76|0);
  HEAPF32[$210>>2] = $209;
  $211 = +HEAPF32[$203>>2];
  $212 = $177 + $211;
  $213 = $212 != 0.0;
  if ($213) {
   $214 = 1.0 / $212;
   $216 = $214;
  } else {
   $216 = 0.0;
  }
  $215 = (($this) + 204|0);
  HEAPF32[$215>>2] = $216;
 } else {
  __ZNK7b2Mat3315GetSymInverse33EPS_($K,$182);
  $217 = (($this) + 100|0);
  HEAPF32[$217>>2] = 0.0;
  $218 = (($this) + 76|0);
  HEAPF32[$218>>2] = 0.0;
 }
 $219 = (($data) + 24|0);
 $220 = HEAP8[$219>>0]|0;
 $221 = ($220<<24>>24)==(0);
 $222 = (($this) + 104|0);
 if ($221) {
  __ZN6b2Vec37SetZeroEv($222);
  $wA$0 = $79;$wB$0 = $98;
  $239 = HEAP32[$10>>2]|0;
  $240 = HEAP32[$63>>2]|0;
  $241 = (($240) + (($239*12)|0)|0);
  $242 = $vA;
  $243 = $242;
  $244 = HEAP32[$243>>2]|0;
  $245 = (($242) + 4)|0;
  $246 = $245;
  $247 = HEAP32[$246>>2]|0;
  $248 = $241;
  $249 = $248;
  HEAP32[$249>>2] = $244;
  $250 = (($248) + 4)|0;
  $251 = $250;
  HEAP32[$251>>2] = $247;
  $252 = HEAP32[$10>>2]|0;
  $253 = HEAP32[$63>>2]|0;
  $254 = ((($253) + (($252*12)|0)|0) + 8|0);
  HEAPF32[$254>>2] = $wA$0;
  $255 = HEAP32[$15>>2]|0;
  $256 = HEAP32[$63>>2]|0;
  $257 = (($256) + (($255*12)|0)|0);
  $258 = $vB;
  $259 = $258;
  $260 = HEAP32[$259>>2]|0;
  $261 = (($258) + 4)|0;
  $262 = $261;
  $263 = HEAP32[$262>>2]|0;
  $264 = $257;
  $265 = $264;
  HEAP32[$265>>2] = $260;
  $266 = (($264) + 4)|0;
  $267 = $266;
  HEAP32[$267>>2] = $263;
  $268 = HEAP32[$15>>2]|0;
  $269 = HEAP32[$63>>2]|0;
  $270 = ((($269) + (($268*12)|0)|0) + 8|0);
  HEAPF32[$270>>2] = $wB$0;
  STACKTOP = sp;return;
 } else {
  $223 = (($data) + 8|0);
  $224 = +HEAPF32[$223>>2];
  __ZN6b2Vec3mLEf($222,$224);
  $225 = +HEAPF32[$222>>2];
  $226 = (($this) + 108|0);
  $227 = +HEAPF32[$226>>2];
  __ZN6b2Vec2C2Eff($P,$225,$227);
  __ZmlfRK6b2Vec2($4,$123,$P);
  __ZN6b2Vec2mIERKS_($vA,$4);
  $228 = (+__Z7b2CrossRK6b2Vec2S1_($99,$P));
  $229 = (($this) + 112|0);
  $230 = +HEAPF32[$229>>2];
  $231 = $228 + $230;
  $232 = $125 * $231;
  $233 = $79 - $232;
  __ZmlfRK6b2Vec2($5,$124,$P);
  __ZN6b2Vec2pLERKS_($vB,$5);
  $234 = (+__Z7b2CrossRK6b2Vec2S1_($111,$P));
  $235 = +HEAPF32[$229>>2];
  $236 = $234 + $235;
  $237 = $126 * $236;
  $238 = $98 + $237;
  $wA$0 = $233;$wB$0 = $238;
  $239 = HEAP32[$10>>2]|0;
  $240 = HEAP32[$63>>2]|0;
  $241 = (($240) + (($239*12)|0)|0);
  $242 = $vA;
  $243 = $242;
  $244 = HEAP32[$243>>2]|0;
  $245 = (($242) + 4)|0;
  $246 = $245;
  $247 = HEAP32[$246>>2]|0;
  $248 = $241;
  $249 = $248;
  HEAP32[$249>>2] = $244;
  $250 = (($248) + 4)|0;
  $251 = $250;
  HEAP32[$251>>2] = $247;
  $252 = HEAP32[$10>>2]|0;
  $253 = HEAP32[$63>>2]|0;
  $254 = ((($253) + (($252*12)|0)|0) + 8|0);
  HEAPF32[$254>>2] = $wA$0;
  $255 = HEAP32[$15>>2]|0;
  $256 = HEAP32[$63>>2]|0;
  $257 = (($256) + (($255*12)|0)|0);
  $258 = $vB;
  $259 = $258;
  $260 = HEAP32[$259>>2]|0;
  $261 = (($258) + 4)|0;
  $262 = $261;
  $263 = HEAP32[$262>>2]|0;
  $264 = $257;
  $265 = $264;
  HEAP32[$265>>2] = $260;
  $266 = (($264) + 4)|0;
  $267 = $266;
  HEAP32[$267>>2] = $263;
  $268 = HEAP32[$15>>2]|0;
  $269 = HEAP32[$63>>2]|0;
  $270 = ((($269) + (($268*12)|0)|0) + 8|0);
  HEAPF32[$270>>2] = $wB$0;
  STACKTOP = sp;return;
 }
}
function __ZN11b2WeldJoint24SolveVelocityConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0, $109 = 0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0, $113 = 0.0, $114 = 0, $115 = 0;
 var $116 = 0.0, $117 = 0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0;
 var $61 = 0.0, $62 = 0, $63 = 0, $64 = 0.0, $65 = 0, $66 = 0.0, $67 = 0.0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0;
 var $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0.0, $84 = 0, $85 = 0.0, $86 = 0.0, $87 = 0, $88 = 0.0, $89 = 0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $Cdot = 0, $Cdot1 = 0, $Cdot11 = 0, $P = 0, $P3 = 0, $impulse = 0, $impulse1 = 0, $vA = 0, $vB = 0, $wA$0 = 0.0, $wB$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 208|0;
 $vA = sp + 24|0;
 $vB = sp + 16|0;
 $Cdot1 = sp + 192|0;
 $0 = sp + 184|0;
 $1 = sp + 176|0;
 $2 = sp + 168|0;
 $3 = sp + 160|0;
 $impulse1 = sp + 8|0;
 $4 = sp + 152|0;
 $P = sp;
 $5 = sp + 144|0;
 $6 = sp + 136|0;
 $Cdot11 = sp + 128|0;
 $7 = sp + 120|0;
 $8 = sp + 112|0;
 $9 = sp + 104|0;
 $10 = sp + 96|0;
 $Cdot = sp + 80|0;
 $impulse = sp + 68|0;
 $11 = sp + 56|0;
 $P3 = sp + 48|0;
 $12 = sp + 40|0;
 $13 = sp + 32|0;
 $14 = (($this) + 116|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($data) + 32|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + (($15*12)|0)|0);
 $19 = $18;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) + 4)|0;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 $25 = $vA;
 $26 = $25;
 HEAP32[$26>>2] = $21;
 $27 = (($25) + 4)|0;
 $28 = $27;
 HEAP32[$28>>2] = $24;
 $29 = HEAP32[$14>>2]|0;
 $30 = HEAP32[$16>>2]|0;
 $31 = ((($30) + (($29*12)|0)|0) + 8|0);
 $32 = +HEAPF32[$31>>2];
 $33 = (($this) + 120|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($30) + (($34*12)|0)|0);
 $36 = $35;
 $37 = $36;
 $38 = HEAP32[$37>>2]|0;
 $39 = (($36) + 4)|0;
 $40 = $39;
 $41 = HEAP32[$40>>2]|0;
 $42 = $vB;
 $43 = $42;
 HEAP32[$43>>2] = $38;
 $44 = (($42) + 4)|0;
 $45 = $44;
 HEAP32[$45>>2] = $41;
 $46 = HEAP32[$33>>2]|0;
 $47 = HEAP32[$16>>2]|0;
 $48 = ((($47) + (($46*12)|0)|0) + 8|0);
 $49 = +HEAPF32[$48>>2];
 $50 = (($this) + 156|0);
 $51 = +HEAPF32[$50>>2];
 $52 = (($this) + 160|0);
 $53 = +HEAPF32[$52>>2];
 $54 = (($this) + 164|0);
 $55 = +HEAPF32[$54>>2];
 $56 = (($this) + 168|0);
 $57 = +HEAPF32[$56>>2];
 $58 = (($this) + 68|0);
 $59 = +HEAPF32[$58>>2];
 $60 = $59 > 0.0;
 if ($60) {
  $61 = $49 - $32;
  $62 = (($this) + 172|0);
  $63 = (($this) + 204|0);
  $64 = +HEAPF32[$63>>2];
  $65 = (($this) + 76|0);
  $66 = +HEAPF32[$65>>2];
  $67 = $61 + $66;
  $68 = (($this) + 100|0);
  $69 = +HEAPF32[$68>>2];
  $70 = (($this) + 112|0);
  $71 = +HEAPF32[$70>>2];
  $72 = $69 * $71;
  $73 = $67 + $72;
  $74 = $64 * $73;
  $75 = -$74;
  $76 = $71 - $74;
  HEAPF32[$70>>2] = $76;
  $77 = $55 * $75;
  $78 = $32 - $77;
  $79 = $57 * $75;
  $80 = $49 + $79;
  $81 = (($this) + 132|0);
  __Z7b2CrossfRK6b2Vec2($2,$80,$81);
  __ZplRK6b2Vec2S1_($1,$vB,$2);
  __ZmiRK6b2Vec2S1_($0,$1,$vA);
  $82 = (($this) + 124|0);
  __Z7b2CrossfRK6b2Vec2($3,$78,$82);
  __ZmiRK6b2Vec2S1_($Cdot1,$0,$3);
  __Z7b2Mul22RK7b2Mat33RK6b2Vec2($4,$62,$Cdot1);
  __ZNK6b2Vec2ngEv($impulse1,$4);
  $83 = +HEAPF32[$impulse1>>2];
  $84 = (($this) + 104|0);
  $85 = +HEAPF32[$84>>2];
  $86 = $83 + $85;
  HEAPF32[$84>>2] = $86;
  $87 = (($impulse1) + 4|0);
  $88 = +HEAPF32[$87>>2];
  $89 = (($this) + 108|0);
  $90 = +HEAPF32[$89>>2];
  $91 = $88 + $90;
  HEAPF32[$89>>2] = $91;
  $92 = $impulse1;
  $93 = $92;
  $94 = HEAP32[$93>>2]|0;
  $95 = (($92) + 4)|0;
  $96 = $95;
  $97 = HEAP32[$96>>2]|0;
  $98 = $P;
  $99 = $98;
  HEAP32[$99>>2] = $94;
  $100 = (($98) + 4)|0;
  $101 = $100;
  HEAP32[$101>>2] = $97;
  __ZmlfRK6b2Vec2($5,$51,$P);
  __ZN6b2Vec2mIERKS_($vA,$5);
  $102 = (+__Z7b2CrossRK6b2Vec2S1_($82,$P));
  $103 = $55 * $102;
  $104 = $78 - $103;
  __ZmlfRK6b2Vec2($6,$53,$P);
  __ZN6b2Vec2pLERKS_($vB,$6);
  $105 = (+__Z7b2CrossRK6b2Vec2S1_($81,$P));
  $106 = $57 * $105;
  $107 = $80 + $106;
  $wA$0 = $104;$wB$0 = $107;
  $130 = HEAP32[$14>>2]|0;
  $131 = HEAP32[$16>>2]|0;
  $132 = (($131) + (($130*12)|0)|0);
  $133 = $vA;
  $134 = $133;
  $135 = HEAP32[$134>>2]|0;
  $136 = (($133) + 4)|0;
  $137 = $136;
  $138 = HEAP32[$137>>2]|0;
  $139 = $132;
  $140 = $139;
  HEAP32[$140>>2] = $135;
  $141 = (($139) + 4)|0;
  $142 = $141;
  HEAP32[$142>>2] = $138;
  $143 = HEAP32[$14>>2]|0;
  $144 = HEAP32[$16>>2]|0;
  $145 = ((($144) + (($143*12)|0)|0) + 8|0);
  HEAPF32[$145>>2] = $wA$0;
  $146 = HEAP32[$33>>2]|0;
  $147 = HEAP32[$16>>2]|0;
  $148 = (($147) + (($146*12)|0)|0);
  $149 = $vB;
  $150 = $149;
  $151 = HEAP32[$150>>2]|0;
  $152 = (($149) + 4)|0;
  $153 = $152;
  $154 = HEAP32[$153>>2]|0;
  $155 = $148;
  $156 = $155;
  HEAP32[$156>>2] = $151;
  $157 = (($155) + 4)|0;
  $158 = $157;
  HEAP32[$158>>2] = $154;
  $159 = HEAP32[$33>>2]|0;
  $160 = HEAP32[$16>>2]|0;
  $161 = ((($160) + (($159*12)|0)|0) + 8|0);
  HEAPF32[$161>>2] = $wB$0;
  STACKTOP = sp;return;
 } else {
  $108 = (($this) + 132|0);
  __Z7b2CrossfRK6b2Vec2($9,$49,$108);
  __ZplRK6b2Vec2S1_($8,$vB,$9);
  __ZmiRK6b2Vec2S1_($7,$8,$vA);
  $109 = (($this) + 124|0);
  __Z7b2CrossfRK6b2Vec2($10,$32,$109);
  __ZmiRK6b2Vec2S1_($Cdot11,$7,$10);
  $110 = $49 - $32;
  $111 = +HEAPF32[$Cdot11>>2];
  $112 = (($Cdot11) + 4|0);
  $113 = +HEAPF32[$112>>2];
  __ZN6b2Vec3C2Efff($Cdot,$111,$113,$110);
  $114 = (($this) + 172|0);
  __Z5b2MulRK7b2Mat33RK6b2Vec3($11,$114,$Cdot);
  __ZNK6b2Vec3ngEv($impulse,$11);
  $115 = (($this) + 104|0);
  __ZN6b2Vec3pLERKS_($115,$impulse);
  $116 = +HEAPF32[$impulse>>2];
  $117 = (($impulse) + 4|0);
  $118 = +HEAPF32[$117>>2];
  __ZN6b2Vec2C2Eff($P3,$116,$118);
  __ZmlfRK6b2Vec2($12,$51,$P3);
  __ZN6b2Vec2mIERKS_($vA,$12);
  $119 = (+__Z7b2CrossRK6b2Vec2S1_($109,$P3));
  $120 = (($impulse) + 8|0);
  $121 = +HEAPF32[$120>>2];
  $122 = $119 + $121;
  $123 = $55 * $122;
  $124 = $32 - $123;
  __ZmlfRK6b2Vec2($13,$53,$P3);
  __ZN6b2Vec2pLERKS_($vB,$13);
  $125 = (+__Z7b2CrossRK6b2Vec2S1_($108,$P3));
  $126 = +HEAPF32[$120>>2];
  $127 = $125 + $126;
  $128 = $57 * $127;
  $129 = $49 + $128;
  $wA$0 = $124;$wB$0 = $129;
  $130 = HEAP32[$14>>2]|0;
  $131 = HEAP32[$16>>2]|0;
  $132 = (($131) + (($130*12)|0)|0);
  $133 = $vA;
  $134 = $133;
  $135 = HEAP32[$134>>2]|0;
  $136 = (($133) + 4)|0;
  $137 = $136;
  $138 = HEAP32[$137>>2]|0;
  $139 = $132;
  $140 = $139;
  HEAP32[$140>>2] = $135;
  $141 = (($139) + 4)|0;
  $142 = $141;
  HEAP32[$142>>2] = $138;
  $143 = HEAP32[$14>>2]|0;
  $144 = HEAP32[$16>>2]|0;
  $145 = ((($144) + (($143*12)|0)|0) + 8|0);
  HEAPF32[$145>>2] = $wA$0;
  $146 = HEAP32[$33>>2]|0;
  $147 = HEAP32[$16>>2]|0;
  $148 = (($147) + (($146*12)|0)|0);
  $149 = $vB;
  $150 = $149;
  $151 = HEAP32[$150>>2]|0;
  $152 = (($149) + 4)|0;
  $153 = $152;
  $154 = HEAP32[$153>>2]|0;
  $155 = $148;
  $156 = $155;
  HEAP32[$156>>2] = $151;
  $157 = (($155) + 4)|0;
  $158 = $157;
  HEAP32[$158>>2] = $154;
  $159 = HEAP32[$33>>2]|0;
  $160 = HEAP32[$16>>2]|0;
  $161 = ((($160) + (($159*12)|0)|0) + 8|0);
  HEAPF32[$161>>2] = $wB$0;
  STACKTOP = sp;return;
 }
}
function __ZN11b2WeldJoint24SolvePositionConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$pn = 0.0, $$pn2 = 0.0, $$pn3 = 0.0, $$pn4 = 0.0, $0 = 0, $1 = 0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0, $106 = 0.0, $107 = 0, $108 = 0.0, $109 = 0, $11 = 0, $110 = 0.0, $111 = 0;
 var $112 = 0, $113 = 0.0, $114 = 0, $115 = 0.0, $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0, $126 = 0.0, $127 = 0.0, $128 = 0, $129 = 0.0, $13 = 0;
 var $130 = 0.0, $131 = 0, $132 = 0.0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0;
 var $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0;
 var $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0.0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0;
 var $49 = 0.0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0;
 var $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0.0, $83 = 0.0, $84 = 0.0;
 var $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0, $C = 0, $C1 = 0, $C11 = 0, $K = 0;
 var $P = 0, $P2 = 0, $aA$0 = 0.0, $aB$0 = 0.0, $angularError$0 = 0.0, $cA = 0, $cB = 0, $impulse = 0, $positionError$0 = 0.0, $qA = 0, $qB = 0, $rA = 0, $rB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0;
 $cA = sp + 8|0;
 $cB = sp;
 $qA = sp + 240|0;
 $qB = sp + 232|0;
 $rA = sp + 224|0;
 $0 = sp + 216|0;
 $rB = sp + 208|0;
 $1 = sp + 200|0;
 $K = sp + 160|0;
 $C1 = sp + 152|0;
 $2 = sp + 144|0;
 $3 = sp + 136|0;
 $P = sp + 128|0;
 $4 = sp + 120|0;
 $5 = sp + 112|0;
 $6 = sp + 104|0;
 $C11 = sp + 96|0;
 $7 = sp + 88|0;
 $8 = sp + 80|0;
 $C = sp + 64|0;
 $impulse = sp + 52|0;
 $9 = sp + 40|0;
 $P2 = sp + 32|0;
 $10 = sp + 24|0;
 $11 = sp + 16|0;
 $12 = (($this) + 116|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($data) + 28|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + (($13*12)|0)|0);
 $17 = $16;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) + 4)|0;
 $21 = $20;
 $22 = HEAP32[$21>>2]|0;
 $23 = $cA;
 $24 = $23;
 HEAP32[$24>>2] = $19;
 $25 = (($23) + 4)|0;
 $26 = $25;
 HEAP32[$26>>2] = $22;
 $27 = HEAP32[$12>>2]|0;
 $28 = HEAP32[$14>>2]|0;
 $29 = ((($28) + (($27*12)|0)|0) + 8|0);
 $30 = +HEAPF32[$29>>2];
 $31 = (($this) + 120|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($28) + (($32*12)|0)|0);
 $34 = $33;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = (($34) + 4)|0;
 $38 = $37;
 $39 = HEAP32[$38>>2]|0;
 $40 = $cB;
 $41 = $40;
 HEAP32[$41>>2] = $36;
 $42 = (($40) + 4)|0;
 $43 = $42;
 HEAP32[$43>>2] = $39;
 $44 = HEAP32[$31>>2]|0;
 $45 = HEAP32[$14>>2]|0;
 $46 = ((($45) + (($44*12)|0)|0) + 8|0);
 $47 = +HEAPF32[$46>>2];
 __ZN5b2RotC2Ef($qA,$30);
 __ZN5b2RotC2Ef($qB,$47);
 $48 = (($this) + 156|0);
 $49 = +HEAPF32[$48>>2];
 $50 = (($this) + 160|0);
 $51 = +HEAPF32[$50>>2];
 $52 = (($this) + 164|0);
 $53 = +HEAPF32[$52>>2];
 $54 = (($this) + 168|0);
 $55 = +HEAPF32[$54>>2];
 $56 = (($this) + 80|0);
 $57 = (($this) + 140|0);
 __ZmiRK6b2Vec2S1_($0,$56,$57);
 __Z5b2MulRK5b2RotRK6b2Vec2($rA,$qA,$0);
 $58 = (($this) + 88|0);
 $59 = (($this) + 148|0);
 __ZmiRK6b2Vec2S1_($1,$58,$59);
 __Z5b2MulRK5b2RotRK6b2Vec2($rB,$qB,$1);
 $60 = $49 + $51;
 $61 = (($rA) + 4|0);
 $62 = +HEAPF32[$61>>2];
 $63 = $62 * $62;
 $64 = $53 * $63;
 $65 = $60 + $64;
 $66 = (($rB) + 4|0);
 $67 = +HEAPF32[$66>>2];
 $68 = $67 * $67;
 $69 = $55 * $68;
 $70 = $65 + $69;
 HEAPF32[$K>>2] = $70;
 $71 = +HEAPF32[$61>>2];
 $72 = +HEAPF32[$rA>>2];
 $73 = $71 * $72;
 $74 = $53 * $73;
 $75 = -$74;
 $76 = +HEAPF32[$66>>2];
 $77 = +HEAPF32[$rB>>2];
 $78 = $76 * $77;
 $79 = $55 * $78;
 $80 = $75 - $79;
 $81 = (($K) + 12|0);
 HEAPF32[$81>>2] = $80;
 $82 = +HEAPF32[$61>>2];
 $83 = $53 * $82;
 $84 = -$83;
 $85 = +HEAPF32[$66>>2];
 $86 = $55 * $85;
 $87 = $84 - $86;
 $88 = (($K) + 24|0);
 HEAPF32[$88>>2] = $87;
 $89 = +HEAPF32[$81>>2];
 $90 = (($K) + 4|0);
 HEAPF32[$90>>2] = $89;
 $91 = +HEAPF32[$rA>>2];
 $92 = $91 * $91;
 $93 = $53 * $92;
 $94 = $60 + $93;
 $95 = +HEAPF32[$rB>>2];
 $96 = $95 * $95;
 $97 = $55 * $96;
 $98 = $94 + $97;
 $99 = (($K) + 16|0);
 HEAPF32[$99>>2] = $98;
 $100 = +HEAPF32[$rA>>2];
 $101 = $53 * $100;
 $102 = +HEAPF32[$rB>>2];
 $103 = $55 * $102;
 $104 = $101 + $103;
 $105 = (($K) + 28|0);
 HEAPF32[$105>>2] = $104;
 $106 = +HEAPF32[$88>>2];
 $107 = (($K) + 8|0);
 HEAPF32[$107>>2] = $106;
 $108 = +HEAPF32[$105>>2];
 $109 = (($K) + 20|0);
 HEAPF32[$109>>2] = $108;
 $110 = $53 + $55;
 $111 = (($K) + 32|0);
 HEAPF32[$111>>2] = $110;
 $112 = (($this) + 68|0);
 $113 = +HEAPF32[$112>>2];
 $114 = $113 > 0.0;
 if ($114) {
  __ZplRK6b2Vec2S1_($3,$cB,$rB);
  __ZmiRK6b2Vec2S1_($2,$3,$cA);
  __ZmiRK6b2Vec2S1_($C1,$2,$rA);
  $115 = (+__ZNK6b2Vec26LengthEv($C1));
  __ZNK7b2Mat337Solve22ERK6b2Vec2($4,$K,$C1);
  __ZNK6b2Vec2ngEv($P,$4);
  __ZmlfRK6b2Vec2($5,$49,$P);
  __ZN6b2Vec2mIERKS_($cA,$5);
  $116 = (+__Z7b2CrossRK6b2Vec2S1_($rA,$P));
  __ZmlfRK6b2Vec2($6,$51,$P);
  __ZN6b2Vec2pLERKS_($cB,$6);
  $117 = (+__Z7b2CrossRK6b2Vec2S1_($rB,$P));
  $$pn3 = $117;$$pn4 = $116;$angularError$0 = 0.0;$positionError$0 = $115;
 } else {
  __ZplRK6b2Vec2S1_($8,$cB,$rB);
  __ZmiRK6b2Vec2S1_($7,$8,$cA);
  __ZmiRK6b2Vec2S1_($C11,$7,$rA);
  $118 = $47 - $30;
  $119 = (($this) + 96|0);
  $120 = +HEAPF32[$119>>2];
  $121 = $118 - $120;
  $122 = (+__ZNK6b2Vec26LengthEv($C11));
  $123 = (+__Z5b2AbsIfET_S0_($121));
  $124 = +HEAPF32[$C11>>2];
  $125 = (($C11) + 4|0);
  $126 = +HEAPF32[$125>>2];
  __ZN6b2Vec3C2Efff($C,$124,$126,$121);
  __ZNK7b2Mat337Solve33ERK6b2Vec3($9,$K,$C);
  __ZNK6b2Vec3ngEv($impulse,$9);
  $127 = +HEAPF32[$impulse>>2];
  $128 = (($impulse) + 4|0);
  $129 = +HEAPF32[$128>>2];
  __ZN6b2Vec2C2Eff($P2,$127,$129);
  __ZmlfRK6b2Vec2($10,$49,$P2);
  __ZN6b2Vec2mIERKS_($cA,$10);
  $130 = (+__Z7b2CrossRK6b2Vec2S1_($rA,$P2));
  $131 = (($impulse) + 8|0);
  $132 = +HEAPF32[$131>>2];
  $133 = $130 + $132;
  __ZmlfRK6b2Vec2($11,$51,$P2);
  __ZN6b2Vec2pLERKS_($cB,$11);
  $134 = (+__Z7b2CrossRK6b2Vec2S1_($rB,$P2));
  $135 = +HEAPF32[$131>>2];
  $136 = $134 + $135;
  $$pn3 = $136;$$pn4 = $133;$angularError$0 = $123;$positionError$0 = $122;
 }
 $$pn2 = $53 * $$pn4;
 $$pn = $55 * $$pn3;
 $aA$0 = $30 - $$pn2;
 $aB$0 = $47 + $$pn;
 $137 = HEAP32[$12>>2]|0;
 $138 = HEAP32[$14>>2]|0;
 $139 = (($138) + (($137*12)|0)|0);
 $140 = $cA;
 $141 = $140;
 $142 = HEAP32[$141>>2]|0;
 $143 = (($140) + 4)|0;
 $144 = $143;
 $145 = HEAP32[$144>>2]|0;
 $146 = $139;
 $147 = $146;
 HEAP32[$147>>2] = $142;
 $148 = (($146) + 4)|0;
 $149 = $148;
 HEAP32[$149>>2] = $145;
 $150 = HEAP32[$12>>2]|0;
 $151 = HEAP32[$14>>2]|0;
 $152 = ((($151) + (($150*12)|0)|0) + 8|0);
 HEAPF32[$152>>2] = $aA$0;
 $153 = HEAP32[$31>>2]|0;
 $154 = HEAP32[$14>>2]|0;
 $155 = (($154) + (($153*12)|0)|0);
 $156 = $cB;
 $157 = $156;
 $158 = HEAP32[$157>>2]|0;
 $159 = (($156) + 4)|0;
 $160 = $159;
 $161 = HEAP32[$160>>2]|0;
 $162 = $155;
 $163 = $162;
 HEAP32[$163>>2] = $158;
 $164 = (($162) + 4)|0;
 $165 = $164;
 HEAP32[$165>>2] = $161;
 $166 = HEAP32[$31>>2]|0;
 $167 = HEAP32[$14>>2]|0;
 $168 = ((($167) + (($166*12)|0)|0) + 8|0);
 HEAPF32[$168>>2] = $aB$0;
 $169 = !($positionError$0 <= 0.004999999888241291);
 if ($169) {
  $171 = 0;
  STACKTOP = sp;return ($171|0);
 }
 $170 = $angularError$0 <= 0.034906588494777679;
 $171 = $170;
 STACKTOP = sp;return ($171|0);
}
function __ZNK11b2WeldJoint10GetAnchorAEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 80|0);
 __ZNK6b2Body13GetWorldPointERK6b2Vec2($agg$result,$1,$2);
 STACKTOP = sp;return;
}
function __ZNK11b2WeldJoint10GetAnchorBEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 88|0);
 __ZNK6b2Body13GetWorldPointERK6b2Vec2($agg$result,$1,$2);
 STACKTOP = sp;return;
}
function __ZNK11b2WeldJoint16GetReactionForceEf($agg$result,$this,$inv_dt) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inv_dt = +$inv_dt;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0.0, $P = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $P = sp;
 $0 = (($this) + 104|0);
 $1 = +HEAPF32[$0>>2];
 $2 = (($this) + 108|0);
 $3 = +HEAPF32[$2>>2];
 __ZN6b2Vec2C2Eff($P,$1,$3);
 __ZmlfRK6b2Vec2($agg$result,$inv_dt,$P);
 STACKTOP = sp;return;
}
function __ZNK11b2WeldJoint17GetReactionTorqueEf($this,$inv_dt) {
 $this = $this|0;
 $inv_dt = +$inv_dt;
 var $0 = 0, $1 = 0.0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 112|0);
 $1 = +HEAPF32[$0>>2];
 $2 = $1 * $inv_dt;
 STACKTOP = sp;return (+$2);
}
function __ZN11b2WeldJoint4DumpEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0;
 var $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer26 = 0, $vararg_ptr12 = 0, $vararg_ptr16 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer26 = sp;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 __Z5b2LogPKcz(3880,$vararg_buffer26);
 HEAP32[$vararg_buffer26>>2] = $3;
 __Z5b2LogPKcz(3904,$vararg_buffer26);
 HEAP32[$vararg_buffer26>>2] = $7;
 __Z5b2LogPKcz(3936,$vararg_buffer26);
 $8 = (($this) + 61|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 HEAP32[$vararg_buffer26>>2] = $10;
 __Z5b2LogPKcz(3968,$vararg_buffer26);
 $11 = (($this) + 80|0);
 $12 = +HEAPF32[$11>>2];
 $13 = $12;
 $14 = (($this) + 84|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $15;
 HEAPF64[tempDoublePtr>>3]=$13;HEAP32[$vararg_buffer26>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer26+4>>2]=HEAP32[tempDoublePtr+4>>2];
 $vararg_ptr12 = (($vararg_buffer26) + 8|0);
 HEAPF64[tempDoublePtr>>3]=$16;HEAP32[$vararg_ptr12>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr12+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(4008,$vararg_buffer26);
 $17 = (($this) + 88|0);
 $18 = +HEAPF32[$17>>2];
 $19 = $18;
 $20 = (($this) + 92|0);
 $21 = +HEAPF32[$20>>2];
 $22 = $21;
 HEAPF64[tempDoublePtr>>3]=$19;HEAP32[$vararg_buffer26>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer26+4>>2]=HEAP32[tempDoublePtr+4>>2];
 $vararg_ptr16 = (($vararg_buffer26) + 8|0);
 HEAPF64[tempDoublePtr>>3]=$22;HEAP32[$vararg_ptr16>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr16+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(4056,$vararg_buffer26);
 $23 = (($this) + 96|0);
 $24 = +HEAPF32[$23>>2];
 $25 = $24;
 HEAPF64[tempDoublePtr>>3]=$25;HEAP32[$vararg_buffer26>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer26+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(4104,$vararg_buffer26);
 $26 = (($this) + 68|0);
 $27 = +HEAPF32[$26>>2];
 $28 = $27;
 HEAPF64[tempDoublePtr>>3]=$28;HEAP32[$vararg_buffer26>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer26+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(4136,$vararg_buffer26);
 $29 = (($this) + 72|0);
 $30 = +HEAPF32[$29>>2];
 $31 = $30;
 HEAPF64[tempDoublePtr>>3]=$31;HEAP32[$vararg_buffer26>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer26+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(4168,$vararg_buffer26);
 $32 = (($this) + 56|0);
 $33 = HEAP32[$32>>2]|0;
 HEAP32[$vararg_buffer26>>2] = $33;
 __Z5b2LogPKcz(4200,$vararg_buffer26);
 STACKTOP = sp;return;
}
function __ZN11b2WeldJointD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN6b2Vec37SetZeroEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$this>>2] = 0.0;
 $0 = (($this) + 4|0);
 HEAPF32[$0>>2] = 0.0;
 $1 = (($this) + 8|0);
 HEAPF32[$1>>2] = 0.0;
 STACKTOP = sp;return;
}
function __ZN6b2Vec3mLEf($this,$s) {
 $this = $this|0;
 $s = +$s;
 var $0 = 0.0, $1 = 0.0, $2 = 0, $3 = 0.0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$this>>2];
 $1 = $0 * $s;
 HEAPF32[$this>>2] = $1;
 $2 = (($this) + 4|0);
 $3 = +HEAPF32[$2>>2];
 $4 = $3 * $s;
 HEAPF32[$2>>2] = $4;
 $5 = (($this) + 8|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $6 * $s;
 HEAPF32[$5>>2] = $7;
 STACKTOP = sp;return;
}
function __Z7b2Mul22RK7b2Mat33RK6b2Vec2($agg$result,$A,$v) {
 $agg$result = $agg$result|0;
 $A = $A|0;
 $v = $v|0;
 var $0 = 0.0, $1 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $2 = 0.0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$A>>2];
 $1 = +HEAPF32[$v>>2];
 $2 = $0 * $1;
 $3 = (($A) + 12|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($v) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $4 * $6;
 $8 = $2 + $7;
 $9 = (($A) + 4|0);
 $10 = +HEAPF32[$9>>2];
 $11 = $1 * $10;
 $12 = (($A) + 16|0);
 $13 = +HEAPF32[$12>>2];
 $14 = $6 * $13;
 $15 = $11 + $14;
 __ZN6b2Vec2C2Eff($agg$result,$8,$15);
 STACKTOP = sp;return;
}
function __ZN6b2Vec3C2Efff($this,$x,$y,$z) {
 $this = $this|0;
 $x = +$x;
 $y = +$y;
 $z = +$z;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$this>>2] = $x;
 $0 = (($this) + 4|0);
 HEAPF32[$0>>2] = $y;
 $1 = (($this) + 8|0);
 HEAPF32[$1>>2] = $z;
 STACKTOP = sp;return;
}
function __Z5b2MulRK7b2Mat33RK6b2Vec3($agg$result,$A,$v) {
 $agg$result = $agg$result|0;
 $A = $A|0;
 $v = $v|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 36|0;
 $1 = sp + 24|0;
 $2 = sp + 12|0;
 $3 = sp;
 $4 = +HEAPF32[$v>>2];
 __ZmlfRK6b2Vec3($1,$4,$A);
 $5 = (($v) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = (($A) + 12|0);
 __ZmlfRK6b2Vec3($2,$6,$7);
 __ZplRK6b2Vec3S1_($0,$1,$2);
 $8 = (($v) + 8|0);
 $9 = +HEAPF32[$8>>2];
 $10 = (($A) + 24|0);
 __ZmlfRK6b2Vec3($3,$9,$10);
 __ZplRK6b2Vec3S1_($agg$result,$0,$3);
 STACKTOP = sp;return;
}
function __ZNK6b2Vec3ngEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0.0, $1 = 0.0, $2 = 0, $3 = 0.0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$this>>2];
 $1 = -$0;
 $2 = (($this) + 4|0);
 $3 = +HEAPF32[$2>>2];
 $4 = -$3;
 $5 = (($this) + 8|0);
 $6 = +HEAPF32[$5>>2];
 $7 = -$6;
 __ZN6b2Vec33SetEfff($agg$result,$1,$4,$7);
 STACKTOP = sp;return;
}
function __ZN6b2Vec3pLERKS_($this,$v) {
 $this = $this|0;
 $v = $v|0;
 var $0 = 0.0, $1 = 0.0, $10 = 0, $11 = 0.0, $12 = 0.0, $2 = 0.0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$v>>2];
 $1 = +HEAPF32[$this>>2];
 $2 = $0 + $1;
 HEAPF32[$this>>2] = $2;
 $3 = (($v) + 4|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($this) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $4 + $6;
 HEAPF32[$5>>2] = $7;
 $8 = (($v) + 8|0);
 $9 = +HEAPF32[$8>>2];
 $10 = (($this) + 8|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $9 + $11;
 HEAPF32[$10>>2] = $12;
 STACKTOP = sp;return;
}
function __ZmlfRK6b2Vec3($agg$result,$s,$a) {
 $agg$result = $agg$result|0;
 $s = +$s;
 $a = $a|0;
 var $0 = 0.0, $1 = 0.0, $2 = 0, $3 = 0.0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$a>>2];
 $1 = $0 * $s;
 $2 = (($a) + 4|0);
 $3 = +HEAPF32[$2>>2];
 $4 = $3 * $s;
 $5 = (($a) + 8|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $6 * $s;
 __ZN6b2Vec3C2Efff($agg$result,$1,$4,$7);
 STACKTOP = sp;return;
}
function __ZplRK6b2Vec3S1_($agg$result,$a,$b) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = 0.0, $1 = 0.0, $10 = 0, $11 = 0.0, $12 = 0.0, $2 = 0.0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$a>>2];
 $1 = +HEAPF32[$b>>2];
 $2 = $0 + $1;
 $3 = (($a) + 4|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($b) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $4 + $6;
 $8 = (($a) + 8|0);
 $9 = +HEAPF32[$8>>2];
 $10 = (($b) + 8|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $9 + $11;
 __ZN6b2Vec3C2Efff($agg$result,$2,$7,$12);
 STACKTOP = sp;return;
}
function __ZN6b2Vec33SetEfff($this,$x_,$y_,$z_) {
 $this = $this|0;
 $x_ = +$x_;
 $y_ = +$y_;
 $z_ = +$z_;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$this>>2] = $x_;
 $0 = (($this) + 4|0);
 HEAPF32[$0>>2] = $y_;
 $1 = (($this) + 8|0);
 HEAPF32[$1>>2] = $z_;
 STACKTOP = sp;return;
}
function __ZN11b2GearJointC2EPK14b2GearJointDef($this,$def) {
 $this = $this|0;
 $def = $def|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0.0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0.0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0.0, $163 = 0, $164 = 0.0, $165 = 0.0, $166 = 0.0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0.0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0.0, $216 = 0, $217 = 0.0, $218 = 0, $219 = 0.0, $22 = 0, $220 = 0.0, $221 = 0, $222 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0.0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0.0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0.0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $coordinateA$0 = 0.0, $coordinateB$0 = 0.0, $pA = 0, $pB = 0, $pC = 0, $pD = 0, $xfA = 0, $xfB = 0, $xfC = 0, $xfD = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $xfA = sp + 144|0;
 $xfC = sp + 128|0;
 $pC = sp + 8|0;
 $pA = sp + 120|0;
 $0 = sp + 112|0;
 $1 = sp + 104|0;
 $2 = sp + 96|0;
 $3 = sp + 88|0;
 $xfB = sp + 72|0;
 $xfD = sp + 56|0;
 $pD = sp;
 $pB = sp + 48|0;
 $4 = sp + 40|0;
 $5 = sp + 32|0;
 $6 = sp + 24|0;
 $7 = sp + 16|0;
 __ZN7b2JointC2EPK10b2JointDef($this,$def);
 HEAP32[$this>>2] = ((4280 + 8|0));
 $8 = (($this) + 92|0);
 $9 = (($this) + 100|0);
 $10 = (($this) + 108|0);
 $11 = (($this) + 116|0);
 $12 = (($this) + 124|0);
 $13 = (($this) + 132|0);
 $14 = (($def) + 20|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 68|0);
 HEAP32[$16>>2] = $15;
 $17 = (($def) + 24|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 72|0);
 HEAP32[$19>>2] = $18;
 $20 = HEAP32[$16>>2]|0;
 $21 = (__ZNK7b2Joint7GetTypeEv($20)|0);
 $22 = (($this) + 76|0);
 HEAP32[$22>>2] = $21;
 $23 = HEAP32[$19>>2]|0;
 $24 = (__ZNK7b2Joint7GetTypeEv($23)|0);
 $25 = (($this) + 80|0);
 HEAP32[$25>>2] = $24;
 $26 = HEAP32[$16>>2]|0;
 $27 = (__ZN7b2Joint8GetBodyAEv($26)|0);
 $28 = (($this) + 84|0);
 HEAP32[$28>>2] = $27;
 $29 = HEAP32[$16>>2]|0;
 $30 = (__ZN7b2Joint8GetBodyBEv($29)|0);
 $31 = (($this) + 48|0);
 HEAP32[$31>>2] = $30;
 $32 = (($30) + 12|0);
 ;HEAP32[$xfA+0>>2]=HEAP32[$32+0>>2]|0;HEAP32[$xfA+4>>2]=HEAP32[$32+4>>2]|0;HEAP32[$xfA+8>>2]=HEAP32[$32+8>>2]|0;HEAP32[$xfA+12>>2]=HEAP32[$32+12>>2]|0;
 $33 = HEAP32[$31>>2]|0;
 $34 = (($33) + 72|0);
 $35 = +HEAPF32[$34>>2];
 $36 = HEAP32[$28>>2]|0;
 $37 = (($36) + 12|0);
 ;HEAP32[$xfC+0>>2]=HEAP32[$37+0>>2]|0;HEAP32[$xfC+4>>2]=HEAP32[$37+4>>2]|0;HEAP32[$xfC+8>>2]=HEAP32[$37+8>>2]|0;HEAP32[$xfC+12>>2]=HEAP32[$37+12>>2]|0;
 $38 = HEAP32[$22>>2]|0;
 $39 = ($38|0)==(1);
 $40 = HEAP32[$14>>2]|0;
 if ($39) {
  $41 = HEAP32[$28>>2]|0;
  $42 = (($41) + 72|0);
  $43 = +HEAPF32[$42>>2];
  $44 = (($40) + 68|0);
  $45 = $44;
  $46 = $45;
  $47 = HEAP32[$46>>2]|0;
  $48 = (($45) + 4)|0;
  $49 = $48;
  $50 = HEAP32[$49>>2]|0;
  $51 = $10;
  $52 = $51;
  HEAP32[$52>>2] = $47;
  $53 = (($51) + 4)|0;
  $54 = $53;
  HEAP32[$54>>2] = $50;
  $55 = (($40) + 76|0);
  $56 = $55;
  $57 = $56;
  $58 = HEAP32[$57>>2]|0;
  $59 = (($56) + 4)|0;
  $60 = $59;
  $61 = HEAP32[$60>>2]|0;
  $62 = $8;
  $63 = $62;
  HEAP32[$63>>2] = $58;
  $64 = (($62) + 4)|0;
  $65 = $64;
  HEAP32[$65>>2] = $61;
  $66 = (($40) + 116|0);
  $67 = +HEAPF32[$66>>2];
  $68 = (($this) + 140|0);
  HEAPF32[$68>>2] = $67;
  __ZN6b2Vec27SetZeroEv($12);
  $69 = $35 - $43;
  $70 = +HEAPF32[$68>>2];
  $71 = $69 - $70;
  $coordinateA$0 = $71;
 } else {
  $72 = (($40) + 68|0);
  $73 = $72;
  $74 = $73;
  $75 = HEAP32[$74>>2]|0;
  $76 = (($73) + 4)|0;
  $77 = $76;
  $78 = HEAP32[$77>>2]|0;
  $79 = $10;
  $80 = $79;
  HEAP32[$80>>2] = $75;
  $81 = (($79) + 4)|0;
  $82 = $81;
  HEAP32[$82>>2] = $78;
  $83 = (($40) + 76|0);
  $84 = $83;
  $85 = $84;
  $86 = HEAP32[$85>>2]|0;
  $87 = (($84) + 4)|0;
  $88 = $87;
  $89 = HEAP32[$88>>2]|0;
  $90 = $8;
  $91 = $90;
  HEAP32[$91>>2] = $86;
  $92 = (($90) + 4)|0;
  $93 = $92;
  HEAP32[$93>>2] = $89;
  $94 = (($40) + 100|0);
  $95 = +HEAPF32[$94>>2];
  $96 = (($this) + 140|0);
  HEAPF32[$96>>2] = $95;
  $97 = (($40) + 84|0);
  $98 = $97;
  $99 = $98;
  $100 = HEAP32[$99>>2]|0;
  $101 = (($98) + 4)|0;
  $102 = $101;
  $103 = HEAP32[$102>>2]|0;
  $104 = $12;
  $105 = $104;
  HEAP32[$105>>2] = $100;
  $106 = (($104) + 4)|0;
  $107 = $106;
  HEAP32[$107>>2] = $103;
  $108 = $10;
  $109 = $108;
  $110 = HEAP32[$109>>2]|0;
  $111 = (($108) + 4)|0;
  $112 = $111;
  $113 = HEAP32[$112>>2]|0;
  $114 = $pC;
  $115 = $114;
  HEAP32[$115>>2] = $110;
  $116 = (($114) + 4)|0;
  $117 = $116;
  HEAP32[$117>>2] = $113;
  $118 = (($xfC) + 8|0);
  $119 = (($xfA) + 8|0);
  __Z5b2MulRK5b2RotRK6b2Vec2($1,$119,$8);
  __ZmiRK6b2Vec2S1_($2,$xfA,$xfC);
  __ZplRK6b2Vec2S1_($0,$1,$2);
  __Z6b2MulTRK5b2RotRK6b2Vec2($pA,$118,$0);
  __ZmiRK6b2Vec2S1_($3,$pA,$pC);
  $120 = (+__Z5b2DotRK6b2Vec2S1_($3,$12));
  $coordinateA$0 = $120;
 }
 $121 = HEAP32[$19>>2]|0;
 $122 = (__ZN7b2Joint8GetBodyAEv($121)|0);
 $123 = (($this) + 88|0);
 HEAP32[$123>>2] = $122;
 $124 = HEAP32[$19>>2]|0;
 $125 = (__ZN7b2Joint8GetBodyBEv($124)|0);
 $126 = (($this) + 52|0);
 HEAP32[$126>>2] = $125;
 $127 = (($125) + 12|0);
 ;HEAP32[$xfB+0>>2]=HEAP32[$127+0>>2]|0;HEAP32[$xfB+4>>2]=HEAP32[$127+4>>2]|0;HEAP32[$xfB+8>>2]=HEAP32[$127+8>>2]|0;HEAP32[$xfB+12>>2]=HEAP32[$127+12>>2]|0;
 $128 = HEAP32[$126>>2]|0;
 $129 = (($128) + 72|0);
 $130 = +HEAPF32[$129>>2];
 $131 = HEAP32[$123>>2]|0;
 $132 = (($131) + 12|0);
 ;HEAP32[$xfD+0>>2]=HEAP32[$132+0>>2]|0;HEAP32[$xfD+4>>2]=HEAP32[$132+4>>2]|0;HEAP32[$xfD+8>>2]=HEAP32[$132+8>>2]|0;HEAP32[$xfD+12>>2]=HEAP32[$132+12>>2]|0;
 $133 = HEAP32[$25>>2]|0;
 $134 = ($133|0)==(1);
 $135 = HEAP32[$17>>2]|0;
 if ($134) {
  $136 = HEAP32[$123>>2]|0;
  $137 = (($136) + 72|0);
  $138 = +HEAPF32[$137>>2];
  $139 = (($135) + 68|0);
  $140 = $139;
  $141 = $140;
  $142 = HEAP32[$141>>2]|0;
  $143 = (($140) + 4)|0;
  $144 = $143;
  $145 = HEAP32[$144>>2]|0;
  $146 = $11;
  $147 = $146;
  HEAP32[$147>>2] = $142;
  $148 = (($146) + 4)|0;
  $149 = $148;
  HEAP32[$149>>2] = $145;
  $150 = (($135) + 76|0);
  $151 = $150;
  $152 = $151;
  $153 = HEAP32[$152>>2]|0;
  $154 = (($151) + 4)|0;
  $155 = $154;
  $156 = HEAP32[$155>>2]|0;
  $157 = $9;
  $158 = $157;
  HEAP32[$158>>2] = $153;
  $159 = (($157) + 4)|0;
  $160 = $159;
  HEAP32[$160>>2] = $156;
  $161 = (($135) + 116|0);
  $162 = +HEAPF32[$161>>2];
  $163 = (($this) + 144|0);
  HEAPF32[$163>>2] = $162;
  __ZN6b2Vec27SetZeroEv($13);
  $164 = $130 - $138;
  $165 = +HEAPF32[$163>>2];
  $166 = $164 - $165;
  $coordinateB$0 = $166;
  $216 = (($def) + 28|0);
  $217 = +HEAPF32[$216>>2];
  $218 = (($this) + 152|0);
  HEAPF32[$218>>2] = $217;
  $219 = $coordinateB$0 * $217;
  $220 = $coordinateA$0 + $219;
  $221 = (($this) + 148|0);
  HEAPF32[$221>>2] = $220;
  $222 = (($this) + 156|0);
  HEAPF32[$222>>2] = 0.0;
  STACKTOP = sp;return;
 } else {
  $167 = (($135) + 68|0);
  $168 = $167;
  $169 = $168;
  $170 = HEAP32[$169>>2]|0;
  $171 = (($168) + 4)|0;
  $172 = $171;
  $173 = HEAP32[$172>>2]|0;
  $174 = $11;
  $175 = $174;
  HEAP32[$175>>2] = $170;
  $176 = (($174) + 4)|0;
  $177 = $176;
  HEAP32[$177>>2] = $173;
  $178 = (($135) + 76|0);
  $179 = $178;
  $180 = $179;
  $181 = HEAP32[$180>>2]|0;
  $182 = (($179) + 4)|0;
  $183 = $182;
  $184 = HEAP32[$183>>2]|0;
  $185 = $9;
  $186 = $185;
  HEAP32[$186>>2] = $181;
  $187 = (($185) + 4)|0;
  $188 = $187;
  HEAP32[$188>>2] = $184;
  $189 = (($135) + 100|0);
  $190 = +HEAPF32[$189>>2];
  $191 = (($this) + 144|0);
  HEAPF32[$191>>2] = $190;
  $192 = (($135) + 84|0);
  $193 = $192;
  $194 = $193;
  $195 = HEAP32[$194>>2]|0;
  $196 = (($193) + 4)|0;
  $197 = $196;
  $198 = HEAP32[$197>>2]|0;
  $199 = $13;
  $200 = $199;
  HEAP32[$200>>2] = $195;
  $201 = (($199) + 4)|0;
  $202 = $201;
  HEAP32[$202>>2] = $198;
  $203 = $11;
  $204 = $203;
  $205 = HEAP32[$204>>2]|0;
  $206 = (($203) + 4)|0;
  $207 = $206;
  $208 = HEAP32[$207>>2]|0;
  $209 = $pD;
  $210 = $209;
  HEAP32[$210>>2] = $205;
  $211 = (($209) + 4)|0;
  $212 = $211;
  HEAP32[$212>>2] = $208;
  $213 = (($xfD) + 8|0);
  $214 = (($xfB) + 8|0);
  __Z5b2MulRK5b2RotRK6b2Vec2($5,$214,$9);
  __ZmiRK6b2Vec2S1_($6,$xfB,$xfD);
  __ZplRK6b2Vec2S1_($4,$5,$6);
  __Z6b2MulTRK5b2RotRK6b2Vec2($pB,$213,$4);
  __ZmiRK6b2Vec2S1_($7,$pB,$pD);
  $215 = (+__Z5b2DotRK6b2Vec2S1_($7,$13));
  $coordinateB$0 = $215;
  $216 = (($def) + 28|0);
  $217 = +HEAPF32[$216>>2];
  $218 = (($this) + 152|0);
  HEAPF32[$218>>2] = $217;
  $219 = $coordinateB$0 * $217;
  $220 = $coordinateA$0 + $219;
  $221 = (($this) + 148|0);
  HEAPF32[$221>>2] = $220;
  $222 = (($this) + 156|0);
  HEAPF32[$222>>2] = 0.0;
  STACKTOP = sp;return;
 }
}
function __ZN11b2GearJoint23InitVelocityConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0.0, $104 = 0, $105 = 0, $106 = 0, $107 = 0.0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0.0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0.0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0.0, $135 = 0, $136 = 0, $137 = 0, $138 = 0.0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0.0, $154 = 0, $155 = 0, $156 = 0, $157 = 0.0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0.0, $173 = 0, $174 = 0, $175 = 0, $176 = 0.0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0.0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0.0, $2 = 0, $20 = 0, $200 = 0.0, $201 = 0.0, $202 = 0.0, $203 = 0.0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0.0, $219 = 0, $22 = 0, $220 = 0.0, $221 = 0, $222 = 0.0, $223 = 0.0;
 var $224 = 0.0, $225 = 0.0, $226 = 0.0, $227 = 0.0, $228 = 0.0, $229 = 0.0, $23 = 0, $230 = 0.0, $231 = 0.0, $232 = 0.0, $233 = 0.0, $234 = 0.0, $235 = 0.0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0.0;
 var $242 = 0, $243 = 0.0, $244 = 0, $245 = 0.0, $246 = 0.0, $247 = 0.0, $248 = 0.0, $249 = 0.0, $25 = 0, $250 = 0.0, $251 = 0.0, $252 = 0.0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0.0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0.0, $27 = 0, $270 = 0.0, $271 = 0.0, $272 = 0, $273 = 0.0, $274 = 0.0, $275 = 0.0, $276 = 0, $277 = 0.0, $278 = 0.0;
 var $279 = 0.0, $28 = 0, $280 = 0.0, $281 = 0.0, $282 = 0.0, $283 = 0.0, $284 = 0.0, $285 = 0.0, $286 = 0.0, $287 = 0.0, $288 = 0.0, $289 = 0.0, $29 = 0, $290 = 0.0, $291 = 0.0, $292 = 0.0, $293 = 0.0, $294 = 0, $295 = 0.0, $296 = 0.0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0.0, $301 = 0, $302 = 0.0, $303 = 0.0, $304 = 0, $305 = 0.0, $306 = 0.0, $307 = 0.0, $308 = 0, $309 = 0.0, $31 = 0, $310 = 0.0, $311 = 0.0, $312 = 0.0, $313 = 0.0;
 var $314 = 0, $315 = 0.0, $316 = 0.0, $317 = 0.0, $318 = 0, $319 = 0.0, $32 = 0, $320 = 0.0, $321 = 0.0, $322 = 0.0, $323 = 0.0, $324 = 0.0, $325 = 0.0, $326 = 0.0, $327 = 0, $328 = 0.0, $329 = 0.0, $33 = 0, $330 = 0.0, $331 = 0.0;
 var $332 = 0.0, $333 = 0.0, $334 = 0.0, $335 = 0.0, $336 = 0, $337 = 0.0, $338 = 0.0, $339 = 0.0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0.0, $84 = 0, $85 = 0, $86 = 0, $87 = 0.0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0.0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0.0, $96 = 0, $97 = 0, $98 = 0, $99 = 0.0, $qA = 0, $qB = 0, $qC = 0, $qD = 0, $rA = 0, $rB = 0, $rC = 0, $rD = 0, $storemerge = 0.0, $storemerge6 = 0.0, $u = 0, $u1 = 0, $vA = 0, $vB = 0, $vC = 0;
 var $vD = 0, $wA$0 = 0.0, $wB$0 = 0.0, $wC$0 = 0.0, $wD$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $vA = sp + 40|0;
 $vB = sp + 32|0;
 $vC = sp + 24|0;
 $vD = sp + 16|0;
 $qA = sp + 176|0;
 $qB = sp + 168|0;
 $qC = sp + 160|0;
 $qD = sp + 152|0;
 $u = sp + 8|0;
 $rC = sp + 144|0;
 $0 = sp + 136|0;
 $rA = sp + 128|0;
 $1 = sp + 120|0;
 $u1 = sp + 112|0;
 $rD = sp + 104|0;
 $2 = sp + 96|0;
 $rB = sp + 88|0;
 $3 = sp + 80|0;
 $4 = sp;
 $5 = sp + 72|0;
 $6 = sp + 64|0;
 $7 = sp + 56|0;
 $8 = sp + 48|0;
 $9 = (($this) + 48|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 160|0);
 HEAP32[$13>>2] = $12;
 $14 = (($this) + 52|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 164|0);
 HEAP32[$18>>2] = $17;
 $19 = (($this) + 84|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($20) + 8|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 168|0);
 HEAP32[$23>>2] = $22;
 $24 = (($this) + 88|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($this) + 172|0);
 HEAP32[$28>>2] = $27;
 $29 = (($this) + 176|0);
 $30 = HEAP32[$9>>2]|0;
 $31 = (($30) + 44|0);
 $32 = $31;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = (($32) + 4)|0;
 $36 = $35;
 $37 = HEAP32[$36>>2]|0;
 $38 = $29;
 $39 = $38;
 HEAP32[$39>>2] = $34;
 $40 = (($38) + 4)|0;
 $41 = $40;
 HEAP32[$41>>2] = $37;
 $42 = (($this) + 184|0);
 $43 = HEAP32[$14>>2]|0;
 $44 = (($43) + 44|0);
 $45 = $44;
 $46 = $45;
 $47 = HEAP32[$46>>2]|0;
 $48 = (($45) + 4)|0;
 $49 = $48;
 $50 = HEAP32[$49>>2]|0;
 $51 = $42;
 $52 = $51;
 HEAP32[$52>>2] = $47;
 $53 = (($51) + 4)|0;
 $54 = $53;
 HEAP32[$54>>2] = $50;
 $55 = (($this) + 192|0);
 $56 = HEAP32[$19>>2]|0;
 $57 = (($56) + 44|0);
 $58 = $57;
 $59 = $58;
 $60 = HEAP32[$59>>2]|0;
 $61 = (($58) + 4)|0;
 $62 = $61;
 $63 = HEAP32[$62>>2]|0;
 $64 = $55;
 $65 = $64;
 HEAP32[$65>>2] = $60;
 $66 = (($64) + 4)|0;
 $67 = $66;
 HEAP32[$67>>2] = $63;
 $68 = (($this) + 200|0);
 $69 = HEAP32[$24>>2]|0;
 $70 = (($69) + 44|0);
 $71 = $70;
 $72 = $71;
 $73 = HEAP32[$72>>2]|0;
 $74 = (($71) + 4)|0;
 $75 = $74;
 $76 = HEAP32[$75>>2]|0;
 $77 = $68;
 $78 = $77;
 HEAP32[$78>>2] = $73;
 $79 = (($77) + 4)|0;
 $80 = $79;
 HEAP32[$80>>2] = $76;
 $81 = HEAP32[$9>>2]|0;
 $82 = (($81) + 136|0);
 $83 = +HEAPF32[$82>>2];
 $84 = (($this) + 208|0);
 HEAPF32[$84>>2] = $83;
 $85 = HEAP32[$14>>2]|0;
 $86 = (($85) + 136|0);
 $87 = +HEAPF32[$86>>2];
 $88 = (($this) + 212|0);
 HEAPF32[$88>>2] = $87;
 $89 = HEAP32[$19>>2]|0;
 $90 = (($89) + 136|0);
 $91 = +HEAPF32[$90>>2];
 $92 = (($this) + 216|0);
 HEAPF32[$92>>2] = $91;
 $93 = HEAP32[$24>>2]|0;
 $94 = (($93) + 136|0);
 $95 = +HEAPF32[$94>>2];
 $96 = (($this) + 220|0);
 HEAPF32[$96>>2] = $95;
 $97 = HEAP32[$9>>2]|0;
 $98 = (($97) + 144|0);
 $99 = +HEAPF32[$98>>2];
 $100 = (($this) + 224|0);
 HEAPF32[$100>>2] = $99;
 $101 = HEAP32[$14>>2]|0;
 $102 = (($101) + 144|0);
 $103 = +HEAPF32[$102>>2];
 $104 = (($this) + 228|0);
 HEAPF32[$104>>2] = $103;
 $105 = HEAP32[$19>>2]|0;
 $106 = (($105) + 144|0);
 $107 = +HEAPF32[$106>>2];
 $108 = (($this) + 232|0);
 HEAPF32[$108>>2] = $107;
 $109 = HEAP32[$24>>2]|0;
 $110 = (($109) + 144|0);
 $111 = +HEAPF32[$110>>2];
 $112 = (($this) + 236|0);
 HEAPF32[$112>>2] = $111;
 $113 = HEAP32[$13>>2]|0;
 $114 = (($data) + 28|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = ((($115) + (($113*12)|0)|0) + 8|0);
 $117 = +HEAPF32[$116>>2];
 $118 = (($data) + 32|0);
 $119 = HEAP32[$118>>2]|0;
 $120 = (($119) + (($113*12)|0)|0);
 $121 = $120;
 $122 = $121;
 $123 = HEAP32[$122>>2]|0;
 $124 = (($121) + 4)|0;
 $125 = $124;
 $126 = HEAP32[$125>>2]|0;
 $127 = $vA;
 $128 = $127;
 HEAP32[$128>>2] = $123;
 $129 = (($127) + 4)|0;
 $130 = $129;
 HEAP32[$130>>2] = $126;
 $131 = HEAP32[$13>>2]|0;
 $132 = HEAP32[$118>>2]|0;
 $133 = ((($132) + (($131*12)|0)|0) + 8|0);
 $134 = +HEAPF32[$133>>2];
 $135 = HEAP32[$18>>2]|0;
 $136 = HEAP32[$114>>2]|0;
 $137 = ((($136) + (($135*12)|0)|0) + 8|0);
 $138 = +HEAPF32[$137>>2];
 $139 = (($132) + (($135*12)|0)|0);
 $140 = $139;
 $141 = $140;
 $142 = HEAP32[$141>>2]|0;
 $143 = (($140) + 4)|0;
 $144 = $143;
 $145 = HEAP32[$144>>2]|0;
 $146 = $vB;
 $147 = $146;
 HEAP32[$147>>2] = $142;
 $148 = (($146) + 4)|0;
 $149 = $148;
 HEAP32[$149>>2] = $145;
 $150 = HEAP32[$18>>2]|0;
 $151 = HEAP32[$118>>2]|0;
 $152 = ((($151) + (($150*12)|0)|0) + 8|0);
 $153 = +HEAPF32[$152>>2];
 $154 = HEAP32[$23>>2]|0;
 $155 = HEAP32[$114>>2]|0;
 $156 = ((($155) + (($154*12)|0)|0) + 8|0);
 $157 = +HEAPF32[$156>>2];
 $158 = (($151) + (($154*12)|0)|0);
 $159 = $158;
 $160 = $159;
 $161 = HEAP32[$160>>2]|0;
 $162 = (($159) + 4)|0;
 $163 = $162;
 $164 = HEAP32[$163>>2]|0;
 $165 = $vC;
 $166 = $165;
 HEAP32[$166>>2] = $161;
 $167 = (($165) + 4)|0;
 $168 = $167;
 HEAP32[$168>>2] = $164;
 $169 = HEAP32[$23>>2]|0;
 $170 = HEAP32[$118>>2]|0;
 $171 = ((($170) + (($169*12)|0)|0) + 8|0);
 $172 = +HEAPF32[$171>>2];
 $173 = HEAP32[$28>>2]|0;
 $174 = HEAP32[$114>>2]|0;
 $175 = ((($174) + (($173*12)|0)|0) + 8|0);
 $176 = +HEAPF32[$175>>2];
 $177 = (($170) + (($173*12)|0)|0);
 $178 = $177;
 $179 = $178;
 $180 = HEAP32[$179>>2]|0;
 $181 = (($178) + 4)|0;
 $182 = $181;
 $183 = HEAP32[$182>>2]|0;
 $184 = $vD;
 $185 = $184;
 HEAP32[$185>>2] = $180;
 $186 = (($184) + 4)|0;
 $187 = $186;
 HEAP32[$187>>2] = $183;
 $188 = HEAP32[$28>>2]|0;
 $189 = HEAP32[$118>>2]|0;
 $190 = ((($189) + (($188*12)|0)|0) + 8|0);
 $191 = +HEAPF32[$190>>2];
 __ZN5b2RotC2Ef($qA,$117);
 __ZN5b2RotC2Ef($qB,$138);
 __ZN5b2RotC2Ef($qC,$157);
 __ZN5b2RotC2Ef($qD,$176);
 $192 = (($this) + 272|0);
 HEAPF32[$192>>2] = 0.0;
 $193 = (($this) + 76|0);
 $194 = HEAP32[$193>>2]|0;
 $195 = ($194|0)==(1);
 if ($195) {
  $196 = (($this) + 240|0);
  __ZN6b2Vec27SetZeroEv($196);
  $197 = (($this) + 256|0);
  HEAPF32[$197>>2] = 1.0;
  $198 = (($this) + 264|0);
  HEAPF32[$198>>2] = 1.0;
  $199 = +HEAPF32[$100>>2];
  $200 = +HEAPF32[$108>>2];
  $201 = $199 + $200;
  $202 = +HEAPF32[$192>>2];
  $203 = $202 + $201;
  $storemerge = $203;
 } else {
  $204 = (($this) + 124|0);
  __Z5b2MulRK5b2RotRK6b2Vec2($u,$qC,$204);
  $205 = (($this) + 108|0);
  __ZmiRK6b2Vec2S1_($0,$205,$55);
  __Z5b2MulRK5b2RotRK6b2Vec2($rC,$qC,$0);
  $206 = (($this) + 92|0);
  __ZmiRK6b2Vec2S1_($1,$206,$29);
  __Z5b2MulRK5b2RotRK6b2Vec2($rA,$qA,$1);
  $207 = (($this) + 240|0);
  $208 = $u;
  $209 = $208;
  $210 = HEAP32[$209>>2]|0;
  $211 = (($208) + 4)|0;
  $212 = $211;
  $213 = HEAP32[$212>>2]|0;
  $214 = $207;
  $215 = $214;
  HEAP32[$215>>2] = $210;
  $216 = (($214) + 4)|0;
  $217 = $216;
  HEAP32[$217>>2] = $213;
  $218 = (+__Z7b2CrossRK6b2Vec2S1_($rC,$u));
  $219 = (($this) + 264|0);
  HEAPF32[$219>>2] = $218;
  $220 = (+__Z7b2CrossRK6b2Vec2S1_($rA,$u));
  $221 = (($this) + 256|0);
  HEAPF32[$221>>2] = $220;
  $222 = +HEAPF32[$92>>2];
  $223 = +HEAPF32[$84>>2];
  $224 = $222 + $223;
  $225 = +HEAPF32[$108>>2];
  $226 = +HEAPF32[$219>>2];
  $227 = $225 * $226;
  $228 = $226 * $227;
  $229 = $224 + $228;
  $230 = +HEAPF32[$100>>2];
  $231 = $220 * $230;
  $232 = $220 * $231;
  $233 = $229 + $232;
  $234 = +HEAPF32[$192>>2];
  $235 = $234 + $233;
  $storemerge = $235;
 }
 HEAPF32[$192>>2] = $storemerge;
 $236 = (($this) + 80|0);
 $237 = HEAP32[$236>>2]|0;
 $238 = ($237|0)==(1);
 if ($238) {
  $239 = (($this) + 248|0);
  __ZN6b2Vec27SetZeroEv($239);
  $240 = (($this) + 152|0);
  $241 = +HEAPF32[$240>>2];
  $242 = (($this) + 260|0);
  HEAPF32[$242>>2] = $241;
  $243 = +HEAPF32[$240>>2];
  $244 = (($this) + 268|0);
  HEAPF32[$244>>2] = $243;
  $245 = +HEAPF32[$240>>2];
  $246 = $245 * $245;
  $247 = +HEAPF32[$104>>2];
  $248 = +HEAPF32[$112>>2];
  $249 = $247 + $248;
  $250 = $246 * $249;
  $251 = +HEAPF32[$192>>2];
  $252 = $251 + $250;
  $storemerge6 = $252;
 } else {
  $253 = (($this) + 132|0);
  __Z5b2MulRK5b2RotRK6b2Vec2($u1,$qD,$253);
  $254 = (($this) + 116|0);
  __ZmiRK6b2Vec2S1_($2,$254,$68);
  __Z5b2MulRK5b2RotRK6b2Vec2($rD,$qD,$2);
  $255 = (($this) + 100|0);
  __ZmiRK6b2Vec2S1_($3,$255,$42);
  __Z5b2MulRK5b2RotRK6b2Vec2($rB,$qB,$3);
  $256 = (($this) + 248|0);
  $257 = (($this) + 152|0);
  $258 = +HEAPF32[$257>>2];
  __ZmlfRK6b2Vec2($4,$258,$u1);
  $259 = $4;
  $260 = $259;
  $261 = HEAP32[$260>>2]|0;
  $262 = (($259) + 4)|0;
  $263 = $262;
  $264 = HEAP32[$263>>2]|0;
  $265 = $256;
  $266 = $265;
  HEAP32[$266>>2] = $261;
  $267 = (($265) + 4)|0;
  $268 = $267;
  HEAP32[$268>>2] = $264;
  $269 = +HEAPF32[$257>>2];
  $270 = (+__Z7b2CrossRK6b2Vec2S1_($rD,$u1));
  $271 = $269 * $270;
  $272 = (($this) + 268|0);
  HEAPF32[$272>>2] = $271;
  $273 = +HEAPF32[$257>>2];
  $274 = (+__Z7b2CrossRK6b2Vec2S1_($rB,$u1));
  $275 = $273 * $274;
  $276 = (($this) + 260|0);
  HEAPF32[$276>>2] = $275;
  $277 = +HEAPF32[$257>>2];
  $278 = $277 * $277;
  $279 = +HEAPF32[$96>>2];
  $280 = +HEAPF32[$88>>2];
  $281 = $279 + $280;
  $282 = $278 * $281;
  $283 = +HEAPF32[$112>>2];
  $284 = +HEAPF32[$272>>2];
  $285 = $283 * $284;
  $286 = $284 * $285;
  $287 = $282 + $286;
  $288 = +HEAPF32[$104>>2];
  $289 = $275 * $288;
  $290 = $275 * $289;
  $291 = $287 + $290;
  $292 = +HEAPF32[$192>>2];
  $293 = $292 + $291;
  $storemerge6 = $293;
 }
 HEAPF32[$192>>2] = $storemerge6;
 $294 = $storemerge6 > 0.0;
 if ($294) {
  $295 = 1.0 / $storemerge6;
  $296 = $295;
 } else {
  $296 = 0.0;
 }
 HEAPF32[$192>>2] = $296;
 $297 = (($data) + 24|0);
 $298 = HEAP8[$297>>0]|0;
 $299 = ($298<<24>>24)==(0);
 if ($299) {
  $340 = (($this) + 156|0);
  HEAPF32[$340>>2] = 0.0;
  $wA$0 = $134;$wB$0 = $153;$wC$0 = $172;$wD$0 = $191;
  $341 = HEAP32[$13>>2]|0;
  $342 = HEAP32[$118>>2]|0;
  $343 = (($342) + (($341*12)|0)|0);
  $344 = $vA;
  $345 = $344;
  $346 = HEAP32[$345>>2]|0;
  $347 = (($344) + 4)|0;
  $348 = $347;
  $349 = HEAP32[$348>>2]|0;
  $350 = $343;
  $351 = $350;
  HEAP32[$351>>2] = $346;
  $352 = (($350) + 4)|0;
  $353 = $352;
  HEAP32[$353>>2] = $349;
  $354 = HEAP32[$13>>2]|0;
  $355 = HEAP32[$118>>2]|0;
  $356 = ((($355) + (($354*12)|0)|0) + 8|0);
  HEAPF32[$356>>2] = $wA$0;
  $357 = HEAP32[$18>>2]|0;
  $358 = HEAP32[$118>>2]|0;
  $359 = (($358) + (($357*12)|0)|0);
  $360 = $vB;
  $361 = $360;
  $362 = HEAP32[$361>>2]|0;
  $363 = (($360) + 4)|0;
  $364 = $363;
  $365 = HEAP32[$364>>2]|0;
  $366 = $359;
  $367 = $366;
  HEAP32[$367>>2] = $362;
  $368 = (($366) + 4)|0;
  $369 = $368;
  HEAP32[$369>>2] = $365;
  $370 = HEAP32[$18>>2]|0;
  $371 = HEAP32[$118>>2]|0;
  $372 = ((($371) + (($370*12)|0)|0) + 8|0);
  HEAPF32[$372>>2] = $wB$0;
  $373 = HEAP32[$23>>2]|0;
  $374 = HEAP32[$118>>2]|0;
  $375 = (($374) + (($373*12)|0)|0);
  $376 = $vC;
  $377 = $376;
  $378 = HEAP32[$377>>2]|0;
  $379 = (($376) + 4)|0;
  $380 = $379;
  $381 = HEAP32[$380>>2]|0;
  $382 = $375;
  $383 = $382;
  HEAP32[$383>>2] = $378;
  $384 = (($382) + 4)|0;
  $385 = $384;
  HEAP32[$385>>2] = $381;
  $386 = HEAP32[$23>>2]|0;
  $387 = HEAP32[$118>>2]|0;
  $388 = ((($387) + (($386*12)|0)|0) + 8|0);
  HEAPF32[$388>>2] = $wC$0;
  $389 = HEAP32[$28>>2]|0;
  $390 = HEAP32[$118>>2]|0;
  $391 = (($390) + (($389*12)|0)|0);
  $392 = $vD;
  $393 = $392;
  $394 = HEAP32[$393>>2]|0;
  $395 = (($392) + 4)|0;
  $396 = $395;
  $397 = HEAP32[$396>>2]|0;
  $398 = $391;
  $399 = $398;
  HEAP32[$399>>2] = $394;
  $400 = (($398) + 4)|0;
  $401 = $400;
  HEAP32[$401>>2] = $397;
  $402 = HEAP32[$28>>2]|0;
  $403 = HEAP32[$118>>2]|0;
  $404 = ((($403) + (($402*12)|0)|0) + 8|0);
  HEAPF32[$404>>2] = $wD$0;
  STACKTOP = sp;return;
 } else {
  $300 = +HEAPF32[$84>>2];
  $301 = (($this) + 156|0);
  $302 = +HEAPF32[$301>>2];
  $303 = $300 * $302;
  $304 = (($this) + 240|0);
  __ZmlfRK6b2Vec2($5,$303,$304);
  __ZN6b2Vec2pLERKS_($vA,$5);
  $305 = +HEAPF32[$100>>2];
  $306 = +HEAPF32[$301>>2];
  $307 = $305 * $306;
  $308 = (($this) + 256|0);
  $309 = +HEAPF32[$308>>2];
  $310 = $307 * $309;
  $311 = $134 + $310;
  $312 = +HEAPF32[$88>>2];
  $313 = $306 * $312;
  $314 = (($this) + 248|0);
  __ZmlfRK6b2Vec2($6,$313,$314);
  __ZN6b2Vec2pLERKS_($vB,$6);
  $315 = +HEAPF32[$104>>2];
  $316 = +HEAPF32[$301>>2];
  $317 = $315 * $316;
  $318 = (($this) + 260|0);
  $319 = +HEAPF32[$318>>2];
  $320 = $317 * $319;
  $321 = $153 + $320;
  $322 = +HEAPF32[$92>>2];
  $323 = $316 * $322;
  __ZmlfRK6b2Vec2($7,$323,$304);
  __ZN6b2Vec2mIERKS_($vC,$7);
  $324 = +HEAPF32[$108>>2];
  $325 = +HEAPF32[$301>>2];
  $326 = $324 * $325;
  $327 = (($this) + 264|0);
  $328 = +HEAPF32[$327>>2];
  $329 = $326 * $328;
  $330 = $172 - $329;
  $331 = +HEAPF32[$96>>2];
  $332 = $325 * $331;
  __ZmlfRK6b2Vec2($8,$332,$314);
  __ZN6b2Vec2mIERKS_($vD,$8);
  $333 = +HEAPF32[$112>>2];
  $334 = +HEAPF32[$301>>2];
  $335 = $333 * $334;
  $336 = (($this) + 268|0);
  $337 = +HEAPF32[$336>>2];
  $338 = $335 * $337;
  $339 = $191 - $338;
  $wA$0 = $311;$wB$0 = $321;$wC$0 = $330;$wD$0 = $339;
  $341 = HEAP32[$13>>2]|0;
  $342 = HEAP32[$118>>2]|0;
  $343 = (($342) + (($341*12)|0)|0);
  $344 = $vA;
  $345 = $344;
  $346 = HEAP32[$345>>2]|0;
  $347 = (($344) + 4)|0;
  $348 = $347;
  $349 = HEAP32[$348>>2]|0;
  $350 = $343;
  $351 = $350;
  HEAP32[$351>>2] = $346;
  $352 = (($350) + 4)|0;
  $353 = $352;
  HEAP32[$353>>2] = $349;
  $354 = HEAP32[$13>>2]|0;
  $355 = HEAP32[$118>>2]|0;
  $356 = ((($355) + (($354*12)|0)|0) + 8|0);
  HEAPF32[$356>>2] = $wA$0;
  $357 = HEAP32[$18>>2]|0;
  $358 = HEAP32[$118>>2]|0;
  $359 = (($358) + (($357*12)|0)|0);
  $360 = $vB;
  $361 = $360;
  $362 = HEAP32[$361>>2]|0;
  $363 = (($360) + 4)|0;
  $364 = $363;
  $365 = HEAP32[$364>>2]|0;
  $366 = $359;
  $367 = $366;
  HEAP32[$367>>2] = $362;
  $368 = (($366) + 4)|0;
  $369 = $368;
  HEAP32[$369>>2] = $365;
  $370 = HEAP32[$18>>2]|0;
  $371 = HEAP32[$118>>2]|0;
  $372 = ((($371) + (($370*12)|0)|0) + 8|0);
  HEAPF32[$372>>2] = $wB$0;
  $373 = HEAP32[$23>>2]|0;
  $374 = HEAP32[$118>>2]|0;
  $375 = (($374) + (($373*12)|0)|0);
  $376 = $vC;
  $377 = $376;
  $378 = HEAP32[$377>>2]|0;
  $379 = (($376) + 4)|0;
  $380 = $379;
  $381 = HEAP32[$380>>2]|0;
  $382 = $375;
  $383 = $382;
  HEAP32[$383>>2] = $378;
  $384 = (($382) + 4)|0;
  $385 = $384;
  HEAP32[$385>>2] = $381;
  $386 = HEAP32[$23>>2]|0;
  $387 = HEAP32[$118>>2]|0;
  $388 = ((($387) + (($386*12)|0)|0) + 8|0);
  HEAPF32[$388>>2] = $wC$0;
  $389 = HEAP32[$28>>2]|0;
  $390 = HEAP32[$118>>2]|0;
  $391 = (($390) + (($389*12)|0)|0);
  $392 = $vD;
  $393 = $392;
  $394 = HEAP32[$393>>2]|0;
  $395 = (($392) + 4)|0;
  $396 = $395;
  $397 = HEAP32[$396>>2]|0;
  $398 = $391;
  $399 = $398;
  HEAP32[$399>>2] = $394;
  $400 = (($398) + 4)|0;
  $401 = $400;
  HEAP32[$401>>2] = $397;
  $402 = HEAP32[$28>>2]|0;
  $403 = HEAP32[$118>>2]|0;
  $404 = ((($403) + (($402*12)|0)|0) + 8|0);
  HEAPF32[$404>>2] = $wD$0;
  STACKTOP = sp;return;
 }
}
function __ZN11b2GearJoint24SolveVelocityConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0.0, $103 = 0.0, $104 = 0, $105 = 0.0, $106 = 0.0, $107 = 0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0, $114 = 0.0, $115 = 0.0;
 var $116 = 0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0, $123 = 0.0, $124 = 0.0, $125 = 0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0, $132 = 0.0, $133 = 0.0;
 var $134 = 0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0.0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0.0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0.0, $76 = 0, $77 = 0.0;
 var $78 = 0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0.0, $83 = 0.0, $84 = 0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0;
 var $96 = 0.0, $97 = 0, $98 = 0.0, $99 = 0.0, $vA = 0, $vB = 0, $vC = 0, $vD = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $vA = sp + 24|0;
 $vB = sp + 16|0;
 $vC = sp + 8|0;
 $vD = sp;
 $0 = sp + 72|0;
 $1 = sp + 64|0;
 $2 = sp + 56|0;
 $3 = sp + 48|0;
 $4 = sp + 40|0;
 $5 = sp + 32|0;
 $6 = (($this) + 160|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($data) + 32|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + (($7*12)|0)|0);
 $11 = $10;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + 4)|0;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = $vA;
 $18 = $17;
 HEAP32[$18>>2] = $13;
 $19 = (($17) + 4)|0;
 $20 = $19;
 HEAP32[$20>>2] = $16;
 $21 = HEAP32[$6>>2]|0;
 $22 = HEAP32[$8>>2]|0;
 $23 = ((($22) + (($21*12)|0)|0) + 8|0);
 $24 = +HEAPF32[$23>>2];
 $25 = (($this) + 164|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($22) + (($26*12)|0)|0);
 $28 = $27;
 $29 = $28;
 $30 = HEAP32[$29>>2]|0;
 $31 = (($28) + 4)|0;
 $32 = $31;
 $33 = HEAP32[$32>>2]|0;
 $34 = $vB;
 $35 = $34;
 HEAP32[$35>>2] = $30;
 $36 = (($34) + 4)|0;
 $37 = $36;
 HEAP32[$37>>2] = $33;
 $38 = HEAP32[$25>>2]|0;
 $39 = HEAP32[$8>>2]|0;
 $40 = ((($39) + (($38*12)|0)|0) + 8|0);
 $41 = +HEAPF32[$40>>2];
 $42 = (($this) + 168|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (($39) + (($43*12)|0)|0);
 $45 = $44;
 $46 = $45;
 $47 = HEAP32[$46>>2]|0;
 $48 = (($45) + 4)|0;
 $49 = $48;
 $50 = HEAP32[$49>>2]|0;
 $51 = $vC;
 $52 = $51;
 HEAP32[$52>>2] = $47;
 $53 = (($51) + 4)|0;
 $54 = $53;
 HEAP32[$54>>2] = $50;
 $55 = HEAP32[$42>>2]|0;
 $56 = HEAP32[$8>>2]|0;
 $57 = ((($56) + (($55*12)|0)|0) + 8|0);
 $58 = +HEAPF32[$57>>2];
 $59 = (($this) + 172|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = (($56) + (($60*12)|0)|0);
 $62 = $61;
 $63 = $62;
 $64 = HEAP32[$63>>2]|0;
 $65 = (($62) + 4)|0;
 $66 = $65;
 $67 = HEAP32[$66>>2]|0;
 $68 = $vD;
 $69 = $68;
 HEAP32[$69>>2] = $64;
 $70 = (($68) + 4)|0;
 $71 = $70;
 HEAP32[$71>>2] = $67;
 $72 = HEAP32[$59>>2]|0;
 $73 = HEAP32[$8>>2]|0;
 $74 = ((($73) + (($72*12)|0)|0) + 8|0);
 $75 = +HEAPF32[$74>>2];
 $76 = (($this) + 240|0);
 __ZmiRK6b2Vec2S1_($0,$vA,$vC);
 $77 = (+__Z5b2DotRK6b2Vec2S1_($76,$0));
 $78 = (($this) + 248|0);
 __ZmiRK6b2Vec2S1_($1,$vB,$vD);
 $79 = (+__Z5b2DotRK6b2Vec2S1_($78,$1));
 $80 = $77 + $79;
 $81 = (($this) + 256|0);
 $82 = +HEAPF32[$81>>2];
 $83 = $24 * $82;
 $84 = (($this) + 264|0);
 $85 = +HEAPF32[$84>>2];
 $86 = $58 * $85;
 $87 = $83 - $86;
 $88 = (($this) + 260|0);
 $89 = +HEAPF32[$88>>2];
 $90 = $41 * $89;
 $91 = (($this) + 268|0);
 $92 = +HEAPF32[$91>>2];
 $93 = $75 * $92;
 $94 = $90 - $93;
 $95 = $87 + $94;
 $96 = $80 + $95;
 $97 = (($this) + 272|0);
 $98 = +HEAPF32[$97>>2];
 $99 = $98 * $96;
 $100 = -$99;
 $101 = (($this) + 156|0);
 $102 = +HEAPF32[$101>>2];
 $103 = $102 - $99;
 HEAPF32[$101>>2] = $103;
 $104 = (($this) + 208|0);
 $105 = +HEAPF32[$104>>2];
 $106 = $105 * $100;
 __ZmlfRK6b2Vec2($2,$106,$76);
 __ZN6b2Vec2pLERKS_($vA,$2);
 $107 = (($this) + 224|0);
 $108 = +HEAPF32[$107>>2];
 $109 = $108 * $100;
 $110 = +HEAPF32[$81>>2];
 $111 = $109 * $110;
 $112 = $24 + $111;
 $113 = (($this) + 212|0);
 $114 = +HEAPF32[$113>>2];
 $115 = $114 * $100;
 __ZmlfRK6b2Vec2($3,$115,$78);
 __ZN6b2Vec2pLERKS_($vB,$3);
 $116 = (($this) + 228|0);
 $117 = +HEAPF32[$116>>2];
 $118 = $117 * $100;
 $119 = +HEAPF32[$88>>2];
 $120 = $118 * $119;
 $121 = $41 + $120;
 $122 = (($this) + 216|0);
 $123 = +HEAPF32[$122>>2];
 $124 = $123 * $100;
 __ZmlfRK6b2Vec2($4,$124,$76);
 __ZN6b2Vec2mIERKS_($vC,$4);
 $125 = (($this) + 232|0);
 $126 = +HEAPF32[$125>>2];
 $127 = $126 * $100;
 $128 = +HEAPF32[$84>>2];
 $129 = $127 * $128;
 $130 = $58 - $129;
 $131 = (($this) + 220|0);
 $132 = +HEAPF32[$131>>2];
 $133 = $132 * $100;
 __ZmlfRK6b2Vec2($5,$133,$78);
 __ZN6b2Vec2mIERKS_($vD,$5);
 $134 = (($this) + 236|0);
 $135 = +HEAPF32[$134>>2];
 $136 = $135 * $100;
 $137 = +HEAPF32[$91>>2];
 $138 = $136 * $137;
 $139 = $75 - $138;
 $140 = HEAP32[$6>>2]|0;
 $141 = HEAP32[$8>>2]|0;
 $142 = (($141) + (($140*12)|0)|0);
 $143 = $vA;
 $144 = $143;
 $145 = HEAP32[$144>>2]|0;
 $146 = (($143) + 4)|0;
 $147 = $146;
 $148 = HEAP32[$147>>2]|0;
 $149 = $142;
 $150 = $149;
 HEAP32[$150>>2] = $145;
 $151 = (($149) + 4)|0;
 $152 = $151;
 HEAP32[$152>>2] = $148;
 $153 = HEAP32[$6>>2]|0;
 $154 = HEAP32[$8>>2]|0;
 $155 = ((($154) + (($153*12)|0)|0) + 8|0);
 HEAPF32[$155>>2] = $112;
 $156 = HEAP32[$25>>2]|0;
 $157 = HEAP32[$8>>2]|0;
 $158 = (($157) + (($156*12)|0)|0);
 $159 = $vB;
 $160 = $159;
 $161 = HEAP32[$160>>2]|0;
 $162 = (($159) + 4)|0;
 $163 = $162;
 $164 = HEAP32[$163>>2]|0;
 $165 = $158;
 $166 = $165;
 HEAP32[$166>>2] = $161;
 $167 = (($165) + 4)|0;
 $168 = $167;
 HEAP32[$168>>2] = $164;
 $169 = HEAP32[$25>>2]|0;
 $170 = HEAP32[$8>>2]|0;
 $171 = ((($170) + (($169*12)|0)|0) + 8|0);
 HEAPF32[$171>>2] = $121;
 $172 = HEAP32[$42>>2]|0;
 $173 = HEAP32[$8>>2]|0;
 $174 = (($173) + (($172*12)|0)|0);
 $175 = $vC;
 $176 = $175;
 $177 = HEAP32[$176>>2]|0;
 $178 = (($175) + 4)|0;
 $179 = $178;
 $180 = HEAP32[$179>>2]|0;
 $181 = $174;
 $182 = $181;
 HEAP32[$182>>2] = $177;
 $183 = (($181) + 4)|0;
 $184 = $183;
 HEAP32[$184>>2] = $180;
 $185 = HEAP32[$42>>2]|0;
 $186 = HEAP32[$8>>2]|0;
 $187 = ((($186) + (($185*12)|0)|0) + 8|0);
 HEAPF32[$187>>2] = $130;
 $188 = HEAP32[$59>>2]|0;
 $189 = HEAP32[$8>>2]|0;
 $190 = (($189) + (($188*12)|0)|0);
 $191 = $vD;
 $192 = $191;
 $193 = HEAP32[$192>>2]|0;
 $194 = (($191) + 4)|0;
 $195 = $194;
 $196 = HEAP32[$195>>2]|0;
 $197 = $190;
 $198 = $197;
 HEAP32[$198>>2] = $193;
 $199 = (($197) + 4)|0;
 $200 = $199;
 HEAP32[$200>>2] = $196;
 $201 = HEAP32[$59>>2]|0;
 $202 = HEAP32[$8>>2]|0;
 $203 = ((($202) + (($201*12)|0)|0) + 8|0);
 HEAPF32[$203>>2] = $139;
 STACKTOP = sp;return;
}
function __ZN11b2GearJoint24SolvePositionConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$pn = 0.0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0.0, $112 = 0.0, $113 = 0, $114 = 0.0;
 var $115 = 0, $116 = 0.0, $117 = 0.0, $118 = 0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0.0, $134 = 0.0, $135 = 0, $136 = 0.0, $137 = 0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0, $143 = 0.0, $144 = 0.0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0.0, $152 = 0.0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0, $159 = 0.0, $16 = 0, $160 = 0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0, $165 = 0.0, $166 = 0.0, $167 = 0.0, $168 = 0.0, $169 = 0;
 var $17 = 0, $170 = 0.0, $171 = 0.0, $172 = 0.0, $173 = 0.0, $174 = 0.0, $175 = 0, $176 = 0, $177 = 0.0, $178 = 0, $179 = 0.0, $18 = 0, $180 = 0.0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0, $186 = 0.0, $187 = 0.0;
 var $188 = 0, $189 = 0.0, $19 = 0, $190 = 0.0, $191 = 0.0, $192 = 0.0, $193 = 0, $194 = 0.0, $195 = 0.0, $196 = 0, $197 = 0.0, $198 = 0.0, $199 = 0.0, $2 = 0, $20 = 0, $200 = 0.0, $201 = 0, $202 = 0.0, $203 = 0.0, $204 = 0;
 var $205 = 0.0, $206 = 0.0, $207 = 0.0, $208 = 0.0, $209 = 0, $21 = 0, $210 = 0.0, $211 = 0.0, $212 = 0, $213 = 0.0, $214 = 0.0, $215 = 0.0, $216 = 0.0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0.0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0.0, $89 = 0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0, $94 = 0.0, $95 = 0.0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $JvAC = 0, $JvBD = 0, $JwA$0 = 0.0, $JwB$0 = 0.0, $JwC$0 = 0.0, $JwD$0 = 0.0, $cA = 0, $cB = 0, $cC = 0, $cD = 0, $coordinateA$0 = 0.0, $coordinateB$0 = 0.0, $impulse$0 = 0.0, $mass$0 = 0.0, $mass$0$in = 0.0, $mass$1 = 0.0, $pA = 0, $pB = 0;
 var $pC = 0, $pD = 0, $qA = 0, $qB = 0, $qC = 0, $qD = 0, $rA = 0, $rB = 0, $rC = 0, $rD = 0, $u = 0, $u1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $cA = sp + 48|0;
 $cB = sp + 40|0;
 $cC = sp + 32|0;
 $cD = sp + 24|0;
 $qA = sp + 264|0;
 $qB = sp + 256|0;
 $qC = sp + 248|0;
 $qD = sp + 240|0;
 $JvAC = sp + 16|0;
 $JvBD = sp + 8|0;
 $u = sp;
 $rC = sp + 232|0;
 $0 = sp + 224|0;
 $rA = sp + 216|0;
 $1 = sp + 208|0;
 $pC = sp + 200|0;
 $pA = sp + 192|0;
 $2 = sp + 184|0;
 $3 = sp + 176|0;
 $4 = sp + 168|0;
 $u1 = sp + 160|0;
 $rD = sp + 152|0;
 $5 = sp + 144|0;
 $rB = sp + 136|0;
 $6 = sp + 128|0;
 $pD = sp + 120|0;
 $pB = sp + 112|0;
 $7 = sp + 104|0;
 $8 = sp + 96|0;
 $9 = sp + 88|0;
 $10 = sp + 80|0;
 $11 = sp + 72|0;
 $12 = sp + 64|0;
 $13 = sp + 56|0;
 $14 = (($this) + 160|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($data) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + (($15*12)|0)|0);
 $19 = $18;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) + 4)|0;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 $25 = $cA;
 $26 = $25;
 HEAP32[$26>>2] = $21;
 $27 = (($25) + 4)|0;
 $28 = $27;
 HEAP32[$28>>2] = $24;
 $29 = HEAP32[$14>>2]|0;
 $30 = HEAP32[$16>>2]|0;
 $31 = ((($30) + (($29*12)|0)|0) + 8|0);
 $32 = +HEAPF32[$31>>2];
 $33 = (($this) + 164|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($30) + (($34*12)|0)|0);
 $36 = $35;
 $37 = $36;
 $38 = HEAP32[$37>>2]|0;
 $39 = (($36) + 4)|0;
 $40 = $39;
 $41 = HEAP32[$40>>2]|0;
 $42 = $cB;
 $43 = $42;
 HEAP32[$43>>2] = $38;
 $44 = (($42) + 4)|0;
 $45 = $44;
 HEAP32[$45>>2] = $41;
 $46 = HEAP32[$33>>2]|0;
 $47 = HEAP32[$16>>2]|0;
 $48 = ((($47) + (($46*12)|0)|0) + 8|0);
 $49 = +HEAPF32[$48>>2];
 $50 = (($this) + 168|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = (($47) + (($51*12)|0)|0);
 $53 = $52;
 $54 = $53;
 $55 = HEAP32[$54>>2]|0;
 $56 = (($53) + 4)|0;
 $57 = $56;
 $58 = HEAP32[$57>>2]|0;
 $59 = $cC;
 $60 = $59;
 HEAP32[$60>>2] = $55;
 $61 = (($59) + 4)|0;
 $62 = $61;
 HEAP32[$62>>2] = $58;
 $63 = HEAP32[$50>>2]|0;
 $64 = HEAP32[$16>>2]|0;
 $65 = ((($64) + (($63*12)|0)|0) + 8|0);
 $66 = +HEAPF32[$65>>2];
 $67 = (($this) + 172|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($64) + (($68*12)|0)|0);
 $70 = $69;
 $71 = $70;
 $72 = HEAP32[$71>>2]|0;
 $73 = (($70) + 4)|0;
 $74 = $73;
 $75 = HEAP32[$74>>2]|0;
 $76 = $cD;
 $77 = $76;
 HEAP32[$77>>2] = $72;
 $78 = (($76) + 4)|0;
 $79 = $78;
 HEAP32[$79>>2] = $75;
 $80 = HEAP32[$67>>2]|0;
 $81 = HEAP32[$16>>2]|0;
 $82 = ((($81) + (($80*12)|0)|0) + 8|0);
 $83 = +HEAPF32[$82>>2];
 __ZN5b2RotC2Ef($qA,$32);
 __ZN5b2RotC2Ef($qB,$49);
 __ZN5b2RotC2Ef($qC,$66);
 __ZN5b2RotC2Ef($qD,$83);
 $84 = (($this) + 76|0);
 $85 = HEAP32[$84>>2]|0;
 $86 = ($85|0)==(1);
 if ($86) {
  __ZN6b2Vec27SetZeroEv($JvAC);
  $87 = (($this) + 224|0);
  $88 = +HEAPF32[$87>>2];
  $89 = (($this) + 232|0);
  $90 = +HEAPF32[$89>>2];
  $91 = $88 + $90;
  $92 = $32 - $66;
  $93 = (($this) + 140|0);
  $94 = +HEAPF32[$93>>2];
  $95 = $92 - $94;
  $JwA$0 = 1.0;$JwC$0 = 1.0;$coordinateA$0 = $95;$mass$0$in = $91;
 } else {
  $96 = (($this) + 124|0);
  __Z5b2MulRK5b2RotRK6b2Vec2($u,$qC,$96);
  $97 = (($this) + 108|0);
  $98 = (($this) + 192|0);
  __ZmiRK6b2Vec2S1_($0,$97,$98);
  __Z5b2MulRK5b2RotRK6b2Vec2($rC,$qC,$0);
  $99 = (($this) + 92|0);
  $100 = (($this) + 176|0);
  __ZmiRK6b2Vec2S1_($1,$99,$100);
  __Z5b2MulRK5b2RotRK6b2Vec2($rA,$qA,$1);
  $101 = $u;
  $102 = $101;
  $103 = HEAP32[$102>>2]|0;
  $104 = (($101) + 4)|0;
  $105 = $104;
  $106 = HEAP32[$105>>2]|0;
  $107 = $JvAC;
  $108 = $107;
  HEAP32[$108>>2] = $103;
  $109 = (($107) + 4)|0;
  $110 = $109;
  HEAP32[$110>>2] = $106;
  $111 = (+__Z7b2CrossRK6b2Vec2S1_($rC,$u));
  $112 = (+__Z7b2CrossRK6b2Vec2S1_($rA,$u));
  $113 = (($this) + 216|0);
  $114 = +HEAPF32[$113>>2];
  $115 = (($this) + 208|0);
  $116 = +HEAPF32[$115>>2];
  $117 = $114 + $116;
  $118 = (($this) + 232|0);
  $119 = +HEAPF32[$118>>2];
  $120 = $111 * $119;
  $121 = $111 * $120;
  $122 = $117 + $121;
  $123 = (($this) + 224|0);
  $124 = +HEAPF32[$123>>2];
  $125 = $112 * $124;
  $126 = $112 * $125;
  $127 = $122 + $126;
  __ZmiRK6b2Vec2S1_($pC,$97,$98);
  __ZmiRK6b2Vec2S1_($3,$cA,$cC);
  __ZplRK6b2Vec2S1_($2,$rA,$3);
  __Z6b2MulTRK5b2RotRK6b2Vec2($pA,$qC,$2);
  __ZmiRK6b2Vec2S1_($4,$pA,$pC);
  $128 = (+__Z5b2DotRK6b2Vec2S1_($4,$96));
  $JwA$0 = $112;$JwC$0 = $111;$coordinateA$0 = $128;$mass$0$in = $127;
 }
 $mass$0 = $mass$0$in + 0.0;
 $129 = (($this) + 80|0);
 $130 = HEAP32[$129>>2]|0;
 $131 = ($130|0)==(1);
 if ($131) {
  __ZN6b2Vec27SetZeroEv($JvBD);
  $132 = (($this) + 152|0);
  $133 = +HEAPF32[$132>>2];
  $134 = $133 * $133;
  $135 = (($this) + 228|0);
  $136 = +HEAPF32[$135>>2];
  $137 = (($this) + 236|0);
  $138 = +HEAPF32[$137>>2];
  $139 = $136 + $138;
  $140 = $134 * $139;
  $141 = $49 - $83;
  $142 = (($this) + 144|0);
  $143 = +HEAPF32[$142>>2];
  $144 = $141 - $143;
  $$pn = $140;$JwB$0 = $133;$JwD$0 = $133;$coordinateB$0 = $144;
 } else {
  $145 = (($this) + 132|0);
  __Z5b2MulRK5b2RotRK6b2Vec2($u1,$qD,$145);
  $146 = (($this) + 116|0);
  $147 = (($this) + 200|0);
  __ZmiRK6b2Vec2S1_($5,$146,$147);
  __Z5b2MulRK5b2RotRK6b2Vec2($rD,$qD,$5);
  $148 = (($this) + 100|0);
  $149 = (($this) + 184|0);
  __ZmiRK6b2Vec2S1_($6,$148,$149);
  __Z5b2MulRK5b2RotRK6b2Vec2($rB,$qB,$6);
  $150 = (($this) + 152|0);
  $151 = +HEAPF32[$150>>2];
  __ZmlfRK6b2Vec2($JvBD,$151,$u1);
  $152 = +HEAPF32[$150>>2];
  $153 = (+__Z7b2CrossRK6b2Vec2S1_($rD,$u1));
  $154 = $152 * $153;
  $155 = (+__Z7b2CrossRK6b2Vec2S1_($rB,$u1));
  $156 = $152 * $155;
  $157 = $152 * $152;
  $158 = (($this) + 220|0);
  $159 = +HEAPF32[$158>>2];
  $160 = (($this) + 212|0);
  $161 = +HEAPF32[$160>>2];
  $162 = $159 + $161;
  $163 = $157 * $162;
  $164 = (($this) + 236|0);
  $165 = +HEAPF32[$164>>2];
  $166 = $154 * $165;
  $167 = $154 * $166;
  $168 = $163 + $167;
  $169 = (($this) + 228|0);
  $170 = +HEAPF32[$169>>2];
  $171 = $156 * $170;
  $172 = $156 * $171;
  $173 = $168 + $172;
  __ZmiRK6b2Vec2S1_($pD,$146,$147);
  __ZmiRK6b2Vec2S1_($8,$cB,$cD);
  __ZplRK6b2Vec2S1_($7,$rB,$8);
  __Z6b2MulTRK5b2RotRK6b2Vec2($pB,$qD,$7);
  __ZmiRK6b2Vec2S1_($9,$pB,$pD);
  $174 = (+__Z5b2DotRK6b2Vec2S1_($9,$145));
  $$pn = $173;$JwB$0 = $156;$JwD$0 = $154;$coordinateB$0 = $174;
 }
 $mass$1 = $mass$0 + $$pn;
 $175 = $mass$1 > 0.0;
 if ($175) {
  $176 = (($this) + 152|0);
  $177 = +HEAPF32[$176>>2];
  $178 = (($this) + 148|0);
  $179 = $coordinateB$0 * $177;
  $180 = +HEAPF32[$178>>2];
  $181 = $coordinateA$0 + $179;
  $182 = $181 - $180;
  $183 = -$182;
  $184 = $183 / $mass$1;
  $impulse$0 = $184;
 } else {
  $impulse$0 = 0.0;
 }
 $185 = (($this) + 208|0);
 $186 = +HEAPF32[$185>>2];
 $187 = $impulse$0 * $186;
 __ZmlfRK6b2Vec2($10,$187,$JvAC);
 __ZN6b2Vec2pLERKS_($cA,$10);
 $188 = (($this) + 224|0);
 $189 = +HEAPF32[$188>>2];
 $190 = $impulse$0 * $189;
 $191 = $JwA$0 * $190;
 $192 = $32 + $191;
 $193 = (($this) + 212|0);
 $194 = +HEAPF32[$193>>2];
 $195 = $impulse$0 * $194;
 __ZmlfRK6b2Vec2($11,$195,$JvBD);
 __ZN6b2Vec2pLERKS_($cB,$11);
 $196 = (($this) + 228|0);
 $197 = +HEAPF32[$196>>2];
 $198 = $impulse$0 * $197;
 $199 = $JwB$0 * $198;
 $200 = $49 + $199;
 $201 = (($this) + 216|0);
 $202 = +HEAPF32[$201>>2];
 $203 = $impulse$0 * $202;
 __ZmlfRK6b2Vec2($12,$203,$JvAC);
 __ZN6b2Vec2mIERKS_($cC,$12);
 $204 = (($this) + 232|0);
 $205 = +HEAPF32[$204>>2];
 $206 = $impulse$0 * $205;
 $207 = $JwC$0 * $206;
 $208 = $66 - $207;
 $209 = (($this) + 220|0);
 $210 = +HEAPF32[$209>>2];
 $211 = $impulse$0 * $210;
 __ZmlfRK6b2Vec2($13,$211,$JvBD);
 __ZN6b2Vec2mIERKS_($cD,$13);
 $212 = (($this) + 236|0);
 $213 = +HEAPF32[$212>>2];
 $214 = $impulse$0 * $213;
 $215 = $JwD$0 * $214;
 $216 = $83 - $215;
 $217 = HEAP32[$14>>2]|0;
 $218 = HEAP32[$16>>2]|0;
 $219 = (($218) + (($217*12)|0)|0);
 $220 = $cA;
 $221 = $220;
 $222 = HEAP32[$221>>2]|0;
 $223 = (($220) + 4)|0;
 $224 = $223;
 $225 = HEAP32[$224>>2]|0;
 $226 = $219;
 $227 = $226;
 HEAP32[$227>>2] = $222;
 $228 = (($226) + 4)|0;
 $229 = $228;
 HEAP32[$229>>2] = $225;
 $230 = HEAP32[$14>>2]|0;
 $231 = HEAP32[$16>>2]|0;
 $232 = ((($231) + (($230*12)|0)|0) + 8|0);
 HEAPF32[$232>>2] = $192;
 $233 = HEAP32[$33>>2]|0;
 $234 = HEAP32[$16>>2]|0;
 $235 = (($234) + (($233*12)|0)|0);
 $236 = $cB;
 $237 = $236;
 $238 = HEAP32[$237>>2]|0;
 $239 = (($236) + 4)|0;
 $240 = $239;
 $241 = HEAP32[$240>>2]|0;
 $242 = $235;
 $243 = $242;
 HEAP32[$243>>2] = $238;
 $244 = (($242) + 4)|0;
 $245 = $244;
 HEAP32[$245>>2] = $241;
 $246 = HEAP32[$33>>2]|0;
 $247 = HEAP32[$16>>2]|0;
 $248 = ((($247) + (($246*12)|0)|0) + 8|0);
 HEAPF32[$248>>2] = $200;
 $249 = HEAP32[$50>>2]|0;
 $250 = HEAP32[$16>>2]|0;
 $251 = (($250) + (($249*12)|0)|0);
 $252 = $cC;
 $253 = $252;
 $254 = HEAP32[$253>>2]|0;
 $255 = (($252) + 4)|0;
 $256 = $255;
 $257 = HEAP32[$256>>2]|0;
 $258 = $251;
 $259 = $258;
 HEAP32[$259>>2] = $254;
 $260 = (($258) + 4)|0;
 $261 = $260;
 HEAP32[$261>>2] = $257;
 $262 = HEAP32[$50>>2]|0;
 $263 = HEAP32[$16>>2]|0;
 $264 = ((($263) + (($262*12)|0)|0) + 8|0);
 HEAPF32[$264>>2] = $208;
 $265 = HEAP32[$67>>2]|0;
 $266 = HEAP32[$16>>2]|0;
 $267 = (($266) + (($265*12)|0)|0);
 $268 = $cD;
 $269 = $268;
 $270 = HEAP32[$269>>2]|0;
 $271 = (($268) + 4)|0;
 $272 = $271;
 $273 = HEAP32[$272>>2]|0;
 $274 = $267;
 $275 = $274;
 HEAP32[$275>>2] = $270;
 $276 = (($274) + 4)|0;
 $277 = $276;
 HEAP32[$277>>2] = $273;
 $278 = HEAP32[$67>>2]|0;
 $279 = HEAP32[$16>>2]|0;
 $280 = ((($279) + (($278*12)|0)|0) + 8|0);
 HEAPF32[$280>>2] = $216;
 STACKTOP = sp;return 1;
}
function __ZNK11b2GearJoint10GetAnchorAEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 92|0);
 __ZNK6b2Body13GetWorldPointERK6b2Vec2($agg$result,$1,$2);
 STACKTOP = sp;return;
}
function __ZNK11b2GearJoint10GetAnchorBEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 100|0);
 __ZNK6b2Body13GetWorldPointERK6b2Vec2($agg$result,$1,$2);
 STACKTOP = sp;return;
}
function __ZNK11b2GearJoint16GetReactionForceEf($agg$result,$this,$inv_dt) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inv_dt = +$inv_dt;
 var $0 = 0, $1 = 0.0, $2 = 0, $P = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $P = sp;
 $0 = (($this) + 156|0);
 $1 = +HEAPF32[$0>>2];
 $2 = (($this) + 240|0);
 __ZmlfRK6b2Vec2($P,$1,$2);
 __ZmlfRK6b2Vec2($agg$result,$inv_dt,$P);
 STACKTOP = sp;return;
}
function __ZNK11b2GearJoint17GetReactionTorqueEf($this,$inv_dt) {
 $this = $this|0;
 $inv_dt = +$inv_dt;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0.0, $4 = 0.0, $5 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = +HEAPF32[$0>>2];
 $2 = (($this) + 256|0);
 $3 = +HEAPF32[$2>>2];
 $4 = $1 * $3;
 $5 = $4 * $inv_dt;
 STACKTOP = sp;return (+$5);
}
function __ZNK11b2GearJoint8GetRatioEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 152|0);
 $1 = +HEAPF32[$0>>2];
 STACKTOP = sp;return (+$1);
}
function __ZN11b2GearJoint4DumpEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer18 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer18 = sp;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 68|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + 56|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 72|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 56|0);
 $15 = HEAP32[$14>>2]|0;
 __Z5b2LogPKcz(4336,$vararg_buffer18);
 HEAP32[$vararg_buffer18>>2] = $3;
 __Z5b2LogPKcz(4360,$vararg_buffer18);
 HEAP32[$vararg_buffer18>>2] = $7;
 __Z5b2LogPKcz(4392,$vararg_buffer18);
 $16 = (($this) + 61|0);
 $17 = HEAP8[$16>>0]|0;
 $18 = $17&255;
 HEAP32[$vararg_buffer18>>2] = $18;
 __Z5b2LogPKcz(4424,$vararg_buffer18);
 HEAP32[$vararg_buffer18>>2] = $11;
 __Z5b2LogPKcz(4464,$vararg_buffer18);
 HEAP32[$vararg_buffer18>>2] = $15;
 __Z5b2LogPKcz(4496,$vararg_buffer18);
 $19 = (($this) + 152|0);
 $20 = +HEAPF32[$19>>2];
 $21 = $20;
 HEAPF64[tempDoublePtr>>3]=$21;HEAP32[$vararg_buffer18>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer18+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(4528,$vararg_buffer18);
 $22 = (($this) + 56|0);
 $23 = HEAP32[$22>>2]|0;
 HEAP32[$vararg_buffer18>>2] = $23;
 __Z5b2LogPKcz(4552,$vararg_buffer18);
 STACKTOP = sp;return;
}
function __ZN11b2GearJointD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK7b2Joint7GetTypeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN19b2PrismaticJointDef10InitializeEP6b2BodyS1_RK6b2Vec2S4_($this,$bA,$bB,$anchor,$axis) {
 $this = $this|0;
 $bA = $bA|0;
 $bB = $bB|0;
 $anchor = $anchor|0;
 $axis = $axis|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0.0;
 var $45 = 0.0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $bA;
 $4 = (($this) + 12|0);
 HEAP32[$4>>2] = $bB;
 $5 = (($this) + 20|0);
 $6 = HEAP32[$3>>2]|0;
 __ZNK6b2Body13GetLocalPointERK6b2Vec2($0,$6,$anchor);
 $7 = $0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 4)|0;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = $5;
 $14 = $13;
 HEAP32[$14>>2] = $9;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = $12;
 $17 = (($this) + 28|0);
 $18 = HEAP32[$4>>2]|0;
 __ZNK6b2Body13GetLocalPointERK6b2Vec2($1,$18,$anchor);
 $19 = $1;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) + 4)|0;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 $25 = $17;
 $26 = $25;
 HEAP32[$26>>2] = $21;
 $27 = (($25) + 4)|0;
 $28 = $27;
 HEAP32[$28>>2] = $24;
 $29 = (($this) + 36|0);
 $30 = HEAP32[$3>>2]|0;
 __ZNK6b2Body14GetLocalVectorERK6b2Vec2($2,$30,$axis);
 $31 = $2;
 $32 = $31;
 $33 = HEAP32[$32>>2]|0;
 $34 = (($31) + 4)|0;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = $29;
 $38 = $37;
 HEAP32[$38>>2] = $33;
 $39 = (($37) + 4)|0;
 $40 = $39;
 HEAP32[$40>>2] = $36;
 $41 = HEAP32[$4>>2]|0;
 $42 = (+__ZNK6b2Body8GetAngleEv($41));
 $43 = HEAP32[$3>>2]|0;
 $44 = (+__ZNK6b2Body8GetAngleEv($43));
 $45 = $42 - $44;
 $46 = (($this) + 44|0);
 HEAPF32[$46>>2] = $45;
 STACKTOP = sp;return;
}
function __ZN16b2PrismaticJointC2EPK19b2PrismaticJointDef($this,$def) {
 $this = $this|0;
 $def = $def|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0;
 var $63 = 0.0, $64 = 0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN7b2JointC2EPK10b2JointDef($this,$def);
 HEAP32[$this>>2] = ((4632 + 8|0));
 $1 = (($this) + 68|0);
 $2 = (($this) + 76|0);
 $3 = (($this) + 84|0);
 $4 = (($this) + 92|0);
 $5 = (($this) + 104|0);
 $6 = (($this) + 184|0);
 $7 = (($this) + 192|0);
 $8 = (($def) + 20|0);
 $9 = $8;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = $1;
 $16 = $15;
 HEAP32[$16>>2] = $11;
 $17 = (($15) + 4)|0;
 $18 = $17;
 HEAP32[$18>>2] = $14;
 $19 = (($def) + 28|0);
 $20 = $19;
 $21 = $20;
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20) + 4)|0;
 $24 = $23;
 $25 = HEAP32[$24>>2]|0;
 $26 = $2;
 $27 = $26;
 HEAP32[$27>>2] = $22;
 $28 = (($26) + 4)|0;
 $29 = $28;
 HEAP32[$29>>2] = $25;
 $30 = (($def) + 36|0);
 $31 = $30;
 $32 = $31;
 $33 = HEAP32[$32>>2]|0;
 $34 = (($31) + 4)|0;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = $3;
 $38 = $37;
 HEAP32[$38>>2] = $33;
 $39 = (($37) + 4)|0;
 $40 = $39;
 HEAP32[$40>>2] = $36;
 (+__ZN6b2Vec29NormalizeEv($3));
 __Z7b2CrossfRK6b2Vec2($0,1.0,$3);
 $41 = $0;
 $42 = $41;
 $43 = HEAP32[$42>>2]|0;
 $44 = (($41) + 4)|0;
 $45 = $44;
 $46 = HEAP32[$45>>2]|0;
 $47 = $4;
 $48 = $47;
 HEAP32[$48>>2] = $43;
 $49 = (($47) + 4)|0;
 $50 = $49;
 HEAP32[$50>>2] = $46;
 $51 = (($def) + 44|0);
 $52 = +HEAPF32[$51>>2];
 $53 = (($this) + 100|0);
 HEAPF32[$53>>2] = $52;
 __ZN6b2Vec37SetZeroEv($5);
 $54 = (($this) + 252|0);
 HEAPF32[$54>>2] = 0.0;
 $55 = (($this) + 116|0);
 HEAPF32[$55>>2] = 0.0;
 $56 = (($def) + 52|0);
 $57 = +HEAPF32[$56>>2];
 $58 = (($this) + 120|0);
 HEAPF32[$58>>2] = $57;
 $59 = (($def) + 56|0);
 $60 = +HEAPF32[$59>>2];
 $61 = (($this) + 124|0);
 HEAPF32[$61>>2] = $60;
 $62 = (($def) + 64|0);
 $63 = +HEAPF32[$62>>2];
 $64 = (($this) + 128|0);
 HEAPF32[$64>>2] = $63;
 $65 = (($def) + 68|0);
 $66 = +HEAPF32[$65>>2];
 $67 = (($this) + 132|0);
 HEAPF32[$67>>2] = $66;
 $68 = (($def) + 48|0);
 $69 = HEAP8[$68>>0]|0;
 $70 = (($this) + 136|0);
 HEAP8[$70>>0] = $69;
 $71 = (($def) + 60|0);
 $72 = HEAP8[$71>>0]|0;
 $73 = (($this) + 137|0);
 HEAP8[$73>>0] = $72;
 $74 = (($this) + 140|0);
 HEAP32[$74>>2] = 0;
 __ZN6b2Vec27SetZeroEv($6);
 __ZN6b2Vec27SetZeroEv($7);
 STACKTOP = sp;return;
}
function __ZN16b2PrismaticJoint23InitVelocityConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0.0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0.0, $132 = 0, $133 = 0;
 var $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0.0, $151 = 0;
 var $152 = 0.0, $153 = 0, $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0.0, $161 = 0.0, $162 = 0, $163 = 0, $164 = 0.0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0.0, $178 = 0, $179 = 0.0, $18 = 0, $180 = 0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0.0, $186 = 0.0, $187 = 0.0, $188 = 0.0;
 var $189 = 0.0, $19 = 0, $190 = 0.0, $191 = 0.0, $192 = 0.0, $193 = 0.0, $194 = 0.0, $195 = 0, $196 = 0.0, $197 = 0.0, $198 = 0.0, $199 = 0.0, $2 = 0, $20 = 0, $200 = 0.0, $201 = 0.0, $202 = 0.0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0.0, $21 = 0, $210 = 0, $211 = 0.0, $212 = 0, $213 = 0.0, $214 = 0.0, $215 = 0.0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0.0, $241 = 0.0;
 var $242 = 0, $243 = 0.0, $244 = 0.0, $245 = 0.0, $246 = 0.0, $247 = 0, $248 = 0.0, $249 = 0.0, $25 = 0, $250 = 0.0, $251 = 0.0, $252 = 0.0, $253 = 0, $254 = 0.0, $255 = 0.0, $256 = 0.0, $257 = 0.0, $258 = 0.0, $259 = 0.0, $26 = 0;
 var $260 = 0.0, $261 = 0.0, $262 = 0.0, $263 = 0.0, $264 = 0.0, $265 = 0.0, $266 = 0.0, $267 = 0.0, $268 = 0.0, $269 = 0.0, $27 = 0, $270 = 0.0, $271 = 0.0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0, $58 = 0.0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0.0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0.0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0.0, $99 = 0, $P = 0, $cA = 0, $cB = 0, $d = 0, $k22$0 = 0.0, $qA = 0, $qB = 0, $rA = 0, $rB = 0, $storemerge = 0.0, $vA = 0, $vB = 0, $wA$0 = 0.0, $wB$0 = 0.0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $cA = sp + 40|0;
 $vA = sp + 32|0;
 $cB = sp + 24|0;
 $vB = sp + 16|0;
 $qA = sp + 168|0;
 $qB = sp + 160|0;
 $rA = sp + 152|0;
 $0 = sp + 144|0;
 $rB = sp + 136|0;
 $1 = sp + 128|0;
 $d = sp + 120|0;
 $2 = sp + 112|0;
 $3 = sp + 104|0;
 $4 = sp + 8|0;
 $5 = sp + 96|0;
 $6 = sp;
 $7 = sp + 88|0;
 $P = sp + 80|0;
 $8 = sp + 72|0;
 $9 = sp + 64|0;
 $10 = sp + 56|0;
 $11 = sp + 48|0;
 $12 = (($this) + 48|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 144|0);
 HEAP32[$16>>2] = $15;
 $17 = (($this) + 52|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($this) + 148|0);
 HEAP32[$21>>2] = $20;
 $22 = (($this) + 152|0);
 $23 = HEAP32[$12>>2]|0;
 $24 = (($23) + 44|0);
 $25 = $24;
 $26 = $25;
 $27 = HEAP32[$26>>2]|0;
 $28 = (($25) + 4)|0;
 $29 = $28;
 $30 = HEAP32[$29>>2]|0;
 $31 = $22;
 $32 = $31;
 HEAP32[$32>>2] = $27;
 $33 = (($31) + 4)|0;
 $34 = $33;
 HEAP32[$34>>2] = $30;
 $35 = (($this) + 160|0);
 $36 = HEAP32[$17>>2]|0;
 $37 = (($36) + 44|0);
 $38 = $37;
 $39 = $38;
 $40 = HEAP32[$39>>2]|0;
 $41 = (($38) + 4)|0;
 $42 = $41;
 $43 = HEAP32[$42>>2]|0;
 $44 = $35;
 $45 = $44;
 HEAP32[$45>>2] = $40;
 $46 = (($44) + 4)|0;
 $47 = $46;
 HEAP32[$47>>2] = $43;
 $48 = HEAP32[$12>>2]|0;
 $49 = (($48) + 136|0);
 $50 = +HEAPF32[$49>>2];
 $51 = (($this) + 168|0);
 HEAPF32[$51>>2] = $50;
 $52 = HEAP32[$17>>2]|0;
 $53 = (($52) + 136|0);
 $54 = +HEAPF32[$53>>2];
 $55 = (($this) + 172|0);
 HEAPF32[$55>>2] = $54;
 $56 = HEAP32[$12>>2]|0;
 $57 = (($56) + 144|0);
 $58 = +HEAPF32[$57>>2];
 $59 = (($this) + 176|0);
 HEAPF32[$59>>2] = $58;
 $60 = HEAP32[$17>>2]|0;
 $61 = (($60) + 144|0);
 $62 = +HEAPF32[$61>>2];
 $63 = (($this) + 180|0);
 HEAPF32[$63>>2] = $62;
 $64 = HEAP32[$16>>2]|0;
 $65 = (($data) + 28|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) + (($64*12)|0)|0);
 $68 = $67;
 $69 = $68;
 $70 = HEAP32[$69>>2]|0;
 $71 = (($68) + 4)|0;
 $72 = $71;
 $73 = HEAP32[$72>>2]|0;
 $74 = $cA;
 $75 = $74;
 HEAP32[$75>>2] = $70;
 $76 = (($74) + 4)|0;
 $77 = $76;
 HEAP32[$77>>2] = $73;
 $78 = HEAP32[$16>>2]|0;
 $79 = HEAP32[$65>>2]|0;
 $80 = ((($79) + (($78*12)|0)|0) + 8|0);
 $81 = +HEAPF32[$80>>2];
 $82 = (($data) + 32|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = (($83) + (($78*12)|0)|0);
 $85 = $84;
 $86 = $85;
 $87 = HEAP32[$86>>2]|0;
 $88 = (($85) + 4)|0;
 $89 = $88;
 $90 = HEAP32[$89>>2]|0;
 $91 = $vA;
 $92 = $91;
 HEAP32[$92>>2] = $87;
 $93 = (($91) + 4)|0;
 $94 = $93;
 HEAP32[$94>>2] = $90;
 $95 = HEAP32[$16>>2]|0;
 $96 = HEAP32[$82>>2]|0;
 $97 = ((($96) + (($95*12)|0)|0) + 8|0);
 $98 = +HEAPF32[$97>>2];
 $99 = HEAP32[$21>>2]|0;
 $100 = HEAP32[$65>>2]|0;
 $101 = (($100) + (($99*12)|0)|0);
 $102 = $101;
 $103 = $102;
 $104 = HEAP32[$103>>2]|0;
 $105 = (($102) + 4)|0;
 $106 = $105;
 $107 = HEAP32[$106>>2]|0;
 $108 = $cB;
 $109 = $108;
 HEAP32[$109>>2] = $104;
 $110 = (($108) + 4)|0;
 $111 = $110;
 HEAP32[$111>>2] = $107;
 $112 = HEAP32[$21>>2]|0;
 $113 = HEAP32[$65>>2]|0;
 $114 = ((($113) + (($112*12)|0)|0) + 8|0);
 $115 = +HEAPF32[$114>>2];
 $116 = HEAP32[$82>>2]|0;
 $117 = (($116) + (($112*12)|0)|0);
 $118 = $117;
 $119 = $118;
 $120 = HEAP32[$119>>2]|0;
 $121 = (($118) + 4)|0;
 $122 = $121;
 $123 = HEAP32[$122>>2]|0;
 $124 = $vB;
 $125 = $124;
 HEAP32[$125>>2] = $120;
 $126 = (($124) + 4)|0;
 $127 = $126;
 HEAP32[$127>>2] = $123;
 $128 = HEAP32[$21>>2]|0;
 $129 = HEAP32[$82>>2]|0;
 $130 = ((($129) + (($128*12)|0)|0) + 8|0);
 $131 = +HEAPF32[$130>>2];
 __ZN5b2RotC2Ef($qA,$81);
 __ZN5b2RotC2Ef($qB,$115);
 $132 = (($this) + 68|0);
 __ZmiRK6b2Vec2S1_($0,$132,$22);
 __Z5b2MulRK5b2RotRK6b2Vec2($rA,$qA,$0);
 $133 = (($this) + 76|0);
 __ZmiRK6b2Vec2S1_($1,$133,$35);
 __Z5b2MulRK5b2RotRK6b2Vec2($rB,$qB,$1);
 __ZmiRK6b2Vec2S1_($3,$cB,$cA);
 __ZplRK6b2Vec2S1_($2,$3,$rB);
 __ZmiRK6b2Vec2S1_($d,$2,$rA);
 $134 = +HEAPF32[$51>>2];
 $135 = +HEAPF32[$55>>2];
 $136 = +HEAPF32[$59>>2];
 $137 = +HEAPF32[$63>>2];
 $138 = (($this) + 184|0);
 $139 = (($this) + 84|0);
 __Z5b2MulRK5b2RotRK6b2Vec2($4,$qA,$139);
 $140 = $4;
 $141 = $140;
 $142 = HEAP32[$141>>2]|0;
 $143 = (($140) + 4)|0;
 $144 = $143;
 $145 = HEAP32[$144>>2]|0;
 $146 = $138;
 $147 = $146;
 HEAP32[$147>>2] = $142;
 $148 = (($146) + 4)|0;
 $149 = $148;
 HEAP32[$149>>2] = $145;
 __ZplRK6b2Vec2S1_($5,$d,$rA);
 $150 = (+__Z7b2CrossRK6b2Vec2S1_($5,$138));
 $151 = (($this) + 208|0);
 HEAPF32[$151>>2] = $150;
 $152 = (+__Z7b2CrossRK6b2Vec2S1_($rB,$138));
 $153 = (($this) + 212|0);
 HEAPF32[$153>>2] = $152;
 $154 = $134 + $135;
 $155 = +HEAPF32[$151>>2];
 $156 = $136 * $155;
 $157 = $155 * $156;
 $158 = $154 + $157;
 $159 = $137 * $152;
 $160 = $152 * $159;
 $161 = $160 + $158;
 $162 = (($this) + 252|0);
 $163 = $161 > 0.0;
 if ($163) {
  $164 = 1.0 / $161;
  $storemerge = $164;
 } else {
  $storemerge = $161;
 }
 HEAPF32[$162>>2] = $storemerge;
 $165 = (($this) + 192|0);
 $166 = (($this) + 92|0);
 __Z5b2MulRK5b2RotRK6b2Vec2($6,$qA,$166);
 $167 = $6;
 $168 = $167;
 $169 = HEAP32[$168>>2]|0;
 $170 = (($167) + 4)|0;
 $171 = $170;
 $172 = HEAP32[$171>>2]|0;
 $173 = $165;
 $174 = $173;
 HEAP32[$174>>2] = $169;
 $175 = (($173) + 4)|0;
 $176 = $175;
 HEAP32[$176>>2] = $172;
 __ZplRK6b2Vec2S1_($7,$d,$rA);
 $177 = (+__Z7b2CrossRK6b2Vec2S1_($7,$165));
 $178 = (($this) + 200|0);
 HEAPF32[$178>>2] = $177;
 $179 = (+__Z7b2CrossRK6b2Vec2S1_($rB,$165));
 $180 = (($this) + 204|0);
 HEAPF32[$180>>2] = $179;
 $181 = +HEAPF32[$178>>2];
 $182 = $136 * $181;
 $183 = $181 * $182;
 $184 = $154 + $183;
 $185 = $137 * $179;
 $186 = $179 * $185;
 $187 = $186 + $184;
 $188 = $185 + $182;
 $189 = +HEAPF32[$151>>2];
 $190 = $182 * $189;
 $191 = +HEAPF32[$153>>2];
 $192 = $185 * $191;
 $193 = $190 + $192;
 $194 = $136 + $137;
 $195 = $194 == 0.0;
 $k22$0 = $195 ? 1.0 : $194;
 $196 = $136 * $189;
 $197 = $137 * $191;
 $198 = $196 + $197;
 $199 = $189 * $196;
 $200 = $154 + $199;
 $201 = $191 * $197;
 $202 = $200 + $201;
 $203 = (($this) + 216|0);
 __ZN6b2Vec33SetEfff($203,$187,$188,$193);
 $204 = (($this) + 228|0);
 __ZN6b2Vec33SetEfff($204,$188,$k22$0,$198);
 $205 = (($this) + 240|0);
 __ZN6b2Vec33SetEfff($205,$193,$198,$202);
 $206 = (($this) + 136|0);
 $207 = HEAP8[$206>>0]|0;
 $208 = ($207<<24>>24)==(0);
 do {
  if ($208) {
   $229 = (($this) + 140|0);
   HEAP32[$229>>2] = 0;
   $230 = (($this) + 112|0);
   HEAPF32[$230>>2] = 0.0;
  } else {
   $209 = (+__Z5b2DotRK6b2Vec2S1_($138,$d));
   $210 = (($this) + 124|0);
   $211 = +HEAPF32[$210>>2];
   $212 = (($this) + 120|0);
   $213 = +HEAPF32[$212>>2];
   $214 = $211 - $213;
   $215 = (+__Z5b2AbsIfET_S0_($214));
   $216 = $215 < 0.0099999997764825821;
   if ($216) {
    $217 = (($this) + 140|0);
    HEAP32[$217>>2] = 3;
    break;
   }
   $218 = !($209 <= $213);
   if (!($218)) {
    $219 = (($this) + 140|0);
    $220 = HEAP32[$219>>2]|0;
    $221 = ($220|0)==(1);
    if ($221) {
     break;
    }
    HEAP32[$219>>2] = 1;
    $222 = (($this) + 112|0);
    HEAPF32[$222>>2] = 0.0;
    break;
   }
   $223 = !($209 >= $211);
   $224 = (($this) + 140|0);
   if ($223) {
    HEAP32[$224>>2] = 0;
    $228 = (($this) + 112|0);
    HEAPF32[$228>>2] = 0.0;
    break;
   }
   $225 = HEAP32[$224>>2]|0;
   $226 = ($225|0)==(2);
   if (!($226)) {
    HEAP32[$224>>2] = 2;
    $227 = (($this) + 112|0);
    HEAPF32[$227>>2] = 0.0;
   }
  }
 } while(0);
 $231 = (($this) + 137|0);
 $232 = HEAP8[$231>>0]|0;
 $233 = ($232<<24>>24)==(0);
 if ($233) {
  $234 = (($this) + 116|0);
  HEAPF32[$234>>2] = 0.0;
 }
 $235 = (($data) + 24|0);
 $236 = HEAP8[$235>>0]|0;
 $237 = ($236<<24>>24)==(0);
 $238 = (($this) + 104|0);
 if ($237) {
  __ZN6b2Vec37SetZeroEv($238);
  $272 = (($this) + 116|0);
  HEAPF32[$272>>2] = 0.0;
  $wA$0 = $98;$wB$0 = $131;
  $273 = HEAP32[$16>>2]|0;
  $274 = HEAP32[$82>>2]|0;
  $275 = (($274) + (($273*12)|0)|0);
  $276 = $vA;
  $277 = $276;
  $278 = HEAP32[$277>>2]|0;
  $279 = (($276) + 4)|0;
  $280 = $279;
  $281 = HEAP32[$280>>2]|0;
  $282 = $275;
  $283 = $282;
  HEAP32[$283>>2] = $278;
  $284 = (($282) + 4)|0;
  $285 = $284;
  HEAP32[$285>>2] = $281;
  $286 = HEAP32[$16>>2]|0;
  $287 = HEAP32[$82>>2]|0;
  $288 = ((($287) + (($286*12)|0)|0) + 8|0);
  HEAPF32[$288>>2] = $wA$0;
  $289 = HEAP32[$21>>2]|0;
  $290 = HEAP32[$82>>2]|0;
  $291 = (($290) + (($289*12)|0)|0);
  $292 = $vB;
  $293 = $292;
  $294 = HEAP32[$293>>2]|0;
  $295 = (($292) + 4)|0;
  $296 = $295;
  $297 = HEAP32[$296>>2]|0;
  $298 = $291;
  $299 = $298;
  HEAP32[$299>>2] = $294;
  $300 = (($298) + 4)|0;
  $301 = $300;
  HEAP32[$301>>2] = $297;
  $302 = HEAP32[$21>>2]|0;
  $303 = HEAP32[$82>>2]|0;
  $304 = ((($303) + (($302*12)|0)|0) + 8|0);
  HEAPF32[$304>>2] = $wB$0;
  STACKTOP = sp;return;
 } else {
  $239 = (($data) + 8|0);
  $240 = +HEAPF32[$239>>2];
  __ZN6b2Vec3mLEf($238,$240);
  $241 = +HEAPF32[$239>>2];
  $242 = (($this) + 116|0);
  $243 = +HEAPF32[$242>>2];
  $244 = $241 * $243;
  HEAPF32[$242>>2] = $244;
  $245 = +HEAPF32[$238>>2];
  __ZmlfRK6b2Vec2($8,$245,$165);
  $246 = +HEAPF32[$242>>2];
  $247 = (($this) + 112|0);
  $248 = +HEAPF32[$247>>2];
  $249 = $246 + $248;
  __ZmlfRK6b2Vec2($9,$249,$138);
  __ZplRK6b2Vec2S1_($P,$8,$9);
  $250 = +HEAPF32[$238>>2];
  $251 = +HEAPF32[$178>>2];
  $252 = $250 * $251;
  $253 = (($this) + 108|0);
  $254 = +HEAPF32[$253>>2];
  $255 = $252 + $254;
  $256 = +HEAPF32[$242>>2];
  $257 = +HEAPF32[$247>>2];
  $258 = $256 + $257;
  $259 = +HEAPF32[$151>>2];
  $260 = $258 * $259;
  $261 = $255 + $260;
  $262 = +HEAPF32[$180>>2];
  $263 = $250 * $262;
  $264 = $254 + $263;
  $265 = +HEAPF32[$153>>2];
  $266 = $258 * $265;
  $267 = $264 + $266;
  __ZmlfRK6b2Vec2($10,$134,$P);
  __ZN6b2Vec2mIERKS_($vA,$10);
  $268 = $136 * $261;
  $269 = $98 - $268;
  __ZmlfRK6b2Vec2($11,$135,$P);
  __ZN6b2Vec2pLERKS_($vB,$11);
  $270 = $137 * $267;
  $271 = $131 + $270;
  $wA$0 = $269;$wB$0 = $271;
  $273 = HEAP32[$16>>2]|0;
  $274 = HEAP32[$82>>2]|0;
  $275 = (($274) + (($273*12)|0)|0);
  $276 = $vA;
  $277 = $276;
  $278 = HEAP32[$277>>2]|0;
  $279 = (($276) + 4)|0;
  $280 = $279;
  $281 = HEAP32[$280>>2]|0;
  $282 = $275;
  $283 = $282;
  HEAP32[$283>>2] = $278;
  $284 = (($282) + 4)|0;
  $285 = $284;
  HEAP32[$285>>2] = $281;
  $286 = HEAP32[$16>>2]|0;
  $287 = HEAP32[$82>>2]|0;
  $288 = ((($287) + (($286*12)|0)|0) + 8|0);
  HEAPF32[$288>>2] = $wA$0;
  $289 = HEAP32[$21>>2]|0;
  $290 = HEAP32[$82>>2]|0;
  $291 = (($290) + (($289*12)|0)|0);
  $292 = $vB;
  $293 = $292;
  $294 = HEAP32[$293>>2]|0;
  $295 = (($292) + 4)|0;
  $296 = $295;
  $297 = HEAP32[$296>>2]|0;
  $298 = $291;
  $299 = $298;
  HEAP32[$299>>2] = $294;
  $300 = (($298) + 4)|0;
  $301 = $300;
  HEAP32[$301>>2] = $297;
  $302 = HEAP32[$21>>2]|0;
  $303 = HEAP32[$82>>2]|0;
  $304 = ((($303) + (($302*12)|0)|0) + 8|0);
  HEAPF32[$304>>2] = $wB$0;
  STACKTOP = sp;return;
 }
}
function __ZN16b2PrismaticJoint24SolveVelocityConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$pn = 0.0, $$pn2 = 0.0, $$pn3 = 0.0, $$pn4 = 0.0, $0 = 0, $1 = 0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0, $104 = 0.0, $105 = 0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0, $11 = 0, $110 = 0.0, $111 = 0.0;
 var $112 = 0.0, $113 = 0.0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0.0, $123 = 0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0, $128 = 0.0, $129 = 0.0, $13 = 0;
 var $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0.0, $138 = 0.0, $139 = 0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0, $143 = 0.0, $144 = 0, $145 = 0.0, $146 = 0.0, $147 = 0, $148 = 0.0;
 var $149 = 0, $15 = 0, $150 = 0.0, $151 = 0.0, $152 = 0, $153 = 0.0, $154 = 0.0, $155 = 0, $156 = 0.0, $157 = 0, $158 = 0.0, $159 = 0, $16 = 0, $160 = 0.0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0, $165 = 0.0, $166 = 0.0;
 var $167 = 0.0, $168 = 0.0, $169 = 0.0, $17 = 0, $170 = 0.0, $171 = 0.0, $172 = 0.0, $173 = 0.0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0, $178 = 0.0, $179 = 0, $18 = 0, $180 = 0.0, $181 = 0.0, $182 = 0, $183 = 0.0, $184 = 0;
 var $185 = 0.0, $186 = 0.0, $187 = 0.0, $188 = 0.0, $189 = 0.0, $19 = 0, $190 = 0.0, $191 = 0.0, $192 = 0.0, $193 = 0.0, $194 = 0.0, $195 = 0.0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0;
 var $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0.0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0.0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0.0, $71 = 0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0, $86 = 0.0, $87 = 0.0, $88 = 0;
 var $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0, $Cdot1 = 0, $Cdot3 = 0, $P = 0, $P4 = 0, $P8 = 0, $b = 0, $df = 0, $df7 = 0;
 var $f1 = 0, $f2r = 0, $vA = 0, $vB = 0, $wA$0 = 0.0, $wA$1 = 0.0, $wB$0 = 0.0, $wB$1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $vA = sp + 8|0;
 $vB = sp;
 $0 = sp + 264|0;
 $P = sp + 256|0;
 $1 = sp + 248|0;
 $2 = sp + 240|0;
 $Cdot1 = sp + 232|0;
 $3 = sp + 224|0;
 $4 = sp + 216|0;
 $Cdot3 = sp + 204|0;
 $f1 = sp + 192|0;
 $df = sp + 180|0;
 $5 = sp + 168|0;
 $b = sp + 160|0;
 $6 = sp + 152|0;
 $7 = sp + 144|0;
 $8 = sp + 136|0;
 $f2r = sp + 128|0;
 $9 = sp + 120|0;
 $10 = sp + 112|0;
 $11 = sp + 96|0;
 $P4 = sp + 88|0;
 $12 = sp + 80|0;
 $13 = sp + 72|0;
 $14 = sp + 64|0;
 $15 = sp + 56|0;
 $df7 = sp + 48|0;
 $16 = sp + 40|0;
 $P8 = sp + 32|0;
 $17 = sp + 24|0;
 $18 = sp + 16|0;
 $19 = (($this) + 144|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($data) + 32|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + (($20*12)|0)|0);
 $24 = $23;
 $25 = $24;
 $26 = HEAP32[$25>>2]|0;
 $27 = (($24) + 4)|0;
 $28 = $27;
 $29 = HEAP32[$28>>2]|0;
 $30 = $vA;
 $31 = $30;
 HEAP32[$31>>2] = $26;
 $32 = (($30) + 4)|0;
 $33 = $32;
 HEAP32[$33>>2] = $29;
 $34 = HEAP32[$19>>2]|0;
 $35 = HEAP32[$21>>2]|0;
 $36 = ((($35) + (($34*12)|0)|0) + 8|0);
 $37 = +HEAPF32[$36>>2];
 $38 = (($this) + 148|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (($35) + (($39*12)|0)|0);
 $41 = $40;
 $42 = $41;
 $43 = HEAP32[$42>>2]|0;
 $44 = (($41) + 4)|0;
 $45 = $44;
 $46 = HEAP32[$45>>2]|0;
 $47 = $vB;
 $48 = $47;
 HEAP32[$48>>2] = $43;
 $49 = (($47) + 4)|0;
 $50 = $49;
 HEAP32[$50>>2] = $46;
 $51 = HEAP32[$38>>2]|0;
 $52 = HEAP32[$21>>2]|0;
 $53 = ((($52) + (($51*12)|0)|0) + 8|0);
 $54 = +HEAPF32[$53>>2];
 $55 = (($this) + 168|0);
 $56 = +HEAPF32[$55>>2];
 $57 = (($this) + 172|0);
 $58 = +HEAPF32[$57>>2];
 $59 = (($this) + 176|0);
 $60 = +HEAPF32[$59>>2];
 $61 = (($this) + 180|0);
 $62 = +HEAPF32[$61>>2];
 $63 = (($this) + 137|0);
 $64 = HEAP8[$63>>0]|0;
 $65 = ($64<<24>>24)==(0);
 if ($65) {
  $wA$0 = $37;$wB$0 = $54;
 } else {
  $66 = (($this) + 140|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = ($67|0)==(3);
  if ($68) {
   $wA$0 = $37;$wB$0 = $54;
  } else {
   $69 = (($this) + 184|0);
   __ZmiRK6b2Vec2S1_($0,$vB,$vA);
   $70 = (+__Z5b2DotRK6b2Vec2S1_($69,$0));
   $71 = (($this) + 212|0);
   $72 = +HEAPF32[$71>>2];
   $73 = $54 * $72;
   $74 = $70 + $73;
   $75 = (($this) + 208|0);
   $76 = +HEAPF32[$75>>2];
   $77 = $37 * $76;
   $78 = $74 - $77;
   $79 = (($this) + 252|0);
   $80 = +HEAPF32[$79>>2];
   $81 = (($this) + 132|0);
   $82 = +HEAPF32[$81>>2];
   $83 = $82 - $78;
   $84 = $80 * $83;
   $85 = (($this) + 116|0);
   $86 = +HEAPF32[$85>>2];
   $87 = +HEAPF32[$data>>2];
   $88 = (($this) + 128|0);
   $89 = +HEAPF32[$88>>2];
   $90 = $87 * $89;
   $91 = $86 + $84;
   $92 = -$90;
   $93 = (+__Z7b2ClampIfET_S0_S0_S0_($91,$92,$90));
   HEAPF32[$85>>2] = $93;
   $94 = $93 - $86;
   __ZmlfRK6b2Vec2($P,$94,$69);
   $95 = +HEAPF32[$75>>2];
   $96 = $94 * $95;
   $97 = +HEAPF32[$71>>2];
   $98 = $94 * $97;
   __ZmlfRK6b2Vec2($1,$56,$P);
   __ZN6b2Vec2mIERKS_($vA,$1);
   $99 = $60 * $96;
   $100 = $37 - $99;
   __ZmlfRK6b2Vec2($2,$58,$P);
   __ZN6b2Vec2pLERKS_($vB,$2);
   $101 = $62 * $98;
   $102 = $54 + $101;
   $wA$0 = $100;$wB$0 = $102;
  }
 }
 $103 = (($this) + 192|0);
 __ZmiRK6b2Vec2S1_($3,$vB,$vA);
 $104 = (+__Z5b2DotRK6b2Vec2S1_($103,$3));
 $105 = (($this) + 204|0);
 $106 = +HEAPF32[$105>>2];
 $107 = $wB$0 * $106;
 $108 = $104 + $107;
 $109 = (($this) + 200|0);
 $110 = +HEAPF32[$109>>2];
 $111 = $wA$0 * $110;
 $112 = $108 - $111;
 HEAPF32[$Cdot1>>2] = $112;
 $113 = $wB$0 - $wA$0;
 $114 = (($Cdot1) + 4|0);
 HEAPF32[$114>>2] = $113;
 $115 = (($this) + 136|0);
 $116 = HEAP8[$115>>0]|0;
 $117 = ($116<<24>>24)==(0);
 if (!($117)) {
  $118 = (($this) + 140|0);
  $119 = HEAP32[$118>>2]|0;
  $120 = ($119|0)==(0);
  if (!($120)) {
   $121 = (($this) + 184|0);
   __ZmiRK6b2Vec2S1_($4,$vB,$vA);
   $122 = (+__Z5b2DotRK6b2Vec2S1_($121,$4));
   $123 = (($this) + 212|0);
   $124 = +HEAPF32[$123>>2];
   $125 = $wB$0 * $124;
   $126 = $122 + $125;
   $127 = (($this) + 208|0);
   $128 = +HEAPF32[$127>>2];
   $129 = $wA$0 * $128;
   $130 = $126 - $129;
   $131 = +HEAPF32[$Cdot1>>2];
   $132 = +HEAPF32[$114>>2];
   __ZN6b2Vec3C2Efff($Cdot3,$131,$132,$130);
   $133 = (($this) + 104|0);
   ;HEAP32[$f1+0>>2]=HEAP32[$133+0>>2]|0;HEAP32[$f1+4>>2]=HEAP32[$133+4>>2]|0;HEAP32[$f1+8>>2]=HEAP32[$133+8>>2]|0;
   $134 = (($this) + 216|0);
   __ZNK6b2Vec3ngEv($5,$Cdot3);
   __ZNK7b2Mat337Solve33ERK6b2Vec3($df,$134,$5);
   __ZN6b2Vec3pLERKS_($133,$df);
   $135 = HEAP32[$118>>2]|0;
   if ((($135|0) == 2)) {
    $139 = (($this) + 112|0);
    $140 = +HEAPF32[$139>>2];
    $141 = (+__Z5b2MinIfET_S0_S0_($140,0.0));
    HEAPF32[$139>>2] = $141;
   } else if ((($135|0) == 1)) {
    $136 = (($this) + 112|0);
    $137 = +HEAPF32[$136>>2];
    $138 = (+__Z5b2MaxIfET_S0_S0_($137,0.0));
    HEAPF32[$136>>2] = $138;
   }
   __ZNK6b2Vec2ngEv($6,$Cdot1);
   $142 = (($this) + 112|0);
   $143 = +HEAPF32[$142>>2];
   $144 = (($f1) + 8|0);
   $145 = +HEAPF32[$144>>2];
   $146 = $143 - $145;
   $147 = (($this) + 240|0);
   $148 = +HEAPF32[$147>>2];
   $149 = (($this) + 244|0);
   $150 = +HEAPF32[$149>>2];
   __ZN6b2Vec2C2Eff($8,$148,$150);
   __ZmlfRK6b2Vec2($7,$146,$8);
   __ZmiRK6b2Vec2S1_($b,$6,$7);
   __ZNK7b2Mat337Solve22ERK6b2Vec2($9,$134,$b);
   $151 = +HEAPF32[$f1>>2];
   $152 = (($f1) + 4|0);
   $153 = +HEAPF32[$152>>2];
   __ZN6b2Vec2C2Eff($10,$151,$153);
   __ZplRK6b2Vec2S1_($f2r,$9,$10);
   $154 = +HEAPF32[$f2r>>2];
   HEAPF32[$133>>2] = $154;
   $155 = (($f2r) + 4|0);
   $156 = +HEAPF32[$155>>2];
   $157 = (($this) + 108|0);
   HEAPF32[$157>>2] = $156;
   __ZmiRK6b2Vec3S1_($11,$133,$f1);
   ;HEAP32[$df+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$df+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$df+8>>2]=HEAP32[$11+8>>2]|0;
   $158 = +HEAPF32[$df>>2];
   __ZmlfRK6b2Vec2($12,$158,$103);
   $159 = (($df) + 8|0);
   $160 = +HEAPF32[$159>>2];
   __ZmlfRK6b2Vec2($13,$160,$121);
   __ZplRK6b2Vec2S1_($P4,$12,$13);
   $161 = +HEAPF32[$df>>2];
   $162 = +HEAPF32[$109>>2];
   $163 = $161 * $162;
   $164 = (($df) + 4|0);
   $165 = +HEAPF32[$164>>2];
   $166 = $163 + $165;
   $167 = +HEAPF32[$159>>2];
   $168 = +HEAPF32[$127>>2];
   $169 = $167 * $168;
   $170 = $166 + $169;
   $171 = +HEAPF32[$105>>2];
   $172 = $161 * $171;
   $173 = $165 + $172;
   $174 = +HEAPF32[$123>>2];
   $175 = $167 * $174;
   $176 = $173 + $175;
   __ZmlfRK6b2Vec2($14,$56,$P4);
   __ZN6b2Vec2mIERKS_($vA,$14);
   __ZmlfRK6b2Vec2($15,$58,$P4);
   __ZN6b2Vec2pLERKS_($vB,$15);
   $$pn3 = $176;$$pn4 = $170;
   $$pn2 = $60 * $$pn4;
   $$pn = $62 * $$pn3;
   $wA$1 = $wA$0 - $$pn2;
   $wB$1 = $wB$0 + $$pn;
   $196 = HEAP32[$19>>2]|0;
   $197 = HEAP32[$21>>2]|0;
   $198 = (($197) + (($196*12)|0)|0);
   $199 = $vA;
   $200 = $199;
   $201 = HEAP32[$200>>2]|0;
   $202 = (($199) + 4)|0;
   $203 = $202;
   $204 = HEAP32[$203>>2]|0;
   $205 = $198;
   $206 = $205;
   HEAP32[$206>>2] = $201;
   $207 = (($205) + 4)|0;
   $208 = $207;
   HEAP32[$208>>2] = $204;
   $209 = HEAP32[$19>>2]|0;
   $210 = HEAP32[$21>>2]|0;
   $211 = ((($210) + (($209*12)|0)|0) + 8|0);
   HEAPF32[$211>>2] = $wA$1;
   $212 = HEAP32[$38>>2]|0;
   $213 = HEAP32[$21>>2]|0;
   $214 = (($213) + (($212*12)|0)|0);
   $215 = $vB;
   $216 = $215;
   $217 = HEAP32[$216>>2]|0;
   $218 = (($215) + 4)|0;
   $219 = $218;
   $220 = HEAP32[$219>>2]|0;
   $221 = $214;
   $222 = $221;
   HEAP32[$222>>2] = $217;
   $223 = (($221) + 4)|0;
   $224 = $223;
   HEAP32[$224>>2] = $220;
   $225 = HEAP32[$38>>2]|0;
   $226 = HEAP32[$21>>2]|0;
   $227 = ((($226) + (($225*12)|0)|0) + 8|0);
   HEAPF32[$227>>2] = $wB$1;
   STACKTOP = sp;return;
  }
 }
 $177 = (($this) + 216|0);
 __ZNK6b2Vec2ngEv($16,$Cdot1);
 __ZNK7b2Mat337Solve22ERK6b2Vec2($df7,$177,$16);
 $178 = +HEAPF32[$df7>>2];
 $179 = (($this) + 104|0);
 $180 = +HEAPF32[$179>>2];
 $181 = $178 + $180;
 HEAPF32[$179>>2] = $181;
 $182 = (($df7) + 4|0);
 $183 = +HEAPF32[$182>>2];
 $184 = (($this) + 108|0);
 $185 = +HEAPF32[$184>>2];
 $186 = $183 + $185;
 HEAPF32[$184>>2] = $186;
 $187 = +HEAPF32[$df7>>2];
 __ZmlfRK6b2Vec2($P8,$187,$103);
 $188 = +HEAPF32[$df7>>2];
 $189 = +HEAPF32[$109>>2];
 $190 = $188 * $189;
 $191 = +HEAPF32[$182>>2];
 $192 = $190 + $191;
 $193 = +HEAPF32[$105>>2];
 $194 = $188 * $193;
 $195 = $191 + $194;
 __ZmlfRK6b2Vec2($17,$56,$P8);
 __ZN6b2Vec2mIERKS_($vA,$17);
 __ZmlfRK6b2Vec2($18,$58,$P8);
 __ZN6b2Vec2pLERKS_($vB,$18);
 $$pn3 = $195;$$pn4 = $192;
 $$pn2 = $60 * $$pn4;
 $$pn = $62 * $$pn3;
 $wA$1 = $wA$0 - $$pn2;
 $wB$1 = $wB$0 + $$pn;
 $196 = HEAP32[$19>>2]|0;
 $197 = HEAP32[$21>>2]|0;
 $198 = (($197) + (($196*12)|0)|0);
 $199 = $vA;
 $200 = $199;
 $201 = HEAP32[$200>>2]|0;
 $202 = (($199) + 4)|0;
 $203 = $202;
 $204 = HEAP32[$203>>2]|0;
 $205 = $198;
 $206 = $205;
 HEAP32[$206>>2] = $201;
 $207 = (($205) + 4)|0;
 $208 = $207;
 HEAP32[$208>>2] = $204;
 $209 = HEAP32[$19>>2]|0;
 $210 = HEAP32[$21>>2]|0;
 $211 = ((($210) + (($209*12)|0)|0) + 8|0);
 HEAPF32[$211>>2] = $wA$1;
 $212 = HEAP32[$38>>2]|0;
 $213 = HEAP32[$21>>2]|0;
 $214 = (($213) + (($212*12)|0)|0);
 $215 = $vB;
 $216 = $215;
 $217 = HEAP32[$216>>2]|0;
 $218 = (($215) + 4)|0;
 $219 = $218;
 $220 = HEAP32[$219>>2]|0;
 $221 = $214;
 $222 = $221;
 HEAP32[$222>>2] = $217;
 $223 = (($221) + 4)|0;
 $224 = $223;
 HEAP32[$224>>2] = $220;
 $225 = HEAP32[$38>>2]|0;
 $226 = HEAP32[$21>>2]|0;
 $227 = ((($226) + (($225*12)|0)|0) + 8|0);
 HEAPF32[$227>>2] = $wB$1;
 STACKTOP = sp;return;
}
function __ZN16b2PrismaticJoint24SolvePositionConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0, $114 = 0.0, $115 = 0.0;
 var $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0, $123 = 0.0, $124 = 0.0, $125 = 0, $126 = 0, $127 = 0.0, $128 = 0, $129 = 0.0, $13 = 0, $130 = 0, $131 = 0.0, $132 = 0.0, $133 = 0;
 var $134 = 0, $135 = 0.0, $136 = 0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0.0, $15 = 0, $150 = 0.0, $151 = 0.0;
 var $152 = 0.0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0.0, $55 = 0;
 var $56 = 0.0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0.0, $63 = 0.0, $64 = 0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0, $73 = 0.0;
 var $74 = 0.0, $75 = 0.0, $76 = 0, $77 = 0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0, $81 = 0.0, $82 = 0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0, $91 = 0.0;
 var $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0, $97 = 0.0, $98 = 0.0, $99 = 0.0, $C = 0, $C1 = 0, $C2$0 = 0.0, $K = 0, $K4 = 0, $P = 0, $active$0$off0 = 0, $axis = 0, $cA = 0, $cB = 0, $d = 0, $impulse1 = 0;
 var $k22$0 = 0.0, $k223$0 = 0.0, $linearError$0 = 0.0, $perp = 0, $qA = 0, $qB = 0, $rA = 0, $rB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $cA = sp + 8|0;
 $cB = sp;
 $qA = sp + 264|0;
 $qB = sp + 256|0;
 $rA = sp + 248|0;
 $0 = sp + 240|0;
 $rB = sp + 232|0;
 $1 = sp + 224|0;
 $d = sp + 216|0;
 $2 = sp + 208|0;
 $3 = sp + 200|0;
 $axis = sp + 192|0;
 $4 = sp + 184|0;
 $perp = sp + 176|0;
 $5 = sp + 168|0;
 $C1 = sp + 160|0;
 $K = sp + 124|0;
 $C = sp + 112|0;
 $6 = sp + 100|0;
 $7 = sp + 88|0;
 $K4 = sp + 72|0;
 $impulse1 = sp + 64|0;
 $8 = sp + 56|0;
 $P = sp + 48|0;
 $9 = sp + 40|0;
 $10 = sp + 32|0;
 $11 = sp + 24|0;
 $12 = sp + 16|0;
 $13 = (($this) + 144|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($data) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + (($14*12)|0)|0);
 $18 = $17;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + 4)|0;
 $22 = $21;
 $23 = HEAP32[$22>>2]|0;
 $24 = $cA;
 $25 = $24;
 HEAP32[$25>>2] = $20;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = $23;
 $28 = HEAP32[$13>>2]|0;
 $29 = HEAP32[$15>>2]|0;
 $30 = ((($29) + (($28*12)|0)|0) + 8|0);
 $31 = +HEAPF32[$30>>2];
 $32 = (($this) + 148|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (($29) + (($33*12)|0)|0);
 $35 = $34;
 $36 = $35;
 $37 = HEAP32[$36>>2]|0;
 $38 = (($35) + 4)|0;
 $39 = $38;
 $40 = HEAP32[$39>>2]|0;
 $41 = $cB;
 $42 = $41;
 HEAP32[$42>>2] = $37;
 $43 = (($41) + 4)|0;
 $44 = $43;
 HEAP32[$44>>2] = $40;
 $45 = HEAP32[$32>>2]|0;
 $46 = HEAP32[$15>>2]|0;
 $47 = ((($46) + (($45*12)|0)|0) + 8|0);
 $48 = +HEAPF32[$47>>2];
 __ZN5b2RotC2Ef($qA,$31);
 __ZN5b2RotC2Ef($qB,$48);
 $49 = (($this) + 168|0);
 $50 = +HEAPF32[$49>>2];
 $51 = (($this) + 172|0);
 $52 = +HEAPF32[$51>>2];
 $53 = (($this) + 176|0);
 $54 = +HEAPF32[$53>>2];
 $55 = (($this) + 180|0);
 $56 = +HEAPF32[$55>>2];
 $57 = (($this) + 68|0);
 $58 = (($this) + 152|0);
 __ZmiRK6b2Vec2S1_($0,$57,$58);
 __Z5b2MulRK5b2RotRK6b2Vec2($rA,$qA,$0);
 $59 = (($this) + 76|0);
 $60 = (($this) + 160|0);
 __ZmiRK6b2Vec2S1_($1,$59,$60);
 __Z5b2MulRK5b2RotRK6b2Vec2($rB,$qB,$1);
 __ZplRK6b2Vec2S1_($3,$cB,$rB);
 __ZmiRK6b2Vec2S1_($2,$3,$cA);
 __ZmiRK6b2Vec2S1_($d,$2,$rA);
 $61 = (($this) + 84|0);
 __Z5b2MulRK5b2RotRK6b2Vec2($axis,$qA,$61);
 __ZplRK6b2Vec2S1_($4,$d,$rA);
 $62 = (+__Z7b2CrossRK6b2Vec2S1_($4,$axis));
 $63 = (+__Z7b2CrossRK6b2Vec2S1_($rB,$axis));
 $64 = (($this) + 92|0);
 __Z5b2MulRK5b2RotRK6b2Vec2($perp,$qA,$64);
 __ZplRK6b2Vec2S1_($5,$d,$rA);
 $65 = (+__Z7b2CrossRK6b2Vec2S1_($5,$perp));
 $66 = (+__Z7b2CrossRK6b2Vec2S1_($rB,$perp));
 $67 = (+__Z5b2DotRK6b2Vec2S1_($perp,$d));
 HEAPF32[$C1>>2] = $67;
 $68 = $48 - $31;
 $69 = (($this) + 100|0);
 $70 = +HEAPF32[$69>>2];
 $71 = $68 - $70;
 $72 = (($C1) + 4|0);
 HEAPF32[$72>>2] = $71;
 $73 = +HEAPF32[$C1>>2];
 $74 = (+__Z5b2AbsIfET_S0_($73));
 $75 = (+__Z5b2AbsIfET_S0_($71));
 $76 = (($this) + 136|0);
 $77 = HEAP8[$76>>0]|0;
 $78 = ($77<<24>>24)==(0);
 do {
  if ($78) {
   $C2$0 = 0.0;$active$0$off0 = 0;$linearError$0 = $74;
  } else {
   $79 = (+__Z5b2DotRK6b2Vec2S1_($axis,$d));
   $80 = (($this) + 124|0);
   $81 = +HEAPF32[$80>>2];
   $82 = (($this) + 120|0);
   $83 = +HEAPF32[$82>>2];
   $84 = $81 - $83;
   $85 = (+__Z5b2AbsIfET_S0_($84));
   $86 = $85 < 0.0099999997764825821;
   if ($86) {
    $87 = (+__Z7b2ClampIfET_S0_S0_S0_($79,-0.20000000298023224,0.20000000298023224));
    $88 = (+__Z5b2AbsIfET_S0_($79));
    $89 = (+__Z5b2MaxIfET_S0_S0_($74,$88));
    $C2$0 = $87;$active$0$off0 = 1;$linearError$0 = $89;
    break;
   }
   $90 = !($79 <= $83);
   if (!($90)) {
    $91 = $79 - $83;
    $92 = $91 + 0.004999999888241291;
    $93 = (+__Z7b2ClampIfET_S0_S0_S0_($92,-0.20000000298023224,0.0));
    $94 = $83 - $79;
    $95 = (+__Z5b2MaxIfET_S0_S0_($74,$94));
    $C2$0 = $93;$active$0$off0 = 1;$linearError$0 = $95;
    break;
   }
   $96 = !($79 >= $81);
   if ($96) {
    $C2$0 = 0.0;$active$0$off0 = 0;$linearError$0 = $74;
   } else {
    $97 = $79 - $81;
    $98 = $97 + -0.004999999888241291;
    $99 = (+__Z7b2ClampIfET_S0_S0_S0_($98,0.0,0.20000000298023224));
    $100 = (+__Z5b2MaxIfET_S0_S0_($74,$97));
    $C2$0 = $99;$active$0$off0 = 1;$linearError$0 = $100;
   }
  }
 } while(0);
 $101 = $50 + $52;
 $102 = $54 * $65;
 $103 = $65 * $102;
 $104 = $101 + $103;
 $105 = $56 * $66;
 $106 = $66 * $105;
 $107 = $104 + $106;
 $108 = $102 + $105;
 if ($active$0$off0) {
  $109 = $62 * $102;
  $110 = $63 * $105;
  $111 = $109 + $110;
  $112 = $54 + $56;
  $113 = $112 == 0.0;
  $k22$0 = $113 ? 1.0 : $112;
  $114 = $54 * $62;
  $115 = $56 * $63;
  $116 = $114 + $115;
  $117 = $62 * $114;
  $118 = $101 + $117;
  $119 = $63 * $115;
  $120 = $118 + $119;
  __ZN6b2Vec33SetEfff($K,$107,$108,$111);
  $121 = (($K) + 12|0);
  __ZN6b2Vec33SetEfff($121,$108,$k22$0,$116);
  $122 = (($K) + 24|0);
  __ZN6b2Vec33SetEfff($122,$111,$116,$120);
  $123 = +HEAPF32[$C1>>2];
  HEAPF32[$C>>2] = $123;
  $124 = +HEAPF32[$72>>2];
  $125 = (($C) + 4|0);
  HEAPF32[$125>>2] = $124;
  $126 = (($C) + 8|0);
  HEAPF32[$126>>2] = $C2$0;
  __ZNK6b2Vec3ngEv($7,$C);
  __ZNK7b2Mat337Solve33ERK6b2Vec3($6,$K,$7);
  $127 = +HEAPF32[$6>>2];
  $128 = (($6) + 4|0);
  $129 = +HEAPF32[$128>>2];
  $130 = (($6) + 8|0);
  $131 = +HEAPF32[$130>>2];
  $138 = $127;$139 = $131;$142 = $129;
 } else {
  $132 = $54 + $56;
  $133 = $132 == 0.0;
  $k223$0 = $133 ? 1.0 : $132;
  __ZN6b2Vec23SetEff($K4,$107,$108);
  $134 = (($K4) + 8|0);
  __ZN6b2Vec23SetEff($134,$108,$k223$0);
  __ZNK6b2Vec2ngEv($8,$C1);
  __ZNK7b2Mat225SolveERK6b2Vec2($impulse1,$K4,$8);
  $135 = +HEAPF32[$impulse1>>2];
  $136 = (($impulse1) + 4|0);
  $137 = +HEAPF32[$136>>2];
  $138 = $135;$139 = 0.0;$142 = $137;
 }
 __ZmlfRK6b2Vec2($9,$138,$perp);
 __ZmlfRK6b2Vec2($10,$139,$axis);
 __ZplRK6b2Vec2S1_($P,$9,$10);
 $140 = $65 * $138;
 $141 = $142 + $140;
 $143 = $62 * $139;
 $144 = $143 + $141;
 $145 = $66 * $138;
 $146 = $142 + $145;
 $147 = $63 * $139;
 $148 = $147 + $146;
 __ZmlfRK6b2Vec2($11,$50,$P);
 __ZN6b2Vec2mIERKS_($cA,$11);
 $149 = $54 * $144;
 $150 = $31 - $149;
 __ZmlfRK6b2Vec2($12,$52,$P);
 __ZN6b2Vec2pLERKS_($cB,$12);
 $151 = $56 * $148;
 $152 = $48 + $151;
 $153 = HEAP32[$13>>2]|0;
 $154 = HEAP32[$15>>2]|0;
 $155 = (($154) + (($153*12)|0)|0);
 $156 = $cA;
 $157 = $156;
 $158 = HEAP32[$157>>2]|0;
 $159 = (($156) + 4)|0;
 $160 = $159;
 $161 = HEAP32[$160>>2]|0;
 $162 = $155;
 $163 = $162;
 HEAP32[$163>>2] = $158;
 $164 = (($162) + 4)|0;
 $165 = $164;
 HEAP32[$165>>2] = $161;
 $166 = HEAP32[$13>>2]|0;
 $167 = HEAP32[$15>>2]|0;
 $168 = ((($167) + (($166*12)|0)|0) + 8|0);
 HEAPF32[$168>>2] = $150;
 $169 = HEAP32[$32>>2]|0;
 $170 = HEAP32[$15>>2]|0;
 $171 = (($170) + (($169*12)|0)|0);
 $172 = $cB;
 $173 = $172;
 $174 = HEAP32[$173>>2]|0;
 $175 = (($172) + 4)|0;
 $176 = $175;
 $177 = HEAP32[$176>>2]|0;
 $178 = $171;
 $179 = $178;
 HEAP32[$179>>2] = $174;
 $180 = (($178) + 4)|0;
 $181 = $180;
 HEAP32[$181>>2] = $177;
 $182 = HEAP32[$32>>2]|0;
 $183 = HEAP32[$15>>2]|0;
 $184 = ((($183) + (($182*12)|0)|0) + 8|0);
 HEAPF32[$184>>2] = $152;
 $185 = !($linearError$0 <= 0.004999999888241291);
 if ($185) {
  $187 = 0;
  STACKTOP = sp;return ($187|0);
 }
 $186 = $75 <= 0.034906588494777679;
 $187 = $186;
 STACKTOP = sp;return ($187|0);
}
function __ZNK16b2PrismaticJoint10GetAnchorAEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 68|0);
 __ZNK6b2Body13GetWorldPointERK6b2Vec2($agg$result,$1,$2);
 STACKTOP = sp;return;
}
function __ZNK16b2PrismaticJoint10GetAnchorBEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 76|0);
 __ZNK6b2Body13GetWorldPointERK6b2Vec2($agg$result,$1,$2);
 STACKTOP = sp;return;
}
function __ZNK16b2PrismaticJoint16GetReactionForceEf($agg$result,$this,$inv_dt) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inv_dt = +$inv_dt;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($this) + 104|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($this) + 192|0);
 __ZmlfRK6b2Vec2($1,$4,$5);
 $6 = (($this) + 116|0);
 $7 = +HEAPF32[$6>>2];
 $8 = (($this) + 112|0);
 $9 = +HEAPF32[$8>>2];
 $10 = $7 + $9;
 $11 = (($this) + 184|0);
 __ZmlfRK6b2Vec2($2,$10,$11);
 __ZplRK6b2Vec2S1_($0,$1,$2);
 __ZmlfRK6b2Vec2($agg$result,$inv_dt,$0);
 STACKTOP = sp;return;
}
function __ZNK16b2PrismaticJoint17GetReactionTorqueEf($this,$inv_dt) {
 $this = $this|0;
 $inv_dt = +$inv_dt;
 var $0 = 0, $1 = 0.0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 108|0);
 $1 = +HEAPF32[$0>>2];
 $2 = $1 * $inv_dt;
 STACKTOP = sp;return (+$2);
}
function __ZNK16b2PrismaticJoint19GetJointTranslationEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $axis = 0, $d = 0, $pA = 0, $pB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $pA = sp + 24|0;
 $pB = sp + 16|0;
 $d = sp + 8|0;
 $axis = sp;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 68|0);
 __ZNK6b2Body13GetWorldPointERK6b2Vec2($pA,$1,$2);
 $3 = (($this) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 76|0);
 __ZNK6b2Body13GetWorldPointERK6b2Vec2($pB,$4,$5);
 __ZmiRK6b2Vec2S1_($d,$pB,$pA);
 $6 = HEAP32[$0>>2]|0;
 $7 = (($this) + 84|0);
 __ZNK6b2Body14GetWorldVectorERK6b2Vec2($axis,$6,$7);
 $8 = (+__Z5b2DotRK6b2Vec2S1_($d,$axis));
 STACKTOP = sp;return (+$8);
}
function __ZNK16b2PrismaticJoint14IsLimitEnabledEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 136|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN16b2PrismaticJoint11EnableLimitEb($this,$flag) {
 $this = $this|0;
 $flag = $flag|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $flag&1;
 $1 = (($this) + 136|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2&255;
 $4 = ($0|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 48|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN6b2Body8SetAwakeEb($6,1);
 $7 = (($this) + 52|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN6b2Body8SetAwakeEb($8,1);
 $9 = $flag&1;
 HEAP8[$1>>0] = $9;
 $10 = (($this) + 112|0);
 HEAPF32[$10>>2] = 0.0;
 STACKTOP = sp;return;
}
function __ZNK16b2PrismaticJoint14IsMotorEnabledEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 137|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN16b2PrismaticJoint11EnableMotorEb($this,$flag) {
 $this = $this|0;
 $flag = $flag|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN6b2Body8SetAwakeEb($1,1);
 $2 = (($this) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN6b2Body8SetAwakeEb($3,1);
 $4 = (($this) + 137|0);
 $5 = $flag&1;
 HEAP8[$4>>0] = $5;
 STACKTOP = sp;return;
}
function __ZN16b2PrismaticJoint13SetMotorSpeedEf($this,$speed) {
 $this = $this|0;
 $speed = +$speed;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN6b2Body8SetAwakeEb($1,1);
 $2 = (($this) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN6b2Body8SetAwakeEb($3,1);
 $4 = (($this) + 132|0);
 HEAPF32[$4>>2] = $speed;
 STACKTOP = sp;return;
}
function __ZNK16b2PrismaticJoint13GetMotorForceEf($this,$inv_dt) {
 $this = $this|0;
 $inv_dt = +$inv_dt;
 var $0 = 0, $1 = 0.0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = +HEAPF32[$0>>2];
 $2 = $1 * $inv_dt;
 STACKTOP = sp;return (+$2);
}
function __ZN16b2PrismaticJoint4DumpEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0;
 var $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0.0, $46 = 0.0, $47 = 0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer42 = 0, $vararg_ptr12 = 0, $vararg_ptr16 = 0, $vararg_ptr20 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer42 = sp;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 __Z5b2LogPKcz(4688,$vararg_buffer42);
 HEAP32[$vararg_buffer42>>2] = $3;
 __Z5b2LogPKcz(4720,$vararg_buffer42);
 HEAP32[$vararg_buffer42>>2] = $7;
 __Z5b2LogPKcz(4752,$vararg_buffer42);
 $8 = (($this) + 61|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 HEAP32[$vararg_buffer42>>2] = $10;
 __Z5b2LogPKcz(4784,$vararg_buffer42);
 $11 = (($this) + 68|0);
 $12 = +HEAPF32[$11>>2];
 $13 = $12;
 $14 = (($this) + 72|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $15;
 HEAPF64[tempDoublePtr>>3]=$13;HEAP32[$vararg_buffer42>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer42+4>>2]=HEAP32[tempDoublePtr+4>>2];
 $vararg_ptr12 = (($vararg_buffer42) + 8|0);
 HEAPF64[tempDoublePtr>>3]=$16;HEAP32[$vararg_ptr12>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr12+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(4824,$vararg_buffer42);
 $17 = (($this) + 76|0);
 $18 = +HEAPF32[$17>>2];
 $19 = $18;
 $20 = (($this) + 80|0);
 $21 = +HEAPF32[$20>>2];
 $22 = $21;
 HEAPF64[tempDoublePtr>>3]=$19;HEAP32[$vararg_buffer42>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer42+4>>2]=HEAP32[tempDoublePtr+4>>2];
 $vararg_ptr16 = (($vararg_buffer42) + 8|0);
 HEAPF64[tempDoublePtr>>3]=$22;HEAP32[$vararg_ptr16>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr16+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(4872,$vararg_buffer42);
 $23 = (($this) + 84|0);
 $24 = +HEAPF32[$23>>2];
 $25 = $24;
 $26 = (($this) + 88|0);
 $27 = +HEAPF32[$26>>2];
 $28 = $27;
 HEAPF64[tempDoublePtr>>3]=$25;HEAP32[$vararg_buffer42>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer42+4>>2]=HEAP32[tempDoublePtr+4>>2];
 $vararg_ptr20 = (($vararg_buffer42) + 8|0);
 HEAPF64[tempDoublePtr>>3]=$28;HEAP32[$vararg_ptr20>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr20+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(4920,$vararg_buffer42);
 $29 = (($this) + 100|0);
 $30 = +HEAPF32[$29>>2];
 $31 = $30;
 HEAPF64[tempDoublePtr>>3]=$31;HEAP32[$vararg_buffer42>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer42+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(4960,$vararg_buffer42);
 $32 = (($this) + 136|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = $33&255;
 HEAP32[$vararg_buffer42>>2] = $34;
 __Z5b2LogPKcz(4992,$vararg_buffer42);
 $35 = (($this) + 120|0);
 $36 = +HEAPF32[$35>>2];
 $37 = $36;
 HEAPF64[tempDoublePtr>>3]=$37;HEAP32[$vararg_buffer42>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer42+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(5024,$vararg_buffer42);
 $38 = (($this) + 124|0);
 $39 = +HEAPF32[$38>>2];
 $40 = $39;
 HEAPF64[tempDoublePtr>>3]=$40;HEAP32[$vararg_buffer42>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer42+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(5064,$vararg_buffer42);
 $41 = (($this) + 137|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = $42&255;
 HEAP32[$vararg_buffer42>>2] = $43;
 __Z5b2LogPKcz(5104,$vararg_buffer42);
 $44 = (($this) + 132|0);
 $45 = +HEAPF32[$44>>2];
 $46 = $45;
 HEAPF64[tempDoublePtr>>3]=$46;HEAP32[$vararg_buffer42>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer42+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(5136,$vararg_buffer42);
 $47 = (($this) + 128|0);
 $48 = +HEAPF32[$47>>2];
 $49 = $48;
 HEAPF64[tempDoublePtr>>3]=$49;HEAP32[$vararg_buffer42>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer42+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(5168,$vararg_buffer42);
 $50 = (($this) + 56|0);
 $51 = HEAP32[$50>>2]|0;
 HEAP32[$vararg_buffer42>>2] = $51;
 __Z5b2LogPKcz(5200,$vararg_buffer42);
 STACKTOP = sp;return;
}
function __ZN16b2PrismaticJointD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK6b2Body14GetLocalVectorERK6b2Vec2($agg$result,$this,$worldVector) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $worldVector = $worldVector|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 __Z6b2MulTRK5b2RotRK6b2Vec2($agg$result,$0,$worldVector);
 STACKTOP = sp;return;
}
function __ZmiRK6b2Vec3S1_($agg$result,$a,$b) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = 0.0, $1 = 0.0, $10 = 0, $11 = 0.0, $12 = 0.0, $2 = 0.0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$a>>2];
 $1 = +HEAPF32[$b>>2];
 $2 = $0 - $1;
 $3 = (($a) + 4|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($b) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $4 - $6;
 $8 = (($a) + 8|0);
 $9 = +HEAPF32[$8>>2];
 $10 = (($b) + 8|0);
 $11 = +HEAPF32[$10>>2];
 $12 = $9 - $11;
 __ZN6b2Vec3C2Efff($agg$result,$2,$7,$12);
 STACKTOP = sp;return;
}
function __ZNK7b2Mat225SolveERK6b2Vec2($agg$result,$this,$b) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $b = $b|0;
 var $0 = 0.0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0, $3 = 0;
 var $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, $det$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$this>>2];
 $1 = (($this) + 8|0);
 $2 = +HEAPF32[$1>>2];
 $3 = (($this) + 4|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($this) + 12|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $0 * $6;
 $8 = $2 * $4;
 $9 = $7 - $8;
 $10 = $9 != 0.0;
 if ($10) {
  $11 = 1.0 / $9;
  $det$0 = $11;
 } else {
  $det$0 = $9;
 }
 $12 = +HEAPF32[$b>>2];
 $13 = $6 * $12;
 $14 = (($b) + 4|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $2 * $15;
 $17 = $13 - $16;
 $18 = $det$0 * $17;
 HEAPF32[$agg$result>>2] = $18;
 $19 = +HEAPF32[$14>>2];
 $20 = $0 * $19;
 $21 = +HEAPF32[$b>>2];
 $22 = $4 * $21;
 $23 = $20 - $22;
 $24 = $det$0 * $23;
 $25 = (($agg$result) + 4|0);
 HEAPF32[$25>>2] = $24;
 STACKTOP = sp;return;
}
function __ZNK6b2Body14GetWorldVectorERK6b2Vec2($agg$result,$this,$localVector) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $localVector = $localVector|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 __Z5b2MulRK5b2RotRK6b2Vec2($agg$result,$0,$localVector);
 STACKTOP = sp;return;
}
function __ZN11b2RopeJointC2EPK14b2RopeJointDef($this,$def) {
 $this = $this|0;
 $def = $def|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7b2JointC2EPK10b2JointDef($this,$def);
 HEAP32[$this>>2] = ((5288 + 8|0));
 $0 = (($this) + 68|0);
 $1 = (($this) + 76|0);
 $2 = (($def) + 20|0);
 $3 = $2;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $0;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = (($def) + 28|0);
 $14 = $13;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14) + 4)|0;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = $1;
 $21 = $20;
 HEAP32[$21>>2] = $16;
 $22 = (($20) + 4)|0;
 $23 = $22;
 HEAP32[$23>>2] = $19;
 $24 = (($def) + 36|0);
 $25 = +HEAPF32[$24>>2];
 $26 = (($this) + 84|0);
 HEAPF32[$26>>2] = $25;
 $27 = (($this) + 160|0);
 HEAPF32[$27>>2] = 0.0;
 $28 = (($this) + 92|0);
 HEAPF32[$28>>2] = 0.0;
 $29 = (($this) + 164|0);
 HEAP32[$29>>2] = 0;
 $30 = (($this) + 88|0);
 HEAPF32[$30>>2] = 0.0;
 STACKTOP = sp;return;
}
function __ZN11b2RopeJoint23InitVelocityConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0.0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0.0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0.0, $165 = 0, $166 = 0, $167 = 0.0, $168 = 0.0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0.0, $172 = 0, $173 = 0.0, $174 = 0.0, $175 = 0.0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0, $180 = 0.0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0.0, $186 = 0.0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0.0, $191 = 0, $192 = 0.0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0.0, $198 = 0, $199 = 0.0, $2 = 0, $20 = 0, $200 = 0.0, $201 = 0.0, $202 = 0.0, $203 = 0.0, $204 = 0.0;
 var $205 = 0.0, $206 = 0.0, $207 = 0.0, $208 = 0.0, $209 = 0.0, $21 = 0, $210 = 0.0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0.0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0.0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0.0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $P = 0, $cA = 0, $cB = 0, $qA = 0, $qB = 0, $vA = 0, $vB = 0, $wA$0 = 0.0, $wB$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $cA = sp + 48|0;
 $vA = sp + 40|0;
 $cB = sp + 32|0;
 $vB = sp + 24|0;
 $qA = sp + 120|0;
 $qB = sp + 112|0;
 $0 = sp + 16|0;
 $1 = sp + 104|0;
 $2 = sp + 8|0;
 $3 = sp + 96|0;
 $4 = sp;
 $5 = sp + 88|0;
 $6 = sp + 80|0;
 $P = sp + 72|0;
 $7 = sp + 64|0;
 $8 = sp + 56|0;
 $9 = (($this) + 48|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 96|0);
 HEAP32[$13>>2] = $12;
 $14 = (($this) + 52|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($this) + 100|0);
 HEAP32[$18>>2] = $17;
 $19 = (($this) + 128|0);
 $20 = HEAP32[$9>>2]|0;
 $21 = (($20) + 44|0);
 $22 = $21;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 $25 = (($22) + 4)|0;
 $26 = $25;
 $27 = HEAP32[$26>>2]|0;
 $28 = $19;
 $29 = $28;
 HEAP32[$29>>2] = $24;
 $30 = (($28) + 4)|0;
 $31 = $30;
 HEAP32[$31>>2] = $27;
 $32 = (($this) + 136|0);
 $33 = HEAP32[$14>>2]|0;
 $34 = (($33) + 44|0);
 $35 = $34;
 $36 = $35;
 $37 = HEAP32[$36>>2]|0;
 $38 = (($35) + 4)|0;
 $39 = $38;
 $40 = HEAP32[$39>>2]|0;
 $41 = $32;
 $42 = $41;
 HEAP32[$42>>2] = $37;
 $43 = (($41) + 4)|0;
 $44 = $43;
 HEAP32[$44>>2] = $40;
 $45 = HEAP32[$9>>2]|0;
 $46 = (($45) + 136|0);
 $47 = +HEAPF32[$46>>2];
 $48 = (($this) + 144|0);
 HEAPF32[$48>>2] = $47;
 $49 = HEAP32[$14>>2]|0;
 $50 = (($49) + 136|0);
 $51 = +HEAPF32[$50>>2];
 $52 = (($this) + 148|0);
 HEAPF32[$52>>2] = $51;
 $53 = HEAP32[$9>>2]|0;
 $54 = (($53) + 144|0);
 $55 = +HEAPF32[$54>>2];
 $56 = (($this) + 152|0);
 HEAPF32[$56>>2] = $55;
 $57 = HEAP32[$14>>2]|0;
 $58 = (($57) + 144|0);
 $59 = +HEAPF32[$58>>2];
 $60 = (($this) + 156|0);
 HEAPF32[$60>>2] = $59;
 $61 = HEAP32[$13>>2]|0;
 $62 = (($data) + 28|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = (($63) + (($61*12)|0)|0);
 $65 = $64;
 $66 = $65;
 $67 = HEAP32[$66>>2]|0;
 $68 = (($65) + 4)|0;
 $69 = $68;
 $70 = HEAP32[$69>>2]|0;
 $71 = $cA;
 $72 = $71;
 HEAP32[$72>>2] = $67;
 $73 = (($71) + 4)|0;
 $74 = $73;
 HEAP32[$74>>2] = $70;
 $75 = HEAP32[$13>>2]|0;
 $76 = HEAP32[$62>>2]|0;
 $77 = ((($76) + (($75*12)|0)|0) + 8|0);
 $78 = +HEAPF32[$77>>2];
 $79 = (($data) + 32|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = (($80) + (($75*12)|0)|0);
 $82 = $81;
 $83 = $82;
 $84 = HEAP32[$83>>2]|0;
 $85 = (($82) + 4)|0;
 $86 = $85;
 $87 = HEAP32[$86>>2]|0;
 $88 = $vA;
 $89 = $88;
 HEAP32[$89>>2] = $84;
 $90 = (($88) + 4)|0;
 $91 = $90;
 HEAP32[$91>>2] = $87;
 $92 = HEAP32[$13>>2]|0;
 $93 = HEAP32[$79>>2]|0;
 $94 = ((($93) + (($92*12)|0)|0) + 8|0);
 $95 = +HEAPF32[$94>>2];
 $96 = HEAP32[$18>>2]|0;
 $97 = HEAP32[$62>>2]|0;
 $98 = (($97) + (($96*12)|0)|0);
 $99 = $98;
 $100 = $99;
 $101 = HEAP32[$100>>2]|0;
 $102 = (($99) + 4)|0;
 $103 = $102;
 $104 = HEAP32[$103>>2]|0;
 $105 = $cB;
 $106 = $105;
 HEAP32[$106>>2] = $101;
 $107 = (($105) + 4)|0;
 $108 = $107;
 HEAP32[$108>>2] = $104;
 $109 = HEAP32[$18>>2]|0;
 $110 = HEAP32[$62>>2]|0;
 $111 = ((($110) + (($109*12)|0)|0) + 8|0);
 $112 = +HEAPF32[$111>>2];
 $113 = HEAP32[$79>>2]|0;
 $114 = (($113) + (($109*12)|0)|0);
 $115 = $114;
 $116 = $115;
 $117 = HEAP32[$116>>2]|0;
 $118 = (($115) + 4)|0;
 $119 = $118;
 $120 = HEAP32[$119>>2]|0;
 $121 = $vB;
 $122 = $121;
 HEAP32[$122>>2] = $117;
 $123 = (($121) + 4)|0;
 $124 = $123;
 HEAP32[$124>>2] = $120;
 $125 = HEAP32[$18>>2]|0;
 $126 = HEAP32[$79>>2]|0;
 $127 = ((($126) + (($125*12)|0)|0) + 8|0);
 $128 = +HEAPF32[$127>>2];
 __ZN5b2RotC2Ef($qA,$78);
 __ZN5b2RotC2Ef($qB,$112);
 $129 = (($this) + 112|0);
 $130 = (($this) + 68|0);
 __ZmiRK6b2Vec2S1_($1,$130,$19);
 __Z5b2MulRK5b2RotRK6b2Vec2($0,$qA,$1);
 $131 = $0;
 $132 = $131;
 $133 = HEAP32[$132>>2]|0;
 $134 = (($131) + 4)|0;
 $135 = $134;
 $136 = HEAP32[$135>>2]|0;
 $137 = $129;
 $138 = $137;
 HEAP32[$138>>2] = $133;
 $139 = (($137) + 4)|0;
 $140 = $139;
 HEAP32[$140>>2] = $136;
 $141 = (($this) + 120|0);
 $142 = (($this) + 76|0);
 __ZmiRK6b2Vec2S1_($3,$142,$32);
 __Z5b2MulRK5b2RotRK6b2Vec2($2,$qB,$3);
 $143 = $2;
 $144 = $143;
 $145 = HEAP32[$144>>2]|0;
 $146 = (($143) + 4)|0;
 $147 = $146;
 $148 = HEAP32[$147>>2]|0;
 $149 = $141;
 $150 = $149;
 HEAP32[$150>>2] = $145;
 $151 = (($149) + 4)|0;
 $152 = $151;
 HEAP32[$152>>2] = $148;
 $153 = (($this) + 104|0);
 __ZplRK6b2Vec2S1_($6,$cB,$141);
 __ZmiRK6b2Vec2S1_($5,$6,$cA);
 __ZmiRK6b2Vec2S1_($4,$5,$129);
 $154 = $4;
 $155 = $154;
 $156 = HEAP32[$155>>2]|0;
 $157 = (($154) + 4)|0;
 $158 = $157;
 $159 = HEAP32[$158>>2]|0;
 $160 = $153;
 $161 = $160;
 HEAP32[$161>>2] = $156;
 $162 = (($160) + 4)|0;
 $163 = $162;
 HEAP32[$163>>2] = $159;
 $164 = (+__ZNK6b2Vec26LengthEv($153));
 $165 = (($this) + 88|0);
 HEAPF32[$165>>2] = $164;
 $166 = (($this) + 84|0);
 $167 = +HEAPF32[$166>>2];
 $168 = $164 - $167;
 $169 = $168 > 0.0;
 $170 = (($this) + 164|0);
 $$ = $169 ? 2 : 0;
 HEAP32[$170>>2] = $$;
 $171 = +HEAPF32[$165>>2];
 $172 = $171 > 0.004999999888241291;
 if (!($172)) {
  __ZN6b2Vec27SetZeroEv($153);
  $188 = (($this) + 160|0);
  HEAPF32[$188>>2] = 0.0;
  $189 = (($this) + 92|0);
  HEAPF32[$189>>2] = 0.0;
  STACKTOP = sp;return;
 }
 $173 = 1.0 / $171;
 __ZN6b2Vec2mLEf($153,$173);
 $174 = (+__Z7b2CrossRK6b2Vec2S1_($129,$153));
 $175 = (+__Z7b2CrossRK6b2Vec2S1_($141,$153));
 $176 = +HEAPF32[$48>>2];
 $177 = +HEAPF32[$56>>2];
 $178 = $174 * $177;
 $179 = $174 * $178;
 $180 = $176 + $179;
 $181 = +HEAPF32[$52>>2];
 $182 = $181 + $180;
 $183 = +HEAPF32[$60>>2];
 $184 = $175 * $183;
 $185 = $175 * $184;
 $186 = $182 + $185;
 $187 = $186 != 0.0;
 if ($187) {
  $190 = 1.0 / $186;
  $192 = $190;
 } else {
  $192 = 0.0;
 }
 $191 = (($this) + 160|0);
 HEAPF32[$191>>2] = $192;
 $193 = (($data) + 24|0);
 $194 = HEAP8[$193>>0]|0;
 $195 = ($194<<24>>24)==(0);
 if ($195) {
  $211 = (($this) + 92|0);
  HEAPF32[$211>>2] = 0.0;
  $wA$0 = $95;$wB$0 = $128;
 } else {
  $196 = (($data) + 8|0);
  $197 = +HEAPF32[$196>>2];
  $198 = (($this) + 92|0);
  $199 = +HEAPF32[$198>>2];
  $200 = $197 * $199;
  HEAPF32[$198>>2] = $200;
  __ZmlfRK6b2Vec2($P,$200,$153);
  $201 = +HEAPF32[$48>>2];
  __ZmlfRK6b2Vec2($7,$201,$P);
  __ZN6b2Vec2mIERKS_($vA,$7);
  $202 = +HEAPF32[$56>>2];
  $203 = (+__Z7b2CrossRK6b2Vec2S1_($129,$P));
  $204 = $202 * $203;
  $205 = $95 - $204;
  $206 = +HEAPF32[$52>>2];
  __ZmlfRK6b2Vec2($8,$206,$P);
  __ZN6b2Vec2pLERKS_($vB,$8);
  $207 = +HEAPF32[$60>>2];
  $208 = (+__Z7b2CrossRK6b2Vec2S1_($141,$P));
  $209 = $207 * $208;
  $210 = $128 + $209;
  $wA$0 = $205;$wB$0 = $210;
 }
 $212 = HEAP32[$13>>2]|0;
 $213 = HEAP32[$79>>2]|0;
 $214 = (($213) + (($212*12)|0)|0);
 $215 = $vA;
 $216 = $215;
 $217 = HEAP32[$216>>2]|0;
 $218 = (($215) + 4)|0;
 $219 = $218;
 $220 = HEAP32[$219>>2]|0;
 $221 = $214;
 $222 = $221;
 HEAP32[$222>>2] = $217;
 $223 = (($221) + 4)|0;
 $224 = $223;
 HEAP32[$224>>2] = $220;
 $225 = HEAP32[$13>>2]|0;
 $226 = HEAP32[$79>>2]|0;
 $227 = ((($226) + (($225*12)|0)|0) + 8|0);
 HEAPF32[$227>>2] = $wA$0;
 $228 = HEAP32[$18>>2]|0;
 $229 = HEAP32[$79>>2]|0;
 $230 = (($229) + (($228*12)|0)|0);
 $231 = $vB;
 $232 = $231;
 $233 = HEAP32[$232>>2]|0;
 $234 = (($231) + 4)|0;
 $235 = $234;
 $236 = HEAP32[$235>>2]|0;
 $237 = $230;
 $238 = $237;
 HEAP32[$238>>2] = $233;
 $239 = (($237) + 4)|0;
 $240 = $239;
 HEAP32[$240>>2] = $236;
 $241 = HEAP32[$18>>2]|0;
 $242 = HEAP32[$79>>2]|0;
 $243 = ((($242) + (($241*12)|0)|0) + 8|0);
 HEAPF32[$243>>2] = $wB$0;
 STACKTOP = sp;return;
}
function __ZN11b2RopeJoint24SolveVelocityConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0.0, $47 = 0.0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0.0;
 var $55 = 0, $56 = 0.0, $57 = 0.0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0, $64 = 0.0, $65 = 0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0;
 var $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $Cdot$0 = 0.0, $P = 0, $vA = 0, $vB = 0, $vpA = 0, $vpB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $vA = sp + 8|0;
 $vB = sp;
 $vpA = sp + 72|0;
 $0 = sp + 64|0;
 $vpB = sp + 56|0;
 $1 = sp + 48|0;
 $2 = sp + 40|0;
 $P = sp + 32|0;
 $3 = sp + 24|0;
 $4 = sp + 16|0;
 $5 = (($this) + 96|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($data) + 32|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + (($6*12)|0)|0);
 $10 = $9;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = (($10) + 4)|0;
 $14 = $13;
 $15 = HEAP32[$14>>2]|0;
 $16 = $vA;
 $17 = $16;
 HEAP32[$17>>2] = $12;
 $18 = (($16) + 4)|0;
 $19 = $18;
 HEAP32[$19>>2] = $15;
 $20 = HEAP32[$5>>2]|0;
 $21 = HEAP32[$7>>2]|0;
 $22 = ((($21) + (($20*12)|0)|0) + 8|0);
 $23 = +HEAPF32[$22>>2];
 $24 = (($this) + 100|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($21) + (($25*12)|0)|0);
 $27 = $26;
 $28 = $27;
 $29 = HEAP32[$28>>2]|0;
 $30 = (($27) + 4)|0;
 $31 = $30;
 $32 = HEAP32[$31>>2]|0;
 $33 = $vB;
 $34 = $33;
 HEAP32[$34>>2] = $29;
 $35 = (($33) + 4)|0;
 $36 = $35;
 HEAP32[$36>>2] = $32;
 $37 = HEAP32[$24>>2]|0;
 $38 = HEAP32[$7>>2]|0;
 $39 = ((($38) + (($37*12)|0)|0) + 8|0);
 $40 = +HEAPF32[$39>>2];
 $41 = (($this) + 112|0);
 __Z7b2CrossfRK6b2Vec2($0,$23,$41);
 __ZplRK6b2Vec2S1_($vpA,$vA,$0);
 $42 = (($this) + 120|0);
 __Z7b2CrossfRK6b2Vec2($1,$40,$42);
 __ZplRK6b2Vec2S1_($vpB,$vB,$1);
 $43 = (($this) + 88|0);
 $44 = +HEAPF32[$43>>2];
 $45 = (($this) + 84|0);
 $46 = +HEAPF32[$45>>2];
 $47 = $44 - $46;
 $48 = (($this) + 104|0);
 __ZmiRK6b2Vec2S1_($2,$vpB,$vpA);
 $49 = (+__Z5b2DotRK6b2Vec2S1_($48,$2));
 $50 = $47 < 0.0;
 if ($50) {
  $51 = (($data) + 4|0);
  $52 = +HEAPF32[$51>>2];
  $53 = $47 * $52;
  $54 = $49 + $53;
  $Cdot$0 = $54;
 } else {
  $Cdot$0 = $49;
 }
 $55 = (($this) + 160|0);
 $56 = +HEAPF32[$55>>2];
 $57 = $Cdot$0 * $56;
 $58 = (($this) + 92|0);
 $59 = +HEAPF32[$58>>2];
 $60 = $59 - $57;
 $61 = (+__Z5b2MinIfET_S0_S0_(0.0,$60));
 HEAPF32[$58>>2] = $61;
 $62 = $61 - $59;
 __ZmlfRK6b2Vec2($P,$62,$48);
 $63 = (($this) + 144|0);
 $64 = +HEAPF32[$63>>2];
 __ZmlfRK6b2Vec2($3,$64,$P);
 __ZN6b2Vec2mIERKS_($vA,$3);
 $65 = (($this) + 152|0);
 $66 = +HEAPF32[$65>>2];
 $67 = (+__Z7b2CrossRK6b2Vec2S1_($41,$P));
 $68 = $66 * $67;
 $69 = $23 - $68;
 $70 = (($this) + 148|0);
 $71 = +HEAPF32[$70>>2];
 __ZmlfRK6b2Vec2($4,$71,$P);
 __ZN6b2Vec2pLERKS_($vB,$4);
 $72 = (($this) + 156|0);
 $73 = +HEAPF32[$72>>2];
 $74 = (+__Z7b2CrossRK6b2Vec2S1_($42,$P));
 $75 = $73 * $74;
 $76 = $40 + $75;
 $77 = HEAP32[$5>>2]|0;
 $78 = HEAP32[$7>>2]|0;
 $79 = (($78) + (($77*12)|0)|0);
 $80 = $vA;
 $81 = $80;
 $82 = HEAP32[$81>>2]|0;
 $83 = (($80) + 4)|0;
 $84 = $83;
 $85 = HEAP32[$84>>2]|0;
 $86 = $79;
 $87 = $86;
 HEAP32[$87>>2] = $82;
 $88 = (($86) + 4)|0;
 $89 = $88;
 HEAP32[$89>>2] = $85;
 $90 = HEAP32[$5>>2]|0;
 $91 = HEAP32[$7>>2]|0;
 $92 = ((($91) + (($90*12)|0)|0) + 8|0);
 HEAPF32[$92>>2] = $69;
 $93 = HEAP32[$24>>2]|0;
 $94 = HEAP32[$7>>2]|0;
 $95 = (($94) + (($93*12)|0)|0);
 $96 = $vB;
 $97 = $96;
 $98 = HEAP32[$97>>2]|0;
 $99 = (($96) + 4)|0;
 $100 = $99;
 $101 = HEAP32[$100>>2]|0;
 $102 = $95;
 $103 = $102;
 HEAP32[$103>>2] = $98;
 $104 = (($102) + 4)|0;
 $105 = $104;
 HEAP32[$105>>2] = $101;
 $106 = HEAP32[$24>>2]|0;
 $107 = HEAP32[$7>>2]|0;
 $108 = ((($107) + (($106*12)|0)|0) + 8|0);
 HEAPF32[$108>>2] = $76;
 STACKTOP = sp;return;
}
function __ZN11b2RopeJoint24SolvePositionConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0.0, $102 = 0.0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0.0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0.0, $47 = 0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0.0, $59 = 0.0;
 var $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0, $63 = 0.0, $64 = 0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $P = 0, $cA = 0, $cB = 0, $qA = 0, $qB = 0, $rA = 0, $rB = 0, $u = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0;
 $cA = sp + 8|0;
 $cB = sp;
 $qA = sp + 104|0;
 $qB = sp + 96|0;
 $rA = sp + 88|0;
 $0 = sp + 80|0;
 $rB = sp + 72|0;
 $1 = sp + 64|0;
 $u = sp + 56|0;
 $2 = sp + 48|0;
 $3 = sp + 40|0;
 $P = sp + 32|0;
 $4 = sp + 24|0;
 $5 = sp + 16|0;
 $6 = (($this) + 96|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($data) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + (($7*12)|0)|0);
 $11 = $10;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + 4)|0;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = $cA;
 $18 = $17;
 HEAP32[$18>>2] = $13;
 $19 = (($17) + 4)|0;
 $20 = $19;
 HEAP32[$20>>2] = $16;
 $21 = HEAP32[$6>>2]|0;
 $22 = HEAP32[$8>>2]|0;
 $23 = ((($22) + (($21*12)|0)|0) + 8|0);
 $24 = +HEAPF32[$23>>2];
 $25 = (($this) + 100|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($22) + (($26*12)|0)|0);
 $28 = $27;
 $29 = $28;
 $30 = HEAP32[$29>>2]|0;
 $31 = (($28) + 4)|0;
 $32 = $31;
 $33 = HEAP32[$32>>2]|0;
 $34 = $cB;
 $35 = $34;
 HEAP32[$35>>2] = $30;
 $36 = (($34) + 4)|0;
 $37 = $36;
 HEAP32[$37>>2] = $33;
 $38 = HEAP32[$25>>2]|0;
 $39 = HEAP32[$8>>2]|0;
 $40 = ((($39) + (($38*12)|0)|0) + 8|0);
 $41 = +HEAPF32[$40>>2];
 __ZN5b2RotC2Ef($qA,$24);
 __ZN5b2RotC2Ef($qB,$41);
 $42 = (($this) + 68|0);
 $43 = (($this) + 128|0);
 __ZmiRK6b2Vec2S1_($0,$42,$43);
 __Z5b2MulRK5b2RotRK6b2Vec2($rA,$qA,$0);
 $44 = (($this) + 76|0);
 $45 = (($this) + 136|0);
 __ZmiRK6b2Vec2S1_($1,$44,$45);
 __Z5b2MulRK5b2RotRK6b2Vec2($rB,$qB,$1);
 __ZplRK6b2Vec2S1_($3,$cB,$rB);
 __ZmiRK6b2Vec2S1_($2,$3,$cA);
 __ZmiRK6b2Vec2S1_($u,$2,$rA);
 $46 = (+__ZN6b2Vec29NormalizeEv($u));
 $47 = (($this) + 84|0);
 $48 = +HEAPF32[$47>>2];
 $49 = $46 - $48;
 $50 = (+__Z7b2ClampIfET_S0_S0_S0_($49,0.0,0.20000000298023224));
 $51 = (($this) + 160|0);
 $52 = +HEAPF32[$51>>2];
 $53 = $50 * $52;
 $54 = -$53;
 __ZmlfRK6b2Vec2($P,$54,$u);
 $55 = (($this) + 144|0);
 $56 = +HEAPF32[$55>>2];
 __ZmlfRK6b2Vec2($4,$56,$P);
 __ZN6b2Vec2mIERKS_($cA,$4);
 $57 = (($this) + 152|0);
 $58 = +HEAPF32[$57>>2];
 $59 = (+__Z7b2CrossRK6b2Vec2S1_($rA,$P));
 $60 = $58 * $59;
 $61 = $24 - $60;
 $62 = (($this) + 148|0);
 $63 = +HEAPF32[$62>>2];
 __ZmlfRK6b2Vec2($5,$63,$P);
 __ZN6b2Vec2pLERKS_($cB,$5);
 $64 = (($this) + 156|0);
 $65 = +HEAPF32[$64>>2];
 $66 = (+__Z7b2CrossRK6b2Vec2S1_($rB,$P));
 $67 = $65 * $66;
 $68 = $41 + $67;
 $69 = HEAP32[$6>>2]|0;
 $70 = HEAP32[$8>>2]|0;
 $71 = (($70) + (($69*12)|0)|0);
 $72 = $cA;
 $73 = $72;
 $74 = HEAP32[$73>>2]|0;
 $75 = (($72) + 4)|0;
 $76 = $75;
 $77 = HEAP32[$76>>2]|0;
 $78 = $71;
 $79 = $78;
 HEAP32[$79>>2] = $74;
 $80 = (($78) + 4)|0;
 $81 = $80;
 HEAP32[$81>>2] = $77;
 $82 = HEAP32[$6>>2]|0;
 $83 = HEAP32[$8>>2]|0;
 $84 = ((($83) + (($82*12)|0)|0) + 8|0);
 HEAPF32[$84>>2] = $61;
 $85 = HEAP32[$25>>2]|0;
 $86 = HEAP32[$8>>2]|0;
 $87 = (($86) + (($85*12)|0)|0);
 $88 = $cB;
 $89 = $88;
 $90 = HEAP32[$89>>2]|0;
 $91 = (($88) + 4)|0;
 $92 = $91;
 $93 = HEAP32[$92>>2]|0;
 $94 = $87;
 $95 = $94;
 HEAP32[$95>>2] = $90;
 $96 = (($94) + 4)|0;
 $97 = $96;
 HEAP32[$97>>2] = $93;
 $98 = HEAP32[$25>>2]|0;
 $99 = HEAP32[$8>>2]|0;
 $100 = ((($99) + (($98*12)|0)|0) + 8|0);
 HEAPF32[$100>>2] = $68;
 $101 = +HEAPF32[$47>>2];
 $102 = $46 - $101;
 $103 = $102 < 0.004999999888241291;
 STACKTOP = sp;return ($103|0);
}
function __ZNK11b2RopeJoint10GetAnchorAEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 68|0);
 __ZNK6b2Body13GetWorldPointERK6b2Vec2($agg$result,$1,$2);
 STACKTOP = sp;return;
}
function __ZNK11b2RopeJoint10GetAnchorBEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 76|0);
 __ZNK6b2Body13GetWorldPointERK6b2Vec2($agg$result,$1,$2);
 STACKTOP = sp;return;
}
function __ZNK11b2RopeJoint16GetReactionForceEf($agg$result,$this,$inv_dt) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inv_dt = +$inv_dt;
 var $0 = 0, $1 = 0.0, $2 = 0.0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 $1 = +HEAPF32[$0>>2];
 $2 = $1 * $inv_dt;
 $3 = (($this) + 104|0);
 __ZmlfRK6b2Vec2($agg$result,$2,$3);
 STACKTOP = sp;return;
}
function __ZNK11b2RopeJoint17GetReactionTorqueEf($this,$inv_dt) {
 $this = $this|0;
 $inv_dt = +$inv_dt;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return +0;
}
function __ZN11b2RopeJoint4DumpEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer20 = 0, $vararg_ptr12 = 0, $vararg_ptr16 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer20 = sp;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 __Z5b2LogPKcz(5344,$vararg_buffer20);
 HEAP32[$vararg_buffer20>>2] = $3;
 __Z5b2LogPKcz(5368,$vararg_buffer20);
 HEAP32[$vararg_buffer20>>2] = $7;
 __Z5b2LogPKcz(5400,$vararg_buffer20);
 $8 = (($this) + 61|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 HEAP32[$vararg_buffer20>>2] = $10;
 __Z5b2LogPKcz(5432,$vararg_buffer20);
 $11 = (($this) + 68|0);
 $12 = +HEAPF32[$11>>2];
 $13 = $12;
 $14 = (($this) + 72|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $15;
 HEAPF64[tempDoublePtr>>3]=$13;HEAP32[$vararg_buffer20>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer20+4>>2]=HEAP32[tempDoublePtr+4>>2];
 $vararg_ptr12 = (($vararg_buffer20) + 8|0);
 HEAPF64[tempDoublePtr>>3]=$16;HEAP32[$vararg_ptr12>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr12+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(5472,$vararg_buffer20);
 $17 = (($this) + 76|0);
 $18 = +HEAPF32[$17>>2];
 $19 = $18;
 $20 = (($this) + 80|0);
 $21 = +HEAPF32[$20>>2];
 $22 = $21;
 HEAPF64[tempDoublePtr>>3]=$19;HEAP32[$vararg_buffer20>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer20+4>>2]=HEAP32[tempDoublePtr+4>>2];
 $vararg_ptr16 = (($vararg_buffer20) + 8|0);
 HEAPF64[tempDoublePtr>>3]=$22;HEAP32[$vararg_ptr16>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr16+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(5520,$vararg_buffer20);
 $23 = (($this) + 84|0);
 $24 = +HEAPF32[$23>>2];
 $25 = $24;
 HEAPF64[tempDoublePtr>>3]=$25;HEAP32[$vararg_buffer20>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer20+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(5568,$vararg_buffer20);
 $26 = (($this) + 56|0);
 $27 = HEAP32[$26>>2]|0;
 HEAP32[$vararg_buffer20>>2] = $27;
 __Z5b2LogPKcz(5600,$vararg_buffer20);
 STACKTOP = sp;return;
}
function __ZN11b2RopeJointD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN7b2Joint6CreateEPK10b2JointDefP16b2BlockAllocator($def,$allocator) {
 $def = $def|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $joint$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$def>>2]|0;
 do {
  switch ($0|0) {
  case 1:  {
   $7 = (__ZN16b2BlockAllocator8AllocateEi($allocator,228)|0);
   $8 = ($7|0)==(0|0);
   if ($8) {
    $26 = 0;
   } else {
    __ZN15b2RevoluteJointC2EPK18b2RevoluteJointDef($7,$def);
    $26 = $7;
   }
   $joint$0 = $26;
   break;
  }
  case 9:  {
   $17 = (__ZN16b2BlockAllocator8AllocateEi($allocator,180)|0);
   $18 = ($17|0)==(0|0);
   if ($18) {
    $31 = 0;
   } else {
    __ZN15b2FrictionJointC2EPK18b2FrictionJointDef($17,$def);
    $31 = $17;
   }
   $joint$0 = $31;
   break;
  }
  case 4:  {
   $9 = (__ZN16b2BlockAllocator8AllocateEi($allocator,196)|0);
   $10 = ($9|0)==(0|0);
   if ($10) {
    $27 = 0;
   } else {
    __ZN13b2PulleyJointC2EPK16b2PulleyJointDef($9,$def);
    $27 = $9;
   }
   $joint$0 = $27;
   break;
  }
  case 8:  {
   $15 = (__ZN16b2BlockAllocator8AllocateEi($allocator,208)|0);
   $16 = ($15|0)==(0|0);
   if ($16) {
    $30 = 0;
   } else {
    __ZN11b2WeldJointC2EPK14b2WeldJointDef($15,$def);
    $30 = $15;
   }
   $joint$0 = $30;
   break;
  }
  case 5:  {
   $3 = (__ZN16b2BlockAllocator8AllocateEi($allocator,168)|0);
   $4 = ($3|0)==(0|0);
   if ($4) {
    $24 = 0;
   } else {
    __ZN12b2MouseJointC2EPK15b2MouseJointDef($3,$def);
    $24 = $3;
   }
   $joint$0 = $24;
   break;
  }
  case 2:  {
   $5 = (__ZN16b2BlockAllocator8AllocateEi($allocator,256)|0);
   $6 = ($5|0)==(0|0);
   if ($6) {
    $25 = 0;
   } else {
    __ZN16b2PrismaticJointC2EPK19b2PrismaticJointDef($5,$def);
    $25 = $5;
   }
   $joint$0 = $25;
   break;
  }
  case 10:  {
   $19 = (__ZN16b2BlockAllocator8AllocateEi($allocator,168)|0);
   $20 = ($19|0)==(0|0);
   if ($20) {
    $32 = 0;
   } else {
    __ZN11b2RopeJointC2EPK14b2RopeJointDef($19,$def);
    $32 = $19;
   }
   $joint$0 = $32;
   break;
  }
  case 6:  {
   $11 = (__ZN16b2BlockAllocator8AllocateEi($allocator,276)|0);
   $12 = ($11|0)==(0|0);
   if ($12) {
    $28 = 0;
   } else {
    __ZN11b2GearJointC2EPK14b2GearJointDef($11,$def);
    $28 = $11;
   }
   $joint$0 = $28;
   break;
  }
  case 7:  {
   $13 = (__ZN16b2BlockAllocator8AllocateEi($allocator,224)|0);
   $14 = ($13|0)==(0|0);
   if ($14) {
    $29 = 0;
   } else {
    __ZN12b2WheelJointC2EPK15b2WheelJointDef($13,$def);
    $29 = $13;
   }
   $joint$0 = $29;
   break;
  }
  case 3:  {
   $1 = (__ZN16b2BlockAllocator8AllocateEi($allocator,176)|0);
   $2 = ($1|0)==(0|0);
   if ($2) {
    $23 = 0;
   } else {
    __ZN15b2DistanceJointC2EPK18b2DistanceJointDef($1,$def);
    $23 = $1;
   }
   $joint$0 = $23;
   break;
  }
  case 11:  {
   $21 = (__ZN16b2BlockAllocator8AllocateEi($allocator,192)|0);
   $22 = ($21|0)==(0|0);
   if ($22) {
    $33 = 0;
   } else {
    __ZN12b2MotorJointC2EPK15b2MotorJointDef($21,$def);
    $33 = $21;
   }
   $joint$0 = $33;
   break;
  }
  default: {
   $joint$0 = 0;
  }
  }
 } while(0);
 STACKTOP = sp;return ($joint$0|0);
}
function __ZN7b2Joint7DestroyEPS_P16b2BlockAllocator($joint,$allocator) {
 $joint = $joint|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$joint>>2]|0;
 $1 = (($0) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$2 & 127]($joint);
 $3 = (($joint) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 do {
  switch ($4|0) {
  case 11:  {
   __ZN16b2BlockAllocator4FreeEPvi($allocator,$joint,192);
   break;
  }
  case 5:  {
   __ZN16b2BlockAllocator4FreeEPvi($allocator,$joint,168);
   break;
  }
  case 2:  {
   __ZN16b2BlockAllocator4FreeEPvi($allocator,$joint,256);
   break;
  }
  case 1:  {
   __ZN16b2BlockAllocator4FreeEPvi($allocator,$joint,228);
   break;
  }
  case 7:  {
   __ZN16b2BlockAllocator4FreeEPvi($allocator,$joint,224);
   break;
  }
  case 6:  {
   __ZN16b2BlockAllocator4FreeEPvi($allocator,$joint,276);
   break;
  }
  case 8:  {
   __ZN16b2BlockAllocator4FreeEPvi($allocator,$joint,208);
   break;
  }
  case 9:  {
   __ZN16b2BlockAllocator4FreeEPvi($allocator,$joint,180);
   break;
  }
  case 3:  {
   __ZN16b2BlockAllocator4FreeEPvi($allocator,$joint,176);
   break;
  }
  case 10:  {
   __ZN16b2BlockAllocator4FreeEPvi($allocator,$joint,168);
   break;
  }
  case 4:  {
   __ZN16b2BlockAllocator4FreeEPvi($allocator,$joint,196);
   break;
  }
  default: {
  }
  }
 } while(0);
 STACKTOP = sp;return;
}
function __ZN7b2JointC2EPK10b2JointDef($this,$def) {
 $this = $this|0;
 $def = $def|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((5680 + 8|0));
 $0 = HEAP32[$def>>2]|0;
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = $0;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = (($def) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 48|0);
 HEAP32[$6>>2] = $5;
 $7 = (($def) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($this) + 52|0);
 HEAP32[$9>>2] = $8;
 $10 = (($this) + 56|0);
 HEAP32[$10>>2] = 0;
 $11 = (($def) + 16|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = (($this) + 61|0);
 HEAP8[$13>>0] = $12;
 $14 = (($this) + 60|0);
 HEAP8[$14>>0] = 0;
 $15 = (($def) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 64|0);
 HEAP32[$17>>2] = $16;
 $18 = (($this) + 16|0);
 ;HEAP32[$18+0>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;HEAP32[$18+12>>2]=0|0;HEAP32[$18+16>>2]=0|0;HEAP32[$18+20>>2]=0|0;HEAP32[$18+24>>2]=0|0;HEAP32[$18+28>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN7b2Joint4DumpEv($this) {
 $this = $this|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 __Z5b2LogPKcz(5736,$vararg_buffer);
 STACKTOP = sp;return;
}
function __ZN7b2JointD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK6b2Body8IsActiveEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 & 32;
 $3 = ($2<<16>>16)!=(0);
 STACKTOP = sp;return ($3|0);
}
function __ZN18b2RevoluteJointDef10InitializeEP6b2BodyS1_RK6b2Vec2($this,$bA,$bB,$anchor) {
 $this = $this|0;
 $bA = $bA|0;
 $bB = $bB|0;
 $anchor = $anchor|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = $bA;
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = $bB;
 $4 = (($this) + 20|0);
 $5 = HEAP32[$2>>2]|0;
 __ZNK6b2Body13GetLocalPointERK6b2Vec2($0,$5,$anchor);
 $6 = $0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $4;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 $16 = (($this) + 28|0);
 $17 = HEAP32[$3>>2]|0;
 __ZNK6b2Body13GetLocalPointERK6b2Vec2($1,$17,$anchor);
 $18 = $1;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + 4)|0;
 $22 = $21;
 $23 = HEAP32[$22>>2]|0;
 $24 = $16;
 $25 = $24;
 HEAP32[$25>>2] = $20;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = $23;
 $28 = HEAP32[$3>>2]|0;
 $29 = (+__ZNK6b2Body8GetAngleEv($28));
 $30 = HEAP32[$2>>2]|0;
 $31 = (+__ZNK6b2Body8GetAngleEv($30));
 $32 = $29 - $31;
 $33 = (($this) + 36|0);
 HEAPF32[$33>>2] = $32;
 STACKTOP = sp;return;
}
function __ZN15b2RevoluteJointC2EPK18b2RevoluteJointDef($this,$def) {
 $this = $this|0;
 $def = $def|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0.0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7b2JointC2EPK10b2JointDef($this,$def);
 HEAP32[$this>>2] = ((5784 + 8|0));
 $0 = (($this) + 68|0);
 $1 = (($this) + 76|0);
 $2 = (($this) + 84|0);
 $3 = (($def) + 20|0);
 $4 = $3;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 4)|0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = $0;
 $11 = $10;
 HEAP32[$11>>2] = $6;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = $9;
 $14 = (($def) + 28|0);
 $15 = $14;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = $1;
 $22 = $21;
 HEAP32[$22>>2] = $17;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = $20;
 $25 = (($def) + 36|0);
 $26 = +HEAPF32[$25>>2];
 $27 = (($this) + 116|0);
 HEAPF32[$27>>2] = $26;
 __ZN6b2Vec37SetZeroEv($2);
 $28 = (($this) + 96|0);
 HEAPF32[$28>>2] = 0.0;
 $29 = (($def) + 44|0);
 $30 = +HEAPF32[$29>>2];
 $31 = (($this) + 120|0);
 HEAPF32[$31>>2] = $30;
 $32 = (($def) + 48|0);
 $33 = +HEAPF32[$32>>2];
 $34 = (($this) + 124|0);
 HEAPF32[$34>>2] = $33;
 $35 = (($def) + 60|0);
 $36 = +HEAPF32[$35>>2];
 $37 = (($this) + 104|0);
 HEAPF32[$37>>2] = $36;
 $38 = (($def) + 56|0);
 $39 = +HEAPF32[$38>>2];
 $40 = (($this) + 108|0);
 HEAPF32[$40>>2] = $39;
 $41 = (($def) + 40|0);
 $42 = HEAP8[$41>>0]|0;
 $43 = (($this) + 112|0);
 HEAP8[$43>>0] = $42;
 $44 = (($def) + 52|0);
 $45 = HEAP8[$44>>0]|0;
 $46 = (($this) + 100|0);
 HEAP8[$46>>0] = $45;
 $47 = (($this) + 224|0);
 HEAP32[$47>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN15b2RevoluteJoint23InitVelocityConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0, $129 = 0.0, $13 = 0, $130 = 0, $131 = 0.0, $132 = 0.0, $133 = 0.0;
 var $134 = 0.0, $135 = 0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0.0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0.0, $15 = 0, $150 = 0.0, $151 = 0;
 var $152 = 0.0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0, $159 = 0.0, $16 = 0, $160 = 0, $161 = 0.0, $162 = 0.0, $163 = 0.0, $164 = 0.0, $165 = 0.0, $166 = 0.0, $167 = 0.0, $168 = 0.0, $169 = 0, $17 = 0;
 var $170 = 0.0, $171 = 0.0, $172 = 0.0, $173 = 0.0, $174 = 0.0, $175 = 0, $176 = 0.0, $177 = 0, $178 = 0.0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0.0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0.0, $192 = 0, $193 = 0.0, $194 = 0.0, $195 = 0, $196 = 0.0, $197 = 0, $198 = 0.0, $199 = 0.0, $2 = 0, $20 = 0, $200 = 0.0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0.0, $221 = 0.0, $222 = 0, $223 = 0.0;
 var $224 = 0.0, $225 = 0.0, $226 = 0, $227 = 0.0, $228 = 0.0, $229 = 0.0, $23 = 0, $230 = 0.0, $231 = 0, $232 = 0.0, $233 = 0.0, $234 = 0.0, $235 = 0.0, $236 = 0.0, $237 = 0.0, $238 = 0.0, $239 = 0.0, $24 = 0, $240 = 0.0, $241 = 0.0;
 var $242 = 0.0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0, $48 = 0.0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0.0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0.0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0.0, $99 = 0, $P = 0, $brmerge = 0, $brmerge4 = 0, $qA = 0;
 var $qB = 0, $storemerge = 0.0, $vA = 0, $vB = 0, $wA$0 = 0.0, $wB$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $vA = sp + 24|0;
 $vB = sp + 16|0;
 $qA = sp + 80|0;
 $qB = sp + 72|0;
 $0 = sp + 8|0;
 $1 = sp + 64|0;
 $2 = sp;
 $3 = sp + 56|0;
 $P = sp + 48|0;
 $4 = sp + 40|0;
 $5 = sp + 32|0;
 $6 = (($this) + 48|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($this) + 128|0);
 HEAP32[$10>>2] = $9;
 $11 = (($this) + 52|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($this) + 132|0);
 HEAP32[$15>>2] = $14;
 $16 = (($this) + 152|0);
 $17 = HEAP32[$6>>2]|0;
 $18 = (($17) + 44|0);
 $19 = $18;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) + 4)|0;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 $25 = $16;
 $26 = $25;
 HEAP32[$26>>2] = $21;
 $27 = (($25) + 4)|0;
 $28 = $27;
 HEAP32[$28>>2] = $24;
 $29 = (($this) + 160|0);
 $30 = HEAP32[$11>>2]|0;
 $31 = (($30) + 44|0);
 $32 = $31;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = (($32) + 4)|0;
 $36 = $35;
 $37 = HEAP32[$36>>2]|0;
 $38 = $29;
 $39 = $38;
 HEAP32[$39>>2] = $34;
 $40 = (($38) + 4)|0;
 $41 = $40;
 HEAP32[$41>>2] = $37;
 $42 = HEAP32[$6>>2]|0;
 $43 = (($42) + 136|0);
 $44 = +HEAPF32[$43>>2];
 $45 = (($this) + 168|0);
 HEAPF32[$45>>2] = $44;
 $46 = HEAP32[$11>>2]|0;
 $47 = (($46) + 136|0);
 $48 = +HEAPF32[$47>>2];
 $49 = (($this) + 172|0);
 HEAPF32[$49>>2] = $48;
 $50 = HEAP32[$6>>2]|0;
 $51 = (($50) + 144|0);
 $52 = +HEAPF32[$51>>2];
 $53 = (($this) + 176|0);
 HEAPF32[$53>>2] = $52;
 $54 = HEAP32[$11>>2]|0;
 $55 = (($54) + 144|0);
 $56 = +HEAPF32[$55>>2];
 $57 = (($this) + 180|0);
 HEAPF32[$57>>2] = $56;
 $58 = HEAP32[$10>>2]|0;
 $59 = (($data) + 28|0);
 $60 = HEAP32[$59>>2]|0;
 $61 = ((($60) + (($58*12)|0)|0) + 8|0);
 $62 = +HEAPF32[$61>>2];
 $63 = (($data) + 32|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($64) + (($58*12)|0)|0);
 $66 = $65;
 $67 = $66;
 $68 = HEAP32[$67>>2]|0;
 $69 = (($66) + 4)|0;
 $70 = $69;
 $71 = HEAP32[$70>>2]|0;
 $72 = $vA;
 $73 = $72;
 HEAP32[$73>>2] = $68;
 $74 = (($72) + 4)|0;
 $75 = $74;
 HEAP32[$75>>2] = $71;
 $76 = HEAP32[$10>>2]|0;
 $77 = HEAP32[$63>>2]|0;
 $78 = ((($77) + (($76*12)|0)|0) + 8|0);
 $79 = +HEAPF32[$78>>2];
 $80 = HEAP32[$15>>2]|0;
 $81 = HEAP32[$59>>2]|0;
 $82 = ((($81) + (($80*12)|0)|0) + 8|0);
 $83 = +HEAPF32[$82>>2];
 $84 = (($77) + (($80*12)|0)|0);
 $85 = $84;
 $86 = $85;
 $87 = HEAP32[$86>>2]|0;
 $88 = (($85) + 4)|0;
 $89 = $88;
 $90 = HEAP32[$89>>2]|0;
 $91 = $vB;
 $92 = $91;
 HEAP32[$92>>2] = $87;
 $93 = (($91) + 4)|0;
 $94 = $93;
 HEAP32[$94>>2] = $90;
 $95 = HEAP32[$15>>2]|0;
 $96 = HEAP32[$63>>2]|0;
 $97 = ((($96) + (($95*12)|0)|0) + 8|0);
 $98 = +HEAPF32[$97>>2];
 __ZN5b2RotC2Ef($qA,$62);
 __ZN5b2RotC2Ef($qB,$83);
 $99 = (($this) + 136|0);
 $100 = (($this) + 68|0);
 __ZmiRK6b2Vec2S1_($1,$100,$16);
 __Z5b2MulRK5b2RotRK6b2Vec2($0,$qA,$1);
 $101 = $0;
 $102 = $101;
 $103 = HEAP32[$102>>2]|0;
 $104 = (($101) + 4)|0;
 $105 = $104;
 $106 = HEAP32[$105>>2]|0;
 $107 = $99;
 $108 = $107;
 HEAP32[$108>>2] = $103;
 $109 = (($107) + 4)|0;
 $110 = $109;
 HEAP32[$110>>2] = $106;
 $111 = (($this) + 144|0);
 $112 = (($this) + 76|0);
 __ZmiRK6b2Vec2S1_($3,$112,$29);
 __Z5b2MulRK5b2RotRK6b2Vec2($2,$qB,$3);
 $113 = $2;
 $114 = $113;
 $115 = HEAP32[$114>>2]|0;
 $116 = (($113) + 4)|0;
 $117 = $116;
 $118 = HEAP32[$117>>2]|0;
 $119 = $111;
 $120 = $119;
 HEAP32[$120>>2] = $115;
 $121 = (($119) + 4)|0;
 $122 = $121;
 HEAP32[$122>>2] = $118;
 $123 = +HEAPF32[$45>>2];
 $124 = +HEAPF32[$49>>2];
 $125 = +HEAPF32[$53>>2];
 $126 = +HEAPF32[$57>>2];
 $127 = $125 + $126;
 $128 = $127 == 0.0;
 $129 = $123 + $124;
 $130 = (($this) + 140|0);
 $131 = +HEAPF32[$130>>2];
 $132 = $131 * $131;
 $133 = $125 * $132;
 $134 = $129 + $133;
 $135 = (($this) + 148|0);
 $136 = +HEAPF32[$135>>2];
 $137 = $136 * $136;
 $138 = $126 * $137;
 $139 = $134 + $138;
 $140 = (($this) + 184|0);
 HEAPF32[$140>>2] = $139;
 $141 = +HEAPF32[$130>>2];
 $142 = +HEAPF32[$99>>2];
 $143 = $141 * $142;
 $144 = $125 * $143;
 $145 = -$144;
 $146 = +HEAPF32[$135>>2];
 $147 = +HEAPF32[$111>>2];
 $148 = $146 * $147;
 $149 = $126 * $148;
 $150 = $145 - $149;
 $151 = (($this) + 196|0);
 HEAPF32[$151>>2] = $150;
 $152 = +HEAPF32[$130>>2];
 $153 = $125 * $152;
 $154 = -$153;
 $155 = +HEAPF32[$135>>2];
 $156 = $126 * $155;
 $157 = $154 - $156;
 $158 = (($this) + 208|0);
 HEAPF32[$158>>2] = $157;
 $159 = +HEAPF32[$151>>2];
 $160 = (($this) + 188|0);
 HEAPF32[$160>>2] = $159;
 $161 = +HEAPF32[$99>>2];
 $162 = $161 * $161;
 $163 = $125 * $162;
 $164 = $129 + $163;
 $165 = +HEAPF32[$111>>2];
 $166 = $165 * $165;
 $167 = $126 * $166;
 $168 = $164 + $167;
 $169 = (($this) + 200|0);
 HEAPF32[$169>>2] = $168;
 $170 = +HEAPF32[$99>>2];
 $171 = $125 * $170;
 $172 = +HEAPF32[$111>>2];
 $173 = $126 * $172;
 $174 = $171 + $173;
 $175 = (($this) + 212|0);
 HEAPF32[$175>>2] = $174;
 $176 = +HEAPF32[$158>>2];
 $177 = (($this) + 192|0);
 HEAPF32[$177>>2] = $176;
 $178 = +HEAPF32[$175>>2];
 $179 = (($this) + 204|0);
 HEAPF32[$179>>2] = $178;
 $180 = (($this) + 216|0);
 HEAPF32[$180>>2] = $127;
 $181 = (($this) + 220|0);
 $182 = $127 > 0.0;
 if ($182) {
  $183 = 1.0 / $127;
  $storemerge = $183;
 } else {
  $storemerge = $127;
 }
 HEAPF32[$181>>2] = $storemerge;
 $184 = (($this) + 100|0);
 $185 = HEAP8[$184>>0]|0;
 $186 = ($185<<24>>24)==(0);
 $brmerge = $186 | $128;
 if ($brmerge) {
  $187 = (($this) + 96|0);
  HEAPF32[$187>>2] = 0.0;
 }
 $188 = (($this) + 112|0);
 $189 = HEAP8[$188>>0]|0;
 $190 = ($189<<24>>24)==(0);
 $brmerge4 = $190 | $128;
 do {
  if ($brmerge4) {
   $214 = (($this) + 224|0);
   HEAP32[$214>>2] = 0;
  } else {
   $191 = $83 - $62;
   $192 = (($this) + 116|0);
   $193 = +HEAPF32[$192>>2];
   $194 = $191 - $193;
   $195 = (($this) + 124|0);
   $196 = +HEAPF32[$195>>2];
   $197 = (($this) + 120|0);
   $198 = +HEAPF32[$197>>2];
   $199 = $196 - $198;
   $200 = (+__Z5b2AbsIfET_S0_($199));
   $201 = $200 < 0.069813176989555359;
   if ($201) {
    $202 = (($this) + 224|0);
    HEAP32[$202>>2] = 3;
    break;
   }
   $203 = !($194 <= $198);
   if (!($203)) {
    $204 = (($this) + 224|0);
    $205 = HEAP32[$204>>2]|0;
    $206 = ($205|0)==(1);
    if (!($206)) {
     $207 = (($this) + 92|0);
     HEAPF32[$207>>2] = 0.0;
    }
    HEAP32[$204>>2] = 1;
    break;
   }
   $208 = !($194 >= $196);
   $209 = (($this) + 224|0);
   if ($208) {
    HEAP32[$209>>2] = 0;
    $213 = (($this) + 92|0);
    HEAPF32[$213>>2] = 0.0;
    break;
   }
   $210 = HEAP32[$209>>2]|0;
   $211 = ($210|0)==(2);
   if (!($211)) {
    $212 = (($this) + 92|0);
    HEAPF32[$212>>2] = 0.0;
   }
   HEAP32[$209>>2] = 2;
  }
 } while(0);
 $215 = (($data) + 24|0);
 $216 = HEAP8[$215>>0]|0;
 $217 = ($216<<24>>24)==(0);
 $218 = (($this) + 84|0);
 if ($217) {
  __ZN6b2Vec37SetZeroEv($218);
  $243 = (($this) + 96|0);
  HEAPF32[$243>>2] = 0.0;
  $wA$0 = $79;$wB$0 = $98;
  $244 = HEAP32[$10>>2]|0;
  $245 = HEAP32[$63>>2]|0;
  $246 = (($245) + (($244*12)|0)|0);
  $247 = $vA;
  $248 = $247;
  $249 = HEAP32[$248>>2]|0;
  $250 = (($247) + 4)|0;
  $251 = $250;
  $252 = HEAP32[$251>>2]|0;
  $253 = $246;
  $254 = $253;
  HEAP32[$254>>2] = $249;
  $255 = (($253) + 4)|0;
  $256 = $255;
  HEAP32[$256>>2] = $252;
  $257 = HEAP32[$10>>2]|0;
  $258 = HEAP32[$63>>2]|0;
  $259 = ((($258) + (($257*12)|0)|0) + 8|0);
  HEAPF32[$259>>2] = $wA$0;
  $260 = HEAP32[$15>>2]|0;
  $261 = HEAP32[$63>>2]|0;
  $262 = (($261) + (($260*12)|0)|0);
  $263 = $vB;
  $264 = $263;
  $265 = HEAP32[$264>>2]|0;
  $266 = (($263) + 4)|0;
  $267 = $266;
  $268 = HEAP32[$267>>2]|0;
  $269 = $262;
  $270 = $269;
  HEAP32[$270>>2] = $265;
  $271 = (($269) + 4)|0;
  $272 = $271;
  HEAP32[$272>>2] = $268;
  $273 = HEAP32[$15>>2]|0;
  $274 = HEAP32[$63>>2]|0;
  $275 = ((($274) + (($273*12)|0)|0) + 8|0);
  HEAPF32[$275>>2] = $wB$0;
  STACKTOP = sp;return;
 } else {
  $219 = (($data) + 8|0);
  $220 = +HEAPF32[$219>>2];
  __ZN6b2Vec3mLEf($218,$220);
  $221 = +HEAPF32[$219>>2];
  $222 = (($this) + 96|0);
  $223 = +HEAPF32[$222>>2];
  $224 = $221 * $223;
  HEAPF32[$222>>2] = $224;
  $225 = +HEAPF32[$218>>2];
  $226 = (($this) + 88|0);
  $227 = +HEAPF32[$226>>2];
  __ZN6b2Vec2C2Eff($P,$225,$227);
  __ZmlfRK6b2Vec2($4,$123,$P);
  __ZN6b2Vec2mIERKS_($vA,$4);
  $228 = (+__Z7b2CrossRK6b2Vec2S1_($99,$P));
  $229 = +HEAPF32[$222>>2];
  $230 = $228 + $229;
  $231 = (($this) + 92|0);
  $232 = +HEAPF32[$231>>2];
  $233 = $230 + $232;
  $234 = $125 * $233;
  $235 = $79 - $234;
  __ZmlfRK6b2Vec2($5,$124,$P);
  __ZN6b2Vec2pLERKS_($vB,$5);
  $236 = (+__Z7b2CrossRK6b2Vec2S1_($111,$P));
  $237 = +HEAPF32[$222>>2];
  $238 = $236 + $237;
  $239 = +HEAPF32[$231>>2];
  $240 = $238 + $239;
  $241 = $126 * $240;
  $242 = $98 + $241;
  $wA$0 = $235;$wB$0 = $242;
  $244 = HEAP32[$10>>2]|0;
  $245 = HEAP32[$63>>2]|0;
  $246 = (($245) + (($244*12)|0)|0);
  $247 = $vA;
  $248 = $247;
  $249 = HEAP32[$248>>2]|0;
  $250 = (($247) + 4)|0;
  $251 = $250;
  $252 = HEAP32[$251>>2]|0;
  $253 = $246;
  $254 = $253;
  HEAP32[$254>>2] = $249;
  $255 = (($253) + 4)|0;
  $256 = $255;
  HEAP32[$256>>2] = $252;
  $257 = HEAP32[$10>>2]|0;
  $258 = HEAP32[$63>>2]|0;
  $259 = ((($258) + (($257*12)|0)|0) + 8|0);
  HEAPF32[$259>>2] = $wA$0;
  $260 = HEAP32[$15>>2]|0;
  $261 = HEAP32[$63>>2]|0;
  $262 = (($261) + (($260*12)|0)|0);
  $263 = $vB;
  $264 = $263;
  $265 = HEAP32[$264>>2]|0;
  $266 = (($263) + 4)|0;
  $267 = $266;
  $268 = HEAP32[$267>>2]|0;
  $269 = $262;
  $270 = $269;
  HEAP32[$270>>2] = $265;
  $271 = (($269) + 4)|0;
  $272 = $271;
  HEAP32[$272>>2] = $268;
  $273 = HEAP32[$15>>2]|0;
  $274 = HEAP32[$63>>2]|0;
  $275 = ((($274) + (($273*12)|0)|0) + 8|0);
  HEAPF32[$275>>2] = $wB$0;
  STACKTOP = sp;return;
 }
}
function __ZN15b2RevoluteJoint24SolveVelocityConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $$pn = 0.0, $$pn2 = 0.0, $$pn3 = 0.0, $$pn4 = 0.0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0.0, $102 = 0.0, $103 = 0, $104 = 0.0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0.0, $111 = 0;
 var $112 = 0.0, $113 = 0.0, $114 = 0, $115 = 0.0, $116 = 0, $117 = 0.0, $118 = 0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0.0, $123 = 0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0;
 var $130 = 0, $131 = 0.0, $132 = 0.0, $133 = 0, $134 = 0, $135 = 0.0, $136 = 0, $137 = 0.0, $138 = 0.0, $139 = 0, $14 = 0, $140 = 0.0, $141 = 0, $142 = 0.0, $143 = 0, $144 = 0.0, $145 = 0.0, $146 = 0, $147 = 0.0, $148 = 0;
 var $149 = 0.0, $15 = 0, $150 = 0.0, $151 = 0.0, $152 = 0.0, $153 = 0.0, $154 = 0.0, $155 = 0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = 0, $16 = 0, $160 = 0.0, $161 = 0.0, $162 = 0, $163 = 0.0, $164 = 0.0, $165 = 0.0, $166 = 0.0;
 var $167 = 0.0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0.0, $172 = 0, $173 = 0.0, $174 = 0.0, $175 = 0, $176 = 0.0, $177 = 0, $178 = 0.0, $179 = 0.0, $18 = 0, $180 = 0.0, $181 = 0.0, $182 = 0, $183 = 0, $184 = 0;
 var $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0;
 var $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0, $63 = 0.0, $64 = 0.0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0.0, $73 = 0, $74 = 0.0, $75 = 0.0, $76 = 0, $77 = 0.0, $78 = 0.0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0;
 var $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $Cdot1 = 0, $Cdot3 = 0;
 var $Cdot8 = 0, $P = 0, $brmerge = 0, $brmerge5 = 0, $impulse4 = 0, $impulse9 = 0, $reduced = 0, $reduced7 = 0, $rhs = 0, $rhs6 = 0, $vA = 0, $vB = 0, $wA$0 = 0.0, $wA$1 = 0.0, $wB$0 = 0.0, $wB$1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $vA = sp + 8|0;
 $vB = sp;
 $Cdot1 = sp + 264|0;
 $0 = sp + 256|0;
 $1 = sp + 248|0;
 $2 = sp + 240|0;
 $3 = sp + 232|0;
 $Cdot3 = sp + 216|0;
 $impulse4 = sp + 204|0;
 $4 = sp + 192|0;
 $rhs = sp + 184|0;
 $5 = sp + 176|0;
 $6 = sp + 168|0;
 $7 = sp + 160|0;
 $reduced = sp + 152|0;
 $rhs6 = sp + 144|0;
 $8 = sp + 136|0;
 $9 = sp + 128|0;
 $10 = sp + 120|0;
 $reduced7 = sp + 112|0;
 $P = sp + 104|0;
 $11 = sp + 96|0;
 $12 = sp + 88|0;
 $Cdot8 = sp + 80|0;
 $13 = sp + 72|0;
 $14 = sp + 64|0;
 $15 = sp + 56|0;
 $16 = sp + 48|0;
 $impulse9 = sp + 40|0;
 $17 = sp + 32|0;
 $18 = sp + 24|0;
 $19 = sp + 16|0;
 $20 = (($this) + 128|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($data) + 32|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($23) + (($21*12)|0)|0);
 $25 = $24;
 $26 = $25;
 $27 = HEAP32[$26>>2]|0;
 $28 = (($25) + 4)|0;
 $29 = $28;
 $30 = HEAP32[$29>>2]|0;
 $31 = $vA;
 $32 = $31;
 HEAP32[$32>>2] = $27;
 $33 = (($31) + 4)|0;
 $34 = $33;
 HEAP32[$34>>2] = $30;
 $35 = HEAP32[$20>>2]|0;
 $36 = HEAP32[$22>>2]|0;
 $37 = ((($36) + (($35*12)|0)|0) + 8|0);
 $38 = +HEAPF32[$37>>2];
 $39 = (($this) + 132|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($36) + (($40*12)|0)|0);
 $42 = $41;
 $43 = $42;
 $44 = HEAP32[$43>>2]|0;
 $45 = (($42) + 4)|0;
 $46 = $45;
 $47 = HEAP32[$46>>2]|0;
 $48 = $vB;
 $49 = $48;
 HEAP32[$49>>2] = $44;
 $50 = (($48) + 4)|0;
 $51 = $50;
 HEAP32[$51>>2] = $47;
 $52 = HEAP32[$39>>2]|0;
 $53 = HEAP32[$22>>2]|0;
 $54 = ((($53) + (($52*12)|0)|0) + 8|0);
 $55 = +HEAPF32[$54>>2];
 $56 = (($this) + 168|0);
 $57 = +HEAPF32[$56>>2];
 $58 = (($this) + 172|0);
 $59 = +HEAPF32[$58>>2];
 $60 = (($this) + 176|0);
 $61 = +HEAPF32[$60>>2];
 $62 = (($this) + 180|0);
 $63 = +HEAPF32[$62>>2];
 $64 = $61 + $63;
 $65 = $64 == 0.0;
 $66 = (($this) + 100|0);
 $67 = HEAP8[$66>>0]|0;
 $68 = ($67<<24>>24)==(0);
 if ($68) {
  $wA$0 = $38;$wB$0 = $55;
 } else {
  $69 = (($this) + 224|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = ($70|0)==(3);
  $brmerge = $71 | $65;
  if ($brmerge) {
   $wA$0 = $38;$wB$0 = $55;
  } else {
   $72 = $55 - $38;
   $73 = (($this) + 108|0);
   $74 = +HEAPF32[$73>>2];
   $75 = $72 - $74;
   $76 = (($this) + 220|0);
   $77 = +HEAPF32[$76>>2];
   $78 = $77 * $75;
   $79 = (($this) + 96|0);
   $80 = +HEAPF32[$79>>2];
   $81 = +HEAPF32[$data>>2];
   $82 = (($this) + 104|0);
   $83 = +HEAPF32[$82>>2];
   $84 = $81 * $83;
   $85 = $80 - $78;
   $86 = -$84;
   $87 = (+__Z7b2ClampIfET_S0_S0_S0_($85,$86,$84));
   HEAPF32[$79>>2] = $87;
   $88 = $87 - $80;
   $89 = $61 * $88;
   $90 = $38 - $89;
   $91 = $63 * $88;
   $92 = $55 + $91;
   $wA$0 = $90;$wB$0 = $92;
  }
 }
 $93 = (($this) + 112|0);
 $94 = HEAP8[$93>>0]|0;
 $95 = ($94<<24>>24)==(0);
 if (!($95)) {
  $96 = (($this) + 224|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = ($97|0)==(0);
  $brmerge5 = $98 | $65;
  if (!($brmerge5)) {
   $99 = (($this) + 144|0);
   __Z7b2CrossfRK6b2Vec2($2,$wB$0,$99);
   __ZplRK6b2Vec2S1_($1,$vB,$2);
   __ZmiRK6b2Vec2S1_($0,$1,$vA);
   $100 = (($this) + 136|0);
   __Z7b2CrossfRK6b2Vec2($3,$wA$0,$100);
   __ZmiRK6b2Vec2S1_($Cdot1,$0,$3);
   $101 = $wB$0 - $wA$0;
   $102 = +HEAPF32[$Cdot1>>2];
   $103 = (($Cdot1) + 4|0);
   $104 = +HEAPF32[$103>>2];
   __ZN6b2Vec3C2Efff($Cdot3,$102,$104,$101);
   $105 = (($this) + 184|0);
   __ZNK7b2Mat337Solve33ERK6b2Vec3($4,$105,$Cdot3);
   __ZNK6b2Vec3ngEv($impulse4,$4);
   $106 = HEAP32[$96>>2]|0;
   do {
    if ((($106|0) == 1)) {
     $108 = (($this) + 84|0);
     $109 = (($this) + 92|0);
     $110 = +HEAPF32[$109>>2];
     $111 = (($impulse4) + 8|0);
     $112 = +HEAPF32[$111>>2];
     $113 = $110 + $112;
     $114 = $113 < 0.0;
     if ($114) {
      __ZNK6b2Vec2ngEv($5,$Cdot1);
      $115 = +HEAPF32[$109>>2];
      $116 = (($this) + 208|0);
      $117 = +HEAPF32[$116>>2];
      $118 = (($this) + 212|0);
      $119 = +HEAPF32[$118>>2];
      __ZN6b2Vec2C2Eff($7,$117,$119);
      __ZmlfRK6b2Vec2($6,$115,$7);
      __ZplRK6b2Vec2S1_($rhs,$5,$6);
      __ZNK7b2Mat337Solve22ERK6b2Vec2($reduced,$105,$rhs);
      $120 = +HEAPF32[$reduced>>2];
      HEAPF32[$impulse4>>2] = $120;
      $121 = (($reduced) + 4|0);
      $122 = +HEAPF32[$121>>2];
      $123 = (($impulse4) + 4|0);
      HEAPF32[$123>>2] = $122;
      $124 = +HEAPF32[$109>>2];
      $125 = -$124;
      HEAPF32[$111>>2] = $125;
      $126 = +HEAPF32[$reduced>>2];
      $127 = +HEAPF32[$108>>2];
      $128 = $126 + $127;
      HEAPF32[$108>>2] = $128;
      $129 = +HEAPF32[$121>>2];
      $130 = (($this) + 88|0);
      $131 = +HEAPF32[$130>>2];
      $132 = $129 + $131;
      HEAPF32[$130>>2] = $132;
      HEAPF32[$109>>2] = 0.0;
      break;
     } else {
      __ZN6b2Vec3pLERKS_($108,$impulse4);
      break;
     }
    } else if ((($106|0) == 3)) {
     $107 = (($this) + 84|0);
     __ZN6b2Vec3pLERKS_($107,$impulse4);
    } else if ((($106|0) == 2)) {
     $133 = (($this) + 84|0);
     $134 = (($this) + 92|0);
     $135 = +HEAPF32[$134>>2];
     $136 = (($impulse4) + 8|0);
     $137 = +HEAPF32[$136>>2];
     $138 = $135 + $137;
     $139 = $138 > 0.0;
     if ($139) {
      __ZNK6b2Vec2ngEv($8,$Cdot1);
      $140 = +HEAPF32[$134>>2];
      $141 = (($this) + 208|0);
      $142 = +HEAPF32[$141>>2];
      $143 = (($this) + 212|0);
      $144 = +HEAPF32[$143>>2];
      __ZN6b2Vec2C2Eff($10,$142,$144);
      __ZmlfRK6b2Vec2($9,$140,$10);
      __ZplRK6b2Vec2S1_($rhs6,$8,$9);
      __ZNK7b2Mat337Solve22ERK6b2Vec2($reduced7,$105,$rhs6);
      $145 = +HEAPF32[$reduced7>>2];
      HEAPF32[$impulse4>>2] = $145;
      $146 = (($reduced7) + 4|0);
      $147 = +HEAPF32[$146>>2];
      $148 = (($impulse4) + 4|0);
      HEAPF32[$148>>2] = $147;
      $149 = +HEAPF32[$134>>2];
      $150 = -$149;
      HEAPF32[$136>>2] = $150;
      $151 = +HEAPF32[$reduced7>>2];
      $152 = +HEAPF32[$133>>2];
      $153 = $151 + $152;
      HEAPF32[$133>>2] = $153;
      $154 = +HEAPF32[$146>>2];
      $155 = (($this) + 88|0);
      $156 = +HEAPF32[$155>>2];
      $157 = $154 + $156;
      HEAPF32[$155>>2] = $157;
      HEAPF32[$134>>2] = 0.0;
      break;
     } else {
      __ZN6b2Vec3pLERKS_($133,$impulse4);
      break;
     }
    }
   } while(0);
   $158 = +HEAPF32[$impulse4>>2];
   $159 = (($impulse4) + 4|0);
   $160 = +HEAPF32[$159>>2];
   __ZN6b2Vec2C2Eff($P,$158,$160);
   __ZmlfRK6b2Vec2($11,$57,$P);
   __ZN6b2Vec2mIERKS_($vA,$11);
   $161 = (+__Z7b2CrossRK6b2Vec2S1_($100,$P));
   $162 = (($impulse4) + 8|0);
   $163 = +HEAPF32[$162>>2];
   $164 = $161 + $163;
   __ZmlfRK6b2Vec2($12,$59,$P);
   __ZN6b2Vec2pLERKS_($vB,$12);
   $165 = (+__Z7b2CrossRK6b2Vec2S1_($99,$P));
   $166 = +HEAPF32[$162>>2];
   $167 = $165 + $166;
   $$pn3 = $167;$$pn4 = $164;
   $$pn2 = $61 * $$pn4;
   $$pn = $63 * $$pn3;
   $wA$1 = $wA$0 - $$pn2;
   $wB$1 = $wB$0 + $$pn;
   $182 = HEAP32[$20>>2]|0;
   $183 = HEAP32[$22>>2]|0;
   $184 = (($183) + (($182*12)|0)|0);
   $185 = $vA;
   $186 = $185;
   $187 = HEAP32[$186>>2]|0;
   $188 = (($185) + 4)|0;
   $189 = $188;
   $190 = HEAP32[$189>>2]|0;
   $191 = $184;
   $192 = $191;
   HEAP32[$192>>2] = $187;
   $193 = (($191) + 4)|0;
   $194 = $193;
   HEAP32[$194>>2] = $190;
   $195 = HEAP32[$20>>2]|0;
   $196 = HEAP32[$22>>2]|0;
   $197 = ((($196) + (($195*12)|0)|0) + 8|0);
   HEAPF32[$197>>2] = $wA$1;
   $198 = HEAP32[$39>>2]|0;
   $199 = HEAP32[$22>>2]|0;
   $200 = (($199) + (($198*12)|0)|0);
   $201 = $vB;
   $202 = $201;
   $203 = HEAP32[$202>>2]|0;
   $204 = (($201) + 4)|0;
   $205 = $204;
   $206 = HEAP32[$205>>2]|0;
   $207 = $200;
   $208 = $207;
   HEAP32[$208>>2] = $203;
   $209 = (($207) + 4)|0;
   $210 = $209;
   HEAP32[$210>>2] = $206;
   $211 = HEAP32[$39>>2]|0;
   $212 = HEAP32[$22>>2]|0;
   $213 = ((($212) + (($211*12)|0)|0) + 8|0);
   HEAPF32[$213>>2] = $wB$1;
   STACKTOP = sp;return;
  }
 }
 $168 = (($this) + 144|0);
 __Z7b2CrossfRK6b2Vec2($15,$wB$0,$168);
 __ZplRK6b2Vec2S1_($14,$vB,$15);
 __ZmiRK6b2Vec2S1_($13,$14,$vA);
 $169 = (($this) + 136|0);
 __Z7b2CrossfRK6b2Vec2($16,$wA$0,$169);
 __ZmiRK6b2Vec2S1_($Cdot8,$13,$16);
 $170 = (($this) + 184|0);
 __ZNK6b2Vec2ngEv($17,$Cdot8);
 __ZNK7b2Mat337Solve22ERK6b2Vec2($impulse9,$170,$17);
 $171 = +HEAPF32[$impulse9>>2];
 $172 = (($this) + 84|0);
 $173 = +HEAPF32[$172>>2];
 $174 = $171 + $173;
 HEAPF32[$172>>2] = $174;
 $175 = (($impulse9) + 4|0);
 $176 = +HEAPF32[$175>>2];
 $177 = (($this) + 88|0);
 $178 = +HEAPF32[$177>>2];
 $179 = $176 + $178;
 HEAPF32[$177>>2] = $179;
 __ZmlfRK6b2Vec2($18,$57,$impulse9);
 __ZN6b2Vec2mIERKS_($vA,$18);
 $180 = (+__Z7b2CrossRK6b2Vec2S1_($169,$impulse9));
 __ZmlfRK6b2Vec2($19,$59,$impulse9);
 __ZN6b2Vec2pLERKS_($vB,$19);
 $181 = (+__Z7b2CrossRK6b2Vec2S1_($168,$impulse9));
 $$pn3 = $181;$$pn4 = $180;
 $$pn2 = $61 * $$pn4;
 $$pn = $63 * $$pn3;
 $wA$1 = $wA$0 - $$pn2;
 $wB$1 = $wB$0 + $$pn;
 $182 = HEAP32[$20>>2]|0;
 $183 = HEAP32[$22>>2]|0;
 $184 = (($183) + (($182*12)|0)|0);
 $185 = $vA;
 $186 = $185;
 $187 = HEAP32[$186>>2]|0;
 $188 = (($185) + 4)|0;
 $189 = $188;
 $190 = HEAP32[$189>>2]|0;
 $191 = $184;
 $192 = $191;
 HEAP32[$192>>2] = $187;
 $193 = (($191) + 4)|0;
 $194 = $193;
 HEAP32[$194>>2] = $190;
 $195 = HEAP32[$20>>2]|0;
 $196 = HEAP32[$22>>2]|0;
 $197 = ((($196) + (($195*12)|0)|0) + 8|0);
 HEAPF32[$197>>2] = $wA$1;
 $198 = HEAP32[$39>>2]|0;
 $199 = HEAP32[$22>>2]|0;
 $200 = (($199) + (($198*12)|0)|0);
 $201 = $vB;
 $202 = $201;
 $203 = HEAP32[$202>>2]|0;
 $204 = (($201) + 4)|0;
 $205 = $204;
 $206 = HEAP32[$205>>2]|0;
 $207 = $200;
 $208 = $207;
 HEAP32[$208>>2] = $203;
 $209 = (($207) + 4)|0;
 $210 = $209;
 HEAP32[$210>>2] = $206;
 $211 = HEAP32[$39>>2]|0;
 $212 = HEAP32[$22>>2]|0;
 $213 = ((($212) + (($211*12)|0)|0) + 8|0);
 HEAPF32[$213>>2] = $wB$1;
 STACKTOP = sp;return;
}
function __ZN15b2RevoluteJoint24SolvePositionConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0.0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0;
 var $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0, $126 = 0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0;
 var $134 = 0.0, $135 = 0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0, $64 = 0.0, $65 = 0.0;
 var $66 = 0.0, $67 = 0.0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0;
 var $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0.0, $98 = 0, $99 = 0.0, $C3 = 0, $K = 0, $aA$0 = 0.0;
 var $aB$0 = 0.0, $angularError$0 = 0.0, $angularError$1 = 0.0, $brmerge = 0, $cA = 0, $cB = 0, $impulse = 0, $limitImpulse$0 = 0.0, $qA = 0, $qB = 0, $rA = 0, $rB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $cA = sp + 8|0;
 $cB = sp;
 $qA = sp + 128|0;
 $qB = sp + 120|0;
 $rA = sp + 112|0;
 $0 = sp + 104|0;
 $rB = sp + 96|0;
 $1 = sp + 88|0;
 $C3 = sp + 80|0;
 $2 = sp + 72|0;
 $3 = sp + 64|0;
 $K = sp + 48|0;
 $impulse = sp + 40|0;
 $4 = sp + 32|0;
 $5 = sp + 24|0;
 $6 = sp + 16|0;
 $7 = (($this) + 128|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($data) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + (($8*12)|0)|0);
 $12 = $11;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($12) + 4)|0;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = $cA;
 $19 = $18;
 HEAP32[$19>>2] = $14;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = $17;
 $22 = HEAP32[$7>>2]|0;
 $23 = HEAP32[$9>>2]|0;
 $24 = ((($23) + (($22*12)|0)|0) + 8|0);
 $25 = +HEAPF32[$24>>2];
 $26 = (($this) + 132|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($23) + (($27*12)|0)|0);
 $29 = $28;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = (($29) + 4)|0;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = $cB;
 $36 = $35;
 HEAP32[$36>>2] = $31;
 $37 = (($35) + 4)|0;
 $38 = $37;
 HEAP32[$38>>2] = $34;
 $39 = HEAP32[$26>>2]|0;
 $40 = HEAP32[$9>>2]|0;
 $41 = ((($40) + (($39*12)|0)|0) + 8|0);
 $42 = +HEAPF32[$41>>2];
 __ZN5b2RotC2Ef($qA,$25);
 __ZN5b2RotC2Ef($qB,$42);
 $43 = (($this) + 176|0);
 $44 = (($this) + 180|0);
 $45 = (($this) + 112|0);
 $46 = HEAP8[$45>>0]|0;
 $47 = ($46<<24>>24)==(0);
 if ($47) {
  $aA$0 = $25;$aB$0 = $42;$angularError$1 = 0.0;
 } else {
  $48 = +HEAPF32[$44>>2];
  $49 = +HEAPF32[$43>>2];
  $50 = $48 + $49;
  $51 = $50 == 0.0;
  $52 = (($this) + 224|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ($53|0)==(0);
  $brmerge = $54 | $51;
  if ($brmerge) {
   $aA$0 = $25;$aB$0 = $42;$angularError$1 = 0.0;
  } else {
   $55 = $42 - $25;
   $56 = (($this) + 116|0);
   $57 = +HEAPF32[$56>>2];
   $58 = $55 - $57;
   if ((($53|0) == 2)) {
    $78 = (($this) + 124|0);
    $79 = +HEAPF32[$78>>2];
    $80 = $58 - $79;
    $81 = $80 + -0.034906588494777679;
    $82 = (+__Z7b2ClampIfET_S0_S0_S0_($81,0.0,0.13962635397911072));
    $83 = (($this) + 220|0);
    $84 = +HEAPF32[$83>>2];
    $85 = $82 * $84;
    $86 = -$85;
    $angularError$0 = $80;$limitImpulse$0 = $86;
   } else if ((($53|0) == 3)) {
    $59 = (($this) + 120|0);
    $60 = +HEAPF32[$59>>2];
    $61 = $58 - $60;
    $62 = (+__Z7b2ClampIfET_S0_S0_S0_($61,-0.13962635397911072,0.13962635397911072));
    $63 = (($this) + 220|0);
    $64 = +HEAPF32[$63>>2];
    $65 = $62 * $64;
    $66 = -$65;
    $67 = (+__Z5b2AbsIfET_S0_($62));
    $angularError$0 = $67;$limitImpulse$0 = $66;
   } else if ((($53|0) == 1)) {
    $68 = (($this) + 120|0);
    $69 = +HEAPF32[$68>>2];
    $70 = $58 - $69;
    $71 = -$70;
    $72 = $70 + 0.034906588494777679;
    $73 = (+__Z7b2ClampIfET_S0_S0_S0_($72,-0.13962635397911072,0.0));
    $74 = (($this) + 220|0);
    $75 = +HEAPF32[$74>>2];
    $76 = $73 * $75;
    $77 = -$76;
    $angularError$0 = $71;$limitImpulse$0 = $77;
   } else {
    $angularError$0 = 0.0;$limitImpulse$0 = 0.0;
   }
   $87 = +HEAPF32[$43>>2];
   $88 = $limitImpulse$0 * $87;
   $89 = $25 - $88;
   $90 = +HEAPF32[$44>>2];
   $91 = $limitImpulse$0 * $90;
   $92 = $42 + $91;
   $aA$0 = $89;$aB$0 = $92;$angularError$1 = $angularError$0;
  }
 }
 __ZN5b2Rot3SetEf($qA,$aA$0);
 __ZN5b2Rot3SetEf($qB,$aB$0);
 $93 = (($this) + 68|0);
 $94 = (($this) + 152|0);
 __ZmiRK6b2Vec2S1_($0,$93,$94);
 __Z5b2MulRK5b2RotRK6b2Vec2($rA,$qA,$0);
 $95 = (($this) + 76|0);
 $96 = (($this) + 160|0);
 __ZmiRK6b2Vec2S1_($1,$95,$96);
 __Z5b2MulRK5b2RotRK6b2Vec2($rB,$qB,$1);
 __ZplRK6b2Vec2S1_($3,$cB,$rB);
 __ZmiRK6b2Vec2S1_($2,$3,$cA);
 __ZmiRK6b2Vec2S1_($C3,$2,$rA);
 $97 = (+__ZNK6b2Vec26LengthEv($C3));
 $98 = (($this) + 168|0);
 $99 = +HEAPF32[$98>>2];
 $100 = (($this) + 172|0);
 $101 = +HEAPF32[$100>>2];
 $102 = +HEAPF32[$43>>2];
 $103 = +HEAPF32[$44>>2];
 $104 = $99 + $101;
 $105 = (($rA) + 4|0);
 $106 = +HEAPF32[$105>>2];
 $107 = $102 * $106;
 $108 = $106 * $107;
 $109 = $104 + $108;
 $110 = (($rB) + 4|0);
 $111 = +HEAPF32[$110>>2];
 $112 = $103 * $111;
 $113 = $111 * $112;
 $114 = $109 + $113;
 HEAPF32[$K>>2] = $114;
 $115 = +HEAPF32[$rA>>2];
 $116 = $102 * $115;
 $117 = +HEAPF32[$105>>2];
 $118 = $116 * $117;
 $119 = -$118;
 $120 = +HEAPF32[$rB>>2];
 $121 = $103 * $120;
 $122 = +HEAPF32[$110>>2];
 $123 = $121 * $122;
 $124 = $119 - $123;
 $125 = (($K) + 4|0);
 HEAPF32[$125>>2] = $124;
 $126 = (($K) + 8|0);
 HEAPF32[$126>>2] = $124;
 $127 = +HEAPF32[$rA>>2];
 $128 = $102 * $127;
 $129 = $127 * $128;
 $130 = $104 + $129;
 $131 = +HEAPF32[$rB>>2];
 $132 = $103 * $131;
 $133 = $131 * $132;
 $134 = $130 + $133;
 $135 = (($K) + 12|0);
 HEAPF32[$135>>2] = $134;
 __ZNK7b2Mat225SolveERK6b2Vec2($4,$K,$C3);
 __ZNK6b2Vec2ngEv($impulse,$4);
 __ZmlfRK6b2Vec2($5,$99,$impulse);
 __ZN6b2Vec2mIERKS_($cA,$5);
 $136 = (+__Z7b2CrossRK6b2Vec2S1_($rA,$impulse));
 $137 = $102 * $136;
 $138 = $aA$0 - $137;
 __ZmlfRK6b2Vec2($6,$101,$impulse);
 __ZN6b2Vec2pLERKS_($cB,$6);
 $139 = (+__Z7b2CrossRK6b2Vec2S1_($rB,$impulse));
 $140 = $103 * $139;
 $141 = $aB$0 + $140;
 $142 = HEAP32[$7>>2]|0;
 $143 = HEAP32[$9>>2]|0;
 $144 = (($143) + (($142*12)|0)|0);
 $145 = $cA;
 $146 = $145;
 $147 = HEAP32[$146>>2]|0;
 $148 = (($145) + 4)|0;
 $149 = $148;
 $150 = HEAP32[$149>>2]|0;
 $151 = $144;
 $152 = $151;
 HEAP32[$152>>2] = $147;
 $153 = (($151) + 4)|0;
 $154 = $153;
 HEAP32[$154>>2] = $150;
 $155 = HEAP32[$7>>2]|0;
 $156 = HEAP32[$9>>2]|0;
 $157 = ((($156) + (($155*12)|0)|0) + 8|0);
 HEAPF32[$157>>2] = $138;
 $158 = HEAP32[$26>>2]|0;
 $159 = HEAP32[$9>>2]|0;
 $160 = (($159) + (($158*12)|0)|0);
 $161 = $cB;
 $162 = $161;
 $163 = HEAP32[$162>>2]|0;
 $164 = (($161) + 4)|0;
 $165 = $164;
 $166 = HEAP32[$165>>2]|0;
 $167 = $160;
 $168 = $167;
 HEAP32[$168>>2] = $163;
 $169 = (($167) + 4)|0;
 $170 = $169;
 HEAP32[$170>>2] = $166;
 $171 = HEAP32[$26>>2]|0;
 $172 = HEAP32[$9>>2]|0;
 $173 = ((($172) + (($171*12)|0)|0) + 8|0);
 HEAPF32[$173>>2] = $141;
 $174 = !($97 <= 0.004999999888241291);
 if ($174) {
  $176 = 0;
  STACKTOP = sp;return ($176|0);
 }
 $175 = $angularError$1 <= 0.034906588494777679;
 $176 = $175;
 STACKTOP = sp;return ($176|0);
}
function __ZNK15b2RevoluteJoint10GetAnchorAEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 68|0);
 __ZNK6b2Body13GetWorldPointERK6b2Vec2($agg$result,$1,$2);
 STACKTOP = sp;return;
}
function __ZNK15b2RevoluteJoint10GetAnchorBEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 76|0);
 __ZNK6b2Body13GetWorldPointERK6b2Vec2($agg$result,$1,$2);
 STACKTOP = sp;return;
}
function __ZNK15b2RevoluteJoint16GetReactionForceEf($agg$result,$this,$inv_dt) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inv_dt = +$inv_dt;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0.0, $P = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $P = sp;
 $0 = (($this) + 84|0);
 $1 = +HEAPF32[$0>>2];
 $2 = (($this) + 88|0);
 $3 = +HEAPF32[$2>>2];
 __ZN6b2Vec2C2Eff($P,$1,$3);
 __ZmlfRK6b2Vec2($agg$result,$inv_dt,$P);
 STACKTOP = sp;return;
}
function __ZNK15b2RevoluteJoint17GetReactionTorqueEf($this,$inv_dt) {
 $this = $this|0;
 $inv_dt = +$inv_dt;
 var $0 = 0, $1 = 0.0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 92|0);
 $1 = +HEAPF32[$0>>2];
 $2 = $1 * $inv_dt;
 STACKTOP = sp;return (+$2);
}
function __ZNK15b2RevoluteJoint13GetJointAngleEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + 72|0);
 $5 = +HEAPF32[$4>>2];
 $6 = (($1) + 72|0);
 $7 = +HEAPF32[$6>>2];
 $8 = $5 - $7;
 $9 = (($this) + 116|0);
 $10 = +HEAPF32[$9>>2];
 $11 = $8 - $10;
 STACKTOP = sp;return (+$11);
}
function __ZNK15b2RevoluteJoint14IsMotorEnabledEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 100|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN15b2RevoluteJoint11EnableMotorEb($this,$flag) {
 $this = $this|0;
 $flag = $flag|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN6b2Body8SetAwakeEb($1,1);
 $2 = (($this) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN6b2Body8SetAwakeEb($3,1);
 $4 = (($this) + 100|0);
 $5 = $flag&1;
 HEAP8[$4>>0] = $5;
 STACKTOP = sp;return;
}
function __ZN15b2RevoluteJoint13SetMotorSpeedEf($this,$speed) {
 $this = $this|0;
 $speed = +$speed;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN6b2Body8SetAwakeEb($1,1);
 $2 = (($this) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN6b2Body8SetAwakeEb($3,1);
 $4 = (($this) + 108|0);
 HEAPF32[$4>>2] = $speed;
 STACKTOP = sp;return;
}
function __ZNK15b2RevoluteJoint14IsLimitEnabledEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 112|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN15b2RevoluteJoint11EnableLimitEb($this,$flag) {
 $this = $this|0;
 $flag = $flag|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $flag&1;
 $1 = (($this) + 112|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2&255;
 $4 = ($0|0)==($3|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 48|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN6b2Body8SetAwakeEb($6,1);
 $7 = (($this) + 52|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN6b2Body8SetAwakeEb($8,1);
 $9 = $flag&1;
 HEAP8[$1>>0] = $9;
 $10 = (($this) + 92|0);
 HEAPF32[$10>>2] = 0.0;
 STACKTOP = sp;return;
}
function __ZN15b2RevoluteJoint4DumpEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0.0, $43 = 0.0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer38 = 0, $vararg_ptr12 = 0, $vararg_ptr16 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer38 = sp;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 __Z5b2LogPKcz(5840,$vararg_buffer38);
 HEAP32[$vararg_buffer38>>2] = $3;
 __Z5b2LogPKcz(5872,$vararg_buffer38);
 HEAP32[$vararg_buffer38>>2] = $7;
 __Z5b2LogPKcz(5904,$vararg_buffer38);
 $8 = (($this) + 61|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 HEAP32[$vararg_buffer38>>2] = $10;
 __Z5b2LogPKcz(5936,$vararg_buffer38);
 $11 = (($this) + 68|0);
 $12 = +HEAPF32[$11>>2];
 $13 = $12;
 $14 = (($this) + 72|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $15;
 HEAPF64[tempDoublePtr>>3]=$13;HEAP32[$vararg_buffer38>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer38+4>>2]=HEAP32[tempDoublePtr+4>>2];
 $vararg_ptr12 = (($vararg_buffer38) + 8|0);
 HEAPF64[tempDoublePtr>>3]=$16;HEAP32[$vararg_ptr12>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr12+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(5976,$vararg_buffer38);
 $17 = (($this) + 76|0);
 $18 = +HEAPF32[$17>>2];
 $19 = $18;
 $20 = (($this) + 80|0);
 $21 = +HEAPF32[$20>>2];
 $22 = $21;
 HEAPF64[tempDoublePtr>>3]=$19;HEAP32[$vararg_buffer38>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer38+4>>2]=HEAP32[tempDoublePtr+4>>2];
 $vararg_ptr16 = (($vararg_buffer38) + 8|0);
 HEAPF64[tempDoublePtr>>3]=$22;HEAP32[$vararg_ptr16>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr16+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(6024,$vararg_buffer38);
 $23 = (($this) + 116|0);
 $24 = +HEAPF32[$23>>2];
 $25 = $24;
 HEAPF64[tempDoublePtr>>3]=$25;HEAP32[$vararg_buffer38>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer38+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(6072,$vararg_buffer38);
 $26 = (($this) + 112|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = $27&255;
 HEAP32[$vararg_buffer38>>2] = $28;
 __Z5b2LogPKcz(6104,$vararg_buffer38);
 $29 = (($this) + 120|0);
 $30 = +HEAPF32[$29>>2];
 $31 = $30;
 HEAPF64[tempDoublePtr>>3]=$31;HEAP32[$vararg_buffer38>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer38+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(6136,$vararg_buffer38);
 $32 = (($this) + 124|0);
 $33 = +HEAPF32[$32>>2];
 $34 = $33;
 HEAPF64[tempDoublePtr>>3]=$34;HEAP32[$vararg_buffer38>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer38+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(6168,$vararg_buffer38);
 $35 = (($this) + 100|0);
 $36 = HEAP8[$35>>0]|0;
 $37 = $36&255;
 HEAP32[$vararg_buffer38>>2] = $37;
 __Z5b2LogPKcz(6200,$vararg_buffer38);
 $38 = (($this) + 108|0);
 $39 = +HEAPF32[$38>>2];
 $40 = $39;
 HEAPF64[tempDoublePtr>>3]=$40;HEAP32[$vararg_buffer38>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer38+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(6232,$vararg_buffer38);
 $41 = (($this) + 104|0);
 $42 = +HEAPF32[$41>>2];
 $43 = $42;
 HEAPF64[tempDoublePtr>>3]=$43;HEAP32[$vararg_buffer38>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer38+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(6264,$vararg_buffer38);
 $44 = (($this) + 56|0);
 $45 = HEAP32[$44>>2]|0;
 HEAP32[$vararg_buffer38>>2] = $45;
 __Z5b2LogPKcz(6296,$vararg_buffer38);
 STACKTOP = sp;return;
}
function __ZN15b2RevoluteJointD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN15b2WheelJointDef10InitializeEP6b2BodyS1_RK6b2Vec2S4_($this,$bA,$bB,$anchor,$axis) {
 $this = $this|0;
 $bA = $bA|0;
 $bB = $bB|0;
 $anchor = $anchor|0;
 $axis = $axis|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $bA;
 $4 = (($this) + 12|0);
 HEAP32[$4>>2] = $bB;
 $5 = (($this) + 20|0);
 $6 = HEAP32[$3>>2]|0;
 __ZNK6b2Body13GetLocalPointERK6b2Vec2($0,$6,$anchor);
 $7 = $0;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 4)|0;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = $5;
 $14 = $13;
 HEAP32[$14>>2] = $9;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = $12;
 $17 = (($this) + 28|0);
 $18 = HEAP32[$4>>2]|0;
 __ZNK6b2Body13GetLocalPointERK6b2Vec2($1,$18,$anchor);
 $19 = $1;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) + 4)|0;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 $25 = $17;
 $26 = $25;
 HEAP32[$26>>2] = $21;
 $27 = (($25) + 4)|0;
 $28 = $27;
 HEAP32[$28>>2] = $24;
 $29 = (($this) + 36|0);
 $30 = HEAP32[$3>>2]|0;
 __ZNK6b2Body14GetLocalVectorERK6b2Vec2($2,$30,$axis);
 $31 = $2;
 $32 = $31;
 $33 = HEAP32[$32>>2]|0;
 $34 = (($31) + 4)|0;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = $29;
 $38 = $37;
 HEAP32[$38>>2] = $33;
 $39 = (($37) + 4)|0;
 $40 = $39;
 HEAP32[$40>>2] = $36;
 STACKTOP = sp;return;
}
function __ZN12b2WheelJointC2EPK15b2WheelJointDef($this,$def) {
 $this = $this|0;
 $def = $def|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN7b2JointC2EPK10b2JointDef($this,$def);
 HEAP32[$this>>2] = ((6384 + 8|0));
 $1 = (($this) + 76|0);
 $2 = (($this) + 84|0);
 $3 = (($this) + 92|0);
 $4 = (($this) + 100|0);
 $5 = (($this) + 172|0);
 $6 = (($this) + 180|0);
 $7 = (($def) + 20|0);
 $8 = $7;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = $1;
 $15 = $14;
 HEAP32[$15>>2] = $10;
 $16 = (($14) + 4)|0;
 $17 = $16;
 HEAP32[$17>>2] = $13;
 $18 = (($def) + 28|0);
 $19 = $18;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) + 4)|0;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 $25 = $2;
 $26 = $25;
 HEAP32[$26>>2] = $21;
 $27 = (($25) + 4)|0;
 $28 = $27;
 HEAP32[$28>>2] = $24;
 $29 = (($def) + 36|0);
 $30 = $29;
 $31 = $30;
 $32 = HEAP32[$31>>2]|0;
 $33 = (($30) + 4)|0;
 $34 = $33;
 $35 = HEAP32[$34>>2]|0;
 $36 = $3;
 $37 = $36;
 HEAP32[$37>>2] = $32;
 $38 = (($36) + 4)|0;
 $39 = $38;
 HEAP32[$39>>2] = $35;
 __Z7b2CrossfRK6b2Vec2($0,1.0,$3);
 $40 = $0;
 $41 = $40;
 $42 = HEAP32[$41>>2]|0;
 $43 = (($40) + 4)|0;
 $44 = $43;
 $45 = HEAP32[$44>>2]|0;
 $46 = $4;
 $47 = $46;
 HEAP32[$47>>2] = $42;
 $48 = (($46) + 4)|0;
 $49 = $48;
 HEAP32[$49>>2] = $45;
 $50 = (($this) + 204|0);
 HEAPF32[$50>>2] = 0.0;
 $51 = (($this) + 108|0);
 HEAPF32[$51>>2] = 0.0;
 $52 = (($this) + 208|0);
 HEAPF32[$52>>2] = 0.0;
 $53 = (($this) + 112|0);
 HEAPF32[$53>>2] = 0.0;
 $54 = (($this) + 212|0);
 HEAPF32[$54>>2] = 0.0;
 $55 = (($this) + 116|0);
 HEAPF32[$55>>2] = 0.0;
 $56 = (($def) + 48|0);
 $57 = +HEAPF32[$56>>2];
 $58 = (($this) + 120|0);
 HEAPF32[$58>>2] = $57;
 $59 = (($def) + 52|0);
 $60 = +HEAPF32[$59>>2];
 $61 = (($this) + 124|0);
 HEAPF32[$61>>2] = $60;
 $62 = (($def) + 44|0);
 $63 = HEAP8[$62>>0]|0;
 $64 = (($this) + 128|0);
 HEAP8[$64>>0] = $63;
 $65 = (($def) + 56|0);
 $66 = +HEAPF32[$65>>2];
 $67 = (($this) + 68|0);
 HEAPF32[$67>>2] = $66;
 $68 = (($def) + 60|0);
 $69 = +HEAPF32[$68>>2];
 $70 = (($this) + 72|0);
 HEAPF32[$70>>2] = $69;
 $71 = (($this) + 216|0);
 HEAPF32[$71>>2] = 0.0;
 $72 = (($this) + 220|0);
 HEAPF32[$72>>2] = 0.0;
 __ZN6b2Vec27SetZeroEv($5);
 __ZN6b2Vec27SetZeroEv($6);
 STACKTOP = sp;return;
}
function __ZN12b2WheelJoint23InitVelocityConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0.0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0.0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0.0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0.0, $15 = 0, $150 = 0, $151 = 0.0;
 var $152 = 0, $153 = 0.0, $154 = 0.0, $155 = 0.0, $156 = 0.0, $157 = 0.0, $158 = 0.0, $159 = 0.0, $16 = 0, $160 = 0.0, $161 = 0, $162 = 0, $163 = 0.0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0.0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0.0, $183 = 0, $184 = 0.0, $185 = 0, $186 = 0.0, $187 = 0.0, $188 = 0.0;
 var $189 = 0.0, $19 = 0, $190 = 0.0, $191 = 0.0, $192 = 0.0, $193 = 0, $194 = 0.0, $195 = 0.0, $196 = 0.0, $197 = 0.0, $198 = 0.0, $199 = 0, $2 = 0, $20 = 0, $200 = 0.0, $201 = 0.0, $202 = 0.0, $203 = 0.0, $204 = 0.0, $205 = 0.0;
 var $206 = 0.0, $207 = 0.0, $208 = 0.0, $209 = 0, $21 = 0, $210 = 0.0, $211 = 0.0, $212 = 0.0, $213 = 0.0, $214 = 0.0, $215 = 0.0, $216 = 0, $217 = 0.0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0.0, $223 = 0;
 var $224 = 0, $225 = 0.0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0.0, $233 = 0, $234 = 0.0, $235 = 0.0, $236 = 0.0, $237 = 0, $238 = 0.0, $239 = 0.0, $24 = 0, $240 = 0.0, $241 = 0;
 var $242 = 0.0, $243 = 0.0, $244 = 0.0, $245 = 0.0, $246 = 0, $247 = 0.0, $248 = 0.0, $249 = 0.0, $25 = 0, $250 = 0.0, $251 = 0, $252 = 0.0, $253 = 0.0, $254 = 0.0, $255 = 0.0, $256 = 0.0, $257 = 0.0, $258 = 0.0, $259 = 0, $26 = 0;
 var $260 = 0.0, $261 = 0.0, $262 = 0.0, $263 = 0.0, $264 = 0.0, $265 = 0.0, $266 = 0.0, $267 = 0.0, $268 = 0.0, $269 = 0.0, $27 = 0, $270 = 0.0, $271 = 0.0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0.0, $63 = 0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0.0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $P = 0, $cA = 0, $cB = 0, $d = 0, $qA = 0, $qB = 0, $rA = 0, $rB = 0, $storemerge = 0.0, $storemerge6 = 0.0, $vA = 0, $vB = 0, $wA$0 = 0.0;
 var $wB$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0;
 $cA = sp + 40|0;
 $vA = sp + 32|0;
 $cB = sp + 24|0;
 $vB = sp + 16|0;
 $qA = sp + 168|0;
 $qB = sp + 160|0;
 $rA = sp + 152|0;
 $0 = sp + 144|0;
 $rB = sp + 136|0;
 $1 = sp + 128|0;
 $d = sp + 120|0;
 $2 = sp + 112|0;
 $3 = sp + 104|0;
 $4 = sp + 8|0;
 $5 = sp + 96|0;
 $6 = sp;
 $7 = sp + 88|0;
 $P = sp + 80|0;
 $8 = sp + 72|0;
 $9 = sp + 64|0;
 $10 = sp + 56|0;
 $11 = sp + 48|0;
 $12 = (($this) + 48|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 132|0);
 HEAP32[$16>>2] = $15;
 $17 = (($this) + 52|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($this) + 136|0);
 HEAP32[$21>>2] = $20;
 $22 = (($this) + 140|0);
 $23 = HEAP32[$12>>2]|0;
 $24 = (($23) + 44|0);
 $25 = $24;
 $26 = $25;
 $27 = HEAP32[$26>>2]|0;
 $28 = (($25) + 4)|0;
 $29 = $28;
 $30 = HEAP32[$29>>2]|0;
 $31 = $22;
 $32 = $31;
 HEAP32[$32>>2] = $27;
 $33 = (($31) + 4)|0;
 $34 = $33;
 HEAP32[$34>>2] = $30;
 $35 = (($this) + 148|0);
 $36 = HEAP32[$17>>2]|0;
 $37 = (($36) + 44|0);
 $38 = $37;
 $39 = $38;
 $40 = HEAP32[$39>>2]|0;
 $41 = (($38) + 4)|0;
 $42 = $41;
 $43 = HEAP32[$42>>2]|0;
 $44 = $35;
 $45 = $44;
 HEAP32[$45>>2] = $40;
 $46 = (($44) + 4)|0;
 $47 = $46;
 HEAP32[$47>>2] = $43;
 $48 = HEAP32[$12>>2]|0;
 $49 = (($48) + 136|0);
 $50 = +HEAPF32[$49>>2];
 $51 = (($this) + 156|0);
 HEAPF32[$51>>2] = $50;
 $52 = HEAP32[$17>>2]|0;
 $53 = (($52) + 136|0);
 $54 = +HEAPF32[$53>>2];
 $55 = (($this) + 160|0);
 HEAPF32[$55>>2] = $54;
 $56 = HEAP32[$12>>2]|0;
 $57 = (($56) + 144|0);
 $58 = +HEAPF32[$57>>2];
 $59 = (($this) + 164|0);
 HEAPF32[$59>>2] = $58;
 $60 = HEAP32[$17>>2]|0;
 $61 = (($60) + 144|0);
 $62 = +HEAPF32[$61>>2];
 $63 = (($this) + 168|0);
 HEAPF32[$63>>2] = $62;
 $64 = +HEAPF32[$51>>2];
 $65 = +HEAPF32[$55>>2];
 $66 = +HEAPF32[$59>>2];
 $67 = HEAP32[$16>>2]|0;
 $68 = (($data) + 28|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = (($69) + (($67*12)|0)|0);
 $71 = $70;
 $72 = $71;
 $73 = HEAP32[$72>>2]|0;
 $74 = (($71) + 4)|0;
 $75 = $74;
 $76 = HEAP32[$75>>2]|0;
 $77 = $cA;
 $78 = $77;
 HEAP32[$78>>2] = $73;
 $79 = (($77) + 4)|0;
 $80 = $79;
 HEAP32[$80>>2] = $76;
 $81 = HEAP32[$16>>2]|0;
 $82 = HEAP32[$68>>2]|0;
 $83 = ((($82) + (($81*12)|0)|0) + 8|0);
 $84 = +HEAPF32[$83>>2];
 $85 = (($data) + 32|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = (($86) + (($81*12)|0)|0);
 $88 = $87;
 $89 = $88;
 $90 = HEAP32[$89>>2]|0;
 $91 = (($88) + 4)|0;
 $92 = $91;
 $93 = HEAP32[$92>>2]|0;
 $94 = $vA;
 $95 = $94;
 HEAP32[$95>>2] = $90;
 $96 = (($94) + 4)|0;
 $97 = $96;
 HEAP32[$97>>2] = $93;
 $98 = HEAP32[$16>>2]|0;
 $99 = HEAP32[$85>>2]|0;
 $100 = ((($99) + (($98*12)|0)|0) + 8|0);
 $101 = +HEAPF32[$100>>2];
 $102 = HEAP32[$21>>2]|0;
 $103 = HEAP32[$68>>2]|0;
 $104 = (($103) + (($102*12)|0)|0);
 $105 = $104;
 $106 = $105;
 $107 = HEAP32[$106>>2]|0;
 $108 = (($105) + 4)|0;
 $109 = $108;
 $110 = HEAP32[$109>>2]|0;
 $111 = $cB;
 $112 = $111;
 HEAP32[$112>>2] = $107;
 $113 = (($111) + 4)|0;
 $114 = $113;
 HEAP32[$114>>2] = $110;
 $115 = HEAP32[$21>>2]|0;
 $116 = HEAP32[$68>>2]|0;
 $117 = ((($116) + (($115*12)|0)|0) + 8|0);
 $118 = +HEAPF32[$117>>2];
 $119 = HEAP32[$85>>2]|0;
 $120 = (($119) + (($115*12)|0)|0);
 $121 = $120;
 $122 = $121;
 $123 = HEAP32[$122>>2]|0;
 $124 = (($121) + 4)|0;
 $125 = $124;
 $126 = HEAP32[$125>>2]|0;
 $127 = $vB;
 $128 = $127;
 HEAP32[$128>>2] = $123;
 $129 = (($127) + 4)|0;
 $130 = $129;
 HEAP32[$130>>2] = $126;
 $131 = HEAP32[$21>>2]|0;
 $132 = HEAP32[$85>>2]|0;
 $133 = ((($132) + (($131*12)|0)|0) + 8|0);
 $134 = +HEAPF32[$133>>2];
 __ZN5b2RotC2Ef($qA,$84);
 __ZN5b2RotC2Ef($qB,$118);
 $135 = (($this) + 76|0);
 __ZmiRK6b2Vec2S1_($0,$135,$22);
 __Z5b2MulRK5b2RotRK6b2Vec2($rA,$qA,$0);
 $136 = (($this) + 84|0);
 __ZmiRK6b2Vec2S1_($1,$136,$35);
 __Z5b2MulRK5b2RotRK6b2Vec2($rB,$qB,$1);
 __ZplRK6b2Vec2S1_($3,$cB,$rB);
 __ZmiRK6b2Vec2S1_($2,$3,$cA);
 __ZmiRK6b2Vec2S1_($d,$2,$rA);
 $137 = (($this) + 180|0);
 $138 = (($this) + 100|0);
 __Z5b2MulRK5b2RotRK6b2Vec2($4,$qA,$138);
 $139 = $4;
 $140 = $139;
 $141 = HEAP32[$140>>2]|0;
 $142 = (($139) + 4)|0;
 $143 = $142;
 $144 = HEAP32[$143>>2]|0;
 $145 = $137;
 $146 = $145;
 HEAP32[$146>>2] = $141;
 $147 = (($145) + 4)|0;
 $148 = $147;
 HEAP32[$148>>2] = $144;
 __ZplRK6b2Vec2S1_($5,$d,$rA);
 $149 = (+__Z7b2CrossRK6b2Vec2S1_($5,$137));
 $150 = (($this) + 196|0);
 HEAPF32[$150>>2] = $149;
 $151 = (+__Z7b2CrossRK6b2Vec2S1_($rB,$137));
 $152 = (($this) + 200|0);
 HEAPF32[$152>>2] = $151;
 $153 = $64 + $65;
 $154 = +HEAPF32[$150>>2];
 $155 = $66 * $154;
 $156 = $154 * $155;
 $157 = $153 + $156;
 $158 = $62 * $151;
 $159 = $151 * $158;
 $160 = $159 + $157;
 $161 = (($this) + 204|0);
 $162 = $160 > 0.0;
 if ($162) {
  $163 = 1.0 / $160;
  $storemerge6 = $163;
 } else {
  $storemerge6 = $160;
 }
 HEAPF32[$161>>2] = $storemerge6;
 $164 = (($this) + 212|0);
 HEAPF32[$164>>2] = 0.0;
 $165 = (($this) + 216|0);
 HEAPF32[$165>>2] = 0.0;
 $166 = (($this) + 220|0);
 HEAPF32[$166>>2] = 0.0;
 $167 = (($this) + 68|0);
 $168 = +HEAPF32[$167>>2];
 $169 = $168 > 0.0;
 if ($169) {
  $170 = (($this) + 172|0);
  $171 = (($this) + 92|0);
  __Z5b2MulRK5b2RotRK6b2Vec2($6,$qA,$171);
  $172 = $6;
  $173 = $172;
  $174 = HEAP32[$173>>2]|0;
  $175 = (($172) + 4)|0;
  $176 = $175;
  $177 = HEAP32[$176>>2]|0;
  $178 = $170;
  $179 = $178;
  HEAP32[$179>>2] = $174;
  $180 = (($178) + 4)|0;
  $181 = $180;
  HEAP32[$181>>2] = $177;
  __ZplRK6b2Vec2S1_($7,$d,$rA);
  $182 = (+__Z7b2CrossRK6b2Vec2S1_($7,$170));
  $183 = (($this) + 188|0);
  HEAPF32[$183>>2] = $182;
  $184 = (+__Z7b2CrossRK6b2Vec2S1_($rB,$170));
  $185 = (($this) + 192|0);
  HEAPF32[$185>>2] = $184;
  $186 = +HEAPF32[$183>>2];
  $187 = $66 * $186;
  $188 = $186 * $187;
  $189 = $153 + $188;
  $190 = $62 * $184;
  $191 = $184 * $190;
  $192 = $191 + $189;
  $193 = $192 > 0.0;
  if ($193) {
   $194 = 1.0 / $192;
   HEAPF32[$164>>2] = $194;
   $195 = (+__Z5b2DotRK6b2Vec2S1_($d,$170));
   $196 = +HEAPF32[$167>>2];
   $197 = $196 * 6.2831854820251465;
   $198 = $194 * 2.0;
   $199 = (($this) + 72|0);
   $200 = +HEAPF32[$199>>2];
   $201 = $198 * $200;
   $202 = $197 * $201;
   $203 = $194 * $197;
   $204 = $197 * $203;
   $205 = +HEAPF32[$data>>2];
   $206 = $205 * $204;
   $207 = $202 + $206;
   $208 = $205 * $207;
   $209 = $208 > 0.0;
   if ($209) {
    $210 = 1.0 / $208;
    $storemerge = $210;
   } else {
    $storemerge = $208;
   }
   HEAPF32[$166>>2] = $storemerge;
   $211 = $195 * $205;
   $212 = $211 * $204;
   $213 = $212 * $storemerge;
   HEAPF32[$165>>2] = $213;
   $214 = +HEAPF32[$166>>2];
   $215 = $192 + $214;
   HEAPF32[$164>>2] = $215;
   $216 = $215 > 0.0;
   if ($216) {
    $217 = 1.0 / $215;
    HEAPF32[$164>>2] = $217;
   }
  }
 } else {
  $218 = (($this) + 116|0);
  HEAPF32[$218>>2] = 0.0;
 }
 $219 = (($this) + 128|0);
 $220 = HEAP8[$219>>0]|0;
 $221 = ($220<<24>>24)==(0);
 if ($221) {
  $226 = (($this) + 208|0);
  HEAPF32[$226>>2] = 0.0;
  $227 = (($this) + 112|0);
  HEAPF32[$227>>2] = 0.0;
 } else {
  $222 = $62 + $66;
  $223 = (($this) + 208|0);
  HEAPF32[$223>>2] = $222;
  $224 = $222 > 0.0;
  if ($224) {
   $225 = 1.0 / $222;
   HEAPF32[$223>>2] = $225;
  }
 }
 $228 = (($data) + 24|0);
 $229 = HEAP8[$228>>0]|0;
 $230 = ($229<<24>>24)==(0);
 if ($230) {
  $272 = (($this) + 108|0);
  HEAPF32[$272>>2] = 0.0;
  $273 = (($this) + 116|0);
  HEAPF32[$273>>2] = 0.0;
  $274 = (($this) + 112|0);
  HEAPF32[$274>>2] = 0.0;
  $wA$0 = $101;$wB$0 = $134;
  $275 = HEAP32[$16>>2]|0;
  $276 = HEAP32[$85>>2]|0;
  $277 = (($276) + (($275*12)|0)|0);
  $278 = $vA;
  $279 = $278;
  $280 = HEAP32[$279>>2]|0;
  $281 = (($278) + 4)|0;
  $282 = $281;
  $283 = HEAP32[$282>>2]|0;
  $284 = $277;
  $285 = $284;
  HEAP32[$285>>2] = $280;
  $286 = (($284) + 4)|0;
  $287 = $286;
  HEAP32[$287>>2] = $283;
  $288 = HEAP32[$16>>2]|0;
  $289 = HEAP32[$85>>2]|0;
  $290 = ((($289) + (($288*12)|0)|0) + 8|0);
  HEAPF32[$290>>2] = $wA$0;
  $291 = HEAP32[$21>>2]|0;
  $292 = HEAP32[$85>>2]|0;
  $293 = (($292) + (($291*12)|0)|0);
  $294 = $vB;
  $295 = $294;
  $296 = HEAP32[$295>>2]|0;
  $297 = (($294) + 4)|0;
  $298 = $297;
  $299 = HEAP32[$298>>2]|0;
  $300 = $293;
  $301 = $300;
  HEAP32[$301>>2] = $296;
  $302 = (($300) + 4)|0;
  $303 = $302;
  HEAP32[$303>>2] = $299;
  $304 = HEAP32[$21>>2]|0;
  $305 = HEAP32[$85>>2]|0;
  $306 = ((($305) + (($304*12)|0)|0) + 8|0);
  HEAPF32[$306>>2] = $wB$0;
  STACKTOP = sp;return;
 } else {
  $231 = (($data) + 8|0);
  $232 = +HEAPF32[$231>>2];
  $233 = (($this) + 108|0);
  $234 = +HEAPF32[$233>>2];
  $235 = $232 * $234;
  HEAPF32[$233>>2] = $235;
  $236 = +HEAPF32[$231>>2];
  $237 = (($this) + 116|0);
  $238 = +HEAPF32[$237>>2];
  $239 = $236 * $238;
  HEAPF32[$237>>2] = $239;
  $240 = +HEAPF32[$231>>2];
  $241 = (($this) + 112|0);
  $242 = +HEAPF32[$241>>2];
  $243 = $240 * $242;
  HEAPF32[$241>>2] = $243;
  $244 = +HEAPF32[$233>>2];
  __ZmlfRK6b2Vec2($8,$244,$137);
  $245 = +HEAPF32[$237>>2];
  $246 = (($this) + 172|0);
  __ZmlfRK6b2Vec2($9,$245,$246);
  __ZplRK6b2Vec2S1_($P,$8,$9);
  $247 = +HEAPF32[$233>>2];
  $248 = +HEAPF32[$150>>2];
  $249 = $247 * $248;
  $250 = +HEAPF32[$237>>2];
  $251 = (($this) + 188|0);
  $252 = +HEAPF32[$251>>2];
  $253 = $250 * $252;
  $254 = $249 + $253;
  $255 = +HEAPF32[$241>>2];
  $256 = $255 + $254;
  $257 = +HEAPF32[$152>>2];
  $258 = $247 * $257;
  $259 = (($this) + 192|0);
  $260 = +HEAPF32[$259>>2];
  $261 = $250 * $260;
  $262 = $258 + $261;
  $263 = $255 + $262;
  $264 = +HEAPF32[$51>>2];
  __ZmlfRK6b2Vec2($10,$264,$P);
  __ZN6b2Vec2mIERKS_($vA,$10);
  $265 = +HEAPF32[$59>>2];
  $266 = $256 * $265;
  $267 = $101 - $266;
  $268 = +HEAPF32[$55>>2];
  __ZmlfRK6b2Vec2($11,$268,$P);
  __ZN6b2Vec2pLERKS_($vB,$11);
  $269 = +HEAPF32[$63>>2];
  $270 = $263 * $269;
  $271 = $134 + $270;
  $wA$0 = $267;$wB$0 = $271;
  $275 = HEAP32[$16>>2]|0;
  $276 = HEAP32[$85>>2]|0;
  $277 = (($276) + (($275*12)|0)|0);
  $278 = $vA;
  $279 = $278;
  $280 = HEAP32[$279>>2]|0;
  $281 = (($278) + 4)|0;
  $282 = $281;
  $283 = HEAP32[$282>>2]|0;
  $284 = $277;
  $285 = $284;
  HEAP32[$285>>2] = $280;
  $286 = (($284) + 4)|0;
  $287 = $286;
  HEAP32[$287>>2] = $283;
  $288 = HEAP32[$16>>2]|0;
  $289 = HEAP32[$85>>2]|0;
  $290 = ((($289) + (($288*12)|0)|0) + 8|0);
  HEAPF32[$290>>2] = $wA$0;
  $291 = HEAP32[$21>>2]|0;
  $292 = HEAP32[$85>>2]|0;
  $293 = (($292) + (($291*12)|0)|0);
  $294 = $vB;
  $295 = $294;
  $296 = HEAP32[$295>>2]|0;
  $297 = (($294) + 4)|0;
  $298 = $297;
  $299 = HEAP32[$298>>2]|0;
  $300 = $293;
  $301 = $300;
  HEAP32[$301>>2] = $296;
  $302 = (($300) + 4)|0;
  $303 = $302;
  HEAP32[$303>>2] = $299;
  $304 = HEAP32[$21>>2]|0;
  $305 = HEAP32[$85>>2]|0;
  $306 = ((($305) + (($304*12)|0)|0) + 8|0);
  HEAPF32[$306>>2] = $wB$0;
  STACKTOP = sp;return;
 }
}
function __ZN12b2WheelJoint24SolveVelocityConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0.0, $103 = 0, $104 = 0.0, $105 = 0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0, $11 = 0.0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0, $114 = 0.0, $115 = 0.0;
 var $116 = 0.0, $117 = 0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0, $129 = 0, $13 = 0.0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0;
 var $63 = 0.0, $64 = 0.0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0.0, $69 = 0.0, $7 = 0.0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0;
 var $81 = 0.0, $82 = 0.0, $83 = 0, $84 = 0.0, $85 = 0.0, $86 = 0, $87 = 0.0, $88 = 0.0, $89 = 0, $9 = 0.0, $90 = 0.0, $91 = 0.0, $92 = 0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0.0;
 var $P = 0, $P5 = 0, $vA = 0, $vB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $vA = sp + 8|0;
 $vB = sp;
 $0 = sp + 72|0;
 $P = sp + 64|0;
 $1 = sp + 56|0;
 $2 = sp + 48|0;
 $3 = sp + 40|0;
 $P5 = sp + 32|0;
 $4 = sp + 24|0;
 $5 = sp + 16|0;
 $6 = (($this) + 156|0);
 $7 = +HEAPF32[$6>>2];
 $8 = (($this) + 160|0);
 $9 = +HEAPF32[$8>>2];
 $10 = (($this) + 164|0);
 $11 = +HEAPF32[$10>>2];
 $12 = (($this) + 168|0);
 $13 = +HEAPF32[$12>>2];
 $14 = (($this) + 132|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($data) + 32|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + (($15*12)|0)|0);
 $19 = $18;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) + 4)|0;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 $25 = $vA;
 $26 = $25;
 HEAP32[$26>>2] = $21;
 $27 = (($25) + 4)|0;
 $28 = $27;
 HEAP32[$28>>2] = $24;
 $29 = HEAP32[$14>>2]|0;
 $30 = HEAP32[$16>>2]|0;
 $31 = ((($30) + (($29*12)|0)|0) + 8|0);
 $32 = +HEAPF32[$31>>2];
 $33 = (($this) + 136|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($30) + (($34*12)|0)|0);
 $36 = $35;
 $37 = $36;
 $38 = HEAP32[$37>>2]|0;
 $39 = (($36) + 4)|0;
 $40 = $39;
 $41 = HEAP32[$40>>2]|0;
 $42 = $vB;
 $43 = $42;
 HEAP32[$43>>2] = $38;
 $44 = (($42) + 4)|0;
 $45 = $44;
 HEAP32[$45>>2] = $41;
 $46 = HEAP32[$33>>2]|0;
 $47 = HEAP32[$16>>2]|0;
 $48 = ((($47) + (($46*12)|0)|0) + 8|0);
 $49 = +HEAPF32[$48>>2];
 $50 = (($this) + 172|0);
 __ZmiRK6b2Vec2S1_($0,$vB,$vA);
 $51 = (+__Z5b2DotRK6b2Vec2S1_($50,$0));
 $52 = (($this) + 192|0);
 $53 = +HEAPF32[$52>>2];
 $54 = $49 * $53;
 $55 = $51 + $54;
 $56 = (($this) + 188|0);
 $57 = +HEAPF32[$56>>2];
 $58 = $32 * $57;
 $59 = $55 - $58;
 $60 = (($this) + 212|0);
 $61 = +HEAPF32[$60>>2];
 $62 = (($this) + 216|0);
 $63 = +HEAPF32[$62>>2];
 $64 = $59 + $63;
 $65 = (($this) + 220|0);
 $66 = +HEAPF32[$65>>2];
 $67 = (($this) + 116|0);
 $68 = +HEAPF32[$67>>2];
 $69 = $66 * $68;
 $70 = $64 + $69;
 $71 = $61 * $70;
 $72 = -$71;
 $73 = $68 - $71;
 HEAPF32[$67>>2] = $73;
 __ZmlfRK6b2Vec2($P,$72,$50);
 $74 = +HEAPF32[$56>>2];
 $75 = $74 * $72;
 $76 = +HEAPF32[$52>>2];
 $77 = $76 * $72;
 __ZmlfRK6b2Vec2($1,$7,$P);
 __ZN6b2Vec2mIERKS_($vA,$1);
 $78 = $11 * $75;
 $79 = $32 - $78;
 __ZmlfRK6b2Vec2($2,$9,$P);
 __ZN6b2Vec2pLERKS_($vB,$2);
 $80 = $13 * $77;
 $81 = $49 + $80;
 $82 = $81 - $79;
 $83 = (($this) + 124|0);
 $84 = +HEAPF32[$83>>2];
 $85 = $82 - $84;
 $86 = (($this) + 208|0);
 $87 = +HEAPF32[$86>>2];
 $88 = $87 * $85;
 $89 = (($this) + 112|0);
 $90 = +HEAPF32[$89>>2];
 $91 = +HEAPF32[$data>>2];
 $92 = (($this) + 120|0);
 $93 = +HEAPF32[$92>>2];
 $94 = $91 * $93;
 $95 = $90 - $88;
 $96 = -$94;
 $97 = (+__Z7b2ClampIfET_S0_S0_S0_($95,$96,$94));
 HEAPF32[$89>>2] = $97;
 $98 = $97 - $90;
 $99 = $11 * $98;
 $100 = $79 - $99;
 $101 = $13 * $98;
 $102 = $81 + $101;
 $103 = (($this) + 180|0);
 __ZmiRK6b2Vec2S1_($3,$vB,$vA);
 $104 = (+__Z5b2DotRK6b2Vec2S1_($103,$3));
 $105 = (($this) + 200|0);
 $106 = +HEAPF32[$105>>2];
 $107 = $106 * $102;
 $108 = $104 + $107;
 $109 = (($this) + 196|0);
 $110 = +HEAPF32[$109>>2];
 $111 = $100 * $110;
 $112 = $108 - $111;
 $113 = (($this) + 204|0);
 $114 = +HEAPF32[$113>>2];
 $115 = $114 * $112;
 $116 = -$115;
 $117 = (($this) + 108|0);
 $118 = +HEAPF32[$117>>2];
 $119 = $118 - $115;
 HEAPF32[$117>>2] = $119;
 __ZmlfRK6b2Vec2($P5,$116,$103);
 $120 = +HEAPF32[$109>>2];
 $121 = $120 * $116;
 $122 = +HEAPF32[$105>>2];
 $123 = $122 * $116;
 __ZmlfRK6b2Vec2($4,$7,$P5);
 __ZN6b2Vec2mIERKS_($vA,$4);
 $124 = $11 * $121;
 $125 = $100 - $124;
 __ZmlfRK6b2Vec2($5,$9,$P5);
 __ZN6b2Vec2pLERKS_($vB,$5);
 $126 = $13 * $123;
 $127 = $102 + $126;
 $128 = HEAP32[$14>>2]|0;
 $129 = HEAP32[$16>>2]|0;
 $130 = (($129) + (($128*12)|0)|0);
 $131 = $vA;
 $132 = $131;
 $133 = HEAP32[$132>>2]|0;
 $134 = (($131) + 4)|0;
 $135 = $134;
 $136 = HEAP32[$135>>2]|0;
 $137 = $130;
 $138 = $137;
 HEAP32[$138>>2] = $133;
 $139 = (($137) + 4)|0;
 $140 = $139;
 HEAP32[$140>>2] = $136;
 $141 = HEAP32[$14>>2]|0;
 $142 = HEAP32[$16>>2]|0;
 $143 = ((($142) + (($141*12)|0)|0) + 8|0);
 HEAPF32[$143>>2] = $125;
 $144 = HEAP32[$33>>2]|0;
 $145 = HEAP32[$16>>2]|0;
 $146 = (($145) + (($144*12)|0)|0);
 $147 = $vB;
 $148 = $147;
 $149 = HEAP32[$148>>2]|0;
 $150 = (($147) + 4)|0;
 $151 = $150;
 $152 = HEAP32[$151>>2]|0;
 $153 = $146;
 $154 = $153;
 HEAP32[$154>>2] = $149;
 $155 = (($153) + 4)|0;
 $156 = $155;
 HEAP32[$156>>2] = $152;
 $157 = HEAP32[$33>>2]|0;
 $158 = HEAP32[$16>>2]|0;
 $159 = ((($158) + (($157*12)|0)|0) + 8|0);
 HEAPF32[$159>>2] = $127;
 STACKTOP = sp;return;
}
function __ZN12b2WheelJoint24SolvePositionConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0.0;
 var $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0.0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0, $64 = 0.0, $65 = 0;
 var $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0.0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $P = 0, $ay = 0, $cA = 0;
 var $cB = 0, $d = 0, $impulse$0 = 0.0, $qA = 0, $qB = 0, $rA = 0, $rB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $cA = sp + 8|0;
 $cB = sp;
 $qA = sp + 120|0;
 $qB = sp + 112|0;
 $rA = sp + 104|0;
 $0 = sp + 96|0;
 $rB = sp + 88|0;
 $1 = sp + 80|0;
 $d = sp + 72|0;
 $2 = sp + 64|0;
 $3 = sp + 56|0;
 $ay = sp + 48|0;
 $4 = sp + 40|0;
 $P = sp + 32|0;
 $5 = sp + 24|0;
 $6 = sp + 16|0;
 $7 = (($this) + 132|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($data) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + (($8*12)|0)|0);
 $12 = $11;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($12) + 4)|0;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = $cA;
 $19 = $18;
 HEAP32[$19>>2] = $14;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = $17;
 $22 = HEAP32[$7>>2]|0;
 $23 = HEAP32[$9>>2]|0;
 $24 = ((($23) + (($22*12)|0)|0) + 8|0);
 $25 = +HEAPF32[$24>>2];
 $26 = (($this) + 136|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($23) + (($27*12)|0)|0);
 $29 = $28;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = (($29) + 4)|0;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = $cB;
 $36 = $35;
 HEAP32[$36>>2] = $31;
 $37 = (($35) + 4)|0;
 $38 = $37;
 HEAP32[$38>>2] = $34;
 $39 = HEAP32[$26>>2]|0;
 $40 = HEAP32[$9>>2]|0;
 $41 = ((($40) + (($39*12)|0)|0) + 8|0);
 $42 = +HEAPF32[$41>>2];
 __ZN5b2RotC2Ef($qA,$25);
 __ZN5b2RotC2Ef($qB,$42);
 $43 = (($this) + 76|0);
 $44 = (($this) + 140|0);
 __ZmiRK6b2Vec2S1_($0,$43,$44);
 __Z5b2MulRK5b2RotRK6b2Vec2($rA,$qA,$0);
 $45 = (($this) + 84|0);
 $46 = (($this) + 148|0);
 __ZmiRK6b2Vec2S1_($1,$45,$46);
 __Z5b2MulRK5b2RotRK6b2Vec2($rB,$qB,$1);
 __ZmiRK6b2Vec2S1_($3,$cB,$cA);
 __ZplRK6b2Vec2S1_($2,$3,$rB);
 __ZmiRK6b2Vec2S1_($d,$2,$rA);
 $47 = (($this) + 100|0);
 __Z5b2MulRK5b2RotRK6b2Vec2($ay,$qA,$47);
 __ZplRK6b2Vec2S1_($4,$d,$rA);
 $48 = (+__Z7b2CrossRK6b2Vec2S1_($4,$ay));
 $49 = (+__Z7b2CrossRK6b2Vec2S1_($rB,$ay));
 $50 = (+__Z5b2DotRK6b2Vec2S1_($d,$ay));
 $51 = (($this) + 156|0);
 $52 = +HEAPF32[$51>>2];
 $53 = (($this) + 160|0);
 $54 = +HEAPF32[$53>>2];
 $55 = $52 + $54;
 $56 = (($this) + 164|0);
 $57 = +HEAPF32[$56>>2];
 $58 = (($this) + 196|0);
 $59 = +HEAPF32[$58>>2];
 $60 = $57 * $59;
 $61 = $59 * $60;
 $62 = $55 + $61;
 $63 = (($this) + 168|0);
 $64 = +HEAPF32[$63>>2];
 $65 = (($this) + 200|0);
 $66 = +HEAPF32[$65>>2];
 $67 = $64 * $66;
 $68 = $66 * $67;
 $69 = $62 + $68;
 $70 = $69 != 0.0;
 if ($70) {
  $71 = -$50;
  $72 = $71 / $69;
  $impulse$0 = $72;
 } else {
  $impulse$0 = 0.0;
 }
 __ZmlfRK6b2Vec2($P,$impulse$0,$ay);
 $73 = $48 * $impulse$0;
 $74 = $49 * $impulse$0;
 $75 = +HEAPF32[$51>>2];
 __ZmlfRK6b2Vec2($5,$75,$P);
 __ZN6b2Vec2mIERKS_($cA,$5);
 $76 = +HEAPF32[$56>>2];
 $77 = $73 * $76;
 $78 = $25 - $77;
 $79 = +HEAPF32[$53>>2];
 __ZmlfRK6b2Vec2($6,$79,$P);
 __ZN6b2Vec2pLERKS_($cB,$6);
 $80 = +HEAPF32[$63>>2];
 $81 = $74 * $80;
 $82 = $42 + $81;
 $83 = HEAP32[$7>>2]|0;
 $84 = HEAP32[$9>>2]|0;
 $85 = (($84) + (($83*12)|0)|0);
 $86 = $cA;
 $87 = $86;
 $88 = HEAP32[$87>>2]|0;
 $89 = (($86) + 4)|0;
 $90 = $89;
 $91 = HEAP32[$90>>2]|0;
 $92 = $85;
 $93 = $92;
 HEAP32[$93>>2] = $88;
 $94 = (($92) + 4)|0;
 $95 = $94;
 HEAP32[$95>>2] = $91;
 $96 = HEAP32[$7>>2]|0;
 $97 = HEAP32[$9>>2]|0;
 $98 = ((($97) + (($96*12)|0)|0) + 8|0);
 HEAPF32[$98>>2] = $78;
 $99 = HEAP32[$26>>2]|0;
 $100 = HEAP32[$9>>2]|0;
 $101 = (($100) + (($99*12)|0)|0);
 $102 = $cB;
 $103 = $102;
 $104 = HEAP32[$103>>2]|0;
 $105 = (($102) + 4)|0;
 $106 = $105;
 $107 = HEAP32[$106>>2]|0;
 $108 = $101;
 $109 = $108;
 HEAP32[$109>>2] = $104;
 $110 = (($108) + 4)|0;
 $111 = $110;
 HEAP32[$111>>2] = $107;
 $112 = HEAP32[$26>>2]|0;
 $113 = HEAP32[$9>>2]|0;
 $114 = ((($113) + (($112*12)|0)|0) + 8|0);
 HEAPF32[$114>>2] = $82;
 $115 = (+__Z5b2AbsIfET_S0_($50));
 $116 = $115 <= 0.004999999888241291;
 STACKTOP = sp;return ($116|0);
}
function __ZNK12b2WheelJoint10GetAnchorAEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 76|0);
 __ZNK6b2Body13GetWorldPointERK6b2Vec2($agg$result,$1,$2);
 STACKTOP = sp;return;
}
function __ZNK12b2WheelJoint10GetAnchorBEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 84|0);
 __ZNK6b2Body13GetWorldPointERK6b2Vec2($agg$result,$1,$2);
 STACKTOP = sp;return;
}
function __ZNK12b2WheelJoint16GetReactionForceEf($agg$result,$this,$inv_dt) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inv_dt = +$inv_dt;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 $2 = sp;
 $3 = (($this) + 108|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($this) + 180|0);
 __ZmlfRK6b2Vec2($1,$4,$5);
 $6 = (($this) + 116|0);
 $7 = +HEAPF32[$6>>2];
 $8 = (($this) + 172|0);
 __ZmlfRK6b2Vec2($2,$7,$8);
 __ZplRK6b2Vec2S1_($0,$1,$2);
 __ZmlfRK6b2Vec2($agg$result,$inv_dt,$0);
 STACKTOP = sp;return;
}
function __ZNK12b2WheelJoint17GetReactionTorqueEf($this,$inv_dt) {
 $this = $this|0;
 $inv_dt = +$inv_dt;
 var $0 = 0, $1 = 0.0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 112|0);
 $1 = +HEAPF32[$0>>2];
 $2 = $1 * $inv_dt;
 STACKTOP = sp;return (+$2);
}
function __ZN12b2WheelJoint13SetMotorSpeedEf($this,$speed) {
 $this = $this|0;
 $speed = +$speed;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 __ZN6b2Body8SetAwakeEb($1,1);
 $2 = (($this) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN6b2Body8SetAwakeEb($3,1);
 $4 = (($this) + 124|0);
 HEAPF32[$4>>2] = $speed;
 STACKTOP = sp;return;
}
function __ZN12b2WheelJoint4DumpEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0;
 var $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0.0, $43 = 0.0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer36 = 0, $vararg_ptr12 = 0, $vararg_ptr16 = 0, $vararg_ptr20 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer36 = sp;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 __Z5b2LogPKcz(6440,$vararg_buffer36);
 HEAP32[$vararg_buffer36>>2] = $3;
 __Z5b2LogPKcz(6464,$vararg_buffer36);
 HEAP32[$vararg_buffer36>>2] = $7;
 __Z5b2LogPKcz(6496,$vararg_buffer36);
 $8 = (($this) + 61|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 HEAP32[$vararg_buffer36>>2] = $10;
 __Z5b2LogPKcz(6528,$vararg_buffer36);
 $11 = (($this) + 76|0);
 $12 = +HEAPF32[$11>>2];
 $13 = $12;
 $14 = (($this) + 80|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $15;
 HEAPF64[tempDoublePtr>>3]=$13;HEAP32[$vararg_buffer36>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer36+4>>2]=HEAP32[tempDoublePtr+4>>2];
 $vararg_ptr12 = (($vararg_buffer36) + 8|0);
 HEAPF64[tempDoublePtr>>3]=$16;HEAP32[$vararg_ptr12>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr12+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(6568,$vararg_buffer36);
 $17 = (($this) + 84|0);
 $18 = +HEAPF32[$17>>2];
 $19 = $18;
 $20 = (($this) + 88|0);
 $21 = +HEAPF32[$20>>2];
 $22 = $21;
 HEAPF64[tempDoublePtr>>3]=$19;HEAP32[$vararg_buffer36>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer36+4>>2]=HEAP32[tempDoublePtr+4>>2];
 $vararg_ptr16 = (($vararg_buffer36) + 8|0);
 HEAPF64[tempDoublePtr>>3]=$22;HEAP32[$vararg_ptr16>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr16+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(6616,$vararg_buffer36);
 $23 = (($this) + 92|0);
 $24 = +HEAPF32[$23>>2];
 $25 = $24;
 $26 = (($this) + 96|0);
 $27 = +HEAPF32[$26>>2];
 $28 = $27;
 HEAPF64[tempDoublePtr>>3]=$25;HEAP32[$vararg_buffer36>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer36+4>>2]=HEAP32[tempDoublePtr+4>>2];
 $vararg_ptr20 = (($vararg_buffer36) + 8|0);
 HEAPF64[tempDoublePtr>>3]=$28;HEAP32[$vararg_ptr20>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr20+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(6664,$vararg_buffer36);
 $29 = (($this) + 128|0);
 $30 = HEAP8[$29>>0]|0;
 $31 = $30&255;
 HEAP32[$vararg_buffer36>>2] = $31;
 __Z5b2LogPKcz(6704,$vararg_buffer36);
 $32 = (($this) + 124|0);
 $33 = +HEAPF32[$32>>2];
 $34 = $33;
 HEAPF64[tempDoublePtr>>3]=$34;HEAP32[$vararg_buffer36>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer36+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(6736,$vararg_buffer36);
 $35 = (($this) + 120|0);
 $36 = +HEAPF32[$35>>2];
 $37 = $36;
 HEAPF64[tempDoublePtr>>3]=$37;HEAP32[$vararg_buffer36>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer36+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(6768,$vararg_buffer36);
 $38 = (($this) + 68|0);
 $39 = +HEAPF32[$38>>2];
 $40 = $39;
 HEAPF64[tempDoublePtr>>3]=$40;HEAP32[$vararg_buffer36>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer36+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(6800,$vararg_buffer36);
 $41 = (($this) + 72|0);
 $42 = +HEAPF32[$41>>2];
 $43 = $42;
 HEAPF64[tempDoublePtr>>3]=$43;HEAP32[$vararg_buffer36>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer36+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(6832,$vararg_buffer36);
 $44 = (($this) + 56|0);
 $45 = HEAP32[$44>>2]|0;
 HEAP32[$vararg_buffer36>>2] = $45;
 __Z5b2LogPKcz(6864,$vararg_buffer36);
 STACKTOP = sp;return;
}
function __ZN12b2WheelJointD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN16b2PulleyJointDef10InitializeEP6b2BodyS1_RK6b2Vec2S4_S4_S4_f($this,$bA,$bB,$groundA,$groundB,$anchorA,$anchorB,$r) {
 $this = $this|0;
 $bA = $bA|0;
 $bB = $bB|0;
 $groundA = $groundA|0;
 $groundB = $groundB|0;
 $anchorA = $anchorA|0;
 $anchorB = $anchorB|0;
 $r = +$r;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dA = 0, $dB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 8|0;
 $1 = sp;
 $dA = sp + 24|0;
 $dB = sp + 16|0;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = $bA;
 $3 = (($this) + 12|0);
 HEAP32[$3>>2] = $bB;
 $4 = (($this) + 20|0);
 $5 = $groundA;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $4;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 $15 = (($this) + 28|0);
 $16 = $groundB;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16) + 4)|0;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = $15;
 $23 = $22;
 HEAP32[$23>>2] = $18;
 $24 = (($22) + 4)|0;
 $25 = $24;
 HEAP32[$25>>2] = $21;
 $26 = (($this) + 36|0);
 $27 = HEAP32[$2>>2]|0;
 __ZNK6b2Body13GetLocalPointERK6b2Vec2($0,$27,$anchorA);
 $28 = $0;
 $29 = $28;
 $30 = HEAP32[$29>>2]|0;
 $31 = (($28) + 4)|0;
 $32 = $31;
 $33 = HEAP32[$32>>2]|0;
 $34 = $26;
 $35 = $34;
 HEAP32[$35>>2] = $30;
 $36 = (($34) + 4)|0;
 $37 = $36;
 HEAP32[$37>>2] = $33;
 $38 = (($this) + 44|0);
 $39 = HEAP32[$3>>2]|0;
 __ZNK6b2Body13GetLocalPointERK6b2Vec2($1,$39,$anchorB);
 $40 = $1;
 $41 = $40;
 $42 = HEAP32[$41>>2]|0;
 $43 = (($40) + 4)|0;
 $44 = $43;
 $45 = HEAP32[$44>>2]|0;
 $46 = $38;
 $47 = $46;
 HEAP32[$47>>2] = $42;
 $48 = (($46) + 4)|0;
 $49 = $48;
 HEAP32[$49>>2] = $45;
 __ZmiRK6b2Vec2S1_($dA,$anchorA,$groundA);
 $50 = (+__ZNK6b2Vec26LengthEv($dA));
 $51 = (($this) + 52|0);
 HEAPF32[$51>>2] = $50;
 __ZmiRK6b2Vec2S1_($dB,$anchorB,$groundB);
 $52 = (+__ZNK6b2Vec26LengthEv($dB));
 $53 = (($this) + 56|0);
 HEAPF32[$53>>2] = $52;
 $54 = (($this) + 60|0);
 HEAPF32[$54>>2] = $r;
 STACKTOP = sp;return;
}
function __ZN13b2PulleyJointC2EPK16b2PulleyJointDef($this,$def) {
 $this = $this|0;
 $def = $def|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7b2JointC2EPK10b2JointDef($this,$def);
 HEAP32[$this>>2] = ((6944 + 8|0));
 $0 = (($this) + 68|0);
 $1 = (($this) + 76|0);
 $2 = (($this) + 92|0);
 $3 = (($this) + 100|0);
 $4 = (($def) + 20|0);
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $0;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 $15 = (($def) + 28|0);
 $16 = $15;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16) + 4)|0;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = $1;
 $23 = $22;
 HEAP32[$23>>2] = $18;
 $24 = (($22) + 4)|0;
 $25 = $24;
 HEAP32[$25>>2] = $21;
 $26 = (($def) + 36|0);
 $27 = $26;
 $28 = $27;
 $29 = HEAP32[$28>>2]|0;
 $30 = (($27) + 4)|0;
 $31 = $30;
 $32 = HEAP32[$31>>2]|0;
 $33 = $2;
 $34 = $33;
 HEAP32[$34>>2] = $29;
 $35 = (($33) + 4)|0;
 $36 = $35;
 HEAP32[$36>>2] = $32;
 $37 = (($def) + 44|0);
 $38 = $37;
 $39 = $38;
 $40 = HEAP32[$39>>2]|0;
 $41 = (($38) + 4)|0;
 $42 = $41;
 $43 = HEAP32[$42>>2]|0;
 $44 = $3;
 $45 = $44;
 HEAP32[$45>>2] = $40;
 $46 = (($44) + 4)|0;
 $47 = $46;
 HEAP32[$47>>2] = $43;
 $48 = (($def) + 52|0);
 $49 = +HEAPF32[$48>>2];
 $50 = (($this) + 84|0);
 HEAPF32[$50>>2] = $49;
 $51 = (($def) + 56|0);
 $52 = +HEAPF32[$51>>2];
 $53 = (($this) + 88|0);
 HEAPF32[$53>>2] = $52;
 $54 = (($def) + 60|0);
 $55 = +HEAPF32[$54>>2];
 $56 = (($this) + 112|0);
 HEAPF32[$56>>2] = $55;
 $57 = +HEAPF32[$48>>2];
 $58 = +HEAPF32[$51>>2];
 $59 = $55 * $58;
 $60 = $57 + $59;
 $61 = (($this) + 108|0);
 HEAPF32[$61>>2] = $60;
 $62 = (($this) + 116|0);
 HEAPF32[$62>>2] = 0.0;
 STACKTOP = sp;return;
}
function __ZN13b2PulleyJoint23InitVelocityConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0.0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0.0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0.0, $179 = 0.0, $18 = 0, $180 = 0, $181 = 0.0, $182 = 0, $183 = 0.0, $184 = 0.0, $185 = 0.0, $186 = 0.0, $187 = 0.0, $188 = 0.0;
 var $189 = 0.0, $19 = 0, $190 = 0.0, $191 = 0.0, $192 = 0.0, $193 = 0.0, $194 = 0.0, $195 = 0.0, $196 = 0, $197 = 0.0, $198 = 0.0, $199 = 0.0, $2 = 0, $20 = 0, $200 = 0.0, $201 = 0, $202 = 0, $203 = 0.0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0.0, $209 = 0, $21 = 0, $210 = 0.0, $211 = 0.0, $212 = 0.0, $213 = 0.0, $214 = 0.0, $215 = 0.0, $216 = 0.0, $217 = 0.0, $218 = 0.0, $219 = 0.0, $22 = 0, $220 = 0.0, $221 = 0.0, $222 = 0.0, $223 = 0.0;
 var $224 = 0.0, $225 = 0.0, $226 = 0.0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0.0, $97 = 0, $98 = 0, $99 = 0;
 var $PA = 0, $PB = 0, $cA = 0, $cB = 0, $qA = 0, $qB = 0, $storemerge = 0.0, $vA = 0, $vB = 0, $wA$0 = 0.0, $wB$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $cA = sp + 56|0;
 $vA = sp + 48|0;
 $cB = sp + 40|0;
 $vB = sp + 32|0;
 $qA = sp + 136|0;
 $qB = sp + 128|0;
 $0 = sp + 24|0;
 $1 = sp + 120|0;
 $2 = sp + 16|0;
 $3 = sp + 112|0;
 $4 = sp + 8|0;
 $5 = sp + 104|0;
 $6 = sp;
 $7 = sp + 96|0;
 $PA = sp + 88|0;
 $PB = sp + 80|0;
 $8 = sp + 72|0;
 $9 = sp + 64|0;
 $10 = (($this) + 48|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + 8|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 120|0);
 HEAP32[$14>>2] = $13;
 $15 = (($this) + 52|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($this) + 124|0);
 HEAP32[$19>>2] = $18;
 $20 = (($this) + 160|0);
 $21 = HEAP32[$10>>2]|0;
 $22 = (($21) + 44|0);
 $23 = $22;
 $24 = $23;
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23) + 4)|0;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = $20;
 $30 = $29;
 HEAP32[$30>>2] = $25;
 $31 = (($29) + 4)|0;
 $32 = $31;
 HEAP32[$32>>2] = $28;
 $33 = (($this) + 168|0);
 $34 = HEAP32[$15>>2]|0;
 $35 = (($34) + 44|0);
 $36 = $35;
 $37 = $36;
 $38 = HEAP32[$37>>2]|0;
 $39 = (($36) + 4)|0;
 $40 = $39;
 $41 = HEAP32[$40>>2]|0;
 $42 = $33;
 $43 = $42;
 HEAP32[$43>>2] = $38;
 $44 = (($42) + 4)|0;
 $45 = $44;
 HEAP32[$45>>2] = $41;
 $46 = HEAP32[$10>>2]|0;
 $47 = (($46) + 136|0);
 $48 = +HEAPF32[$47>>2];
 $49 = (($this) + 176|0);
 HEAPF32[$49>>2] = $48;
 $50 = HEAP32[$15>>2]|0;
 $51 = (($50) + 136|0);
 $52 = +HEAPF32[$51>>2];
 $53 = (($this) + 180|0);
 HEAPF32[$53>>2] = $52;
 $54 = HEAP32[$10>>2]|0;
 $55 = (($54) + 144|0);
 $56 = +HEAPF32[$55>>2];
 $57 = (($this) + 184|0);
 HEAPF32[$57>>2] = $56;
 $58 = HEAP32[$15>>2]|0;
 $59 = (($58) + 144|0);
 $60 = +HEAPF32[$59>>2];
 $61 = (($this) + 188|0);
 HEAPF32[$61>>2] = $60;
 $62 = HEAP32[$14>>2]|0;
 $63 = (($data) + 28|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = (($64) + (($62*12)|0)|0);
 $66 = $65;
 $67 = $66;
 $68 = HEAP32[$67>>2]|0;
 $69 = (($66) + 4)|0;
 $70 = $69;
 $71 = HEAP32[$70>>2]|0;
 $72 = $cA;
 $73 = $72;
 HEAP32[$73>>2] = $68;
 $74 = (($72) + 4)|0;
 $75 = $74;
 HEAP32[$75>>2] = $71;
 $76 = HEAP32[$14>>2]|0;
 $77 = HEAP32[$63>>2]|0;
 $78 = ((($77) + (($76*12)|0)|0) + 8|0);
 $79 = +HEAPF32[$78>>2];
 $80 = (($data) + 32|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = (($81) + (($76*12)|0)|0);
 $83 = $82;
 $84 = $83;
 $85 = HEAP32[$84>>2]|0;
 $86 = (($83) + 4)|0;
 $87 = $86;
 $88 = HEAP32[$87>>2]|0;
 $89 = $vA;
 $90 = $89;
 HEAP32[$90>>2] = $85;
 $91 = (($89) + 4)|0;
 $92 = $91;
 HEAP32[$92>>2] = $88;
 $93 = HEAP32[$14>>2]|0;
 $94 = HEAP32[$80>>2]|0;
 $95 = ((($94) + (($93*12)|0)|0) + 8|0);
 $96 = +HEAPF32[$95>>2];
 $97 = HEAP32[$19>>2]|0;
 $98 = HEAP32[$63>>2]|0;
 $99 = (($98) + (($97*12)|0)|0);
 $100 = $99;
 $101 = $100;
 $102 = HEAP32[$101>>2]|0;
 $103 = (($100) + 4)|0;
 $104 = $103;
 $105 = HEAP32[$104>>2]|0;
 $106 = $cB;
 $107 = $106;
 HEAP32[$107>>2] = $102;
 $108 = (($106) + 4)|0;
 $109 = $108;
 HEAP32[$109>>2] = $105;
 $110 = HEAP32[$19>>2]|0;
 $111 = HEAP32[$63>>2]|0;
 $112 = ((($111) + (($110*12)|0)|0) + 8|0);
 $113 = +HEAPF32[$112>>2];
 $114 = HEAP32[$80>>2]|0;
 $115 = (($114) + (($110*12)|0)|0);
 $116 = $115;
 $117 = $116;
 $118 = HEAP32[$117>>2]|0;
 $119 = (($116) + 4)|0;
 $120 = $119;
 $121 = HEAP32[$120>>2]|0;
 $122 = $vB;
 $123 = $122;
 HEAP32[$123>>2] = $118;
 $124 = (($122) + 4)|0;
 $125 = $124;
 HEAP32[$125>>2] = $121;
 $126 = HEAP32[$19>>2]|0;
 $127 = HEAP32[$80>>2]|0;
 $128 = ((($127) + (($126*12)|0)|0) + 8|0);
 $129 = +HEAPF32[$128>>2];
 __ZN5b2RotC2Ef($qA,$79);
 __ZN5b2RotC2Ef($qB,$113);
 $130 = (($this) + 144|0);
 $131 = (($this) + 92|0);
 __ZmiRK6b2Vec2S1_($1,$131,$20);
 __Z5b2MulRK5b2RotRK6b2Vec2($0,$qA,$1);
 $132 = $0;
 $133 = $132;
 $134 = HEAP32[$133>>2]|0;
 $135 = (($132) + 4)|0;
 $136 = $135;
 $137 = HEAP32[$136>>2]|0;
 $138 = $130;
 $139 = $138;
 HEAP32[$139>>2] = $134;
 $140 = (($138) + 4)|0;
 $141 = $140;
 HEAP32[$141>>2] = $137;
 $142 = (($this) + 152|0);
 $143 = (($this) + 100|0);
 __ZmiRK6b2Vec2S1_($3,$143,$33);
 __Z5b2MulRK5b2RotRK6b2Vec2($2,$qB,$3);
 $144 = $2;
 $145 = $144;
 $146 = HEAP32[$145>>2]|0;
 $147 = (($144) + 4)|0;
 $148 = $147;
 $149 = HEAP32[$148>>2]|0;
 $150 = $142;
 $151 = $150;
 HEAP32[$151>>2] = $146;
 $152 = (($150) + 4)|0;
 $153 = $152;
 HEAP32[$153>>2] = $149;
 $154 = (($this) + 128|0);
 __ZplRK6b2Vec2S1_($5,$cA,$130);
 $155 = (($this) + 68|0);
 __ZmiRK6b2Vec2S1_($4,$5,$155);
 $156 = $4;
 $157 = $156;
 $158 = HEAP32[$157>>2]|0;
 $159 = (($156) + 4)|0;
 $160 = $159;
 $161 = HEAP32[$160>>2]|0;
 $162 = $154;
 $163 = $162;
 HEAP32[$163>>2] = $158;
 $164 = (($162) + 4)|0;
 $165 = $164;
 HEAP32[$165>>2] = $161;
 $166 = (($this) + 136|0);
 __ZplRK6b2Vec2S1_($7,$cB,$142);
 $167 = (($this) + 76|0);
 __ZmiRK6b2Vec2S1_($6,$7,$167);
 $168 = $6;
 $169 = $168;
 $170 = HEAP32[$169>>2]|0;
 $171 = (($168) + 4)|0;
 $172 = $171;
 $173 = HEAP32[$172>>2]|0;
 $174 = $166;
 $175 = $174;
 HEAP32[$175>>2] = $170;
 $176 = (($174) + 4)|0;
 $177 = $176;
 HEAP32[$177>>2] = $173;
 $178 = (+__ZNK6b2Vec26LengthEv($154));
 $179 = (+__ZNK6b2Vec26LengthEv($166));
 $180 = $178 > 0.049999997019767761;
 if ($180) {
  $181 = 1.0 / $178;
  __ZN6b2Vec2mLEf($154,$181);
 } else {
  __ZN6b2Vec27SetZeroEv($154);
 }
 $182 = $179 > 0.049999997019767761;
 if ($182) {
  $183 = 1.0 / $179;
  __ZN6b2Vec2mLEf($166,$183);
 } else {
  __ZN6b2Vec27SetZeroEv($166);
 }
 $184 = (+__Z7b2CrossRK6b2Vec2S1_($130,$154));
 $185 = (+__Z7b2CrossRK6b2Vec2S1_($142,$166));
 $186 = +HEAPF32[$49>>2];
 $187 = +HEAPF32[$57>>2];
 $188 = $184 * $187;
 $189 = $184 * $188;
 $190 = $186 + $189;
 $191 = +HEAPF32[$53>>2];
 $192 = +HEAPF32[$61>>2];
 $193 = $185 * $192;
 $194 = $185 * $193;
 $195 = $191 + $194;
 $196 = (($this) + 112|0);
 $197 = +HEAPF32[$196>>2];
 $198 = $197 * $197;
 $199 = $198 * $195;
 $200 = $190 + $199;
 $201 = (($this) + 192|0);
 $202 = $200 > 0.0;
 if ($202) {
  $203 = 1.0 / $200;
  $storemerge = $203;
 } else {
  $storemerge = $200;
 }
 HEAPF32[$201>>2] = $storemerge;
 $204 = (($data) + 24|0);
 $205 = HEAP8[$204>>0]|0;
 $206 = ($205<<24>>24)==(0);
 if ($206) {
  $227 = (($this) + 116|0);
  HEAPF32[$227>>2] = 0.0;
  $wA$0 = $96;$wB$0 = $129;
  $228 = HEAP32[$14>>2]|0;
  $229 = HEAP32[$80>>2]|0;
  $230 = (($229) + (($228*12)|0)|0);
  $231 = $vA;
  $232 = $231;
  $233 = HEAP32[$232>>2]|0;
  $234 = (($231) + 4)|0;
  $235 = $234;
  $236 = HEAP32[$235>>2]|0;
  $237 = $230;
  $238 = $237;
  HEAP32[$238>>2] = $233;
  $239 = (($237) + 4)|0;
  $240 = $239;
  HEAP32[$240>>2] = $236;
  $241 = HEAP32[$14>>2]|0;
  $242 = HEAP32[$80>>2]|0;
  $243 = ((($242) + (($241*12)|0)|0) + 8|0);
  HEAPF32[$243>>2] = $wA$0;
  $244 = HEAP32[$19>>2]|0;
  $245 = HEAP32[$80>>2]|0;
  $246 = (($245) + (($244*12)|0)|0);
  $247 = $vB;
  $248 = $247;
  $249 = HEAP32[$248>>2]|0;
  $250 = (($247) + 4)|0;
  $251 = $250;
  $252 = HEAP32[$251>>2]|0;
  $253 = $246;
  $254 = $253;
  HEAP32[$254>>2] = $249;
  $255 = (($253) + 4)|0;
  $256 = $255;
  HEAP32[$256>>2] = $252;
  $257 = HEAP32[$19>>2]|0;
  $258 = HEAP32[$80>>2]|0;
  $259 = ((($258) + (($257*12)|0)|0) + 8|0);
  HEAPF32[$259>>2] = $wB$0;
  STACKTOP = sp;return;
 } else {
  $207 = (($data) + 8|0);
  $208 = +HEAPF32[$207>>2];
  $209 = (($this) + 116|0);
  $210 = +HEAPF32[$209>>2];
  $211 = $208 * $210;
  HEAPF32[$209>>2] = $211;
  $212 = -$211;
  __ZmlfRK6b2Vec2($PA,$212,$154);
  $213 = +HEAPF32[$196>>2];
  $214 = +HEAPF32[$209>>2];
  $215 = $213 * $214;
  $216 = -$215;
  __ZmlfRK6b2Vec2($PB,$216,$166);
  $217 = +HEAPF32[$49>>2];
  __ZmlfRK6b2Vec2($8,$217,$PA);
  __ZN6b2Vec2pLERKS_($vA,$8);
  $218 = +HEAPF32[$57>>2];
  $219 = (+__Z7b2CrossRK6b2Vec2S1_($130,$PA));
  $220 = $218 * $219;
  $221 = $96 + $220;
  $222 = +HEAPF32[$53>>2];
  __ZmlfRK6b2Vec2($9,$222,$PB);
  __ZN6b2Vec2pLERKS_($vB,$9);
  $223 = +HEAPF32[$61>>2];
  $224 = (+__Z7b2CrossRK6b2Vec2S1_($142,$PB));
  $225 = $223 * $224;
  $226 = $129 + $225;
  $wA$0 = $221;$wB$0 = $226;
  $228 = HEAP32[$14>>2]|0;
  $229 = HEAP32[$80>>2]|0;
  $230 = (($229) + (($228*12)|0)|0);
  $231 = $vA;
  $232 = $231;
  $233 = HEAP32[$232>>2]|0;
  $234 = (($231) + 4)|0;
  $235 = $234;
  $236 = HEAP32[$235>>2]|0;
  $237 = $230;
  $238 = $237;
  HEAP32[$238>>2] = $233;
  $239 = (($237) + 4)|0;
  $240 = $239;
  HEAP32[$240>>2] = $236;
  $241 = HEAP32[$14>>2]|0;
  $242 = HEAP32[$80>>2]|0;
  $243 = ((($242) + (($241*12)|0)|0) + 8|0);
  HEAPF32[$243>>2] = $wA$0;
  $244 = HEAP32[$19>>2]|0;
  $245 = HEAP32[$80>>2]|0;
  $246 = (($245) + (($244*12)|0)|0);
  $247 = $vB;
  $248 = $247;
  $249 = HEAP32[$248>>2]|0;
  $250 = (($247) + 4)|0;
  $251 = $250;
  $252 = HEAP32[$251>>2]|0;
  $253 = $246;
  $254 = $253;
  HEAP32[$254>>2] = $249;
  $255 = (($253) + 4)|0;
  $256 = $255;
  HEAP32[$256>>2] = $252;
  $257 = HEAP32[$19>>2]|0;
  $258 = HEAP32[$80>>2]|0;
  $259 = ((($258) + (($257*12)|0)|0) + 8|0);
  HEAPF32[$259>>2] = $wB$0;
  STACKTOP = sp;return;
 }
}
function __ZN13b2PulleyJoint24SolveVelocityConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0.0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0.0, $44 = 0.0, $45 = 0, $46 = 0.0, $47 = 0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0;
 var $59 = 0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0, $67 = 0.0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $PA = 0, $PB = 0, $vA = 0, $vB = 0, $vpA = 0, $vpB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $vA = sp + 8|0;
 $vB = sp;
 $vpA = sp + 72|0;
 $0 = sp + 64|0;
 $vpB = sp + 56|0;
 $1 = sp + 48|0;
 $PA = sp + 40|0;
 $PB = sp + 32|0;
 $2 = sp + 24|0;
 $3 = sp + 16|0;
 $4 = (($this) + 120|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($data) + 32|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + (($5*12)|0)|0);
 $9 = $8;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = $vA;
 $16 = $15;
 HEAP32[$16>>2] = $11;
 $17 = (($15) + 4)|0;
 $18 = $17;
 HEAP32[$18>>2] = $14;
 $19 = HEAP32[$4>>2]|0;
 $20 = HEAP32[$6>>2]|0;
 $21 = ((($20) + (($19*12)|0)|0) + 8|0);
 $22 = +HEAPF32[$21>>2];
 $23 = (($this) + 124|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (($20) + (($24*12)|0)|0);
 $26 = $25;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($26) + 4)|0;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = $vB;
 $33 = $32;
 HEAP32[$33>>2] = $28;
 $34 = (($32) + 4)|0;
 $35 = $34;
 HEAP32[$35>>2] = $31;
 $36 = HEAP32[$23>>2]|0;
 $37 = HEAP32[$6>>2]|0;
 $38 = ((($37) + (($36*12)|0)|0) + 8|0);
 $39 = +HEAPF32[$38>>2];
 $40 = (($this) + 144|0);
 __Z7b2CrossfRK6b2Vec2($0,$22,$40);
 __ZplRK6b2Vec2S1_($vpA,$vA,$0);
 $41 = (($this) + 152|0);
 __Z7b2CrossfRK6b2Vec2($1,$39,$41);
 __ZplRK6b2Vec2S1_($vpB,$vB,$1);
 $42 = (($this) + 128|0);
 $43 = (+__Z5b2DotRK6b2Vec2S1_($42,$vpA));
 $44 = -$43;
 $45 = (($this) + 112|0);
 $46 = +HEAPF32[$45>>2];
 $47 = (($this) + 136|0);
 $48 = (+__Z5b2DotRK6b2Vec2S1_($47,$vpB));
 $49 = $46 * $48;
 $50 = $44 - $49;
 $51 = (($this) + 192|0);
 $52 = +HEAPF32[$51>>2];
 $53 = $52 * $50;
 $54 = (($this) + 116|0);
 $55 = +HEAPF32[$54>>2];
 $56 = $55 - $53;
 HEAPF32[$54>>2] = $56;
 __ZmlfRK6b2Vec2($PA,$53,$42);
 $57 = +HEAPF32[$45>>2];
 $58 = $53 * $57;
 __ZmlfRK6b2Vec2($PB,$58,$47);
 $59 = (($this) + 176|0);
 $60 = +HEAPF32[$59>>2];
 __ZmlfRK6b2Vec2($2,$60,$PA);
 __ZN6b2Vec2pLERKS_($vA,$2);
 $61 = (($this) + 184|0);
 $62 = +HEAPF32[$61>>2];
 $63 = (+__Z7b2CrossRK6b2Vec2S1_($40,$PA));
 $64 = $62 * $63;
 $65 = $22 + $64;
 $66 = (($this) + 180|0);
 $67 = +HEAPF32[$66>>2];
 __ZmlfRK6b2Vec2($3,$67,$PB);
 __ZN6b2Vec2pLERKS_($vB,$3);
 $68 = (($this) + 188|0);
 $69 = +HEAPF32[$68>>2];
 $70 = (+__Z7b2CrossRK6b2Vec2S1_($41,$PB));
 $71 = $69 * $70;
 $72 = $39 + $71;
 $73 = HEAP32[$4>>2]|0;
 $74 = HEAP32[$6>>2]|0;
 $75 = (($74) + (($73*12)|0)|0);
 $76 = $vA;
 $77 = $76;
 $78 = HEAP32[$77>>2]|0;
 $79 = (($76) + 4)|0;
 $80 = $79;
 $81 = HEAP32[$80>>2]|0;
 $82 = $75;
 $83 = $82;
 HEAP32[$83>>2] = $78;
 $84 = (($82) + 4)|0;
 $85 = $84;
 HEAP32[$85>>2] = $81;
 $86 = HEAP32[$4>>2]|0;
 $87 = HEAP32[$6>>2]|0;
 $88 = ((($87) + (($86*12)|0)|0) + 8|0);
 HEAPF32[$88>>2] = $65;
 $89 = HEAP32[$23>>2]|0;
 $90 = HEAP32[$6>>2]|0;
 $91 = (($90) + (($89*12)|0)|0);
 $92 = $vB;
 $93 = $92;
 $94 = HEAP32[$93>>2]|0;
 $95 = (($92) + 4)|0;
 $96 = $95;
 $97 = HEAP32[$96>>2]|0;
 $98 = $91;
 $99 = $98;
 HEAP32[$99>>2] = $94;
 $100 = (($98) + 4)|0;
 $101 = $100;
 HEAP32[$101>>2] = $97;
 $102 = HEAP32[$23>>2]|0;
 $103 = HEAP32[$6>>2]|0;
 $104 = ((($103) + (($102*12)|0)|0) + 8|0);
 HEAPF32[$104>>2] = $72;
 STACKTOP = sp;return;
}
function __ZN13b2PulleyJoint24SolvePositionConstraintsERK12b2SolverData($this,$data) {
 $this = $this|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0.0;
 var $54 = 0.0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0, $64 = 0.0, $65 = 0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0.0;
 var $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0;
 var $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $96 = 0.0, $97 = 0, $98 = 0, $99 = 0, $PA = 0, $PB = 0, $cA = 0, $cB = 0, $mass$0 = 0.0, $qA = 0, $qB = 0, $rA = 0, $rB = 0, $uA = 0;
 var $uB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $cA = sp + 8|0;
 $cB = sp;
 $qA = sp + 120|0;
 $qB = sp + 112|0;
 $rA = sp + 104|0;
 $0 = sp + 96|0;
 $rB = sp + 88|0;
 $1 = sp + 80|0;
 $uA = sp + 72|0;
 $2 = sp + 64|0;
 $uB = sp + 56|0;
 $3 = sp + 48|0;
 $PA = sp + 40|0;
 $PB = sp + 32|0;
 $4 = sp + 24|0;
 $5 = sp + 16|0;
 $6 = (($this) + 120|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($data) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + (($7*12)|0)|0);
 $11 = $10;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + 4)|0;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = $cA;
 $18 = $17;
 HEAP32[$18>>2] = $13;
 $19 = (($17) + 4)|0;
 $20 = $19;
 HEAP32[$20>>2] = $16;
 $21 = HEAP32[$6>>2]|0;
 $22 = HEAP32[$8>>2]|0;
 $23 = ((($22) + (($21*12)|0)|0) + 8|0);
 $24 = +HEAPF32[$23>>2];
 $25 = (($this) + 124|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($22) + (($26*12)|0)|0);
 $28 = $27;
 $29 = $28;
 $30 = HEAP32[$29>>2]|0;
 $31 = (($28) + 4)|0;
 $32 = $31;
 $33 = HEAP32[$32>>2]|0;
 $34 = $cB;
 $35 = $34;
 HEAP32[$35>>2] = $30;
 $36 = (($34) + 4)|0;
 $37 = $36;
 HEAP32[$37>>2] = $33;
 $38 = HEAP32[$25>>2]|0;
 $39 = HEAP32[$8>>2]|0;
 $40 = ((($39) + (($38*12)|0)|0) + 8|0);
 $41 = +HEAPF32[$40>>2];
 __ZN5b2RotC2Ef($qA,$24);
 __ZN5b2RotC2Ef($qB,$41);
 $42 = (($this) + 92|0);
 $43 = (($this) + 160|0);
 __ZmiRK6b2Vec2S1_($0,$42,$43);
 __Z5b2MulRK5b2RotRK6b2Vec2($rA,$qA,$0);
 $44 = (($this) + 100|0);
 $45 = (($this) + 168|0);
 __ZmiRK6b2Vec2S1_($1,$44,$45);
 __Z5b2MulRK5b2RotRK6b2Vec2($rB,$qB,$1);
 __ZplRK6b2Vec2S1_($2,$cA,$rA);
 $46 = (($this) + 68|0);
 __ZmiRK6b2Vec2S1_($uA,$2,$46);
 __ZplRK6b2Vec2S1_($3,$cB,$rB);
 $47 = (($this) + 76|0);
 __ZmiRK6b2Vec2S1_($uB,$3,$47);
 $48 = (+__ZNK6b2Vec26LengthEv($uA));
 $49 = (+__ZNK6b2Vec26LengthEv($uB));
 $50 = $48 > 0.049999997019767761;
 if ($50) {
  $51 = 1.0 / $48;
  __ZN6b2Vec2mLEf($uA,$51);
 } else {
  __ZN6b2Vec27SetZeroEv($uA);
 }
 $52 = $49 > 0.049999997019767761;
 if ($52) {
  $53 = 1.0 / $49;
  __ZN6b2Vec2mLEf($uB,$53);
 } else {
  __ZN6b2Vec27SetZeroEv($uB);
 }
 $54 = (+__Z7b2CrossRK6b2Vec2S1_($rA,$uA));
 $55 = (+__Z7b2CrossRK6b2Vec2S1_($rB,$uB));
 $56 = (($this) + 176|0);
 $57 = +HEAPF32[$56>>2];
 $58 = (($this) + 184|0);
 $59 = +HEAPF32[$58>>2];
 $60 = $54 * $59;
 $61 = $54 * $60;
 $62 = $57 + $61;
 $63 = (($this) + 180|0);
 $64 = +HEAPF32[$63>>2];
 $65 = (($this) + 188|0);
 $66 = +HEAPF32[$65>>2];
 $67 = $55 * $66;
 $68 = $55 * $67;
 $69 = $64 + $68;
 $70 = (($this) + 112|0);
 $71 = +HEAPF32[$70>>2];
 $72 = $71 * $71;
 $73 = $72 * $69;
 $74 = $62 + $73;
 $75 = $74 > 0.0;
 if ($75) {
  $76 = 1.0 / $74;
  $mass$0 = $76;
 } else {
  $mass$0 = $74;
 }
 $77 = (($this) + 108|0);
 $78 = +HEAPF32[$77>>2];
 $79 = $78 - $48;
 $80 = +HEAPF32[$70>>2];
 $81 = $49 * $80;
 $82 = $79 - $81;
 $83 = (+__Z5b2AbsIfET_S0_($82));
 $84 = $mass$0 * $82;
 __ZmlfRK6b2Vec2($PA,$84,$uA);
 $85 = +HEAPF32[$70>>2];
 $86 = $85 * $84;
 __ZmlfRK6b2Vec2($PB,$86,$uB);
 $87 = +HEAPF32[$56>>2];
 __ZmlfRK6b2Vec2($4,$87,$PA);
 __ZN6b2Vec2pLERKS_($cA,$4);
 $88 = +HEAPF32[$58>>2];
 $89 = (+__Z7b2CrossRK6b2Vec2S1_($rA,$PA));
 $90 = $88 * $89;
 $91 = $24 + $90;
 $92 = +HEAPF32[$63>>2];
 __ZmlfRK6b2Vec2($5,$92,$PB);
 __ZN6b2Vec2pLERKS_($cB,$5);
 $93 = +HEAPF32[$65>>2];
 $94 = (+__Z7b2CrossRK6b2Vec2S1_($rB,$PB));
 $95 = $93 * $94;
 $96 = $41 + $95;
 $97 = HEAP32[$6>>2]|0;
 $98 = HEAP32[$8>>2]|0;
 $99 = (($98) + (($97*12)|0)|0);
 $100 = $cA;
 $101 = $100;
 $102 = HEAP32[$101>>2]|0;
 $103 = (($100) + 4)|0;
 $104 = $103;
 $105 = HEAP32[$104>>2]|0;
 $106 = $99;
 $107 = $106;
 HEAP32[$107>>2] = $102;
 $108 = (($106) + 4)|0;
 $109 = $108;
 HEAP32[$109>>2] = $105;
 $110 = HEAP32[$6>>2]|0;
 $111 = HEAP32[$8>>2]|0;
 $112 = ((($111) + (($110*12)|0)|0) + 8|0);
 HEAPF32[$112>>2] = $91;
 $113 = HEAP32[$25>>2]|0;
 $114 = HEAP32[$8>>2]|0;
 $115 = (($114) + (($113*12)|0)|0);
 $116 = $cB;
 $117 = $116;
 $118 = HEAP32[$117>>2]|0;
 $119 = (($116) + 4)|0;
 $120 = $119;
 $121 = HEAP32[$120>>2]|0;
 $122 = $115;
 $123 = $122;
 HEAP32[$123>>2] = $118;
 $124 = (($122) + 4)|0;
 $125 = $124;
 HEAP32[$125>>2] = $121;
 $126 = HEAP32[$25>>2]|0;
 $127 = HEAP32[$8>>2]|0;
 $128 = ((($127) + (($126*12)|0)|0) + 8|0);
 HEAPF32[$128>>2] = $96;
 $129 = $83 < 0.004999999888241291;
 STACKTOP = sp;return ($129|0);
}
function __ZNK13b2PulleyJoint10GetAnchorAEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 92|0);
 __ZNK6b2Body13GetWorldPointERK6b2Vec2($agg$result,$1,$2);
 STACKTOP = sp;return;
}
function __ZNK13b2PulleyJoint10GetAnchorBEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 100|0);
 __ZNK6b2Body13GetWorldPointERK6b2Vec2($agg$result,$1,$2);
 STACKTOP = sp;return;
}
function __ZNK13b2PulleyJoint16GetReactionForceEf($agg$result,$this,$inv_dt) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $inv_dt = +$inv_dt;
 var $0 = 0, $1 = 0.0, $2 = 0, $P = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $P = sp;
 $0 = (($this) + 116|0);
 $1 = +HEAPF32[$0>>2];
 $2 = (($this) + 136|0);
 __ZmlfRK6b2Vec2($P,$1,$2);
 __ZmlfRK6b2Vec2($agg$result,$inv_dt,$P);
 STACKTOP = sp;return;
}
function __ZNK13b2PulleyJoint17GetReactionTorqueEf($this,$inv_dt) {
 $this = $this|0;
 $inv_dt = +$inv_dt;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return +0;
}
function __ZN13b2PulleyJoint4DumpEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0;
 var $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0.0, $43 = 0.0, $44 = 0;
 var $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer34 = 0, $vararg_ptr12 = 0, $vararg_ptr16 = 0, $vararg_ptr20 = 0, $vararg_ptr24 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer34 = sp;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 __Z5b2LogPKcz(7000,$vararg_buffer34);
 HEAP32[$vararg_buffer34>>2] = $3;
 __Z5b2LogPKcz(7024,$vararg_buffer34);
 HEAP32[$vararg_buffer34>>2] = $7;
 __Z5b2LogPKcz(7056,$vararg_buffer34);
 $8 = (($this) + 61|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 HEAP32[$vararg_buffer34>>2] = $10;
 __Z5b2LogPKcz(7088,$vararg_buffer34);
 $11 = (($this) + 68|0);
 $12 = +HEAPF32[$11>>2];
 $13 = $12;
 $14 = (($this) + 72|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $15;
 HEAPF64[tempDoublePtr>>3]=$13;HEAP32[$vararg_buffer34>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer34+4>>2]=HEAP32[tempDoublePtr+4>>2];
 $vararg_ptr12 = (($vararg_buffer34) + 8|0);
 HEAPF64[tempDoublePtr>>3]=$16;HEAP32[$vararg_ptr12>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr12+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(7128,$vararg_buffer34);
 $17 = (($this) + 76|0);
 $18 = +HEAPF32[$17>>2];
 $19 = $18;
 $20 = (($this) + 80|0);
 $21 = +HEAPF32[$20>>2];
 $22 = $21;
 HEAPF64[tempDoublePtr>>3]=$19;HEAP32[$vararg_buffer34>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer34+4>>2]=HEAP32[tempDoublePtr+4>>2];
 $vararg_ptr16 = (($vararg_buffer34) + 8|0);
 HEAPF64[tempDoublePtr>>3]=$22;HEAP32[$vararg_ptr16>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr16+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(7176,$vararg_buffer34);
 $23 = (($this) + 92|0);
 $24 = +HEAPF32[$23>>2];
 $25 = $24;
 $26 = (($this) + 96|0);
 $27 = +HEAPF32[$26>>2];
 $28 = $27;
 HEAPF64[tempDoublePtr>>3]=$25;HEAP32[$vararg_buffer34>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer34+4>>2]=HEAP32[tempDoublePtr+4>>2];
 $vararg_ptr20 = (($vararg_buffer34) + 8|0);
 HEAPF64[tempDoublePtr>>3]=$28;HEAP32[$vararg_ptr20>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr20+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(7224,$vararg_buffer34);
 $29 = (($this) + 100|0);
 $30 = +HEAPF32[$29>>2];
 $31 = $30;
 $32 = (($this) + 104|0);
 $33 = +HEAPF32[$32>>2];
 $34 = $33;
 HEAPF64[tempDoublePtr>>3]=$31;HEAP32[$vararg_buffer34>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer34+4>>2]=HEAP32[tempDoublePtr+4>>2];
 $vararg_ptr24 = (($vararg_buffer34) + 8|0);
 HEAPF64[tempDoublePtr>>3]=$34;HEAP32[$vararg_ptr24>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_ptr24+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(7272,$vararg_buffer34);
 $35 = (($this) + 84|0);
 $36 = +HEAPF32[$35>>2];
 $37 = $36;
 HEAPF64[tempDoublePtr>>3]=$37;HEAP32[$vararg_buffer34>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer34+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(7320,$vararg_buffer34);
 $38 = (($this) + 88|0);
 $39 = +HEAPF32[$38>>2];
 $40 = $39;
 HEAPF64[tempDoublePtr>>3]=$40;HEAP32[$vararg_buffer34>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer34+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(7352,$vararg_buffer34);
 $41 = (($this) + 112|0);
 $42 = +HEAPF32[$41>>2];
 $43 = $42;
 HEAPF64[tempDoublePtr>>3]=$43;HEAP32[$vararg_buffer34>>2]=HEAP32[tempDoublePtr>>2];HEAP32[$vararg_buffer34+4>>2]=HEAP32[tempDoublePtr+4>>2];
 __Z5b2LogPKcz(7384,$vararg_buffer34);
 $44 = (($this) + 56|0);
 $45 = HEAP32[$44>>2]|0;
 HEAP32[$vararg_buffer34>>2] = $45;
 __Z5b2LogPKcz(7408,$vararg_buffer34);
 STACKTOP = sp;return;
}
function __ZN13b2PulleyJoint11ShiftOriginERK6b2Vec2($this,$newOrigin) {
 $this = $this|0;
 $newOrigin = $newOrigin|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 __ZN6b2Vec2mIERKS_($0,$newOrigin);
 $1 = (($this) + 76|0);
 __ZN6b2Vec2mIERKS_($1,$newOrigin);
 STACKTOP = sp;return;
}
function __ZN13b2PulleyJointD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN24b2ChainAndPolygonContact6CreateEP9b2FixtureiS1_iP16b2BlockAllocator($fixtureA,$indexA,$fixtureB,$indexB,$allocator) {
 $fixtureA = $fixtureA|0;
 $indexA = $indexA|0;
 $fixtureB = $fixtureB|0;
 $indexB = $indexB|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN16b2BlockAllocator8AllocateEi($allocator,148)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = 0;
  STACKTOP = sp;return ($2|0);
 }
 __ZN24b2ChainAndPolygonContactC2EP9b2FixtureiS1_i($0,$fixtureA,$indexA,$fixtureB,$indexB);
 $2 = $0;
 STACKTOP = sp;return ($2|0);
}
function __ZN24b2ChainAndPolygonContact7DestroyEP9b2ContactP16b2BlockAllocator($contact,$allocator) {
 $contact = $contact|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$contact>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$2 & 127]($contact);
 __ZN16b2BlockAllocator4FreeEPvi($allocator,$contact,148);
 STACKTOP = sp;return;
}
function __ZN24b2ChainAndPolygonContactC2EP9b2FixtureiS1_i($this,$fixtureA,$indexA,$fixtureB,$indexB) {
 $this = $this|0;
 $fixtureA = $fixtureA|0;
 $indexA = $indexA|0;
 $fixtureB = $fixtureB|0;
 $indexB = $indexB|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9b2ContactC2EP9b2FixtureiS1_i($this,$fixtureA,$indexA,$fixtureB,$indexB);
 HEAP32[$this>>2] = ((7488 + 8|0));
 STACKTOP = sp;return;
}
function __ZN24b2ChainAndPolygonContact8EvaluateEP10b2ManifoldRK11b2TransformS4_($this,$manifold,$xfA,$xfB) {
 $this = $this|0;
 $manifold = $manifold|0;
 $xfA = $xfA|0;
 $xfB = $xfB|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $edge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $edge = sp;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN9b2Fixture8GetShapeEv($1)|0);
 __ZN11b2EdgeShapeC2Ev($edge);
 $3 = (($this) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNK12b2ChainShape12GetChildEdgeEP11b2EdgeShapei($2,$edge,$4);
 $5 = (($this) + 52|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__ZN9b2Fixture8GetShapeEv($6)|0);
 __Z23b2CollideEdgeAndPolygonP10b2ManifoldPK11b2EdgeShapeRK11b2TransformPK14b2PolygonShapeS6_($manifold,$edge,$xfA,$7,$xfB);
 STACKTOP = sp;return;
}
function __ZN9b2ContactD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN24b2ChainAndPolygonContactD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN9b2Contact19InitializeRegistersEv() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9b2Contact7AddTypeEPFPS_P9b2FixtureiS2_iP16b2BlockAllocatorEPFvS0_S4_EN7b2Shape4TypeESA_(6,53,0,0);
 __ZN9b2Contact7AddTypeEPFPS_P9b2FixtureiS2_iP16b2BlockAllocatorEPFvS0_S4_EN7b2Shape4TypeESA_(7,54,2,0);
 __ZN9b2Contact7AddTypeEPFPS_P9b2FixtureiS2_iP16b2BlockAllocatorEPFvS0_S4_EN7b2Shape4TypeESA_(8,55,2,2);
 __ZN9b2Contact7AddTypeEPFPS_P9b2FixtureiS2_iP16b2BlockAllocatorEPFvS0_S4_EN7b2Shape4TypeESA_(9,56,1,0);
 __ZN9b2Contact7AddTypeEPFPS_P9b2FixtureiS2_iP16b2BlockAllocatorEPFvS0_S4_EN7b2Shape4TypeESA_(10,57,1,2);
 __ZN9b2Contact7AddTypeEPFPS_P9b2FixtureiS2_iP16b2BlockAllocatorEPFvS0_S4_EN7b2Shape4TypeESA_(11,58,3,0);
 __ZN9b2Contact7AddTypeEPFPS_P9b2FixtureiS2_iP16b2BlockAllocatorEPFvS0_S4_EN7b2Shape4TypeESA_(12,59,3,2);
 STACKTOP = sp;return;
}
function __ZN9b2Contact7AddTypeEPFPS_P9b2FixtureiS2_iP16b2BlockAllocatorEPFvS0_S4_EN7b2Shape4TypeESA_($createFcn,$destoryFcn,$type1,$type2) {
 $createFcn = $createFcn|0;
 $destoryFcn = $destoryFcn|0;
 $type1 = $type1|0;
 $type2 = $type2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((7584 + (($type1*48)|0)|0) + (($type2*12)|0)|0);
 HEAP32[$0>>2] = $createFcn;
 $1 = (((7584 + (($type1*48)|0)|0) + (($type2*12)|0)|0) + 4|0);
 HEAP32[$1>>2] = $destoryFcn;
 $2 = (((7584 + (($type1*48)|0)|0) + (($type2*12)|0)|0) + 8|0);
 HEAP8[$2>>0] = 1;
 $3 = ($type1|0)==($type2|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = ((7584 + (($type2*48)|0)|0) + (($type1*12)|0)|0);
 HEAP32[$4>>2] = $createFcn;
 $5 = (((7584 + (($type2*48)|0)|0) + (($type1*12)|0)|0) + 4|0);
 HEAP32[$5>>2] = $destoryFcn;
 $6 = (((7584 + (($type2*48)|0)|0) + (($type1*12)|0)|0) + 8|0);
 HEAP8[$6>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN9b2Contact6CreateEP9b2FixtureiS1_iP16b2BlockAllocator($fixtureA,$indexA,$fixtureB,$indexB,$allocator) {
 $fixtureA = $fixtureA|0;
 $indexA = $indexA|0;
 $fixtureB = $fixtureB|0;
 $indexB = $indexB|0;
 $allocator = $allocator|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[7776>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  __ZN9b2Contact19InitializeRegistersEv();
  HEAP8[7776>>0] = 1;
 }
 $2 = (__ZNK9b2Fixture7GetTypeEv($fixtureA)|0);
 $3 = (__ZNK9b2Fixture7GetTypeEv($fixtureB)|0);
 $4 = ((7584 + (($2*48)|0)|0) + (($3*12)|0)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (((7584 + (($2*48)|0)|0) + (($3*12)|0)|0) + 8|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  $11 = (FUNCTION_TABLE_iiiiii[$5 & 15]($fixtureB,$indexB,$fixtureA,$indexA,$allocator)|0);
  $$0 = $11;
  STACKTOP = sp;return ($$0|0);
 } else {
  $10 = (FUNCTION_TABLE_iiiiii[$5 & 15]($fixtureA,$indexA,$fixtureB,$indexB,$allocator)|0);
  $$0 = $10;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function __ZN9b2Contact7DestroyEPS_P16b2BlockAllocator($contact,$allocator) {
 $contact = $contact|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($contact) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($contact) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($contact) + 124|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)>(0);
 if ($6) {
  $7 = (__ZNK9b2Fixture8IsSensorEv($1)|0);
  if (!($7)) {
   $8 = (__ZNK9b2Fixture8IsSensorEv($3)|0);
   if (!($8)) {
    $9 = (__ZN9b2Fixture7GetBodyEv($1)|0);
    __ZN6b2Body8SetAwakeEb($9,1);
    $10 = (__ZN9b2Fixture7GetBodyEv($3)|0);
    __ZN6b2Body8SetAwakeEb($10,1);
   }
  }
 }
 $11 = (__ZNK9b2Fixture7GetTypeEv($1)|0);
 $12 = (__ZNK9b2Fixture7GetTypeEv($3)|0);
 $13 = (((7584 + (($11*48)|0)|0) + (($12*12)|0)|0) + 4|0);
 $14 = HEAP32[$13>>2]|0;
 FUNCTION_TABLE_vii[$14 & 63]($contact,$allocator);
 STACKTOP = sp;return;
}
function __ZN9b2ContactC2EP9b2FixtureiS1_i($this,$fA,$indexA,$fB,$indexB) {
 $this = $this|0;
 $fA = $fA|0;
 $indexA = $indexA|0;
 $fB = $fB|0;
 $indexB = $indexB|0;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((7784 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 4;
 $1 = (($this) + 48|0);
 HEAP32[$1>>2] = $fA;
 $2 = (($this) + 52|0);
 HEAP32[$2>>2] = $fB;
 $3 = (($this) + 56|0);
 HEAP32[$3>>2] = $indexA;
 $4 = (($this) + 60|0);
 HEAP32[$4>>2] = $indexB;
 $5 = (($this) + 124|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 8|0);
 $7 = (($this) + 128|0);
 HEAP32[$7>>2] = 0;
 dest=$6+0|0; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $8 = HEAP32[$1>>2]|0;
 $9 = (($8) + 16|0);
 $10 = +HEAPF32[$9>>2];
 $11 = HEAP32[$2>>2]|0;
 $12 = (($11) + 16|0);
 $13 = +HEAPF32[$12>>2];
 $14 = (+__Z13b2MixFrictionff($10,$13));
 $15 = (($this) + 136|0);
 HEAPF32[$15>>2] = $14;
 $16 = HEAP32[$1>>2]|0;
 $17 = (($16) + 20|0);
 $18 = +HEAPF32[$17>>2];
 $19 = HEAP32[$2>>2]|0;
 $20 = (($19) + 20|0);
 $21 = +HEAPF32[$20>>2];
 $22 = (+__Z16b2MixRestitutionff($18,$21));
 $23 = (($this) + 140|0);
 HEAPF32[$23>>2] = $22;
 $24 = (($this) + 144|0);
 HEAPF32[$24>>2] = 0.0;
 STACKTOP = sp;return;
}
function __ZN9b2Contact6UpdateEP17b2ContactListener($this,$listener) {
 $this = $this|0;
 $listener = $listener|0;
 var $$ = 0, $$$not = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0.0, $43 = 0, $44 = 0.0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $i$013 = 0, $j$012 = 0, $oldManifold = 0, $or$cond = 0, $or$cond10 = 0, $or$cond3 = 0, $or$cond8 = 0, $or$cond9 = 0, $storemerge = 0, $touching$0$off0 = 0;
 var dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $oldManifold = sp;
 $0 = (($this) + 64|0);
 dest=$oldManifold+0|0; src=$0+0|0; stop=dest+64|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 | 4;
 HEAP32[$1>>2] = $3;
 $4 = $2 >>> 1;
 $5 = (($this) + 48|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__ZNK9b2Fixture8IsSensorEv($6)|0);
 $8 = (($this) + 52|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (__ZNK9b2Fixture8IsSensorEv($9)|0);
 $$ = $7 | $10;
 $11 = (__ZN9b2Fixture7GetBodyEv($6)|0);
 $12 = (__ZN9b2Fixture7GetBodyEv($9)|0);
 $13 = (__ZNK6b2Body12GetTransformEv($11)|0);
 $14 = (__ZNK6b2Body12GetTransformEv($12)|0);
 if ($$) {
  $15 = (__ZN9b2Fixture8GetShapeEv($6)|0);
  $16 = (__ZN9b2Fixture8GetShapeEv($9)|0);
  $17 = (($this) + 56|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($this) + 60|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (__Z13b2TestOverlapPK7b2ShapeiS1_iRK11b2TransformS4_($15,$18,$16,$20,$13,$14)|0);
  $22 = (($this) + 124|0);
  HEAP32[$22>>2] = 0;
  $touching$0$off0 = $21;
 } else {
  $23 = HEAP32[$this>>2]|0;
  $24 = HEAP32[$23>>2]|0;
  FUNCTION_TABLE_viiii[$24 & 31]($this,$0,$13,$14);
  $25 = (($this) + 124|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ($26|0)>(0);
  $28 = ($26|0)>(0);
  if ($28) {
   $29 = (($oldManifold) + 60|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)>(0);
   $i$013 = 0;
   while(1) {
    $32 = ((($this) + (($i$013*20)|0)|0) + 72|0);
    HEAPF32[$32>>2] = 0.0;
    $33 = ((($this) + (($i$013*20)|0)|0) + 76|0);
    HEAPF32[$33>>2] = 0.0;
    $34 = ((($this) + (($i$013*20)|0)|0) + 80|0);
    $35 = HEAP32[$34>>2]|0;
    L8: do {
     if ($31) {
      $j$012 = 0;
      while(1) {
       $38 = ((($oldManifold) + (($j$012*20)|0)|0) + 16|0);
       $39 = HEAP32[$38>>2]|0;
       $40 = ($39|0)==($35|0);
       $36 = (($j$012) + 1)|0;
       if ($40) {
        break;
       }
       $37 = ($36|0)<($30|0);
       if ($37) {
        $j$012 = $36;
       } else {
        break L8;
       }
      }
      $41 = ((($oldManifold) + (($j$012*20)|0)|0) + 8|0);
      $42 = +HEAPF32[$41>>2];
      HEAPF32[$32>>2] = $42;
      $43 = ((($oldManifold) + (($j$012*20)|0)|0) + 12|0);
      $44 = +HEAPF32[$43>>2];
      HEAPF32[$33>>2] = $44;
     }
    } while(0);
    $45 = (($i$013) + 1)|0;
    $46 = HEAP32[$25>>2]|0;
    $47 = ($45|0)<($46|0);
    if ($47) {
     $i$013 = $45;
    } else {
     break;
    }
   }
  }
  $48 = $4 & 1;
  $49 = ($48|0)!=(0);
  $50 = $27 ^ $49;
  if ($50) {
   __ZN6b2Body8SetAwakeEb($11,1);
   __ZN6b2Body8SetAwakeEb($12,1);
   $touching$0$off0 = $27;
  } else {
   $touching$0$off0 = $27;
  }
 }
 $51 = HEAP32[$1>>2]|0;
 $52 = $51 & -3;
 $53 = $51 | 2;
 $storemerge = $touching$0$off0 ? $53 : $52;
 HEAP32[$1>>2] = $storemerge;
 $54 = $4 & 1;
 $55 = ($54|0)==(0);
 $56 = ($listener|0)!=(0|0);
 $or$cond = $touching$0$off0 & $56;
 $or$cond8 = $55 & $or$cond;
 if ($or$cond8) {
  $57 = HEAP32[$listener>>2]|0;
  $58 = (($57) + 8|0);
  $59 = HEAP32[$58>>2]|0;
  FUNCTION_TABLE_vii[$59 & 63]($listener,$this);
 }
 $$not = $55 ^ 1;
 $60 = $touching$0$off0 ^ 1;
 $or$cond3 = $56 & $60;
 $or$cond10 = $or$cond3 & $$not;
 if ($or$cond10) {
  $61 = HEAP32[$listener>>2]|0;
  $62 = (($61) + 12|0);
  $63 = HEAP32[$62>>2]|0;
  FUNCTION_TABLE_vii[$63 & 63]($listener,$this);
 }
 $$$not = $$ ^ 1;
 $or$cond9 = $or$cond & $$$not;
 if (!($or$cond9)) {
  STACKTOP = sp;return;
 }
 $64 = HEAP32[$listener>>2]|0;
 $65 = (($64) + 32|0);
 $66 = HEAP32[$65>>2]|0;
 FUNCTION_TABLE_viii[$66 & 15]($listener,$this,$oldManifold);
 STACKTOP = sp;return;
}
function __ZN9b2ContactD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK9b2Fixture7GetTypeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK7b2Shape7GetTypeEv($1)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZNK9b2Fixture8IsSensorEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 38|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __Z13b2MixFrictionff($friction1,$friction2) {
 $friction1 = +$friction1;
 $friction2 = +$friction2;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $friction1 * $friction2;
 $1 = (+Math_sqrt((+$0)));
 STACKTOP = sp;return (+$1);
}
function __Z16b2MixRestitutionff($restitution1,$restitution2) {
 $restitution1 = +$restitution1;
 $restitution2 = +$restitution2;
 var $0 = 0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $restitution1 > $restitution2;
 $1 = $0 ? $restitution1 : $restitution2;
 STACKTOP = sp;return (+$1);
}
function __ZN25b2PolygonAndCircleContact6CreateEP9b2FixtureiS1_iP16b2BlockAllocator($fixtureA,$0,$fixtureB,$1,$allocator) {
 $fixtureA = $fixtureA|0;
 $0 = $0|0;
 $fixtureB = $fixtureB|0;
 $1 = $1|0;
 $allocator = $allocator|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN16b2BlockAllocator8AllocateEi($allocator,148)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = 0;
  STACKTOP = sp;return ($4|0);
 }
 __ZN25b2PolygonAndCircleContactC2EP9b2FixtureS1_($2,$fixtureA,$fixtureB);
 $4 = $2;
 STACKTOP = sp;return ($4|0);
}
function __ZN25b2PolygonAndCircleContact7DestroyEP9b2ContactP16b2BlockAllocator($contact,$allocator) {
 $contact = $contact|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$contact>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$2 & 127]($contact);
 __ZN16b2BlockAllocator4FreeEPvi($allocator,$contact,148);
 STACKTOP = sp;return;
}
function __ZN25b2PolygonAndCircleContactC2EP9b2FixtureS1_($this,$fixtureA,$fixtureB) {
 $this = $this|0;
 $fixtureA = $fixtureA|0;
 $fixtureB = $fixtureB|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9b2ContactC2EP9b2FixtureiS1_i($this,$fixtureA,0,$fixtureB,0);
 HEAP32[$this>>2] = ((7808 + 8|0));
 STACKTOP = sp;return;
}
function __ZN25b2PolygonAndCircleContact8EvaluateEP10b2ManifoldRK11b2TransformS4_($this,$manifold,$xfA,$xfB) {
 $this = $this|0;
 $manifold = $manifold|0;
 $xfA = $xfA|0;
 $xfB = $xfB|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN9b2Fixture8GetShapeEv($1)|0);
 $3 = (($this) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZN9b2Fixture8GetShapeEv($4)|0);
 __Z25b2CollidePolygonAndCircleP10b2ManifoldPK14b2PolygonShapeRK11b2TransformPK13b2CircleShapeS6_($manifold,$2,$xfA,$5,$xfB);
 STACKTOP = sp;return;
}
function __ZN25b2PolygonAndCircleContactD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN15b2CircleContact6CreateEP9b2FixtureiS1_iP16b2BlockAllocator($fixtureA,$0,$fixtureB,$1,$allocator) {
 $fixtureA = $fixtureA|0;
 $0 = $0|0;
 $fixtureB = $fixtureB|0;
 $1 = $1|0;
 $allocator = $allocator|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN16b2BlockAllocator8AllocateEi($allocator,148)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = 0;
  STACKTOP = sp;return ($4|0);
 }
 __ZN15b2CircleContactC2EP9b2FixtureS1_($2,$fixtureA,$fixtureB);
 $4 = $2;
 STACKTOP = sp;return ($4|0);
}
function __ZN15b2CircleContact7DestroyEP9b2ContactP16b2BlockAllocator($contact,$allocator) {
 $contact = $contact|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$contact>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$2 & 127]($contact);
 __ZN16b2BlockAllocator4FreeEPvi($allocator,$contact,148);
 STACKTOP = sp;return;
}
function __ZN15b2CircleContactC2EP9b2FixtureS1_($this,$fixtureA,$fixtureB) {
 $this = $this|0;
 $fixtureA = $fixtureA|0;
 $fixtureB = $fixtureB|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9b2ContactC2EP9b2FixtureiS1_i($this,$fixtureA,0,$fixtureB,0);
 HEAP32[$this>>2] = ((7880 + 8|0));
 STACKTOP = sp;return;
}
function __ZN15b2CircleContact8EvaluateEP10b2ManifoldRK11b2TransformS4_($this,$manifold,$xfA,$xfB) {
 $this = $this|0;
 $manifold = $manifold|0;
 $xfA = $xfA|0;
 $xfB = $xfB|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN9b2Fixture8GetShapeEv($1)|0);
 $3 = (($this) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZN9b2Fixture8GetShapeEv($4)|0);
 __Z16b2CollideCirclesP10b2ManifoldPK13b2CircleShapeRK11b2TransformS3_S6_($manifold,$2,$xfA,$5,$xfB);
 STACKTOP = sp;return;
}
function __ZN15b2CircleContactD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN15b2ContactSolverC2EP18b2ContactSolverDef($this,$def) {
 $this = $this|0;
 $def = $def|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0.0, $112 = 0, $113 = 0.0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0.0, $15 = 0, $150 = 0, $151 = 0.0;
 var $152 = 0.0, $153 = 0, $154 = 0.0, $155 = 0, $156 = 0.0, $157 = 0.0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0.0, $64 = 0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0.0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0.0, $84 = 0, $85 = 0.0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $exitcond = 0, $i$02 = 0, $j$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$this+0>>2]=HEAP32[$def+0>>2]|0;HEAP32[$this+4>>2]=HEAP32[$def+4>>2]|0;HEAP32[$this+8>>2]=HEAP32[$def+8>>2]|0;HEAP32[$this+12>>2]=HEAP32[$def+12>>2]|0;HEAP32[$this+16>>2]=HEAP32[$def+16>>2]|0;HEAP32[$this+20>>2]=HEAP32[$def+20>>2]|0;HEAP32[$this+24>>2]=HEAP32[$def+24>>2]|0;
 $0 = (($def) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 36|0);
 HEAP32[$2>>2] = $1;
 $3 = (($def) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 52|0);
 HEAP32[$5>>2] = $4;
 $6 = HEAP32[$2>>2]|0;
 $7 = ($4*88)|0;
 $8 = (__ZN16b2StackAllocator8AllocateEi($6,$7)|0);
 $9 = (($this) + 40|0);
 HEAP32[$9>>2] = $8;
 $10 = HEAP32[$2>>2]|0;
 $11 = HEAP32[$5>>2]|0;
 $12 = ($11*156)|0;
 $13 = (__ZN16b2StackAllocator8AllocateEi($10,$12)|0);
 $14 = (($this) + 44|0);
 HEAP32[$14>>2] = $13;
 $15 = (($def) + 36|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($this) + 28|0);
 HEAP32[$17>>2] = $16;
 $18 = (($def) + 40|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($this) + 32|0);
 HEAP32[$20>>2] = $19;
 $21 = (($def) + 28|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = (($this) + 48|0);
 HEAP32[$23>>2] = $22;
 $24 = HEAP32[$5>>2]|0;
 $25 = ($24|0)>(0);
 if (!($25)) {
  STACKTOP = sp;return;
 }
 $26 = (($this) + 24|0);
 $27 = (($this) + 8|0);
 $i$02 = 0;
 while(1) {
  $28 = HEAP32[$23>>2]|0;
  $29 = (($28) + ($i$02<<2)|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 48|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (($30) + 52|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = (__ZN9b2Fixture8GetShapeEv($32)|0);
  $36 = (__ZN9b2Fixture8GetShapeEv($34)|0);
  $37 = (($35) + 8|0);
  $38 = +HEAPF32[$37>>2];
  $39 = (($36) + 8|0);
  $40 = +HEAPF32[$39>>2];
  $41 = (__ZN9b2Fixture7GetBodyEv($32)|0);
  $42 = (__ZN9b2Fixture7GetBodyEv($34)|0);
  $43 = (__ZN9b2Contact11GetManifoldEv($30)|0);
  $44 = (($43) + 60|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = HEAP32[$14>>2]|0;
  $47 = (($30) + 136|0);
  $48 = +HEAPF32[$47>>2];
  $49 = ((($46) + (($i$02*156)|0)|0) + 136|0);
  HEAPF32[$49>>2] = $48;
  $50 = (($30) + 140|0);
  $51 = +HEAPF32[$50>>2];
  $52 = ((($46) + (($i$02*156)|0)|0) + 140|0);
  HEAPF32[$52>>2] = $51;
  $53 = (($30) + 144|0);
  $54 = +HEAPF32[$53>>2];
  $55 = ((($46) + (($i$02*156)|0)|0) + 144|0);
  HEAPF32[$55>>2] = $54;
  $56 = (($41) + 8|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ((($46) + (($i$02*156)|0)|0) + 112|0);
  HEAP32[$58>>2] = $57;
  $59 = (($42) + 8|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = ((($46) + (($i$02*156)|0)|0) + 116|0);
  HEAP32[$61>>2] = $60;
  $62 = (($41) + 136|0);
  $63 = +HEAPF32[$62>>2];
  $64 = ((($46) + (($i$02*156)|0)|0) + 120|0);
  HEAPF32[$64>>2] = $63;
  $65 = (($42) + 136|0);
  $66 = +HEAPF32[$65>>2];
  $67 = ((($46) + (($i$02*156)|0)|0) + 124|0);
  HEAPF32[$67>>2] = $66;
  $68 = (($41) + 144|0);
  $69 = +HEAPF32[$68>>2];
  $70 = ((($46) + (($i$02*156)|0)|0) + 128|0);
  HEAPF32[$70>>2] = $69;
  $71 = (($42) + 144|0);
  $72 = +HEAPF32[$71>>2];
  $73 = ((($46) + (($i$02*156)|0)|0) + 132|0);
  HEAPF32[$73>>2] = $72;
  $74 = ((($46) + (($i$02*156)|0)|0) + 152|0);
  HEAP32[$74>>2] = $i$02;
  $75 = ((($46) + (($i$02*156)|0)|0) + 148|0);
  HEAP32[$75>>2] = $45;
  $76 = ((($46) + (($i$02*156)|0)|0) + 96|0);
  __ZN7b2Mat227SetZeroEv($76);
  $77 = ((($46) + (($i$02*156)|0)|0) + 80|0);
  __ZN7b2Mat227SetZeroEv($77);
  $78 = HEAP32[$9>>2]|0;
  $79 = HEAP32[$56>>2]|0;
  $80 = ((($78) + (($i$02*88)|0)|0) + 32|0);
  HEAP32[$80>>2] = $79;
  $81 = HEAP32[$59>>2]|0;
  $82 = ((($78) + (($i$02*88)|0)|0) + 36|0);
  HEAP32[$82>>2] = $81;
  $83 = +HEAPF32[$62>>2];
  $84 = ((($78) + (($i$02*88)|0)|0) + 40|0);
  HEAPF32[$84>>2] = $83;
  $85 = +HEAPF32[$65>>2];
  $86 = ((($78) + (($i$02*88)|0)|0) + 44|0);
  HEAPF32[$86>>2] = $85;
  $87 = ((($78) + (($i$02*88)|0)|0) + 48|0);
  $88 = (($41) + 44|0);
  $89 = $88;
  $90 = $89;
  $91 = HEAP32[$90>>2]|0;
  $92 = (($89) + 4)|0;
  $93 = $92;
  $94 = HEAP32[$93>>2]|0;
  $95 = $87;
  $96 = $95;
  HEAP32[$96>>2] = $91;
  $97 = (($95) + 4)|0;
  $98 = $97;
  HEAP32[$98>>2] = $94;
  $99 = ((($78) + (($i$02*88)|0)|0) + 56|0);
  $100 = (($42) + 44|0);
  $101 = $100;
  $102 = $101;
  $103 = HEAP32[$102>>2]|0;
  $104 = (($101) + 4)|0;
  $105 = $104;
  $106 = HEAP32[$105>>2]|0;
  $107 = $99;
  $108 = $107;
  HEAP32[$108>>2] = $103;
  $109 = (($107) + 4)|0;
  $110 = $109;
  HEAP32[$110>>2] = $106;
  $111 = +HEAPF32[$68>>2];
  $112 = ((($78) + (($i$02*88)|0)|0) + 64|0);
  HEAPF32[$112>>2] = $111;
  $113 = +HEAPF32[$71>>2];
  $114 = ((($78) + (($i$02*88)|0)|0) + 68|0);
  HEAPF32[$114>>2] = $113;
  $115 = ((($78) + (($i$02*88)|0)|0) + 16|0);
  $116 = (($43) + 40|0);
  $117 = $116;
  $118 = $117;
  $119 = HEAP32[$118>>2]|0;
  $120 = (($117) + 4)|0;
  $121 = $120;
  $122 = HEAP32[$121>>2]|0;
  $123 = $115;
  $124 = $123;
  HEAP32[$124>>2] = $119;
  $125 = (($123) + 4)|0;
  $126 = $125;
  HEAP32[$126>>2] = $122;
  $127 = ((($78) + (($i$02*88)|0)|0) + 24|0);
  $128 = (($43) + 48|0);
  $129 = $128;
  $130 = $129;
  $131 = HEAP32[$130>>2]|0;
  $132 = (($129) + 4)|0;
  $133 = $132;
  $134 = HEAP32[$133>>2]|0;
  $135 = $127;
  $136 = $135;
  HEAP32[$136>>2] = $131;
  $137 = (($135) + 4)|0;
  $138 = $137;
  HEAP32[$138>>2] = $134;
  $139 = ((($78) + (($i$02*88)|0)|0) + 84|0);
  HEAP32[$139>>2] = $45;
  $140 = ((($78) + (($i$02*88)|0)|0) + 76|0);
  HEAPF32[$140>>2] = $38;
  $141 = ((($78) + (($i$02*88)|0)|0) + 80|0);
  HEAPF32[$141>>2] = $40;
  $142 = (($43) + 56|0);
  $143 = HEAP32[$142>>2]|0;
  $144 = ((($78) + (($i$02*88)|0)|0) + 72|0);
  HEAP32[$144>>2] = $143;
  $145 = ($45|0)>(0);
  if ($145) {
   $j$01 = 0;
   while(1) {
    $146 = (($43) + (($j$01*20)|0)|0);
    $147 = HEAP8[$26>>0]|0;
    $148 = ($147<<24>>24)==(0);
    if ($148) {
     $159 = (((($46) + (($i$02*156)|0)|0) + (($j$01*36)|0)|0) + 16|0);
     HEAPF32[$159>>2] = 0.0;
     $160 = (((($46) + (($i$02*156)|0)|0) + (($j$01*36)|0)|0) + 20|0);
     HEAPF32[$160>>2] = 0.0;
    } else {
     $149 = +HEAPF32[$27>>2];
     $150 = ((($43) + (($j$01*20)|0)|0) + 8|0);
     $151 = +HEAPF32[$150>>2];
     $152 = $149 * $151;
     $153 = (((($46) + (($i$02*156)|0)|0) + (($j$01*36)|0)|0) + 16|0);
     HEAPF32[$153>>2] = $152;
     $154 = +HEAPF32[$27>>2];
     $155 = ((($43) + (($j$01*20)|0)|0) + 12|0);
     $156 = +HEAPF32[$155>>2];
     $157 = $154 * $156;
     $158 = (((($46) + (($i$02*156)|0)|0) + (($j$01*36)|0)|0) + 20|0);
     HEAPF32[$158>>2] = $157;
    }
    $161 = ((($46) + (($i$02*156)|0)|0) + (($j$01*36)|0)|0);
    __ZN6b2Vec27SetZeroEv($161);
    $162 = (((($46) + (($i$02*156)|0)|0) + (($j$01*36)|0)|0) + 8|0);
    __ZN6b2Vec27SetZeroEv($162);
    $163 = (((($46) + (($i$02*156)|0)|0) + (($j$01*36)|0)|0) + 24|0);
    HEAPF32[$163>>2] = 0.0;
    $164 = (((($46) + (($i$02*156)|0)|0) + (($j$01*36)|0)|0) + 28|0);
    HEAPF32[$164>>2] = 0.0;
    $165 = (((($46) + (($i$02*156)|0)|0) + (($j$01*36)|0)|0) + 32|0);
    HEAPF32[$165>>2] = 0.0;
    $166 = ((($78) + (($i$02*88)|0)|0) + ($j$01<<3)|0);
    $167 = $146;
    $168 = $167;
    $169 = HEAP32[$168>>2]|0;
    $170 = (($167) + 4)|0;
    $171 = $170;
    $172 = HEAP32[$171>>2]|0;
    $173 = $166;
    $174 = $173;
    HEAP32[$174>>2] = $169;
    $175 = (($173) + 4)|0;
    $176 = $175;
    HEAP32[$176>>2] = $172;
    $177 = (($j$01) + 1)|0;
    $exitcond = ($177|0)==($45|0);
    if ($exitcond) {
     break;
    } else {
     $j$01 = $177;
    }
   }
  }
  $178 = (($i$02) + 1)|0;
  $179 = HEAP32[$5>>2]|0;
  $180 = ($178|0)<($179|0);
  if ($180) {
   $i$02 = $178;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN15b2ContactSolverD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 44|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN16b2StackAllocator4FreeEPv($1,$3);
 $4 = HEAP32[$0>>2]|0;
 $5 = (($this) + 40|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN16b2StackAllocator4FreeEPv($4,$6);
 STACKTOP = sp;return;
}
function __ZN15b2ContactSolver29InitializeVelocityConstraintsEv($this) {
 $this = $this|0;
 var $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0.0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0.0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0.0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0.0;
 var $188 = 0.0, $189 = 0.0, $19 = 0, $190 = 0.0, $191 = 0.0, $192 = 0.0, $193 = 0.0, $194 = 0.0, $195 = 0, $196 = 0.0, $197 = 0, $198 = 0.0, $199 = 0.0, $2 = 0, $20 = 0, $200 = 0.0, $201 = 0.0, $202 = 0.0, $203 = 0.0, $204 = 0.0;
 var $205 = 0.0, $206 = 0.0, $207 = 0, $208 = 0.0, $209 = 0, $21 = 0, $210 = 0.0, $211 = 0, $212 = 0.0, $213 = 0, $214 = 0.0, $215 = 0.0, $216 = 0.0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0.0, $221 = 0, $222 = 0.0;
 var $223 = 0, $224 = 0.0, $225 = 0, $226 = 0.0, $227 = 0.0, $228 = 0.0, $229 = 0.0, $23 = 0, $230 = 0.0, $231 = 0.0, $232 = 0.0, $233 = 0.0, $234 = 0.0, $235 = 0.0, $236 = 0.0, $237 = 0.0, $238 = 0.0, $239 = 0.0, $24 = 0, $240 = 0.0;
 var $241 = 0.0, $242 = 0.0, $243 = 0.0, $244 = 0.0, $245 = 0.0, $246 = 0.0, $247 = 0.0, $248 = 0.0, $249 = 0, $25 = 0.0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $26 = 0, $27 = 0.0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0, $45 = 0.0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0.0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0.0, $98 = 0, $99 = 0, $cA = 0, $cB = 0, $exitcond = 0;
 var $i$011 = 0, $j$010 = 0, $localCenterA = 0, $localCenterB = 0, $tangent = 0, $vA = 0, $vB = 0, $worldManifold = 0, $xfA = 0, $xfB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0;
 $localCenterA = sp + 136|0;
 $localCenterB = sp + 128|0;
 $cA = sp + 120|0;
 $vA = sp + 112|0;
 $cB = sp + 104|0;
 $vB = sp + 96|0;
 $xfA = sp + 80|0;
 $xfB = sp + 64|0;
 $0 = sp + 56|0;
 $1 = sp + 216|0;
 $2 = sp + 48|0;
 $3 = sp + 208|0;
 $worldManifold = sp + 16|0;
 $4 = sp + 8|0;
 $5 = sp;
 $tangent = sp + 200|0;
 $6 = sp + 192|0;
 $7 = sp + 184|0;
 $8 = sp + 176|0;
 $9 = sp + 168|0;
 $10 = sp + 160|0;
 $11 = sp + 144|0;
 $12 = (($this) + 52|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)>(0);
 if (!($14)) {
  STACKTOP = sp;return;
 }
 $15 = (($this) + 44|0);
 $16 = (($this) + 40|0);
 $17 = (($this) + 48|0);
 $18 = (($this) + 28|0);
 $19 = (($this) + 32|0);
 $20 = (($xfA) + 8|0);
 $21 = (($xfB) + 8|0);
 $i$011 = 0;
 while(1) {
  $22 = HEAP32[$15>>2]|0;
  $23 = HEAP32[$16>>2]|0;
  $24 = ((($23) + (($i$011*88)|0)|0) + 76|0);
  $25 = +HEAPF32[$24>>2];
  $26 = ((($23) + (($i$011*88)|0)|0) + 80|0);
  $27 = +HEAPF32[$26>>2];
  $28 = ((($22) + (($i$011*156)|0)|0) + 152|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = HEAP32[$17>>2]|0;
  $31 = (($30) + ($29<<2)|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = (__ZN9b2Contact11GetManifoldEv($32)|0);
  $34 = ((($22) + (($i$011*156)|0)|0) + 112|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ((($22) + (($i$011*156)|0)|0) + 116|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ((($22) + (($i$011*156)|0)|0) + 120|0);
  $39 = +HEAPF32[$38>>2];
  $40 = ((($22) + (($i$011*156)|0)|0) + 124|0);
  $41 = +HEAPF32[$40>>2];
  $42 = ((($22) + (($i$011*156)|0)|0) + 128|0);
  $43 = +HEAPF32[$42>>2];
  $44 = ((($22) + (($i$011*156)|0)|0) + 132|0);
  $45 = +HEAPF32[$44>>2];
  $46 = ((($23) + (($i$011*88)|0)|0) + 48|0);
  $47 = $46;
  $48 = $47;
  $49 = HEAP32[$48>>2]|0;
  $50 = (($47) + 4)|0;
  $51 = $50;
  $52 = HEAP32[$51>>2]|0;
  $53 = $localCenterA;
  $54 = $53;
  HEAP32[$54>>2] = $49;
  $55 = (($53) + 4)|0;
  $56 = $55;
  HEAP32[$56>>2] = $52;
  $57 = ((($23) + (($i$011*88)|0)|0) + 56|0);
  $58 = $57;
  $59 = $58;
  $60 = HEAP32[$59>>2]|0;
  $61 = (($58) + 4)|0;
  $62 = $61;
  $63 = HEAP32[$62>>2]|0;
  $64 = $localCenterB;
  $65 = $64;
  HEAP32[$65>>2] = $60;
  $66 = (($64) + 4)|0;
  $67 = $66;
  HEAP32[$67>>2] = $63;
  $68 = HEAP32[$18>>2]|0;
  $69 = (($68) + (($35*12)|0)|0);
  $70 = $69;
  $71 = $70;
  $72 = HEAP32[$71>>2]|0;
  $73 = (($70) + 4)|0;
  $74 = $73;
  $75 = HEAP32[$74>>2]|0;
  $76 = $cA;
  $77 = $76;
  HEAP32[$77>>2] = $72;
  $78 = (($76) + 4)|0;
  $79 = $78;
  HEAP32[$79>>2] = $75;
  $80 = HEAP32[$18>>2]|0;
  $81 = ((($80) + (($35*12)|0)|0) + 8|0);
  $82 = +HEAPF32[$81>>2];
  $83 = HEAP32[$19>>2]|0;
  $84 = (($83) + (($35*12)|0)|0);
  $85 = $84;
  $86 = $85;
  $87 = HEAP32[$86>>2]|0;
  $88 = (($85) + 4)|0;
  $89 = $88;
  $90 = HEAP32[$89>>2]|0;
  $91 = $vA;
  $92 = $91;
  HEAP32[$92>>2] = $87;
  $93 = (($91) + 4)|0;
  $94 = $93;
  HEAP32[$94>>2] = $90;
  $95 = HEAP32[$19>>2]|0;
  $96 = ((($95) + (($35*12)|0)|0) + 8|0);
  $97 = +HEAPF32[$96>>2];
  $98 = HEAP32[$18>>2]|0;
  $99 = (($98) + (($37*12)|0)|0);
  $100 = $99;
  $101 = $100;
  $102 = HEAP32[$101>>2]|0;
  $103 = (($100) + 4)|0;
  $104 = $103;
  $105 = HEAP32[$104>>2]|0;
  $106 = $cB;
  $107 = $106;
  HEAP32[$107>>2] = $102;
  $108 = (($106) + 4)|0;
  $109 = $108;
  HEAP32[$109>>2] = $105;
  $110 = HEAP32[$18>>2]|0;
  $111 = ((($110) + (($37*12)|0)|0) + 8|0);
  $112 = +HEAPF32[$111>>2];
  $113 = HEAP32[$19>>2]|0;
  $114 = (($113) + (($37*12)|0)|0);
  $115 = $114;
  $116 = $115;
  $117 = HEAP32[$116>>2]|0;
  $118 = (($115) + 4)|0;
  $119 = $118;
  $120 = HEAP32[$119>>2]|0;
  $121 = $vB;
  $122 = $121;
  HEAP32[$122>>2] = $117;
  $123 = (($121) + 4)|0;
  $124 = $123;
  HEAP32[$124>>2] = $120;
  $125 = HEAP32[$19>>2]|0;
  $126 = ((($125) + (($37*12)|0)|0) + 8|0);
  $127 = +HEAPF32[$126>>2];
  __ZN5b2Rot3SetEf($20,$82);
  __ZN5b2Rot3SetEf($21,$112);
  __Z5b2MulRK5b2RotRK6b2Vec2($1,$20,$localCenterA);
  __ZmiRK6b2Vec2S1_($0,$cA,$1);
  $128 = $0;
  $129 = $128;
  $130 = HEAP32[$129>>2]|0;
  $131 = (($128) + 4)|0;
  $132 = $131;
  $133 = HEAP32[$132>>2]|0;
  $134 = $xfA;
  $135 = $134;
  HEAP32[$135>>2] = $130;
  $136 = (($134) + 4)|0;
  $137 = $136;
  HEAP32[$137>>2] = $133;
  __Z5b2MulRK5b2RotRK6b2Vec2($3,$21,$localCenterB);
  __ZmiRK6b2Vec2S1_($2,$cB,$3);
  $138 = $2;
  $139 = $138;
  $140 = HEAP32[$139>>2]|0;
  $141 = (($138) + 4)|0;
  $142 = $141;
  $143 = HEAP32[$142>>2]|0;
  $144 = $xfB;
  $145 = $144;
  HEAP32[$145>>2] = $140;
  $146 = (($144) + 4)|0;
  $147 = $146;
  HEAP32[$147>>2] = $143;
  __ZN15b2WorldManifold10InitializeEPK10b2ManifoldRK11b2TransformfS5_f($worldManifold,$33,$xfA,$25,$xfB,$27);
  $148 = ((($22) + (($i$011*156)|0)|0) + 72|0);
  $149 = $worldManifold;
  $150 = $149;
  $151 = HEAP32[$150>>2]|0;
  $152 = (($149) + 4)|0;
  $153 = $152;
  $154 = HEAP32[$153>>2]|0;
  $155 = $148;
  $156 = $155;
  HEAP32[$156>>2] = $151;
  $157 = (($155) + 4)|0;
  $158 = $157;
  HEAP32[$158>>2] = $154;
  $159 = ((($22) + (($i$011*156)|0)|0) + 148|0);
  $160 = HEAP32[$159>>2]|0;
  $161 = ($160|0)>(0);
  do {
   if ($161) {
    $162 = $39 + $41;
    $163 = ((($22) + (($i$011*156)|0)|0) + 140|0);
    $j$010 = 0;
    while(1) {
     $164 = ((($22) + (($i$011*156)|0)|0) + (($j$010*36)|0)|0);
     $165 = ((($worldManifold) + ($j$010<<3)|0) + 8|0);
     __ZmiRK6b2Vec2S1_($4,$165,$cA);
     $166 = $4;
     $167 = $166;
     $168 = HEAP32[$167>>2]|0;
     $169 = (($166) + 4)|0;
     $170 = $169;
     $171 = HEAP32[$170>>2]|0;
     $172 = $164;
     $173 = $172;
     HEAP32[$173>>2] = $168;
     $174 = (($172) + 4)|0;
     $175 = $174;
     HEAP32[$175>>2] = $171;
     $176 = (((($22) + (($i$011*156)|0)|0) + (($j$010*36)|0)|0) + 8|0);
     __ZmiRK6b2Vec2S1_($5,$165,$cB);
     $177 = $5;
     $178 = $177;
     $179 = HEAP32[$178>>2]|0;
     $180 = (($177) + 4)|0;
     $181 = $180;
     $182 = HEAP32[$181>>2]|0;
     $183 = $176;
     $184 = $183;
     HEAP32[$184>>2] = $179;
     $185 = (($183) + 4)|0;
     $186 = $185;
     HEAP32[$186>>2] = $182;
     $187 = (+__Z7b2CrossRK6b2Vec2S1_($164,$148));
     $188 = (+__Z7b2CrossRK6b2Vec2S1_($176,$148));
     $189 = $43 * $187;
     $190 = $187 * $189;
     $191 = $162 + $190;
     $192 = $45 * $188;
     $193 = $188 * $192;
     $194 = $191 + $193;
     $195 = $194 > 0.0;
     if ($195) {
      $196 = 1.0 / $194;
      $198 = $196;
     } else {
      $198 = 0.0;
     }
     $197 = (((($22) + (($i$011*156)|0)|0) + (($j$010*36)|0)|0) + 24|0);
     HEAPF32[$197>>2] = $198;
     __Z7b2CrossRK6b2Vec2f($tangent,$148,1.0);
     $199 = (+__Z7b2CrossRK6b2Vec2S1_($164,$tangent));
     $200 = (+__Z7b2CrossRK6b2Vec2S1_($176,$tangent));
     $201 = $43 * $199;
     $202 = $199 * $201;
     $203 = $162 + $202;
     $204 = $45 * $200;
     $205 = $200 * $204;
     $206 = $203 + $205;
     $207 = $206 > 0.0;
     if ($207) {
      $208 = 1.0 / $206;
      $210 = $208;
     } else {
      $210 = 0.0;
     }
     $209 = (((($22) + (($i$011*156)|0)|0) + (($j$010*36)|0)|0) + 28|0);
     HEAPF32[$209>>2] = $210;
     $211 = (((($22) + (($i$011*156)|0)|0) + (($j$010*36)|0)|0) + 32|0);
     HEAPF32[$211>>2] = 0.0;
     __Z7b2CrossfRK6b2Vec2($9,$127,$176);
     __ZplRK6b2Vec2S1_($8,$vB,$9);
     __ZmiRK6b2Vec2S1_($7,$8,$vA);
     __Z7b2CrossfRK6b2Vec2($10,$97,$164);
     __ZmiRK6b2Vec2S1_($6,$7,$10);
     $212 = (+__Z5b2DotRK6b2Vec2S1_($148,$6));
     $213 = $212 < -1.0;
     if ($213) {
      $214 = +HEAPF32[$163>>2];
      $215 = $212 * $214;
      $216 = -$215;
      HEAPF32[$211>>2] = $216;
     }
     $217 = (($j$010) + 1)|0;
     $exitcond = ($217|0)==($160|0);
     if ($exitcond) {
      break;
     } else {
      $j$010 = $217;
     }
    }
    $$pr = HEAP32[$159>>2]|0;
    $218 = ($$pr|0)==(2);
    if ($218) {
     $219 = (($22) + (($i$011*156)|0)|0);
     $220 = (+__Z7b2CrossRK6b2Vec2S1_($219,$148));
     $221 = ((($22) + (($i$011*156)|0)|0) + 8|0);
     $222 = (+__Z7b2CrossRK6b2Vec2S1_($221,$148));
     $223 = ((($22) + (($i$011*156)|0)|0) + 36|0);
     $224 = (+__Z7b2CrossRK6b2Vec2S1_($223,$148));
     $225 = ((($22) + (($i$011*156)|0)|0) + 44|0);
     $226 = (+__Z7b2CrossRK6b2Vec2S1_($225,$148));
     $227 = $39 + $41;
     $228 = $43 * $220;
     $229 = $220 * $228;
     $230 = $227 + $229;
     $231 = $45 * $222;
     $232 = $222 * $231;
     $233 = $230 + $232;
     $234 = $43 * $224;
     $235 = $224 * $234;
     $236 = $227 + $235;
     $237 = $45 * $226;
     $238 = $226 * $237;
     $239 = $236 + $238;
     $240 = $228 * $224;
     $241 = $227 + $240;
     $242 = $231 * $226;
     $243 = $241 + $242;
     $244 = $233 * $233;
     $245 = $233 * $239;
     $246 = $243 * $243;
     $247 = $245 - $246;
     $248 = $247 * 1000.0;
     $249 = $244 < $248;
     if ($249) {
      $250 = ((($22) + (($i$011*156)|0)|0) + 96|0);
      __ZN6b2Vec23SetEff($250,$233,$243);
      $251 = ((($22) + (($i$011*156)|0)|0) + 104|0);
      __ZN6b2Vec23SetEff($251,$243,$239);
      $252 = ((($22) + (($i$011*156)|0)|0) + 80|0);
      __ZNK7b2Mat2210GetInverseEv($11,$250);
      ;HEAP32[$252+0>>2]=HEAP32[$11+0>>2]|0;HEAP32[$252+4>>2]=HEAP32[$11+4>>2]|0;HEAP32[$252+8>>2]=HEAP32[$11+8>>2]|0;HEAP32[$252+12>>2]=HEAP32[$11+12>>2]|0;
      break;
     } else {
      HEAP32[$159>>2] = 1;
      break;
     }
    }
   }
  } while(0);
  $253 = (($i$011) + 1)|0;
  $254 = HEAP32[$12>>2]|0;
  $255 = ($253|0)<($254|0);
  if ($255) {
   $i$011 = $253;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN15b2ContactSolver9WarmStartEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0;
 var $19 = 0.0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0.0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0;
 var $73 = 0, $74 = 0.0, $75 = 0.0, $76 = 0.0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $P = 0, $exitcond = 0, $i$07 = 0, $j$05 = 0, $normal = 0, $tangent = 0, $vA = 0, $vB = 0, $wA$0$lcssa = 0.0, $wA$03 = 0.0, $wB$0$lcssa = 0.0;
 var $wB$04 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $vA = sp + 16|0;
 $vB = sp + 8|0;
 $normal = sp;
 $tangent = sp + 64|0;
 $P = sp + 56|0;
 $0 = sp + 48|0;
 $1 = sp + 40|0;
 $2 = sp + 32|0;
 $3 = sp + 24|0;
 $4 = (($this) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)>(0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 44|0);
 $8 = (($this) + 32|0);
 $i$07 = 0;
 while(1) {
  $9 = HEAP32[$7>>2]|0;
  $10 = ((($9) + (($i$07*156)|0)|0) + 112|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($9) + (($i$07*156)|0)|0) + 116|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ((($9) + (($i$07*156)|0)|0) + 120|0);
  $15 = +HEAPF32[$14>>2];
  $16 = ((($9) + (($i$07*156)|0)|0) + 128|0);
  $17 = +HEAPF32[$16>>2];
  $18 = ((($9) + (($i$07*156)|0)|0) + 124|0);
  $19 = +HEAPF32[$18>>2];
  $20 = ((($9) + (($i$07*156)|0)|0) + 132|0);
  $21 = +HEAPF32[$20>>2];
  $22 = ((($9) + (($i$07*156)|0)|0) + 148|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = HEAP32[$8>>2]|0;
  $25 = (($24) + (($11*12)|0)|0);
  $26 = $25;
  $27 = $26;
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + 4)|0;
  $30 = $29;
  $31 = HEAP32[$30>>2]|0;
  $32 = $vA;
  $33 = $32;
  HEAP32[$33>>2] = $28;
  $34 = (($32) + 4)|0;
  $35 = $34;
  HEAP32[$35>>2] = $31;
  $36 = HEAP32[$8>>2]|0;
  $37 = ((($36) + (($11*12)|0)|0) + 8|0);
  $38 = +HEAPF32[$37>>2];
  $39 = (($36) + (($13*12)|0)|0);
  $40 = $39;
  $41 = $40;
  $42 = HEAP32[$41>>2]|0;
  $43 = (($40) + 4)|0;
  $44 = $43;
  $45 = HEAP32[$44>>2]|0;
  $46 = $vB;
  $47 = $46;
  HEAP32[$47>>2] = $42;
  $48 = (($46) + 4)|0;
  $49 = $48;
  HEAP32[$49>>2] = $45;
  $50 = HEAP32[$8>>2]|0;
  $51 = ((($50) + (($13*12)|0)|0) + 8|0);
  $52 = +HEAPF32[$51>>2];
  $53 = ((($9) + (($i$07*156)|0)|0) + 72|0);
  $54 = $53;
  $55 = $54;
  $56 = HEAP32[$55>>2]|0;
  $57 = (($54) + 4)|0;
  $58 = $57;
  $59 = HEAP32[$58>>2]|0;
  $60 = $normal;
  $61 = $60;
  HEAP32[$61>>2] = $56;
  $62 = (($60) + 4)|0;
  $63 = $62;
  HEAP32[$63>>2] = $59;
  __Z7b2CrossRK6b2Vec2f($tangent,$normal,1.0);
  $64 = ($23|0)>(0);
  if ($64) {
   $j$05 = 0;$wA$03 = $38;$wB$04 = $52;
   while(1) {
    $65 = (((($9) + (($i$07*156)|0)|0) + (($j$05*36)|0)|0) + 16|0);
    $66 = +HEAPF32[$65>>2];
    __ZmlfRK6b2Vec2($0,$66,$normal);
    $67 = (((($9) + (($i$07*156)|0)|0) + (($j$05*36)|0)|0) + 20|0);
    $68 = +HEAPF32[$67>>2];
    __ZmlfRK6b2Vec2($1,$68,$tangent);
    __ZplRK6b2Vec2S1_($P,$0,$1);
    $69 = ((($9) + (($i$07*156)|0)|0) + (($j$05*36)|0)|0);
    $70 = (+__Z7b2CrossRK6b2Vec2S1_($69,$P));
    $71 = $17 * $70;
    $72 = $wA$03 - $71;
    __ZmlfRK6b2Vec2($2,$15,$P);
    __ZN6b2Vec2mIERKS_($vA,$2);
    $73 = (((($9) + (($i$07*156)|0)|0) + (($j$05*36)|0)|0) + 8|0);
    $74 = (+__Z7b2CrossRK6b2Vec2S1_($73,$P));
    $75 = $21 * $74;
    $76 = $wB$04 + $75;
    __ZmlfRK6b2Vec2($3,$19,$P);
    __ZN6b2Vec2pLERKS_($vB,$3);
    $77 = (($j$05) + 1)|0;
    $exitcond = ($77|0)==($23|0);
    if ($exitcond) {
     $wA$0$lcssa = $72;$wB$0$lcssa = $76;
     break;
    } else {
     $j$05 = $77;$wA$03 = $72;$wB$04 = $76;
    }
   }
  } else {
   $wA$0$lcssa = $38;$wB$0$lcssa = $52;
  }
  $78 = HEAP32[$8>>2]|0;
  $79 = (($78) + (($11*12)|0)|0);
  $80 = $vA;
  $81 = $80;
  $82 = HEAP32[$81>>2]|0;
  $83 = (($80) + 4)|0;
  $84 = $83;
  $85 = HEAP32[$84>>2]|0;
  $86 = $79;
  $87 = $86;
  HEAP32[$87>>2] = $82;
  $88 = (($86) + 4)|0;
  $89 = $88;
  HEAP32[$89>>2] = $85;
  $90 = HEAP32[$8>>2]|0;
  $91 = ((($90) + (($11*12)|0)|0) + 8|0);
  HEAPF32[$91>>2] = $wA$0$lcssa;
  $92 = HEAP32[$8>>2]|0;
  $93 = (($92) + (($13*12)|0)|0);
  $94 = $vB;
  $95 = $94;
  $96 = HEAP32[$95>>2]|0;
  $97 = (($94) + 4)|0;
  $98 = $97;
  $99 = HEAP32[$98>>2]|0;
  $100 = $93;
  $101 = $100;
  HEAP32[$101>>2] = $96;
  $102 = (($100) + 4)|0;
  $103 = $102;
  HEAP32[$103>>2] = $99;
  $104 = HEAP32[$8>>2]|0;
  $105 = ((($104) + (($13*12)|0)|0) + 8|0);
  HEAPF32[$105>>2] = $wB$0$lcssa;
  $106 = (($i$07) + 1)|0;
  $107 = HEAP32[$4>>2]|0;
  $108 = ($106|0)<($107|0);
  if ($108) {
   $i$07 = $106;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN15b2ContactSolver24SolveVelocityConstraintsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0.0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0;
 var $116 = 0.0, $117 = 0.0, $118 = 0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0.0, $138 = 0, $139 = 0.0, $14 = 0, $140 = 0, $141 = 0.0, $142 = 0.0, $143 = 0.0, $144 = 0, $145 = 0.0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0.0, $15 = 0, $150 = 0.0, $151 = 0.0;
 var $152 = 0.0, $153 = 0.0, $154 = 0.0, $155 = 0, $156 = 0.0, $157 = 0, $158 = 0.0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0.0, $163 = 0.0, $164 = 0, $165 = 0.0, $166 = 0.0, $167 = 0, $168 = 0.0, $169 = 0.0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0.0, $173 = 0, $174 = 0.0, $175 = 0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0, $180 = 0.0, $181 = 0.0, $182 = 0.0, $183 = 0.0, $184 = 0.0, $185 = 0.0, $186 = 0.0, $187 = 0.0, $188 = 0.0;
 var $189 = 0.0, $19 = 0, $190 = 0, $191 = 0.0, $192 = 0.0, $193 = 0.0, $194 = 0.0, $195 = 0, $196 = 0.0, $197 = 0.0, $198 = 0.0, $199 = 0.0, $2 = 0, $20 = 0, $200 = 0.0, $201 = 0, $202 = 0, $203 = 0.0, $204 = 0.0, $205 = 0.0;
 var $206 = 0.0, $207 = 0.0, $208 = 0.0, $209 = 0.0, $21 = 0, $210 = 0.0, $211 = 0.0, $212 = 0.0, $213 = 0.0, $214 = 0.0, $215 = 0.0, $216 = 0.0, $217 = 0, $218 = 0.0, $219 = 0.0, $22 = 0, $220 = 0.0, $221 = 0.0, $222 = 0, $223 = 0.0;
 var $224 = 0.0, $225 = 0.0, $226 = 0.0, $227 = 0, $228 = 0, $229 = 0.0, $23 = 0, $230 = 0.0, $231 = 0.0, $232 = 0.0, $233 = 0.0, $234 = 0.0, $235 = 0.0, $236 = 0.0, $237 = 0.0, $238 = 0.0, $239 = 0.0, $24 = 0, $240 = 0.0, $241 = 0.0;
 var $242 = 0.0, $243 = 0.0, $244 = 0.0, $245 = 0, $246 = 0, $247 = 0.0, $248 = 0.0, $249 = 0.0, $25 = 0, $250 = 0.0, $251 = 0.0, $252 = 0.0, $253 = 0.0, $254 = 0.0, $255 = 0.0, $256 = 0.0, $257 = 0.0, $258 = 0.0, $259 = 0.0, $26 = 0;
 var $260 = 0.0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0, $63 = 0.0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0.0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0.0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $P = 0, $P1 = 0, $P111 = 0, $P114 = 0, $P18 = 0, $P2 = 0, $P212 = 0, $P215 = 0;
 var $P29 = 0, $P5 = 0, $a = 0, $b = 0, $d = 0, $d10 = 0, $d13 = 0, $d7 = 0, $dv = 0, $dv1 = 0, $dv2 = 0, $dv26 = 0, $exitcond = 0, $i$012 = 0, $j$08 = 0, $normal = 0, $or$cond = 0, $or$cond20 = 0, $or$cond3 = 0, $or$cond5 = 0;
 var $tangent = 0, $vA = 0, $vB = 0, $wA$0$lcssa = 0.0, $wA$010 = 0.0, $wA$1 = 0.0, $wB$0$lcssa = 0.0, $wB$09 = 0.0, $wB$1 = 0.0, $x = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0;
 $vA = sp + 16|0;
 $vB = sp + 8|0;
 $normal = sp;
 $tangent = sp + 496|0;
 $dv = sp + 488|0;
 $0 = sp + 480|0;
 $1 = sp + 472|0;
 $2 = sp + 464|0;
 $3 = sp + 456|0;
 $P = sp + 448|0;
 $4 = sp + 440|0;
 $5 = sp + 432|0;
 $dv2 = sp + 424|0;
 $6 = sp + 416|0;
 $7 = sp + 408|0;
 $8 = sp + 400|0;
 $9 = sp + 392|0;
 $P5 = sp + 384|0;
 $10 = sp + 376|0;
 $11 = sp + 368|0;
 $a = sp + 360|0;
 $dv1 = sp + 352|0;
 $12 = sp + 344|0;
 $13 = sp + 336|0;
 $14 = sp + 328|0;
 $15 = sp + 320|0;
 $dv26 = sp + 312|0;
 $16 = sp + 304|0;
 $17 = sp + 296|0;
 $18 = sp + 288|0;
 $19 = sp + 280|0;
 $b = sp + 272|0;
 $20 = sp + 264|0;
 $x = sp + 256|0;
 $21 = sp + 248|0;
 $d = sp + 240|0;
 $P1 = sp + 232|0;
 $P2 = sp + 224|0;
 $22 = sp + 216|0;
 $23 = sp + 208|0;
 $24 = sp + 200|0;
 $25 = sp + 192|0;
 $d7 = sp + 184|0;
 $P18 = sp + 176|0;
 $P29 = sp + 168|0;
 $26 = sp + 160|0;
 $27 = sp + 152|0;
 $28 = sp + 144|0;
 $29 = sp + 136|0;
 $d10 = sp + 128|0;
 $P111 = sp + 120|0;
 $P212 = sp + 112|0;
 $30 = sp + 104|0;
 $31 = sp + 96|0;
 $32 = sp + 88|0;
 $33 = sp + 80|0;
 $d13 = sp + 72|0;
 $P114 = sp + 64|0;
 $P215 = sp + 56|0;
 $34 = sp + 48|0;
 $35 = sp + 40|0;
 $36 = sp + 32|0;
 $37 = sp + 24|0;
 $38 = (($this) + 52|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)>(0);
 if (!($40)) {
  STACKTOP = sp;return;
 }
 $41 = (($this) + 44|0);
 $42 = (($this) + 32|0);
 $43 = (($b) + 4|0);
 $44 = (($x) + 4|0);
 $45 = (($d7) + 4|0);
 $46 = (($d10) + 4|0);
 $47 = (($d13) + 4|0);
 $48 = (($x) + 4|0);
 $49 = (($d) + 4|0);
 $i$012 = 0;
 while(1) {
  $50 = HEAP32[$41>>2]|0;
  $51 = (($50) + (($i$012*156)|0)|0);
  $52 = ((($50) + (($i$012*156)|0)|0) + 112|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ((($50) + (($i$012*156)|0)|0) + 116|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ((($50) + (($i$012*156)|0)|0) + 120|0);
  $57 = +HEAPF32[$56>>2];
  $58 = ((($50) + (($i$012*156)|0)|0) + 128|0);
  $59 = +HEAPF32[$58>>2];
  $60 = ((($50) + (($i$012*156)|0)|0) + 124|0);
  $61 = +HEAPF32[$60>>2];
  $62 = ((($50) + (($i$012*156)|0)|0) + 132|0);
  $63 = +HEAPF32[$62>>2];
  $64 = ((($50) + (($i$012*156)|0)|0) + 148|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = HEAP32[$42>>2]|0;
  $67 = (($66) + (($53*12)|0)|0);
  $68 = $67;
  $69 = $68;
  $70 = HEAP32[$69>>2]|0;
  $71 = (($68) + 4)|0;
  $72 = $71;
  $73 = HEAP32[$72>>2]|0;
  $74 = $vA;
  $75 = $74;
  HEAP32[$75>>2] = $70;
  $76 = (($74) + 4)|0;
  $77 = $76;
  HEAP32[$77>>2] = $73;
  $78 = HEAP32[$42>>2]|0;
  $79 = ((($78) + (($53*12)|0)|0) + 8|0);
  $80 = +HEAPF32[$79>>2];
  $81 = (($78) + (($55*12)|0)|0);
  $82 = $81;
  $83 = $82;
  $84 = HEAP32[$83>>2]|0;
  $85 = (($82) + 4)|0;
  $86 = $85;
  $87 = HEAP32[$86>>2]|0;
  $88 = $vB;
  $89 = $88;
  HEAP32[$89>>2] = $84;
  $90 = (($88) + 4)|0;
  $91 = $90;
  HEAP32[$91>>2] = $87;
  $92 = HEAP32[$42>>2]|0;
  $93 = ((($92) + (($55*12)|0)|0) + 8|0);
  $94 = +HEAPF32[$93>>2];
  $95 = ((($50) + (($i$012*156)|0)|0) + 72|0);
  $96 = $95;
  $97 = $96;
  $98 = HEAP32[$97>>2]|0;
  $99 = (($96) + 4)|0;
  $100 = $99;
  $101 = HEAP32[$100>>2]|0;
  $102 = $normal;
  $103 = $102;
  HEAP32[$103>>2] = $98;
  $104 = (($102) + 4)|0;
  $105 = $104;
  HEAP32[$105>>2] = $101;
  __Z7b2CrossRK6b2Vec2f($tangent,$normal,1.0);
  $106 = ((($50) + (($i$012*156)|0)|0) + 136|0);
  $107 = +HEAPF32[$106>>2];
  $108 = ($65|0)>(0);
  if ($108) {
   $109 = ((($50) + (($i$012*156)|0)|0) + 144|0);
   $j$08 = 0;$wA$010 = $80;$wB$09 = $94;
   while(1) {
    $110 = (((($50) + (($i$012*156)|0)|0) + (($j$08*36)|0)|0) + 8|0);
    __Z7b2CrossfRK6b2Vec2($2,$wB$09,$110);
    __ZplRK6b2Vec2S1_($1,$vB,$2);
    __ZmiRK6b2Vec2S1_($0,$1,$vA);
    $111 = ((($50) + (($i$012*156)|0)|0) + (($j$08*36)|0)|0);
    __Z7b2CrossfRK6b2Vec2($3,$wA$010,$111);
    __ZmiRK6b2Vec2S1_($dv,$0,$3);
    $112 = (+__Z5b2DotRK6b2Vec2S1_($dv,$tangent));
    $113 = +HEAPF32[$109>>2];
    $114 = $112 - $113;
    $115 = (((($50) + (($i$012*156)|0)|0) + (($j$08*36)|0)|0) + 28|0);
    $116 = +HEAPF32[$115>>2];
    $117 = $114 * $116;
    $118 = (((($50) + (($i$012*156)|0)|0) + (($j$08*36)|0)|0) + 16|0);
    $119 = +HEAPF32[$118>>2];
    $120 = $107 * $119;
    $121 = (((($50) + (($i$012*156)|0)|0) + (($j$08*36)|0)|0) + 20|0);
    $122 = +HEAPF32[$121>>2];
    $123 = $122 - $117;
    $124 = -$120;
    $125 = (+__Z7b2ClampIfET_S0_S0_S0_($123,$124,$120));
    $126 = $125 - $122;
    HEAPF32[$121>>2] = $125;
    __ZmlfRK6b2Vec2($P,$126,$tangent);
    __ZmlfRK6b2Vec2($4,$57,$P);
    __ZN6b2Vec2mIERKS_($vA,$4);
    $127 = (+__Z7b2CrossRK6b2Vec2S1_($111,$P));
    $128 = $59 * $127;
    $129 = $wA$010 - $128;
    __ZmlfRK6b2Vec2($5,$61,$P);
    __ZN6b2Vec2pLERKS_($vB,$5);
    $130 = (+__Z7b2CrossRK6b2Vec2S1_($110,$P));
    $131 = $63 * $130;
    $132 = $wB$09 + $131;
    $133 = (($j$08) + 1)|0;
    $exitcond = ($133|0)==($65|0);
    if ($exitcond) {
     $wA$0$lcssa = $129;$wB$0$lcssa = $132;
     break;
    } else {
     $j$08 = $133;$wA$010 = $129;$wB$09 = $132;
    }
   }
  } else {
   $wA$0$lcssa = $80;$wB$0$lcssa = $94;
  }
  $134 = HEAP32[$64>>2]|0;
  $135 = ($134|0)==(1);
  do {
   if ($135) {
    $136 = ((($50) + (($i$012*156)|0)|0) + 8|0);
    __Z7b2CrossfRK6b2Vec2($8,$wB$0$lcssa,$136);
    __ZplRK6b2Vec2S1_($7,$vB,$8);
    __ZmiRK6b2Vec2S1_($6,$7,$vA);
    __Z7b2CrossfRK6b2Vec2($9,$wA$0$lcssa,$51);
    __ZmiRK6b2Vec2S1_($dv2,$6,$9);
    $137 = (+__Z5b2DotRK6b2Vec2S1_($dv2,$normal));
    $138 = ((($50) + (($i$012*156)|0)|0) + 24|0);
    $139 = +HEAPF32[$138>>2];
    $140 = ((($50) + (($i$012*156)|0)|0) + 32|0);
    $141 = +HEAPF32[$140>>2];
    $142 = $137 - $141;
    $143 = $139 * $142;
    $144 = ((($50) + (($i$012*156)|0)|0) + 16|0);
    $145 = +HEAPF32[$144>>2];
    $146 = $145 - $143;
    $147 = (+__Z5b2MaxIfET_S0_S0_($146,0.0));
    $148 = $147 - $145;
    HEAPF32[$144>>2] = $147;
    __ZmlfRK6b2Vec2($P5,$148,$normal);
    __ZmlfRK6b2Vec2($10,$57,$P5);
    __ZN6b2Vec2mIERKS_($vA,$10);
    $149 = (+__Z7b2CrossRK6b2Vec2S1_($51,$P5));
    $150 = $59 * $149;
    $151 = $wA$0$lcssa - $150;
    __ZmlfRK6b2Vec2($11,$61,$P5);
    __ZN6b2Vec2pLERKS_($vB,$11);
    $152 = (+__Z7b2CrossRK6b2Vec2S1_($136,$P5));
    $153 = $63 * $152;
    $154 = $wB$0$lcssa + $153;
    $wA$1 = $151;$wB$1 = $154;
   } else {
    $155 = ((($50) + (($i$012*156)|0)|0) + 16|0);
    $156 = +HEAPF32[$155>>2];
    $157 = ((($50) + (($i$012*156)|0)|0) + 52|0);
    $158 = +HEAPF32[$157>>2];
    __ZN6b2Vec2C2Eff($a,$156,$158);
    $159 = ((($50) + (($i$012*156)|0)|0) + 8|0);
    __Z7b2CrossfRK6b2Vec2($14,$wB$0$lcssa,$159);
    __ZplRK6b2Vec2S1_($13,$vB,$14);
    __ZmiRK6b2Vec2S1_($12,$13,$vA);
    __Z7b2CrossfRK6b2Vec2($15,$wA$0$lcssa,$51);
    __ZmiRK6b2Vec2S1_($dv1,$12,$15);
    $160 = ((($50) + (($i$012*156)|0)|0) + 44|0);
    __Z7b2CrossfRK6b2Vec2($18,$wB$0$lcssa,$160);
    __ZplRK6b2Vec2S1_($17,$vB,$18);
    __ZmiRK6b2Vec2S1_($16,$17,$vA);
    $161 = ((($50) + (($i$012*156)|0)|0) + 36|0);
    __Z7b2CrossfRK6b2Vec2($19,$wA$0$lcssa,$161);
    __ZmiRK6b2Vec2S1_($dv26,$16,$19);
    $162 = (+__Z5b2DotRK6b2Vec2S1_($dv1,$normal));
    $163 = (+__Z5b2DotRK6b2Vec2S1_($dv26,$normal));
    $164 = ((($50) + (($i$012*156)|0)|0) + 32|0);
    $165 = +HEAPF32[$164>>2];
    $166 = $162 - $165;
    HEAPF32[$b>>2] = $166;
    $167 = ((($50) + (($i$012*156)|0)|0) + 68|0);
    $168 = +HEAPF32[$167>>2];
    $169 = $163 - $168;
    HEAPF32[$43>>2] = $169;
    $170 = ((($50) + (($i$012*156)|0)|0) + 96|0);
    __Z5b2MulRK7b2Mat22RK6b2Vec2($20,$170,$a);
    __ZN6b2Vec2mIERKS_($b,$20);
    $171 = ((($50) + (($i$012*156)|0)|0) + 80|0);
    __Z5b2MulRK7b2Mat22RK6b2Vec2($21,$171,$b);
    __ZNK6b2Vec2ngEv($x,$21);
    $172 = +HEAPF32[$x>>2];
    $173 = !($172 >= 0.0);
    $174 = +HEAPF32[$48>>2];
    $175 = !($174 >= 0.0);
    $or$cond20 = $173 | $175;
    if (!($or$cond20)) {
     __ZmiRK6b2Vec2S1_($d,$x,$a);
     $176 = +HEAPF32[$d>>2];
     __ZmlfRK6b2Vec2($P1,$176,$normal);
     $177 = +HEAPF32[$49>>2];
     __ZmlfRK6b2Vec2($P2,$177,$normal);
     __ZplRK6b2Vec2S1_($23,$P1,$P2);
     __ZmlfRK6b2Vec2($22,$57,$23);
     __ZN6b2Vec2mIERKS_($vA,$22);
     $178 = (+__Z7b2CrossRK6b2Vec2S1_($51,$P1));
     $179 = (+__Z7b2CrossRK6b2Vec2S1_($161,$P2));
     $180 = $178 + $179;
     $181 = $59 * $180;
     $182 = $wA$0$lcssa - $181;
     __ZplRK6b2Vec2S1_($25,$P1,$P2);
     __ZmlfRK6b2Vec2($24,$61,$25);
     __ZN6b2Vec2pLERKS_($vB,$24);
     $183 = (+__Z7b2CrossRK6b2Vec2S1_($159,$P1));
     $184 = (+__Z7b2CrossRK6b2Vec2S1_($160,$P2));
     $185 = $183 + $184;
     $186 = $63 * $185;
     $187 = $wB$0$lcssa + $186;
     $188 = +HEAPF32[$x>>2];
     HEAPF32[$155>>2] = $188;
     $189 = +HEAPF32[$48>>2];
     HEAPF32[$157>>2] = $189;
     $wA$1 = $182;$wB$1 = $187;
     break;
    }
    $190 = ((($50) + (($i$012*156)|0)|0) + 24|0);
    $191 = +HEAPF32[$190>>2];
    $192 = +HEAPF32[$b>>2];
    $193 = $191 * $192;
    $194 = -$193;
    HEAPF32[$x>>2] = $194;
    HEAPF32[$44>>2] = 0.0;
    $195 = ((($50) + (($i$012*156)|0)|0) + 100|0);
    $196 = +HEAPF32[$195>>2];
    $197 = +HEAPF32[$x>>2];
    $198 = $196 * $197;
    $199 = +HEAPF32[$43>>2];
    $200 = $198 + $199;
    $201 = $197 >= 0.0;
    $202 = $200 >= 0.0;
    $or$cond = $201 & $202;
    if ($or$cond) {
     __ZmiRK6b2Vec2S1_($d7,$x,$a);
     $203 = +HEAPF32[$d7>>2];
     __ZmlfRK6b2Vec2($P18,$203,$normal);
     $204 = +HEAPF32[$45>>2];
     __ZmlfRK6b2Vec2($P29,$204,$normal);
     __ZplRK6b2Vec2S1_($27,$P18,$P29);
     __ZmlfRK6b2Vec2($26,$57,$27);
     __ZN6b2Vec2mIERKS_($vA,$26);
     $205 = (+__Z7b2CrossRK6b2Vec2S1_($51,$P18));
     $206 = (+__Z7b2CrossRK6b2Vec2S1_($161,$P29));
     $207 = $205 + $206;
     $208 = $59 * $207;
     $209 = $wA$0$lcssa - $208;
     __ZplRK6b2Vec2S1_($29,$P18,$P29);
     __ZmlfRK6b2Vec2($28,$61,$29);
     __ZN6b2Vec2pLERKS_($vB,$28);
     $210 = (+__Z7b2CrossRK6b2Vec2S1_($159,$P18));
     $211 = (+__Z7b2CrossRK6b2Vec2S1_($160,$P29));
     $212 = $210 + $211;
     $213 = $63 * $212;
     $214 = $wB$0$lcssa + $213;
     $215 = +HEAPF32[$x>>2];
     HEAPF32[$155>>2] = $215;
     $216 = +HEAPF32[$44>>2];
     HEAPF32[$157>>2] = $216;
     $wA$1 = $209;$wB$1 = $214;
     break;
    }
    HEAPF32[$x>>2] = 0.0;
    $217 = ((($50) + (($i$012*156)|0)|0) + 60|0);
    $218 = +HEAPF32[$217>>2];
    $219 = +HEAPF32[$43>>2];
    $220 = $218 * $219;
    $221 = -$220;
    HEAPF32[$44>>2] = $221;
    $222 = ((($50) + (($i$012*156)|0)|0) + 104|0);
    $223 = +HEAPF32[$222>>2];
    $224 = $223 * $221;
    $225 = +HEAPF32[$b>>2];
    $226 = $225 + $224;
    $227 = $220 <= -0.0;
    $228 = $226 >= 0.0;
    $or$cond3 = $227 & $228;
    if ($or$cond3) {
     __ZmiRK6b2Vec2S1_($d10,$x,$a);
     $229 = +HEAPF32[$d10>>2];
     __ZmlfRK6b2Vec2($P111,$229,$normal);
     $230 = +HEAPF32[$46>>2];
     __ZmlfRK6b2Vec2($P212,$230,$normal);
     __ZplRK6b2Vec2S1_($31,$P111,$P212);
     __ZmlfRK6b2Vec2($30,$57,$31);
     __ZN6b2Vec2mIERKS_($vA,$30);
     $231 = (+__Z7b2CrossRK6b2Vec2S1_($51,$P111));
     $232 = (+__Z7b2CrossRK6b2Vec2S1_($161,$P212));
     $233 = $231 + $232;
     $234 = $59 * $233;
     $235 = $wA$0$lcssa - $234;
     __ZplRK6b2Vec2S1_($33,$P111,$P212);
     __ZmlfRK6b2Vec2($32,$61,$33);
     __ZN6b2Vec2pLERKS_($vB,$32);
     $236 = (+__Z7b2CrossRK6b2Vec2S1_($159,$P111));
     $237 = (+__Z7b2CrossRK6b2Vec2S1_($160,$P212));
     $238 = $236 + $237;
     $239 = $63 * $238;
     $240 = $wB$0$lcssa + $239;
     $241 = +HEAPF32[$x>>2];
     HEAPF32[$155>>2] = $241;
     $242 = +HEAPF32[$44>>2];
     HEAPF32[$157>>2] = $242;
     $wA$1 = $235;$wB$1 = $240;
     break;
    }
    HEAPF32[$x>>2] = 0.0;
    HEAPF32[$44>>2] = 0.0;
    $243 = +HEAPF32[$b>>2];
    $244 = +HEAPF32[$43>>2];
    $245 = $243 >= 0.0;
    $246 = $244 >= 0.0;
    $or$cond5 = $245 & $246;
    if ($or$cond5) {
     __ZmiRK6b2Vec2S1_($d13,$x,$a);
     $247 = +HEAPF32[$d13>>2];
     __ZmlfRK6b2Vec2($P114,$247,$normal);
     $248 = +HEAPF32[$47>>2];
     __ZmlfRK6b2Vec2($P215,$248,$normal);
     __ZplRK6b2Vec2S1_($35,$P114,$P215);
     __ZmlfRK6b2Vec2($34,$57,$35);
     __ZN6b2Vec2mIERKS_($vA,$34);
     $249 = (+__Z7b2CrossRK6b2Vec2S1_($51,$P114));
     $250 = (+__Z7b2CrossRK6b2Vec2S1_($161,$P215));
     $251 = $249 + $250;
     $252 = $59 * $251;
     $253 = $wA$0$lcssa - $252;
     __ZplRK6b2Vec2S1_($37,$P114,$P215);
     __ZmlfRK6b2Vec2($36,$61,$37);
     __ZN6b2Vec2pLERKS_($vB,$36);
     $254 = (+__Z7b2CrossRK6b2Vec2S1_($159,$P114));
     $255 = (+__Z7b2CrossRK6b2Vec2S1_($160,$P215));
     $256 = $254 + $255;
     $257 = $63 * $256;
     $258 = $wB$0$lcssa + $257;
     $259 = +HEAPF32[$x>>2];
     HEAPF32[$155>>2] = $259;
     $260 = +HEAPF32[$44>>2];
     HEAPF32[$157>>2] = $260;
     $wA$1 = $253;$wB$1 = $258;
    } else {
     $wA$1 = $wA$0$lcssa;$wB$1 = $wB$0$lcssa;
    }
   }
  } while(0);
  $261 = HEAP32[$42>>2]|0;
  $262 = (($261) + (($53*12)|0)|0);
  $263 = $vA;
  $264 = $263;
  $265 = HEAP32[$264>>2]|0;
  $266 = (($263) + 4)|0;
  $267 = $266;
  $268 = HEAP32[$267>>2]|0;
  $269 = $262;
  $270 = $269;
  HEAP32[$270>>2] = $265;
  $271 = (($269) + 4)|0;
  $272 = $271;
  HEAP32[$272>>2] = $268;
  $273 = HEAP32[$42>>2]|0;
  $274 = ((($273) + (($53*12)|0)|0) + 8|0);
  HEAPF32[$274>>2] = $wA$1;
  $275 = HEAP32[$42>>2]|0;
  $276 = (($275) + (($55*12)|0)|0);
  $277 = $vB;
  $278 = $277;
  $279 = HEAP32[$278>>2]|0;
  $280 = (($277) + 4)|0;
  $281 = $280;
  $282 = HEAP32[$281>>2]|0;
  $283 = $276;
  $284 = $283;
  HEAP32[$284>>2] = $279;
  $285 = (($283) + 4)|0;
  $286 = $285;
  HEAP32[$286>>2] = $282;
  $287 = HEAP32[$42>>2]|0;
  $288 = ((($287) + (($55*12)|0)|0) + 8|0);
  HEAPF32[$288>>2] = $wB$1;
  $289 = (($i$012) + 1)|0;
  $290 = HEAP32[$38>>2]|0;
  $291 = ($289|0)<($290|0);
  if ($291) {
   $i$012 = $289;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN15b2ContactSolver13StoreImpulsesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $j$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 48|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$0>>2]|0;
 $i$02 = 0;
 while(1) {
  $8 = ((($4) + (($i$02*156)|0)|0) + 152|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (($6) + ($9<<2)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = (__ZN9b2Contact11GetManifoldEv($11)|0);
  $13 = ((($4) + (($i$02*156)|0)|0) + 148|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)>(0);
  if ($15) {
   $16 = HEAP32[$13>>2]|0;
   $j$01 = 0;
   while(1) {
    $17 = (((($4) + (($i$02*156)|0)|0) + (($j$01*36)|0)|0) + 16|0);
    $18 = +HEAPF32[$17>>2];
    $19 = ((($12) + (($j$01*20)|0)|0) + 8|0);
    HEAPF32[$19>>2] = $18;
    $20 = (((($4) + (($i$02*156)|0)|0) + (($j$01*36)|0)|0) + 20|0);
    $21 = +HEAPF32[$20>>2];
    $22 = ((($12) + (($j$01*20)|0)|0) + 12|0);
    HEAPF32[$22>>2] = $21;
    $23 = (($j$01) + 1)|0;
    $24 = ($23|0)<($16|0);
    if ($24) {
     $j$01 = $23;
    } else {
     break;
    }
   }
  }
  $25 = (($i$02) + 1)|0;
  $26 = ($25|0)<($7|0);
  if ($26) {
   $i$02 = $25;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN15b2ContactSolver24SolvePositionConstraintsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0, $113 = 0.0, $114 = 0.0, $115 = 0.0;
 var $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0.0;
 var $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0.0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0, $81 = 0.0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $P = 0, $aA$0$lcssa = 0.0;
 var $aA$010 = 0.0, $aB$0$lcssa = 0.0, $aB$09 = 0.0, $cA = 0, $cB = 0, $exitcond = 0, $i$014 = 0, $j$08 = 0, $localCenterA = 0, $localCenterB = 0, $minSeparation$0$lcssa = 0.0, $minSeparation$015 = 0.0, $minSeparation$1$lcssa = 0.0, $minSeparation$111 = 0.0, $normal = 0, $point = 0, $psm = 0, $rA = 0, $rB = 0, $xfA = 0;
 var $xfB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $localCenterA = sp + 96|0;
 $localCenterB = sp + 88|0;
 $cA = sp + 80|0;
 $cB = sp + 72|0;
 $xfA = sp + 56|0;
 $xfB = sp + 40|0;
 $0 = sp + 152|0;
 $1 = sp + 144|0;
 $psm = sp + 16|0;
 $normal = sp + 8|0;
 $point = sp;
 $rA = sp + 136|0;
 $rB = sp + 128|0;
 $P = sp + 120|0;
 $2 = sp + 112|0;
 $3 = sp + 104|0;
 $4 = (($this) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)>(0);
 if (!($6)) {
  $minSeparation$0$lcssa = 0.0;
  $157 = $minSeparation$0$lcssa >= -0.014999999664723873;
  STACKTOP = sp;return ($157|0);
 }
 $7 = (($this) + 40|0);
 $8 = (($this) + 28|0);
 $9 = (($xfA) + 8|0);
 $10 = (($xfB) + 8|0);
 $11 = (($psm) + 8|0);
 $12 = (($psm) + 16|0);
 $i$014 = 0;$minSeparation$015 = 0.0;
 while(1) {
  $13 = HEAP32[$7>>2]|0;
  $14 = (($13) + (($i$014*88)|0)|0);
  $15 = ((($13) + (($i$014*88)|0)|0) + 32|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($13) + (($i$014*88)|0)|0) + 36|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ((($13) + (($i$014*88)|0)|0) + 48|0);
  $20 = $19;
  $21 = $20;
  $22 = HEAP32[$21>>2]|0;
  $23 = (($20) + 4)|0;
  $24 = $23;
  $25 = HEAP32[$24>>2]|0;
  $26 = $localCenterA;
  $27 = $26;
  HEAP32[$27>>2] = $22;
  $28 = (($26) + 4)|0;
  $29 = $28;
  HEAP32[$29>>2] = $25;
  $30 = ((($13) + (($i$014*88)|0)|0) + 40|0);
  $31 = +HEAPF32[$30>>2];
  $32 = ((($13) + (($i$014*88)|0)|0) + 64|0);
  $33 = +HEAPF32[$32>>2];
  $34 = ((($13) + (($i$014*88)|0)|0) + 56|0);
  $35 = $34;
  $36 = $35;
  $37 = HEAP32[$36>>2]|0;
  $38 = (($35) + 4)|0;
  $39 = $38;
  $40 = HEAP32[$39>>2]|0;
  $41 = $localCenterB;
  $42 = $41;
  HEAP32[$42>>2] = $37;
  $43 = (($41) + 4)|0;
  $44 = $43;
  HEAP32[$44>>2] = $40;
  $45 = ((($13) + (($i$014*88)|0)|0) + 44|0);
  $46 = +HEAPF32[$45>>2];
  $47 = ((($13) + (($i$014*88)|0)|0) + 68|0);
  $48 = +HEAPF32[$47>>2];
  $49 = ((($13) + (($i$014*88)|0)|0) + 84|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = HEAP32[$8>>2]|0;
  $52 = (($51) + (($16*12)|0)|0);
  $53 = $52;
  $54 = $53;
  $55 = HEAP32[$54>>2]|0;
  $56 = (($53) + 4)|0;
  $57 = $56;
  $58 = HEAP32[$57>>2]|0;
  $59 = $cA;
  $60 = $59;
  HEAP32[$60>>2] = $55;
  $61 = (($59) + 4)|0;
  $62 = $61;
  HEAP32[$62>>2] = $58;
  $63 = HEAP32[$8>>2]|0;
  $64 = ((($63) + (($16*12)|0)|0) + 8|0);
  $65 = +HEAPF32[$64>>2];
  $66 = (($63) + (($18*12)|0)|0);
  $67 = $66;
  $68 = $67;
  $69 = HEAP32[$68>>2]|0;
  $70 = (($67) + 4)|0;
  $71 = $70;
  $72 = HEAP32[$71>>2]|0;
  $73 = $cB;
  $74 = $73;
  HEAP32[$74>>2] = $69;
  $75 = (($73) + 4)|0;
  $76 = $75;
  HEAP32[$76>>2] = $72;
  $77 = HEAP32[$8>>2]|0;
  $78 = ((($77) + (($18*12)|0)|0) + 8|0);
  $79 = +HEAPF32[$78>>2];
  $80 = ($50|0)>(0);
  if ($80) {
   $81 = $31 + $46;
   $aA$010 = $65;$aB$09 = $79;$j$08 = 0;$minSeparation$111 = $minSeparation$015;
   while(1) {
    __ZN5b2Rot3SetEf($9,$aA$010);
    __ZN5b2Rot3SetEf($10,$aB$09);
    __Z5b2MulRK5b2RotRK6b2Vec2($0,$9,$localCenterA);
    __ZmiRK6b2Vec2S1_($xfA,$cA,$0);
    __Z5b2MulRK5b2RotRK6b2Vec2($1,$10,$localCenterB);
    __ZmiRK6b2Vec2S1_($xfB,$cB,$1);
    __ZN24b2PositionSolverManifold10InitializeEP27b2ContactPositionConstraintRK11b2TransformS4_i($psm,$14,$xfA,$xfB,$j$08);
    $82 = $psm;
    $83 = $82;
    $84 = HEAP32[$83>>2]|0;
    $85 = (($82) + 4)|0;
    $86 = $85;
    $87 = HEAP32[$86>>2]|0;
    $88 = $normal;
    $89 = $88;
    HEAP32[$89>>2] = $84;
    $90 = (($88) + 4)|0;
    $91 = $90;
    HEAP32[$91>>2] = $87;
    $92 = $11;
    $93 = $92;
    $94 = HEAP32[$93>>2]|0;
    $95 = (($92) + 4)|0;
    $96 = $95;
    $97 = HEAP32[$96>>2]|0;
    $98 = $point;
    $99 = $98;
    HEAP32[$99>>2] = $94;
    $100 = (($98) + 4)|0;
    $101 = $100;
    HEAP32[$101>>2] = $97;
    $102 = +HEAPF32[$12>>2];
    __ZmiRK6b2Vec2S1_($rA,$point,$cA);
    __ZmiRK6b2Vec2S1_($rB,$point,$cB);
    $103 = (+__Z5b2MinIfET_S0_S0_($minSeparation$111,$102));
    $104 = (+__Z7b2CrossRK6b2Vec2S1_($rA,$normal));
    $105 = (+__Z7b2CrossRK6b2Vec2S1_($rB,$normal));
    $106 = $33 * $104;
    $107 = $104 * $106;
    $108 = $81 + $107;
    $109 = $48 * $105;
    $110 = $105 * $109;
    $111 = $108 + $110;
    $112 = $111 > 0.0;
    if ($112) {
     $113 = $102 + 0.004999999888241291;
     $114 = $113 * 0.20000000298023224;
     $115 = (+__Z7b2ClampIfET_S0_S0_S0_($114,-0.20000000298023224,0.0));
     $116 = -$115;
     $117 = $116 / $111;
     $118 = $117;
    } else {
     $118 = 0.0;
    }
    __ZmlfRK6b2Vec2($P,$118,$normal);
    __ZmlfRK6b2Vec2($2,$31,$P);
    __ZN6b2Vec2mIERKS_($cA,$2);
    $119 = (+__Z7b2CrossRK6b2Vec2S1_($rA,$P));
    $120 = $33 * $119;
    $121 = $aA$010 - $120;
    __ZmlfRK6b2Vec2($3,$46,$P);
    __ZN6b2Vec2pLERKS_($cB,$3);
    $122 = (+__Z7b2CrossRK6b2Vec2S1_($rB,$P));
    $123 = $48 * $122;
    $124 = $aB$09 + $123;
    $125 = (($j$08) + 1)|0;
    $exitcond = ($125|0)==($50|0);
    if ($exitcond) {
     $aA$0$lcssa = $121;$aB$0$lcssa = $124;$minSeparation$1$lcssa = $103;
     break;
    } else {
     $aA$010 = $121;$aB$09 = $124;$j$08 = $125;$minSeparation$111 = $103;
    }
   }
  } else {
   $aA$0$lcssa = $65;$aB$0$lcssa = $79;$minSeparation$1$lcssa = $minSeparation$015;
  }
  $126 = HEAP32[$8>>2]|0;
  $127 = (($126) + (($16*12)|0)|0);
  $128 = $cA;
  $129 = $128;
  $130 = HEAP32[$129>>2]|0;
  $131 = (($128) + 4)|0;
  $132 = $131;
  $133 = HEAP32[$132>>2]|0;
  $134 = $127;
  $135 = $134;
  HEAP32[$135>>2] = $130;
  $136 = (($134) + 4)|0;
  $137 = $136;
  HEAP32[$137>>2] = $133;
  $138 = HEAP32[$8>>2]|0;
  $139 = ((($138) + (($16*12)|0)|0) + 8|0);
  HEAPF32[$139>>2] = $aA$0$lcssa;
  $140 = HEAP32[$8>>2]|0;
  $141 = (($140) + (($18*12)|0)|0);
  $142 = $cB;
  $143 = $142;
  $144 = HEAP32[$143>>2]|0;
  $145 = (($142) + 4)|0;
  $146 = $145;
  $147 = HEAP32[$146>>2]|0;
  $148 = $141;
  $149 = $148;
  HEAP32[$149>>2] = $144;
  $150 = (($148) + 4)|0;
  $151 = $150;
  HEAP32[$151>>2] = $147;
  $152 = HEAP32[$8>>2]|0;
  $153 = ((($152) + (($18*12)|0)|0) + 8|0);
  HEAPF32[$153>>2] = $aB$0$lcssa;
  $154 = (($i$014) + 1)|0;
  $155 = HEAP32[$4>>2]|0;
  $156 = ($154|0)<($155|0);
  if ($156) {
   $i$014 = $154;$minSeparation$015 = $minSeparation$1$lcssa;
  } else {
   $minSeparation$0$lcssa = $minSeparation$1$lcssa;
   break;
  }
 }
 $157 = $minSeparation$0$lcssa >= -0.014999999664723873;
 STACKTOP = sp;return ($157|0);
}
function __ZN15b2ContactSolver27SolveTOIPositionConstraintsEii($this,$toiIndexA,$toiIndexB) {
 $this = $this|0;
 $toiIndexA = $toiIndexA|0;
 $toiIndexB = $toiIndexB|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0;
 var $116 = 0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0.0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0.0, $128 = 0.0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0.0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0.0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0.0, $84 = 0, $85 = 0.0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $P = 0, $aA$0$lcssa = 0.0, $aA$09 = 0.0, $aB$0$lcssa = 0.0, $aB$010 = 0.0, $cA = 0, $cB = 0, $exitcond = 0, $i$015 = 0, $iA$0 = 0.0, $iB$0 = 0.0, $j$011 = 0, $localCenterA = 0, $localCenterB = 0, $mA$0 = 0.0, $mB$0 = 0.0, $minSeparation$0$lcssa = 0.0, $minSeparation$016 = 0.0;
 var $minSeparation$1$lcssa = 0.0, $minSeparation$112 = 0.0, $normal = 0, $or$cond = 0, $or$cond8 = 0, $point = 0, $psm = 0, $rA = 0, $rB = 0, $xfA = 0, $xfB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $localCenterA = sp + 96|0;
 $localCenterB = sp + 88|0;
 $cA = sp + 80|0;
 $cB = sp + 72|0;
 $xfA = sp + 56|0;
 $xfB = sp + 40|0;
 $0 = sp + 152|0;
 $1 = sp + 144|0;
 $psm = sp + 16|0;
 $normal = sp + 8|0;
 $point = sp;
 $rA = sp + 136|0;
 $rB = sp + 128|0;
 $P = sp + 120|0;
 $2 = sp + 112|0;
 $3 = sp + 104|0;
 $4 = (($this) + 52|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)>(0);
 if (!($6)) {
  $minSeparation$0$lcssa = 0.0;
  $161 = $minSeparation$0$lcssa >= -0.0074999998323619366;
  STACKTOP = sp;return ($161|0);
 }
 $7 = (($this) + 40|0);
 $8 = (($this) + 28|0);
 $9 = (($xfA) + 8|0);
 $10 = (($xfB) + 8|0);
 $11 = (($psm) + 8|0);
 $12 = (($psm) + 16|0);
 $i$015 = 0;$minSeparation$016 = 0.0;
 while(1) {
  $13 = HEAP32[$7>>2]|0;
  $14 = (($13) + (($i$015*88)|0)|0);
  $15 = ((($13) + (($i$015*88)|0)|0) + 32|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($13) + (($i$015*88)|0)|0) + 36|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ((($13) + (($i$015*88)|0)|0) + 48|0);
  $20 = $19;
  $21 = $20;
  $22 = HEAP32[$21>>2]|0;
  $23 = (($20) + 4)|0;
  $24 = $23;
  $25 = HEAP32[$24>>2]|0;
  $26 = $localCenterA;
  $27 = $26;
  HEAP32[$27>>2] = $22;
  $28 = (($26) + 4)|0;
  $29 = $28;
  HEAP32[$29>>2] = $25;
  $30 = ((($13) + (($i$015*88)|0)|0) + 56|0);
  $31 = $30;
  $32 = $31;
  $33 = HEAP32[$32>>2]|0;
  $34 = (($31) + 4)|0;
  $35 = $34;
  $36 = HEAP32[$35>>2]|0;
  $37 = $localCenterB;
  $38 = $37;
  HEAP32[$38>>2] = $33;
  $39 = (($37) + 4)|0;
  $40 = $39;
  HEAP32[$40>>2] = $36;
  $41 = ((($13) + (($i$015*88)|0)|0) + 84|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ($16|0)==($toiIndexA|0);
  $44 = ($16|0)==($toiIndexB|0);
  $or$cond = $43 | $44;
  if ($or$cond) {
   $45 = ((($13) + (($i$015*88)|0)|0) + 40|0);
   $46 = +HEAPF32[$45>>2];
   $47 = ((($13) + (($i$015*88)|0)|0) + 64|0);
   $48 = +HEAPF32[$47>>2];
   $iA$0 = $48;$mA$0 = $46;
  } else {
   $iA$0 = 0.0;$mA$0 = 0.0;
  }
  $49 = ($18|0)==($toiIndexA|0);
  $50 = ($18|0)==($toiIndexB|0);
  $or$cond8 = $49 | $50;
  if ($or$cond8) {
   $51 = ((($13) + (($i$015*88)|0)|0) + 44|0);
   $52 = +HEAPF32[$51>>2];
   $53 = ((($13) + (($i$015*88)|0)|0) + 68|0);
   $54 = +HEAPF32[$53>>2];
   $iB$0 = $54;$mB$0 = $52;
  } else {
   $iB$0 = 0.0;$mB$0 = 0.0;
  }
  $55 = HEAP32[$8>>2]|0;
  $56 = (($55) + (($16*12)|0)|0);
  $57 = $56;
  $58 = $57;
  $59 = HEAP32[$58>>2]|0;
  $60 = (($57) + 4)|0;
  $61 = $60;
  $62 = HEAP32[$61>>2]|0;
  $63 = $cA;
  $64 = $63;
  HEAP32[$64>>2] = $59;
  $65 = (($63) + 4)|0;
  $66 = $65;
  HEAP32[$66>>2] = $62;
  $67 = HEAP32[$8>>2]|0;
  $68 = ((($67) + (($16*12)|0)|0) + 8|0);
  $69 = +HEAPF32[$68>>2];
  $70 = (($67) + (($18*12)|0)|0);
  $71 = $70;
  $72 = $71;
  $73 = HEAP32[$72>>2]|0;
  $74 = (($71) + 4)|0;
  $75 = $74;
  $76 = HEAP32[$75>>2]|0;
  $77 = $cB;
  $78 = $77;
  HEAP32[$78>>2] = $73;
  $79 = (($77) + 4)|0;
  $80 = $79;
  HEAP32[$80>>2] = $76;
  $81 = HEAP32[$8>>2]|0;
  $82 = ((($81) + (($18*12)|0)|0) + 8|0);
  $83 = +HEAPF32[$82>>2];
  $84 = ($42|0)>(0);
  if ($84) {
   $85 = $mA$0 + $mB$0;
   $aA$09 = $69;$aB$010 = $83;$j$011 = 0;$minSeparation$112 = $minSeparation$016;
   while(1) {
    __ZN5b2Rot3SetEf($9,$aA$09);
    __ZN5b2Rot3SetEf($10,$aB$010);
    __Z5b2MulRK5b2RotRK6b2Vec2($0,$9,$localCenterA);
    __ZmiRK6b2Vec2S1_($xfA,$cA,$0);
    __Z5b2MulRK5b2RotRK6b2Vec2($1,$10,$localCenterB);
    __ZmiRK6b2Vec2S1_($xfB,$cB,$1);
    __ZN24b2PositionSolverManifold10InitializeEP27b2ContactPositionConstraintRK11b2TransformS4_i($psm,$14,$xfA,$xfB,$j$011);
    $86 = $psm;
    $87 = $86;
    $88 = HEAP32[$87>>2]|0;
    $89 = (($86) + 4)|0;
    $90 = $89;
    $91 = HEAP32[$90>>2]|0;
    $92 = $normal;
    $93 = $92;
    HEAP32[$93>>2] = $88;
    $94 = (($92) + 4)|0;
    $95 = $94;
    HEAP32[$95>>2] = $91;
    $96 = $11;
    $97 = $96;
    $98 = HEAP32[$97>>2]|0;
    $99 = (($96) + 4)|0;
    $100 = $99;
    $101 = HEAP32[$100>>2]|0;
    $102 = $point;
    $103 = $102;
    HEAP32[$103>>2] = $98;
    $104 = (($102) + 4)|0;
    $105 = $104;
    HEAP32[$105>>2] = $101;
    $106 = +HEAPF32[$12>>2];
    __ZmiRK6b2Vec2S1_($rA,$point,$cA);
    __ZmiRK6b2Vec2S1_($rB,$point,$cB);
    $107 = (+__Z5b2MinIfET_S0_S0_($minSeparation$112,$106));
    $108 = (+__Z7b2CrossRK6b2Vec2S1_($rA,$normal));
    $109 = (+__Z7b2CrossRK6b2Vec2S1_($rB,$normal));
    $110 = $iA$0 * $108;
    $111 = $108 * $110;
    $112 = $85 + $111;
    $113 = $iB$0 * $109;
    $114 = $109 * $113;
    $115 = $112 + $114;
    $116 = $115 > 0.0;
    if ($116) {
     $117 = $106 + 0.004999999888241291;
     $118 = $117 * 0.75;
     $119 = (+__Z7b2ClampIfET_S0_S0_S0_($118,-0.20000000298023224,0.0));
     $120 = -$119;
     $121 = $120 / $115;
     $122 = $121;
    } else {
     $122 = 0.0;
    }
    __ZmlfRK6b2Vec2($P,$122,$normal);
    __ZmlfRK6b2Vec2($2,$mA$0,$P);
    __ZN6b2Vec2mIERKS_($cA,$2);
    $123 = (+__Z7b2CrossRK6b2Vec2S1_($rA,$P));
    $124 = $iA$0 * $123;
    $125 = $aA$09 - $124;
    __ZmlfRK6b2Vec2($3,$mB$0,$P);
    __ZN6b2Vec2pLERKS_($cB,$3);
    $126 = (+__Z7b2CrossRK6b2Vec2S1_($rB,$P));
    $127 = $iB$0 * $126;
    $128 = $aB$010 + $127;
    $129 = (($j$011) + 1)|0;
    $exitcond = ($129|0)==($42|0);
    if ($exitcond) {
     $aA$0$lcssa = $125;$aB$0$lcssa = $128;$minSeparation$1$lcssa = $107;
     break;
    } else {
     $aA$09 = $125;$aB$010 = $128;$j$011 = $129;$minSeparation$112 = $107;
    }
   }
  } else {
   $aA$0$lcssa = $69;$aB$0$lcssa = $83;$minSeparation$1$lcssa = $minSeparation$016;
  }
  $130 = HEAP32[$8>>2]|0;
  $131 = (($130) + (($16*12)|0)|0);
  $132 = $cA;
  $133 = $132;
  $134 = HEAP32[$133>>2]|0;
  $135 = (($132) + 4)|0;
  $136 = $135;
  $137 = HEAP32[$136>>2]|0;
  $138 = $131;
  $139 = $138;
  HEAP32[$139>>2] = $134;
  $140 = (($138) + 4)|0;
  $141 = $140;
  HEAP32[$141>>2] = $137;
  $142 = HEAP32[$8>>2]|0;
  $143 = ((($142) + (($16*12)|0)|0) + 8|0);
  HEAPF32[$143>>2] = $aA$0$lcssa;
  $144 = HEAP32[$8>>2]|0;
  $145 = (($144) + (($18*12)|0)|0);
  $146 = $cB;
  $147 = $146;
  $148 = HEAP32[$147>>2]|0;
  $149 = (($146) + 4)|0;
  $150 = $149;
  $151 = HEAP32[$150>>2]|0;
  $152 = $145;
  $153 = $152;
  HEAP32[$153>>2] = $148;
  $154 = (($152) + 4)|0;
  $155 = $154;
  HEAP32[$155>>2] = $151;
  $156 = HEAP32[$8>>2]|0;
  $157 = ((($156) + (($18*12)|0)|0) + 8|0);
  HEAPF32[$157>>2] = $aB$0$lcssa;
  $158 = (($i$015) + 1)|0;
  $159 = HEAP32[$4>>2]|0;
  $160 = ($158|0)<($159|0);
  if ($160) {
   $i$015 = $158;$minSeparation$016 = $minSeparation$1$lcssa;
  } else {
   $minSeparation$0$lcssa = $minSeparation$1$lcssa;
   break;
  }
 }
 $161 = $minSeparation$0$lcssa >= -0.0074999998323619366;
 STACKTOP = sp;return ($161|0);
}
function __ZN7b2Mat227SetZeroEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN24b2PositionSolverManifold10InitializeEP27b2ContactPositionConstraintRK11b2TransformS4_i($this,$pc,$xfA,$xfB,$index) {
 $this = $this|0;
 $pc = $pc|0;
 $xfA = $xfA|0;
 $xfB = $xfB|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0.0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0.0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0.0, $89 = 0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0, $93 = 0.0, $94 = 0.0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $clipPoint = 0;
 var $clipPoint2 = 0, $planePoint = 0, $planePoint1 = 0, $pointA = 0, $pointB = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $pointA = sp + 112|0;
 $pointB = sp + 104|0;
 $0 = sp + 48|0;
 $1 = sp + 40|0;
 $2 = sp + 96|0;
 $3 = sp + 88|0;
 $4 = sp + 32|0;
 $planePoint = sp + 80|0;
 $clipPoint = sp + 24|0;
 $5 = sp + 72|0;
 $6 = sp + 16|0;
 $planePoint1 = sp + 64|0;
 $clipPoint2 = sp + 8|0;
 $7 = sp + 56|0;
 $8 = sp;
 $9 = (($pc) + 72|0);
 $10 = HEAP32[$9>>2]|0;
 if ((($10|0) == 1)) {
  $41 = (($xfA) + 8|0);
  $42 = (($pc) + 16|0);
  __Z5b2MulRK5b2RotRK6b2Vec2($4,$41,$42);
  $43 = $4;
  $44 = $43;
  $45 = HEAP32[$44>>2]|0;
  $46 = (($43) + 4)|0;
  $47 = $46;
  $48 = HEAP32[$47>>2]|0;
  $49 = $this;
  $50 = $49;
  HEAP32[$50>>2] = $45;
  $51 = (($49) + 4)|0;
  $52 = $51;
  HEAP32[$52>>2] = $48;
  $53 = (($pc) + 24|0);
  __Z5b2MulRK11b2TransformRK6b2Vec2($planePoint,$xfA,$53);
  $54 = (($pc) + ($index<<3)|0);
  __Z5b2MulRK11b2TransformRK6b2Vec2($clipPoint,$xfB,$54);
  __ZmiRK6b2Vec2S1_($5,$clipPoint,$planePoint);
  $55 = (+__Z5b2DotRK6b2Vec2S1_($5,$this));
  $56 = (($pc) + 76|0);
  $57 = +HEAPF32[$56>>2];
  $58 = $55 - $57;
  $59 = (($pc) + 80|0);
  $60 = +HEAPF32[$59>>2];
  $61 = $58 - $60;
  $62 = (($this) + 16|0);
  HEAPF32[$62>>2] = $61;
  $63 = (($this) + 8|0);
  $64 = $clipPoint;
  $65 = $64;
  $66 = HEAP32[$65>>2]|0;
  $67 = (($64) + 4)|0;
  $68 = $67;
  $69 = HEAP32[$68>>2]|0;
  $70 = $63;
  $71 = $70;
  HEAP32[$71>>2] = $66;
  $72 = (($70) + 4)|0;
  $73 = $72;
  HEAP32[$73>>2] = $69;
  STACKTOP = sp;return;
 } else if ((($10|0) == 2)) {
  $74 = (($xfB) + 8|0);
  $75 = (($pc) + 16|0);
  __Z5b2MulRK5b2RotRK6b2Vec2($6,$74,$75);
  $76 = $6;
  $77 = $76;
  $78 = HEAP32[$77>>2]|0;
  $79 = (($76) + 4)|0;
  $80 = $79;
  $81 = HEAP32[$80>>2]|0;
  $82 = $this;
  $83 = $82;
  HEAP32[$83>>2] = $78;
  $84 = (($82) + 4)|0;
  $85 = $84;
  HEAP32[$85>>2] = $81;
  $86 = (($pc) + 24|0);
  __Z5b2MulRK11b2TransformRK6b2Vec2($planePoint1,$xfB,$86);
  $87 = (($pc) + ($index<<3)|0);
  __Z5b2MulRK11b2TransformRK6b2Vec2($clipPoint2,$xfA,$87);
  __ZmiRK6b2Vec2S1_($7,$clipPoint2,$planePoint1);
  $88 = (+__Z5b2DotRK6b2Vec2S1_($7,$this));
  $89 = (($pc) + 76|0);
  $90 = +HEAPF32[$89>>2];
  $91 = $88 - $90;
  $92 = (($pc) + 80|0);
  $93 = +HEAPF32[$92>>2];
  $94 = $91 - $93;
  $95 = (($this) + 16|0);
  HEAPF32[$95>>2] = $94;
  $96 = (($this) + 8|0);
  $97 = $clipPoint2;
  $98 = $97;
  $99 = HEAP32[$98>>2]|0;
  $100 = (($97) + 4)|0;
  $101 = $100;
  $102 = HEAP32[$101>>2]|0;
  $103 = $96;
  $104 = $103;
  HEAP32[$104>>2] = $99;
  $105 = (($103) + 4)|0;
  $106 = $105;
  HEAP32[$106>>2] = $102;
  __ZNK6b2Vec2ngEv($8,$this);
  $107 = $8;
  $108 = $107;
  $109 = HEAP32[$108>>2]|0;
  $110 = (($107) + 4)|0;
  $111 = $110;
  $112 = HEAP32[$111>>2]|0;
  $113 = $this;
  $114 = $113;
  HEAP32[$114>>2] = $109;
  $115 = (($113) + 4)|0;
  $116 = $115;
  HEAP32[$116>>2] = $112;
  STACKTOP = sp;return;
 } else if ((($10|0) == 0)) {
  $11 = (($pc) + 24|0);
  __Z5b2MulRK11b2TransformRK6b2Vec2($pointA,$xfA,$11);
  __Z5b2MulRK11b2TransformRK6b2Vec2($pointB,$xfB,$pc);
  __ZmiRK6b2Vec2S1_($0,$pointB,$pointA);
  $12 = $0;
  $13 = $12;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 4)|0;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  $18 = $this;
  $19 = $18;
  HEAP32[$19>>2] = $14;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $17;
  (+__ZN6b2Vec29NormalizeEv($this));
  $22 = (($this) + 8|0);
  __ZplRK6b2Vec2S1_($2,$pointA,$pointB);
  __ZmlfRK6b2Vec2($1,0.5,$2);
  $23 = $1;
  $24 = $23;
  $25 = HEAP32[$24>>2]|0;
  $26 = (($23) + 4)|0;
  $27 = $26;
  $28 = HEAP32[$27>>2]|0;
  $29 = $22;
  $30 = $29;
  HEAP32[$30>>2] = $25;
  $31 = (($29) + 4)|0;
  $32 = $31;
  HEAP32[$32>>2] = $28;
  __ZmiRK6b2Vec2S1_($3,$pointB,$pointA);
  $33 = (+__Z5b2DotRK6b2Vec2S1_($3,$this));
  $34 = (($pc) + 76|0);
  $35 = +HEAPF32[$34>>2];
  $36 = $33 - $35;
  $37 = (($pc) + 80|0);
  $38 = +HEAPF32[$37>>2];
  $39 = $36 - $38;
  $40 = (($this) + 16|0);
  HEAPF32[$40>>2] = $39;
  STACKTOP = sp;return;
 } else {
  $117 = (($this) + 16|0);
  HEAPF32[$117>>2] = 0.0;
  $118 = 10224;
  $119 = $118;
  $120 = HEAP32[$119>>2]|0;
  $121 = (($118) + 4)|0;
  $122 = $121;
  $123 = HEAP32[$122>>2]|0;
  $124 = $this;
  $125 = $124;
  HEAP32[$125>>2] = $120;
  $126 = (($124) + 4)|0;
  $127 = $126;
  HEAP32[$127>>2] = $123;
  $128 = (($this) + 8|0);
  $129 = 10224;
  $130 = $129;
  $131 = HEAP32[$130>>2]|0;
  $132 = (($129) + 4)|0;
  $133 = $132;
  $134 = HEAP32[$133>>2]|0;
  $135 = $128;
  $136 = $135;
  HEAP32[$136>>2] = $131;
  $137 = (($135) + 4)|0;
  $138 = $137;
  HEAP32[$138>>2] = $134;
  STACKTOP = sp;return;
 }
}
function __ZN22b2EdgeAndCircleContact6CreateEP9b2FixtureiS1_iP16b2BlockAllocator($fixtureA,$0,$fixtureB,$1,$allocator) {
 $fixtureA = $fixtureA|0;
 $0 = $0|0;
 $fixtureB = $fixtureB|0;
 $1 = $1|0;
 $allocator = $allocator|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN16b2BlockAllocator8AllocateEi($allocator,148)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = 0;
  STACKTOP = sp;return ($4|0);
 }
 __ZN22b2EdgeAndCircleContactC2EP9b2FixtureS1_($2,$fixtureA,$fixtureB);
 $4 = $2;
 STACKTOP = sp;return ($4|0);
}
function __ZN22b2EdgeAndCircleContact7DestroyEP9b2ContactP16b2BlockAllocator($contact,$allocator) {
 $contact = $contact|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$contact>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$2 & 127]($contact);
 __ZN16b2BlockAllocator4FreeEPvi($allocator,$contact,148);
 STACKTOP = sp;return;
}
function __ZN22b2EdgeAndCircleContactC2EP9b2FixtureS1_($this,$fixtureA,$fixtureB) {
 $this = $this|0;
 $fixtureA = $fixtureA|0;
 $fixtureB = $fixtureB|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9b2ContactC2EP9b2FixtureiS1_i($this,$fixtureA,0,$fixtureB,0);
 HEAP32[$this>>2] = ((7944 + 8|0));
 STACKTOP = sp;return;
}
function __ZN22b2EdgeAndCircleContact8EvaluateEP10b2ManifoldRK11b2TransformS4_($this,$manifold,$xfA,$xfB) {
 $this = $this|0;
 $manifold = $manifold|0;
 $xfA = $xfA|0;
 $xfB = $xfB|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN9b2Fixture8GetShapeEv($1)|0);
 $3 = (($this) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZN9b2Fixture8GetShapeEv($4)|0);
 __Z22b2CollideEdgeAndCircleP10b2ManifoldPK11b2EdgeShapeRK11b2TransformPK13b2CircleShapeS6_($manifold,$2,$xfA,$5,$xfB);
 STACKTOP = sp;return;
}
function __ZN22b2EdgeAndCircleContactD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN23b2ChainAndCircleContact6CreateEP9b2FixtureiS1_iP16b2BlockAllocator($fixtureA,$indexA,$fixtureB,$indexB,$allocator) {
 $fixtureA = $fixtureA|0;
 $indexA = $indexA|0;
 $fixtureB = $fixtureB|0;
 $indexB = $indexB|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN16b2BlockAllocator8AllocateEi($allocator,148)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = 0;
  STACKTOP = sp;return ($2|0);
 }
 __ZN23b2ChainAndCircleContactC2EP9b2FixtureiS1_i($0,$fixtureA,$indexA,$fixtureB,$indexB);
 $2 = $0;
 STACKTOP = sp;return ($2|0);
}
function __ZN23b2ChainAndCircleContact7DestroyEP9b2ContactP16b2BlockAllocator($contact,$allocator) {
 $contact = $contact|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$contact>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$2 & 127]($contact);
 __ZN16b2BlockAllocator4FreeEPvi($allocator,$contact,148);
 STACKTOP = sp;return;
}
function __ZN23b2ChainAndCircleContactC2EP9b2FixtureiS1_i($this,$fixtureA,$indexA,$fixtureB,$indexB) {
 $this = $this|0;
 $fixtureA = $fixtureA|0;
 $indexA = $indexA|0;
 $fixtureB = $fixtureB|0;
 $indexB = $indexB|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9b2ContactC2EP9b2FixtureiS1_i($this,$fixtureA,$indexA,$fixtureB,$indexB);
 HEAP32[$this>>2] = ((8016 + 8|0));
 STACKTOP = sp;return;
}
function __ZN23b2ChainAndCircleContact8EvaluateEP10b2ManifoldRK11b2TransformS4_($this,$manifold,$xfA,$xfB) {
 $this = $this|0;
 $manifold = $manifold|0;
 $xfA = $xfA|0;
 $xfB = $xfB|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $edge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $edge = sp;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN9b2Fixture8GetShapeEv($1)|0);
 __ZN11b2EdgeShapeC2Ev($edge);
 $3 = (($this) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 __ZNK12b2ChainShape12GetChildEdgeEP11b2EdgeShapei($2,$edge,$4);
 $5 = (($this) + 52|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__ZN9b2Fixture8GetShapeEv($6)|0);
 __Z22b2CollideEdgeAndCircleP10b2ManifoldPK11b2EdgeShapeRK11b2TransformPK13b2CircleShapeS6_($manifold,$edge,$xfA,$7,$xfB);
 STACKTOP = sp;return;
}
function __ZN23b2ChainAndCircleContactD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN23b2EdgeAndPolygonContact6CreateEP9b2FixtureiS1_iP16b2BlockAllocator($fixtureA,$0,$fixtureB,$1,$allocator) {
 $fixtureA = $fixtureA|0;
 $0 = $0|0;
 $fixtureB = $fixtureB|0;
 $1 = $1|0;
 $allocator = $allocator|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN16b2BlockAllocator8AllocateEi($allocator,148)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = 0;
  STACKTOP = sp;return ($4|0);
 }
 __ZN23b2EdgeAndPolygonContactC2EP9b2FixtureS1_($2,$fixtureA,$fixtureB);
 $4 = $2;
 STACKTOP = sp;return ($4|0);
}
function __ZN23b2EdgeAndPolygonContact7DestroyEP9b2ContactP16b2BlockAllocator($contact,$allocator) {
 $contact = $contact|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$contact>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$2 & 127]($contact);
 __ZN16b2BlockAllocator4FreeEPvi($allocator,$contact,148);
 STACKTOP = sp;return;
}
function __ZN23b2EdgeAndPolygonContactC2EP9b2FixtureS1_($this,$fixtureA,$fixtureB) {
 $this = $this|0;
 $fixtureA = $fixtureA|0;
 $fixtureB = $fixtureB|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9b2ContactC2EP9b2FixtureiS1_i($this,$fixtureA,0,$fixtureB,0);
 HEAP32[$this>>2] = ((8088 + 8|0));
 STACKTOP = sp;return;
}
function __ZN23b2EdgeAndPolygonContact8EvaluateEP10b2ManifoldRK11b2TransformS4_($this,$manifold,$xfA,$xfB) {
 $this = $this|0;
 $manifold = $manifold|0;
 $xfA = $xfA|0;
 $xfB = $xfB|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN9b2Fixture8GetShapeEv($1)|0);
 $3 = (($this) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZN9b2Fixture8GetShapeEv($4)|0);
 __Z23b2CollideEdgeAndPolygonP10b2ManifoldPK11b2EdgeShapeRK11b2TransformPK14b2PolygonShapeS6_($manifold,$2,$xfA,$5,$xfB);
 STACKTOP = sp;return;
}
function __ZN23b2EdgeAndPolygonContactD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN16b2PolygonContact6CreateEP9b2FixtureiS1_iP16b2BlockAllocator($fixtureA,$0,$fixtureB,$1,$allocator) {
 $fixtureA = $fixtureA|0;
 $0 = $0|0;
 $fixtureB = $fixtureB|0;
 $1 = $1|0;
 $allocator = $allocator|0;
 var $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (__ZN16b2BlockAllocator8AllocateEi($allocator,148)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = 0;
  STACKTOP = sp;return ($4|0);
 }
 __ZN16b2PolygonContactC2EP9b2FixtureS1_($2,$fixtureA,$fixtureB);
 $4 = $2;
 STACKTOP = sp;return ($4|0);
}
function __ZN16b2PolygonContact7DestroyEP9b2ContactP16b2BlockAllocator($contact,$allocator) {
 $contact = $contact|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$contact>>2]|0;
 $1 = (($0) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 FUNCTION_TABLE_vi[$2 & 127]($contact);
 __ZN16b2BlockAllocator4FreeEPvi($allocator,$contact,148);
 STACKTOP = sp;return;
}
function __ZN16b2PolygonContactC2EP9b2FixtureS1_($this,$fixtureA,$fixtureB) {
 $this = $this|0;
 $fixtureA = $fixtureA|0;
 $fixtureB = $fixtureB|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN9b2ContactC2EP9b2FixtureiS1_i($this,$fixtureA,0,$fixtureB,0);
 HEAP32[$this>>2] = ((8160 + 8|0));
 STACKTOP = sp;return;
}
function __ZN16b2PolygonContact8EvaluateEP10b2ManifoldRK11b2TransformS4_($this,$manifold,$xfA,$xfB) {
 $this = $this|0;
 $manifold = $manifold|0;
 $xfA = $xfA|0;
 $xfB = $xfB|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN9b2Fixture8GetShapeEv($1)|0);
 $3 = (($this) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZN9b2Fixture8GetShapeEv($4)|0);
 __Z17b2CollidePolygonsP10b2ManifoldPK14b2PolygonShapeRK11b2TransformS3_S6_($manifold,$2,$xfA,$5,$xfB);
 STACKTOP = sp;return;
}
function __ZN16b2PolygonContactD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN9b2FixtureC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 __ZN8b2FilterC2Ev($0);
 $1 = (($this) + 40|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 24|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 28|0);
 HEAP32[$3>>2] = 0;
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN9b2Fixture6CreateEP16b2BlockAllocatorP6b2BodyPK12b2FixtureDef($this,$allocator,$body,$def) {
 $this = $this|0;
 $allocator = $allocator|0;
 $body = $body|0;
 $def = $def|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0.0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($def) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 40|0);
 HEAP32[$2>>2] = $1;
 $3 = (($def) + 8|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($this) + 16|0);
 HEAPF32[$5>>2] = $4;
 $6 = (($def) + 12|0);
 $7 = +HEAPF32[$6>>2];
 $8 = (($this) + 20|0);
 HEAPF32[$8>>2] = $7;
 $9 = (($this) + 8|0);
 HEAP32[$9>>2] = $body;
 $10 = (($this) + 4|0);
 HEAP32[$10>>2] = 0;
 $11 = (($this) + 32|0);
 $12 = (($def) + 22|0);
 ;HEAP16[$11+0>>1]=HEAP16[$12+0>>1]|0;HEAP16[$11+2>>1]=HEAP16[$12+2>>1]|0;HEAP16[$11+4>>1]=HEAP16[$12+4>>1]|0;
 $13 = (($def) + 20|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = (($this) + 38|0);
 HEAP8[$15>>0] = $14;
 $16 = HEAP32[$def>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 8|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (FUNCTION_TABLE_iii[$19 & 63]($16,$allocator)|0);
 $21 = (($this) + 12|0);
 HEAP32[$21>>2] = $20;
 $22 = HEAP32[$20>>2]|0;
 $23 = (($22) + 12|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = (FUNCTION_TABLE_ii[$24 & 15]($20)|0);
 $26 = ($25*28)|0;
 $27 = (__ZN16b2BlockAllocator8AllocateEi($allocator,$26)|0);
 $28 = (($this) + 24|0);
 HEAP32[$28>>2] = $27;
 $29 = ($25|0)>(0);
 if (!($29)) {
  $34 = (($this) + 28|0);
  HEAP32[$34>>2] = 0;
  $35 = (($def) + 16|0);
  $36 = +HEAPF32[$35>>2];
  HEAPF32[$this>>2] = $36;
  STACKTOP = sp;return;
 }
 $30 = HEAP32[$28>>2]|0;
 $i$01 = 0;
 while(1) {
  $31 = ((($30) + (($i$01*28)|0)|0) + 16|0);
  HEAP32[$31>>2] = 0;
  $32 = ((($30) + (($i$01*28)|0)|0) + 24|0);
  HEAP32[$32>>2] = -1;
  $33 = (($i$01) + 1)|0;
  $exitcond = ($33|0)==($25|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $33;
  }
 }
 $34 = (($this) + 28|0);
 HEAP32[$34>>2] = 0;
 $35 = (($def) + 16|0);
 $36 = +HEAPF32[$35>>2];
 HEAPF32[$this>>2] = $36;
 STACKTOP = sp;return;
}
function __ZN9b2Fixture7DestroyEP16b2BlockAllocator($this,$allocator) {
 $this = $this|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 15]($1)|0);
 $6 = (($this) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5*28)|0;
 __ZN16b2BlockAllocator4FreeEPvi($allocator,$7,$8);
 HEAP32[$6>>2] = 0;
 $9 = HEAP32[$0>>2]|0;
 $10 = (($9) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 if ((($11|0) == 1)) {
  $14 = HEAP32[$9>>2]|0;
  $15 = HEAP32[$14>>2]|0;
  FUNCTION_TABLE_vi[$15 & 127]($9);
  __ZN16b2BlockAllocator4FreeEPvi($allocator,$9,48);
  HEAP32[$0>>2] = 0;
  STACKTOP = sp;return;
 } else if ((($11|0) == 3)) {
  $18 = HEAP32[$9>>2]|0;
  $19 = HEAP32[$18>>2]|0;
  FUNCTION_TABLE_vi[$19 & 127]($9);
  __ZN16b2BlockAllocator4FreeEPvi($allocator,$9,40);
  HEAP32[$0>>2] = 0;
  STACKTOP = sp;return;
 } else if ((($11|0) == 0)) {
  $12 = HEAP32[$9>>2]|0;
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_vi[$13 & 127]($9);
  __ZN16b2BlockAllocator4FreeEPvi($allocator,$9,20);
  HEAP32[$0>>2] = 0;
  STACKTOP = sp;return;
 } else if ((($11|0) == 2)) {
  $16 = HEAP32[$9>>2]|0;
  $17 = HEAP32[$16>>2]|0;
  FUNCTION_TABLE_vi[$17 & 127]($9);
  __ZN16b2BlockAllocator4FreeEPvi($allocator,$9,152);
  HEAP32[$0>>2] = 0;
  STACKTOP = sp;return;
 } else {
  HEAP32[$0>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN9b2Fixture13CreateProxiesEP12b2BroadPhaseRK11b2Transform($this,$broadPhase,$xf) {
 $this = $this|0;
 $broadPhase = $broadPhase|0;
 $xf = $xf|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 15]($1)|0);
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = $5;
 $7 = ($5|0)>(0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 24|0);
 $i$01 = 0;
 while(1) {
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + (($i$01*28)|0)|0);
  $11 = HEAP32[$0>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 28|0);
  $14 = HEAP32[$13>>2]|0;
  FUNCTION_TABLE_viiii[$14 & 31]($11,$10,$xf,$i$01);
  $15 = (__ZN12b2BroadPhase11CreateProxyERK6b2AABBPv($broadPhase,$10,$10)|0);
  $16 = ((($9) + (($i$01*28)|0)|0) + 24|0);
  HEAP32[$16>>2] = $15;
  $17 = ((($9) + (($i$01*28)|0)|0) + 16|0);
  HEAP32[$17>>2] = $this;
  $18 = ((($9) + (($i$01*28)|0)|0) + 20|0);
  HEAP32[$18>>2] = $i$01;
  $19 = (($i$01) + 1)|0;
  $20 = HEAP32[$6>>2]|0;
  $21 = ($19|0)<($20|0);
  if ($21) {
   $i$01 = $19;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN9b2Fixture14DestroyProxiesEP12b2BroadPhase($this,$broadPhase) {
 $this = $this|0;
 $broadPhase = $broadPhase|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  HEAP32[$0>>2] = 0;
  STACKTOP = sp;return;
 }
 $3 = (($this) + 24|0);
 $i$01 = 0;
 while(1) {
  $4 = HEAP32[$3>>2]|0;
  $5 = ((($4) + (($i$01*28)|0)|0) + 24|0);
  $6 = HEAP32[$5>>2]|0;
  __ZN12b2BroadPhase12DestroyProxyEi($broadPhase,$6);
  HEAP32[$5>>2] = -1;
  $7 = (($i$01) + 1)|0;
  $8 = HEAP32[$0>>2]|0;
  $9 = ($7|0)<($8|0);
  if ($9) {
   $i$01 = $7;
  } else {
   break;
  }
 }
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN9b2Fixture11SynchronizeEP12b2BroadPhaseRK11b2TransformS4_($this,$broadPhase,$transform1,$transform2) {
 $this = $this|0;
 $broadPhase = $broadPhase|0;
 $transform1 = $transform1|0;
 $transform2 = $transform2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $aabb1 = 0, $aabb2 = 0, $displacement = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $aabb1 = sp + 24|0;
 $aabb2 = sp + 8|0;
 $displacement = sp;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$0>>2]|0;
 $4 = ($3|0)>(0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 24|0);
 $6 = (($this) + 12|0);
 $i$01 = 0;
 while(1) {
  $7 = HEAP32[$5>>2]|0;
  $8 = HEAP32[$6>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($9) + 28|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($7) + (($i$01*28)|0)|0) + 20|0);
  $13 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_viiii[$11 & 31]($8,$aabb1,$transform1,$13);
  $14 = HEAP32[$6>>2]|0;
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + 28|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = HEAP32[$12>>2]|0;
  FUNCTION_TABLE_viiii[$17 & 31]($14,$aabb2,$transform2,$18);
  $19 = (($7) + (($i$01*28)|0)|0);
  __ZN6b2AABB7CombineERKS_S1_($19,$aabb1,$aabb2);
  __ZmiRK6b2Vec2S1_($displacement,$transform2,$transform1);
  $20 = ((($7) + (($i$01*28)|0)|0) + 24|0);
  $21 = HEAP32[$20>>2]|0;
  __ZN12b2BroadPhase9MoveProxyEiRK6b2AABBRK6b2Vec2($broadPhase,$21,$19,$displacement);
  $22 = (($i$01) + 1)|0;
  $23 = HEAP32[$0>>2]|0;
  $24 = ($22|0)<($23|0);
  if ($24) {
   $i$01 = $22;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN6b2Body14GetContactListEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 128|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN9b2Contact11GetFixtureAEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN9b2Contact11GetFixtureBEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN9b2Contact16FlagForFilteringEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 | 8;
 HEAP32[$0>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN7b2WorldC2ERK6b2Vec2($this,$gravity) {
 $this = $this|0;
 $gravity = $gravity|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16b2BlockAllocatorC2Ev($this);
 $0 = (($this) + 76|0);
 __ZN16b2StackAllocatorC2Ev($0);
 $1 = (($this) + 102880|0);
 __ZN16b2ContactManagerC2Ev($1);
 __ZN7b2World4InitERK6b2Vec2($this,$gravity);
 STACKTOP = sp;return;
}
function __ZN7b2World4InitERK6b2Vec2($this,$gravity) {
 $this = $this|0;
 $gravity = $gravity|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 102992|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 102996|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 102960|0);
 $3 = (($this) + 103004|0);
 ;HEAP32[$2+0>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;
 HEAP8[$3>>0] = 1;
 $4 = (($this) + 103005|0);
 HEAP8[$4>>0] = 1;
 $5 = (($this) + 103006|0);
 HEAP8[$5>>0] = 0;
 $6 = (($this) + 103007|0);
 HEAP8[$6>>0] = 1;
 $7 = (($this) + 102988|0);
 HEAP8[$7>>0] = 1;
 $8 = (($this) + 102980|0);
 $9 = $gravity;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = $8;
 $16 = $15;
 HEAP32[$16>>2] = $11;
 $17 = (($15) + 4)|0;
 $18 = $17;
 HEAP32[$18>>2] = $14;
 $19 = (($this) + 102876|0);
 HEAP32[$19>>2] = 4;
 $20 = (($this) + 103000|0);
 HEAPF32[$20>>2] = 0.0;
 $21 = (($this) + 102956|0);
 HEAP32[$21>>2] = $this;
 $22 = (($this) + 103040|0);
 HEAP32[$22>>2] = 10232;
 $23 = HEAP32[10264>>2]|0;
 $24 = (($this) + 103044|0);
 HEAP32[$24>>2] = $23;
 $25 = (($this) + 103008|0);
 ;HEAP32[$25+0>>2]=0|0;HEAP32[$25+4>>2]=0|0;HEAP32[$25+8>>2]=0|0;HEAP32[$25+12>>2]=0|0;HEAP32[$25+16>>2]=0|0;HEAP32[$25+20>>2]=0|0;HEAP32[$25+24>>2]=0|0;HEAP32[$25+28>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN7b2WorldD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $b$04 = 0, $f$0 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 102960|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $b$04 = $1;
  while(1) {
   $6 = (($b$04) + 112|0);
   $3 = HEAP32[$6>>2]|0;
   $7 = (($b$04) + 116|0);
   $8 = HEAP32[$7>>2]|0;
   $f$0 = $8;
   while(1) {
    $9 = ($f$0|0)==(0|0);
    if ($9) {
     break;
    }
    $10 = (($f$0) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($f$0) + 28|0);
    HEAP32[$12>>2] = 0;
    __ZN9b2Fixture7DestroyEP16b2BlockAllocator($f$0,$this);
    $f$0 = $11;
   }
   $4 = ($3|0)==(0|0);
   if ($4) {
    break;
   } else {
    $b$04 = $3;
   }
  }
 }
 $5 = (($this) + 102968|0);
 while(1) {
  $13 = HEAP32[$5>>2]|0;
  $14 = ($13|0)==(0|0);
  if ($14) {
   break;
  }
  __ZN7b2World21DestroyParticleSystemEP16b2ParticleSystem($this,$13);
 }
 $15 = (($this) + 102880|0);
 __ZN16b2ContactManagerD2Ev($15);
 $16 = (($this) + 76|0);
 __ZN16b2StackAllocatorD2Ev($16);
 __ZN16b2BlockAllocatorD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN7b2World21DestroyParticleSystemEP16b2ParticleSystem($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK7b2World8IsLockedEv($this)|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($p) + 404|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($p) + 408|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($2) + 408|0);
  HEAP32[$6>>2] = $5;
 }
 $7 = (($p) + 408|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$1>>2]|0;
  $11 = (($8) + 404|0);
  HEAP32[$11>>2] = $10;
 }
 $12 = (($this) + 102968|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==($p|0);
 if ($14) {
  $15 = HEAP32[$7>>2]|0;
  HEAP32[$12>>2] = $15;
 }
 __ZN16b2ParticleSystemD2Ev($p);
 __ZN16b2BlockAllocator4FreeEPvi($this,$p,416);
 STACKTOP = sp;return;
}
function __ZN7b2World18SetContactListenerEP17b2ContactListener($this,$listener) {
 $this = $this|0;
 $listener = $listener|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 102952|0);
 HEAP32[$0>>2] = $listener;
 STACKTOP = sp;return;
}
function __ZN7b2World10CreateBodyEPK9b2BodyDef($this,$def) {
 $this = $this|0;
 $def = $def|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK7b2World8IsLockedEv($this)|0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (__ZN16b2BlockAllocator8AllocateEi($this,168)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
 } else {
  __ZN6b2BodyC2EPK9b2BodyDefP7b2World($1,$def,$this);
  $4 = $1;
 }
 $3 = (($4) + 108|0);
 HEAP32[$3>>2] = 0;
 $5 = (($this) + 102960|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 112|0);
 HEAP32[$7>>2] = $6;
 $8 = HEAP32[$5>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = (($8) + 108|0);
  HEAP32[$10>>2] = $4;
 }
 HEAP32[$5>>2] = $4;
 $11 = (($this) + 102972|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1)|0;
 HEAP32[$11>>2] = $13;
 $$0 = $4;
 STACKTOP = sp;return ($$0|0);
}
function __ZN7b2World11DestroyBodyEP6b2Body($this,$b) {
 $this = $this|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $ce$02 = 0, $f$01 = 0, $je$06 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK7b2World8IsLockedEv($this)|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($b) + 124|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = (($this) + 102992|0);
  $je$06 = $2;
  while(1) {
   $5 = (($je$06) + 12|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = HEAP32[$4>>2]|0;
   $8 = ($7|0)==(0|0);
   if (!($8)) {
    $9 = HEAP32[$7>>2]|0;
    $10 = (($9) + 8|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (($je$06) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    FUNCTION_TABLE_vii[$11 & 63]($7,$13);
   }
   $14 = (($je$06) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   __ZN7b2World12DestroyJointEP7b2Joint($this,$15);
   HEAP32[$1>>2] = $6;
   $16 = ($6|0)==(0|0);
   if ($16) {
    break;
   } else {
    $je$06 = $6;
   }
  }
 }
 HEAP32[$1>>2] = 0;
 $17 = (($b) + 128|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  $20 = (($this) + 102880|0);
  $ce$02 = $18;
  while(1) {
   $21 = (($ce$02) + 12|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($ce$02) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   __ZN16b2ContactManager7DestroyEP9b2Contact($20,$24);
   $25 = ($22|0)==(0|0);
   if ($25) {
    break;
   } else {
    $ce$02 = $22;
   }
  }
 }
 HEAP32[$17>>2] = 0;
 $26 = (($b) + 116|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if (!($28)) {
  $29 = (($this) + 102992|0);
  $30 = (($this) + 102880|0);
  $31 = (($b) + 120|0);
  $f$01 = $27;
  while(1) {
   $32 = (($f$01) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = HEAP32[$29>>2]|0;
   $35 = ($34|0)==(0|0);
   if (!($35)) {
    $36 = HEAP32[$34>>2]|0;
    $37 = (($36) + 12|0);
    $38 = HEAP32[$37>>2]|0;
    FUNCTION_TABLE_vii[$38 & 63]($34,$f$01);
   }
   __ZN9b2Fixture14DestroyProxiesEP12b2BroadPhase($f$01,$30);
   __ZN9b2Fixture7DestroyEP16b2BlockAllocator($f$01,$this);
   __ZN16b2BlockAllocator4FreeEPvi($this,$f$01,44);
   HEAP32[$26>>2] = $33;
   $39 = HEAP32[$31>>2]|0;
   $40 = (($39) + -1)|0;
   HEAP32[$31>>2] = $40;
   $41 = ($33|0)==(0|0);
   if ($41) {
    break;
   } else {
    $f$01 = $33;
   }
  }
 }
 HEAP32[$26>>2] = 0;
 $42 = (($b) + 120|0);
 HEAP32[$42>>2] = 0;
 $43 = (($b) + 108|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(0|0);
 if (!($45)) {
  $46 = (($b) + 112|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($44) + 112|0);
  HEAP32[$48>>2] = $47;
 }
 $49 = (($b) + 112|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($50|0)==(0|0);
 if (!($51)) {
  $52 = HEAP32[$43>>2]|0;
  $53 = (($50) + 108|0);
  HEAP32[$53>>2] = $52;
 }
 $54 = (($this) + 102960|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($55|0)==($b|0);
 if ($56) {
  $57 = HEAP32[$49>>2]|0;
  HEAP32[$54>>2] = $57;
 }
 $58 = (($this) + 102972|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($59) + -1)|0;
 HEAP32[$58>>2] = $60;
 __ZN6b2BodyD2Ev($b);
 __ZN16b2BlockAllocator4FreeEPvi($this,$b,168);
 STACKTOP = sp;return;
}
function __ZN7b2World12DestroyJointEP7b2Joint($this,$j) {
 $this = $this|0;
 $j = $j|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $edge$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK7b2World8IsLockedEv($this)|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($j) + 61|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = (($j) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = (($j) + 12|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (($4) + 12|0);
  HEAP32[$8>>2] = $7;
 }
 $9 = (($j) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  $12 = HEAP32[$3>>2]|0;
  $13 = (($10) + 8|0);
  HEAP32[$13>>2] = $12;
 }
 $14 = (($this) + 102964|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==($j|0);
 if ($16) {
  $17 = HEAP32[$9>>2]|0;
  HEAP32[$14>>2] = $17;
 }
 $18 = (($j) + 48|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($j) + 52|0);
 $21 = HEAP32[$20>>2]|0;
 __ZN6b2Body8SetAwakeEb($19,1);
 __ZN6b2Body8SetAwakeEb($21,1);
 $22 = (($j) + 16|0);
 $23 = (($j) + 24|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  $26 = (($j) + 28|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = (($24) + 12|0);
  HEAP32[$28>>2] = $27;
 }
 $29 = (($j) + 28|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0|0);
 if (!($31)) {
  $32 = HEAP32[$23>>2]|0;
  $33 = (($30) + 8|0);
  HEAP32[$33>>2] = $32;
 }
 $34 = (($19) + 124|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($22|0)==($35|0);
 if ($36) {
  $37 = HEAP32[$29>>2]|0;
  HEAP32[$34>>2] = $37;
 }
 HEAP32[$23>>2] = 0;
 HEAP32[$29>>2] = 0;
 $38 = (($j) + 32|0);
 $39 = (($j) + 40|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)==(0|0);
 if (!($41)) {
  $42 = (($j) + 44|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($40) + 12|0);
  HEAP32[$44>>2] = $43;
 }
 $45 = (($j) + 44|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ($46|0)==(0|0);
 if (!($47)) {
  $48 = HEAP32[$39>>2]|0;
  $49 = (($46) + 8|0);
  HEAP32[$49>>2] = $48;
 }
 $50 = (($21) + 124|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($38|0)==($51|0);
 if ($52) {
  $53 = HEAP32[$45>>2]|0;
  HEAP32[$50>>2] = $53;
 }
 HEAP32[$39>>2] = 0;
 HEAP32[$45>>2] = 0;
 __ZN7b2Joint7DestroyEPS_P16b2BlockAllocator($j,$this);
 $54 = (($this) + 102976|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = (($55) + -1)|0;
 HEAP32[$54>>2] = $56;
 $57 = ($2<<24>>24)==(0);
 if (!($57)) {
  STACKTOP = sp;return;
 }
 $58 = (__ZN6b2Body14GetContactListEv($21)|0);
 $59 = ($58|0)==(0|0);
 if ($59) {
  STACKTOP = sp;return;
 } else {
  $edge$01 = $58;
 }
 while(1) {
  $60 = HEAP32[$edge$01>>2]|0;
  $61 = ($60|0)==($19|0);
  if ($61) {
   $62 = (($edge$01) + 4|0);
   $63 = HEAP32[$62>>2]|0;
   __ZN9b2Contact16FlagForFilteringEv($63);
  }
  $64 = (($edge$01) + 12|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ($65|0)==(0|0);
  if ($66) {
   break;
  } else {
   $edge$01 = $65;
  }
 }
 STACKTOP = sp;return;
}
function __ZN7b2World11CreateJointEPK10b2JointDef($this,$def) {
 $this = $this|0;
 $def = $def|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $edge$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK7b2World8IsLockedEv($this)|0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (__ZN7b2Joint6CreateEPK10b2JointDefP16b2BlockAllocator($def,$this)|0);
 $2 = (($1) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 102964|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($1) + 12|0);
 HEAP32[$5>>2] = $4;
 $6 = HEAP32[$3>>2]|0;
 $7 = ($6|0)==(0|0);
 if (!($7)) {
  $8 = (($6) + 8|0);
  HEAP32[$8>>2] = $1;
 }
 HEAP32[$3>>2] = $1;
 $9 = (($this) + 102976|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + 1)|0;
 HEAP32[$9>>2] = $11;
 $12 = (($1) + 16|0);
 $13 = (($1) + 20|0);
 HEAP32[$13>>2] = $1;
 $14 = (($1) + 52|0);
 $15 = HEAP32[$14>>2]|0;
 HEAP32[$12>>2] = $15;
 $16 = (($1) + 24|0);
 HEAP32[$16>>2] = 0;
 $17 = (($1) + 48|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 124|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (($1) + 28|0);
 HEAP32[$21>>2] = $20;
 $22 = HEAP32[$17>>2]|0;
 $23 = (($22) + 124|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  $26 = (($24) + 8|0);
  HEAP32[$26>>2] = $12;
 }
 $27 = HEAP32[$17>>2]|0;
 $28 = (($27) + 124|0);
 HEAP32[$28>>2] = $12;
 $29 = (($1) + 32|0);
 $30 = (($1) + 36|0);
 HEAP32[$30>>2] = $1;
 $31 = HEAP32[$17>>2]|0;
 HEAP32[$29>>2] = $31;
 $32 = (($1) + 40|0);
 HEAP32[$32>>2] = 0;
 $33 = HEAP32[$14>>2]|0;
 $34 = (($33) + 124|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($1) + 44|0);
 HEAP32[$36>>2] = $35;
 $37 = HEAP32[$14>>2]|0;
 $38 = (($37) + 124|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0|0);
 if (!($40)) {
  $41 = (($39) + 8|0);
  HEAP32[$41>>2] = $29;
 }
 $42 = HEAP32[$14>>2]|0;
 $43 = (($42) + 124|0);
 HEAP32[$43>>2] = $29;
 $44 = (($def) + 8|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($def) + 16|0);
 $47 = HEAP8[$46>>0]|0;
 $48 = ($47<<24>>24)==(0);
 if (!($48)) {
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 }
 $49 = (($def) + 12|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (__ZN6b2Body14GetContactListEv($50)|0);
 $52 = ($51|0)==(0|0);
 if ($52) {
  $$0 = $1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $edge$01 = $51;
 }
 while(1) {
  $53 = HEAP32[$edge$01>>2]|0;
  $54 = ($53|0)==($45|0);
  if ($54) {
   $55 = (($edge$01) + 4|0);
   $56 = HEAP32[$55>>2]|0;
   __ZN9b2Contact16FlagForFilteringEv($56);
  }
  $57 = (($edge$01) + 12|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($58|0)==(0|0);
  if ($59) {
   $$0 = $1;
   break;
  } else {
   $edge$01 = $58;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZN7b2World20CreateParticleSystemEPK19b2ParticleSystemDef($this,$def) {
 $this = $this|0;
 $def = $def|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK7b2World8IsLockedEv($this)|0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (__ZN16b2BlockAllocator8AllocateEi($this,416)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = 0;
 } else {
  __ZN16b2ParticleSystemC2EPK19b2ParticleSystemDefP7b2World($1,$def,$this);
  $4 = $1;
 }
 $3 = (($4) + 404|0);
 HEAP32[$3>>2] = 0;
 $5 = (($this) + 102968|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($4) + 408|0);
 HEAP32[$7>>2] = $6;
 $8 = HEAP32[$5>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = (($8) + 404|0);
  HEAP32[$10>>2] = $4;
 }
 HEAP32[$5>>2] = $4;
 $$0 = $4;
 STACKTOP = sp;return ($$0|0);
}
function __ZN7b2World5SolveERK10b2TimeStep($this,$step) {
 $this = $this|0;
 $step = $step|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0, $133 = 0.0;
 var $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0.0, $165 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $b$0 = 0, $b$043 = 0, $b$044 = 0, $b1$0 = 0, $b1$038 = 0, $b1$039 = 0, $b5$01 = 0, $c$0 = 0, $c$033 = 0, $c$034 = 0, $ce$0 = 0, $ce$02 = 0, $ce$04 = 0, $i$017 = 0;
 var $island = 0, $j$0 = 0, $j$028 = 0, $j$029 = 0, $je$0 = 0, $je$011 = 0, $je$09 = 0, $profile = 0, $seed$0 = 0, $seed$023 = 0, $seed$024 = 0, $stackCount$0$be = 0, $stackCount$015 = 0, $stackCount$1$lcssa = 0, $stackCount$13 = 0, $stackCount$2 = 0, $stackCount$310 = 0, $stackCount$4 = 0, $timer = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $island = sp + 40|0;
 $profile = sp + 8|0;
 $timer = sp;
 $0 = (($this) + 102960|0);
 $b$043 = HEAP32[$0>>2]|0;
 $1 = ($b$043|0)==(0|0);
 if (!($1)) {
  $b$044 = $b$043;
  while(1) {
   $2 = (($b$044) + 28|0);
   $3 = (($b$044) + 12|0);
   ;HEAP32[$2+0>>2]=HEAP32[$3+0>>2]|0;HEAP32[$2+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$3+12>>2]|0;
   $4 = (($b$044) + 112|0);
   $b$0 = HEAP32[$4>>2]|0;
   $5 = ($b$0|0)==(0|0);
   if ($5) {
    break;
   } else {
    $b$044 = $b$0;
   }
  }
 }
 $6 = (($this) + 103020|0);
 HEAPF32[$6>>2] = 0.0;
 $7 = (($this) + 103024|0);
 HEAPF32[$7>>2] = 0.0;
 $8 = (($this) + 103028|0);
 HEAPF32[$8>>2] = 0.0;
 $9 = (($this) + 102972|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($this) + 102880|0);
 $12 = (($this) + 102944|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 102976|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($this) + 76|0);
 $17 = (($this) + 102952|0);
 $18 = HEAP32[$17>>2]|0;
 __ZN8b2IslandC2EiiiP16b2StackAllocatorP17b2ContactListener($island,$10,$13,$15,$16,$18);
 $b1$038 = HEAP32[$0>>2]|0;
 $19 = ($b1$038|0)==(0|0);
 if (!($19)) {
  $b1$039 = $b1$038;
  while(1) {
   $20 = (($b1$039) + 4|0);
   $21 = HEAP16[$20>>1]|0;
   $22 = $21&65535;
   $23 = $22 & 65534;
   $24 = $23&65535;
   HEAP16[$20>>1] = $24;
   $25 = (($b1$039) + 112|0);
   $b1$0 = HEAP32[$25>>2]|0;
   $26 = ($b1$0|0)==(0|0);
   if ($26) {
    break;
   } else {
    $b1$039 = $b1$0;
   }
  }
 }
 $27 = (($this) + 102940|0);
 $c$033 = HEAP32[$27>>2]|0;
 $28 = ($c$033|0)==(0|0);
 if (!($28)) {
  $c$034 = $c$033;
  while(1) {
   $29 = (($c$034) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = $30 & -2;
   HEAP32[$29>>2] = $31;
   $32 = (($c$034) + 12|0);
   $c$0 = HEAP32[$32>>2]|0;
   $33 = ($c$0|0)==(0|0);
   if ($33) {
    break;
   } else {
    $c$034 = $c$0;
   }
  }
 }
 $34 = (($this) + 102964|0);
 $j$028 = HEAP32[$34>>2]|0;
 $35 = ($j$028|0)==(0|0);
 if (!($35)) {
  $j$029 = $j$028;
  while(1) {
   $36 = (($j$029) + 60|0);
   HEAP8[$36>>0] = 0;
   $37 = (($j$029) + 12|0);
   $j$0 = HEAP32[$37>>2]|0;
   $38 = ($j$0|0)==(0|0);
   if ($38) {
    break;
   } else {
    $j$029 = $j$0;
   }
  }
 }
 $39 = HEAP32[$9>>2]|0;
 $40 = $39 << 2;
 $41 = (__ZN16b2StackAllocator8AllocateEi($16,$40)|0);
 $seed$023 = HEAP32[$0>>2]|0;
 $42 = ($seed$023|0)==(0|0);
 if (!($42)) {
  $43 = (($this) + 102980|0);
  $44 = (($this) + 102988|0);
  $45 = (($profile) + 12|0);
  $46 = (($profile) + 16|0);
  $47 = (($profile) + 20|0);
  $48 = (($island) + 28|0);
  $49 = (($island) + 8|0);
  $seed$024 = $seed$023;
  while(1) {
   $50 = (($seed$024) + 4|0);
   $51 = HEAP16[$50>>1]|0;
   $52 = $51 & 1;
   $53 = ($52<<16>>16)==(0);
   if ($53) {
    $54 = (__ZNK6b2Body7IsAwakeEv($seed$024)|0);
    if ($54) {
     $55 = (__ZNK6b2Body8IsActiveEv($seed$024)|0);
     if ($55) {
      $56 = (__ZNK6b2Body7GetTypeEv($seed$024)|0);
      $57 = ($56|0)==(0);
      if (!($57)) {
       __ZN8b2Island5ClearEv($island);
       HEAP32[$41>>2] = $seed$024;
       $58 = HEAP16[$50>>1]|0;
       $59 = $58&65535;
       $60 = $59 | 1;
       $61 = $60&65535;
       HEAP16[$50>>1] = $61;
       $stackCount$015 = 1;
       while(1) {
        $62 = (($stackCount$015) + -1)|0;
        $63 = (($41) + ($62<<2)|0);
        $64 = HEAP32[$63>>2]|0;
        __ZN8b2Island3AddEP6b2Body($island,$64);
        __ZN6b2Body8SetAwakeEb($64,1);
        $65 = (__ZNK6b2Body7GetTypeEv($64)|0);
        $66 = ($65|0)==(0);
        if ($66) {
         $stackCount$0$be = $62;
        } else {
         $68 = (($64) + 128|0);
         $ce$02 = HEAP32[$68>>2]|0;
         $69 = ($ce$02|0)==(0|0);
         if ($69) {
          $stackCount$1$lcssa = $62;
         } else {
          $ce$04 = $ce$02;$stackCount$13 = $62;
          while(1) {
           $70 = (($ce$04) + 4|0);
           $71 = HEAP32[$70>>2]|0;
           $72 = (($71) + 4|0);
           $73 = HEAP32[$72>>2]|0;
           $74 = $73 & 1;
           $75 = ($74|0)==(0);
           do {
            if ($75) {
             $76 = (__ZNK9b2Contact9IsEnabledEv($71)|0);
             if (!($76)) {
              $stackCount$2 = $stackCount$13;
              break;
             }
             $77 = (__ZNK9b2Contact10IsTouchingEv($71)|0);
             if (!($77)) {
              $stackCount$2 = $stackCount$13;
              break;
             }
             $78 = (($71) + 48|0);
             $79 = HEAP32[$78>>2]|0;
             $80 = (($79) + 38|0);
             $81 = HEAP8[$80>>0]|0;
             $82 = ($81<<24>>24)==(0);
             if (!($82)) {
              $stackCount$2 = $stackCount$13;
              break;
             }
             $83 = (($71) + 52|0);
             $84 = HEAP32[$83>>2]|0;
             $85 = (($84) + 38|0);
             $86 = HEAP8[$85>>0]|0;
             $87 = ($86<<24>>24)==(0);
             if (!($87)) {
              $stackCount$2 = $stackCount$13;
              break;
             }
             __ZN8b2Island3AddEP9b2Contact($island,$71);
             $88 = HEAP32[$72>>2]|0;
             $89 = $88 | 1;
             HEAP32[$72>>2] = $89;
             $90 = HEAP32[$ce$04>>2]|0;
             $91 = (($90) + 4|0);
             $92 = HEAP16[$91>>1]|0;
             $93 = $92 & 1;
             $94 = ($93<<16>>16)==(0);
             if (!($94)) {
              $stackCount$2 = $stackCount$13;
              break;
             }
             $95 = (($stackCount$13) + 1)|0;
             $96 = (($41) + ($stackCount$13<<2)|0);
             HEAP32[$96>>2] = $90;
             $97 = HEAP16[$91>>1]|0;
             $98 = $97&65535;
             $99 = $98 | 1;
             $100 = $99&65535;
             HEAP16[$91>>1] = $100;
             $stackCount$2 = $95;
            } else {
             $stackCount$2 = $stackCount$13;
            }
           } while(0);
           $101 = (($ce$04) + 12|0);
           $ce$0 = HEAP32[$101>>2]|0;
           $102 = ($ce$0|0)==(0|0);
           if ($102) {
            $stackCount$1$lcssa = $stackCount$2;
            break;
           } else {
            $ce$04 = $ce$0;$stackCount$13 = $stackCount$2;
           }
          }
         }
         $103 = (($64) + 124|0);
         $je$09 = HEAP32[$103>>2]|0;
         $104 = ($je$09|0)==(0|0);
         if ($104) {
          $stackCount$0$be = $stackCount$1$lcssa;
         } else {
          $je$011 = $je$09;$stackCount$310 = $stackCount$1$lcssa;
          while(1) {
           $105 = (($je$011) + 4|0);
           $106 = HEAP32[$105>>2]|0;
           $107 = (($106) + 60|0);
           $108 = HEAP8[$107>>0]|0;
           $109 = ($108<<24>>24)==(0);
           do {
            if ($109) {
             $110 = HEAP32[$je$011>>2]|0;
             $111 = (__ZNK6b2Body8IsActiveEv($110)|0);
             if (!($111)) {
              $stackCount$4 = $stackCount$310;
              break;
             }
             __ZN8b2Island3AddEP7b2Joint($island,$106);
             $112 = HEAP32[$105>>2]|0;
             $113 = (($112) + 60|0);
             HEAP8[$113>>0] = 1;
             $114 = (($110) + 4|0);
             $115 = HEAP16[$114>>1]|0;
             $116 = $115 & 1;
             $117 = ($116<<16>>16)==(0);
             if (!($117)) {
              $stackCount$4 = $stackCount$310;
              break;
             }
             $118 = (($stackCount$310) + 1)|0;
             $119 = (($41) + ($stackCount$310<<2)|0);
             HEAP32[$119>>2] = $110;
             $120 = HEAP16[$114>>1]|0;
             $121 = $120&65535;
             $122 = $121 | 1;
             $123 = $122&65535;
             HEAP16[$114>>1] = $123;
             $stackCount$4 = $118;
            } else {
             $stackCount$4 = $stackCount$310;
            }
           } while(0);
           $124 = (($je$011) + 12|0);
           $je$0 = HEAP32[$124>>2]|0;
           $125 = ($je$0|0)==(0|0);
           if ($125) {
            $stackCount$0$be = $stackCount$4;
            break;
           } else {
            $je$011 = $je$0;$stackCount$310 = $stackCount$4;
           }
          }
         }
        }
        $67 = ($stackCount$0$be|0)>(0);
        if ($67) {
         $stackCount$015 = $stackCount$0$be;
        } else {
         break;
        }
       }
       $126 = HEAP8[$44>>0]|0;
       $127 = ($126<<24>>24)!=(0);
       __ZN8b2Island5SolveEP9b2ProfileRK10b2TimeStepRK6b2Vec2b($island,$profile,$step,$43,$127);
       $128 = +HEAPF32[$45>>2];
       $129 = +HEAPF32[$6>>2];
       $130 = $128 + $129;
       HEAPF32[$6>>2] = $130;
       $131 = +HEAPF32[$46>>2];
       $132 = +HEAPF32[$7>>2];
       $133 = $131 + $132;
       HEAPF32[$7>>2] = $133;
       $134 = +HEAPF32[$47>>2];
       $135 = +HEAPF32[$8>>2];
       $136 = $134 + $135;
       HEAPF32[$8>>2] = $136;
       $137 = HEAP32[$48>>2]|0;
       $138 = ($137|0)>(0);
       if ($138) {
        $i$017 = 0;
        while(1) {
         $139 = HEAP32[$49>>2]|0;
         $140 = (($139) + ($i$017<<2)|0);
         $141 = HEAP32[$140>>2]|0;
         $142 = (__ZNK6b2Body7GetTypeEv($141)|0);
         $143 = ($142|0)==(0);
         if ($143) {
          $144 = (($141) + 4|0);
          $145 = HEAP16[$144>>1]|0;
          $146 = $145&65535;
          $147 = $146 & 65534;
          $148 = $147&65535;
          HEAP16[$144>>1] = $148;
         }
         $149 = (($i$017) + 1)|0;
         $150 = HEAP32[$48>>2]|0;
         $151 = ($149|0)<($150|0);
         if ($151) {
          $i$017 = $149;
         } else {
          break;
         }
        }
       }
      }
     }
    }
   }
   $152 = (($seed$024) + 112|0);
   $seed$0 = HEAP32[$152>>2]|0;
   $153 = ($seed$0|0)==(0|0);
   if ($153) {
    break;
   } else {
    $seed$024 = $seed$0;
   }
  }
 }
 __ZN16b2StackAllocator4FreeEPv($16,$41);
 __ZN7b2TimerC2Ev($timer);
 $154 = HEAP32[$0>>2]|0;
 $155 = ($154|0)==(0|0);
 if ($155) {
  __ZN16b2ContactManager15FindNewContactsEv($11);
  $164 = (+__ZNK7b2Timer15GetMillisecondsEv($timer));
  $165 = (($this) + 103032|0);
  HEAPF32[$165>>2] = $164;
  __ZN8b2IslandD2Ev($island);
  STACKTOP = sp;return;
 } else {
  $b5$01 = $154;
 }
 while(1) {
  $156 = (($b5$01) + 4|0);
  $157 = HEAP16[$156>>1]|0;
  $158 = $157 & 1;
  $159 = ($158<<16>>16)==(0);
  if (!($159)) {
   $160 = (__ZNK6b2Body7GetTypeEv($b5$01)|0);
   $161 = ($160|0)==(0);
   if (!($161)) {
    __ZN6b2Body19SynchronizeFixturesEv($b5$01);
   }
  }
  $162 = (__ZN6b2Body7GetNextEv($b5$01)|0);
  $163 = ($162|0)==(0|0);
  if ($163) {
   break;
  } else {
   $b5$01 = $162;
  }
 }
 __ZN16b2ContactManager15FindNewContactsEv($11);
 $164 = (+__ZNK7b2Timer15GetMillisecondsEv($timer));
 $165 = (($this) + 103032|0);
 HEAPF32[$165>>2] = $164;
 __ZN8b2IslandD2Ev($island);
 STACKTOP = sp;return;
}
function __ZN7b2World8SolveTOIERK10b2TimeStep($this,$step) {
 $this = $this|0;
 $step = $step|0;
 var $$ = 0, $$2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0.0;
 var $187 = 0.0, $188 = 0.0, $189 = 0.0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0.0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0.0, $8 = 0, $80 = 0, $81 = 0, $82 = 0.0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $alpha$0 = 0.0, $alpha$1 = 0.0, $alpha0$0 = 0.0, $b$0 = 0, $b$042 = 0, $b$043 = 0, $backup = 0, $backup1 = 0, $backup2 = 0, $bodies = 0, $brmerge = 0, $brmerge3 = 0, $c$0 = 0, $c$038 = 0, $c$039 = 0, $c1$0 = 0;
 var $c1$06 = 0, $c1$09 = 0, $ce$0 = 0, $ce$016 = 0, $ce$017 = 0, $ce8$0 = 0, $ce8$022 = 0, $ce8$023 = 0, $i$020 = 0, $i6$028 = 0, $input = 0, $island = 0, $minAlpha$07 = 0.0, $minAlpha$1 = 0.0, $minContact$08 = 0, $minContact$1 = 0, $or$cond = 0, $output = 0, $subStep = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 336|0;
 $island = sp + 284|0;
 $input = sp + 152|0;
 $output = sp + 144|0;
 $backup1 = sp + 108|0;
 $backup2 = sp + 72|0;
 $bodies = sp + 64|0;
 $backup = sp + 28|0;
 $subStep = sp;
 $0 = (($this) + 76|0);
 $1 = (($this) + 102880|0);
 $2 = (($this) + 102952|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN8b2IslandC2EiiiP16b2StackAllocatorP17b2ContactListener($island,64,32,0,$0,$3);
 $4 = (($this) + 103007|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if (!($6)) {
  $7 = (($this) + 102960|0);
  $b$042 = HEAP32[$7>>2]|0;
  $8 = ($b$042|0)==(0|0);
  if (!($8)) {
   $b$043 = $b$042;
   while(1) {
    $9 = (($b$043) + 4|0);
    $10 = HEAP16[$9>>1]|0;
    $11 = $10&65535;
    $12 = $11 & 65534;
    $13 = $12&65535;
    HEAP16[$9>>1] = $13;
    $14 = (($b$043) + 76|0);
    HEAPF32[$14>>2] = 0.0;
    $15 = (($b$043) + 112|0);
    $b$0 = HEAP32[$15>>2]|0;
    $16 = ($b$0|0)==(0|0);
    if ($16) {
     break;
    } else {
     $b$043 = $b$0;
    }
   }
  }
  $17 = (($this) + 102940|0);
  $c$038 = HEAP32[$17>>2]|0;
  $18 = ($c$038|0)==(0|0);
  if (!($18)) {
   $c$039 = $c$038;
   while(1) {
    $41 = (($c$039) + 4|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = $42 & -34;
    HEAP32[$41>>2] = $43;
    $44 = (($c$039) + 128|0);
    HEAP32[$44>>2] = 0;
    $45 = (($c$039) + 132|0);
    HEAPF32[$45>>2] = 1.0;
    $46 = (($c$039) + 12|0);
    $c$0 = HEAP32[$46>>2]|0;
    $47 = ($c$0|0)==(0|0);
    if ($47) {
     break;
    } else {
     $c$039 = $c$0;
    }
   }
  }
 }
 $19 = (($this) + 102940|0);
 $20 = (($bodies) + 4|0);
 $21 = (($island) + 28|0);
 $22 = (($island) + 40|0);
 $23 = (($island) + 36|0);
 $24 = (($island) + 44|0);
 $25 = (($subStep) + 4|0);
 $26 = (($subStep) + 8|0);
 $27 = (($subStep) + 16|0);
 $28 = (($step) + 12|0);
 $29 = (($subStep) + 12|0);
 $30 = (($step) + 20|0);
 $31 = (($subStep) + 20|0);
 $32 = (($subStep) + 24|0);
 $33 = (($island) + 28|0);
 $34 = (($this) + 103006|0);
 $35 = (($island) + 8|0);
 $36 = (($input) + 28|0);
 $37 = (($input) + 56|0);
 $38 = (($input) + 92|0);
 $39 = (($input) + 128|0);
 $40 = (($output) + 4|0);
 while(1) {
  $c1$06 = HEAP32[$19>>2]|0;
  $48 = ($c1$06|0)==(0|0);
  if ($48) {
   label = 27;
   break;
  } else {
   $c1$09 = $c1$06;$minAlpha$07 = 1.0;$minContact$08 = 0;
  }
  while(1) {
   $49 = (__ZNK9b2Contact9IsEnabledEv($c1$09)|0);
   do {
    if ($49) {
     $50 = (($c1$09) + 128|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)>(8);
     if ($52) {
      $minAlpha$1 = $minAlpha$07;$minContact$1 = $minContact$08;
     } else {
      $53 = (($c1$09) + 4|0);
      $54 = HEAP32[$53>>2]|0;
      $55 = $54 & 32;
      $56 = ($55|0)==(0);
      if ($56) {
       $59 = (__ZN9b2Contact11GetFixtureAEv($c1$09)|0);
       $60 = (__ZN9b2Contact11GetFixtureBEv($c1$09)|0);
       $61 = (__ZNK9b2Fixture8IsSensorEv($59)|0);
       if ($61) {
        $minAlpha$1 = $minAlpha$07;$minContact$1 = $minContact$08;
        break;
       }
       $62 = (__ZNK9b2Fixture8IsSensorEv($60)|0);
       if ($62) {
        $minAlpha$1 = $minAlpha$07;$minContact$1 = $minContact$08;
        break;
       }
       $63 = (__ZN9b2Fixture7GetBodyEv($59)|0);
       $64 = (__ZN9b2Fixture7GetBodyEv($60)|0);
       $65 = HEAP32[$63>>2]|0;
       $66 = HEAP32[$64>>2]|0;
       $67 = (__ZNK6b2Body7IsAwakeEv($63)|0);
       $68 = ($65|0)!=(0);
       $$ = $67 & $68;
       $69 = (__ZNK6b2Body7IsAwakeEv($64)|0);
       $70 = ($66|0)!=(0);
       $71 = $69 & $70;
       $brmerge = $$ | $71;
       if (!($brmerge)) {
        $minAlpha$1 = $minAlpha$07;$minContact$1 = $minContact$08;
        break;
       }
       $72 = (__ZNK6b2Body8IsBulletEv($63)|0);
       $73 = ($65|0)!=(2);
       $$2 = $72 | $73;
       $74 = (__ZNK6b2Body8IsBulletEv($64)|0);
       $75 = ($66|0)!=(2);
       $76 = $74 | $75;
       $brmerge3 = $$2 | $76;
       if (!($brmerge3)) {
        $minAlpha$1 = $minAlpha$07;$minContact$1 = $minContact$08;
        break;
       }
       $77 = (($63) + 44|0);
       $78 = (($63) + 76|0);
       $79 = +HEAPF32[$78>>2];
       $80 = (($64) + 44|0);
       $81 = (($64) + 76|0);
       $82 = +HEAPF32[$81>>2];
       $83 = $79 < $82;
       if ($83) {
        __ZN7b2Sweep7AdvanceEf($77,$82);
        $alpha0$0 = $82;
       } else {
        $84 = $82 < $79;
        if ($84) {
         __ZN7b2Sweep7AdvanceEf($80,$79);
         $alpha0$0 = $79;
        } else {
         $alpha0$0 = $79;
        }
       }
       $85 = (__ZNK9b2Contact14GetChildIndexAEv($c1$09)|0);
       $86 = (__ZNK9b2Contact14GetChildIndexBEv($c1$09)|0);
       __ZN10b2TOIInputC2Ev($input);
       $87 = (__ZN9b2Fixture8GetShapeEv($59)|0);
       __ZN15b2DistanceProxy3SetEPK7b2Shapei($input,$87,$85);
       $88 = (__ZN9b2Fixture8GetShapeEv($60)|0);
       __ZN15b2DistanceProxy3SetEPK7b2Shapei($36,$88,$86);
       dest=$37+0|0; src=$77+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       dest=$38+0|0; src=$80+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
       HEAPF32[$39>>2] = 1.0;
       __Z14b2TimeOfImpactP11b2TOIOutputPK10b2TOIInput($output,$input);
       $89 = HEAP32[$output>>2]|0;
       $90 = ($89|0)==(3);
       if ($90) {
        $91 = +HEAPF32[$40>>2];
        $92 = 1.0 - $alpha0$0;
        $93 = $92 * $91;
        $94 = $alpha0$0 + $93;
        $95 = (+__Z5b2MinIfET_S0_S0_($94,1.0));
        $alpha$0 = $95;
       } else {
        $alpha$0 = 1.0;
       }
       $96 = (($c1$09) + 132|0);
       HEAPF32[$96>>2] = $alpha$0;
       $97 = HEAP32[$53>>2]|0;
       $98 = $97 | 32;
       HEAP32[$53>>2] = $98;
       $alpha$1 = $alpha$0;
      } else {
       $57 = (($c1$09) + 132|0);
       $58 = +HEAPF32[$57>>2];
       $alpha$1 = $58;
      }
      $99 = $alpha$1 < $minAlpha$07;
      if ($99) {
       $minAlpha$1 = $alpha$1;$minContact$1 = $c1$09;
      } else {
       $minAlpha$1 = $minAlpha$07;$minContact$1 = $minContact$08;
      }
     }
    } else {
     $minAlpha$1 = $minAlpha$07;$minContact$1 = $minContact$08;
    }
   } while(0);
   $100 = (($c1$09) + 12|0);
   $c1$0 = HEAP32[$100>>2]|0;
   $101 = ($c1$0|0)==(0|0);
   if ($101) {
    break;
   } else {
    $c1$09 = $c1$0;$minAlpha$07 = $minAlpha$1;$minContact$08 = $minContact$1;
   }
  }
  $102 = ($minContact$1|0)==(0|0);
  $103 = $minAlpha$1 > 0.99999880790710449;
  $or$cond = $102 | $103;
  if ($or$cond) {
   label = 27;
   break;
  }
  $104 = (__ZN9b2Contact11GetFixtureAEv($minContact$1)|0);
  $105 = (__ZN9b2Contact11GetFixtureBEv($minContact$1)|0);
  $106 = (__ZN9b2Fixture7GetBodyEv($104)|0);
  $107 = (__ZN9b2Fixture7GetBodyEv($105)|0);
  $108 = (($106) + 44|0);
  dest=$backup1+0|0; src=$108+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $109 = (($107) + 44|0);
  dest=$backup2+0|0; src=$109+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  __ZN6b2Body7AdvanceEf($106,$minAlpha$1);
  __ZN6b2Body7AdvanceEf($107,$minAlpha$1);
  $110 = HEAP32[$2>>2]|0;
  __ZN9b2Contact6UpdateEP17b2ContactListener($minContact$1,$110);
  $111 = (($minContact$1) + 4|0);
  $112 = HEAP32[$111>>2]|0;
  $113 = $112 & -33;
  HEAP32[$111>>2] = $113;
  $114 = (($minContact$1) + 128|0);
  $115 = HEAP32[$114>>2]|0;
  $116 = (($115) + 1)|0;
  HEAP32[$114>>2] = $116;
  $117 = (__ZNK9b2Contact9IsEnabledEv($minContact$1)|0);
  if ($117) {
   $118 = (__ZNK9b2Contact10IsTouchingEv($minContact$1)|0);
   if ($118) {
    __ZN6b2Body8SetAwakeEb($106,1);
    __ZN6b2Body8SetAwakeEb($107,1);
    __ZN8b2Island5ClearEv($island);
    __ZN8b2Island3AddEP6b2Body($island,$106);
    __ZN8b2Island3AddEP6b2Body($island,$107);
    __ZN8b2Island3AddEP9b2Contact($island,$minContact$1);
    $119 = (($106) + 4|0);
    $120 = HEAP16[$119>>1]|0;
    $121 = $120&65535;
    $122 = $121 | 1;
    $123 = $122&65535;
    HEAP16[$119>>1] = $123;
    $124 = (($107) + 4|0);
    $125 = HEAP16[$124>>1]|0;
    $126 = $125&65535;
    $127 = $126 | 1;
    $128 = $127&65535;
    HEAP16[$124>>1] = $128;
    $129 = HEAP32[$111>>2]|0;
    $130 = $129 | 1;
    HEAP32[$111>>2] = $130;
    HEAP32[$bodies>>2] = $106;
    HEAP32[$20>>2] = $107;
    $i$020 = 0;
    while(1) {
     $131 = (($bodies) + ($i$020<<2)|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = HEAP32[$132>>2]|0;
     $134 = ($133|0)==(2);
     L42: do {
      if ($134) {
       $135 = (($132) + 128|0);
       $ce$016 = HEAP32[$135>>2]|0;
       $136 = ($ce$016|0)==(0|0);
       if (!($136)) {
        $ce$017 = $ce$016;
        while(1) {
         $137 = HEAP32[$21>>2]|0;
         $138 = HEAP32[$22>>2]|0;
         $139 = ($137|0)==($138|0);
         if ($139) {
          break L42;
         }
         $140 = HEAP32[$23>>2]|0;
         $141 = HEAP32[$24>>2]|0;
         $142 = ($140|0)==($141|0);
         if ($142) {
          break L42;
         }
         $143 = (($ce$017) + 4|0);
         $144 = HEAP32[$143>>2]|0;
         $145 = (($144) + 4|0);
         $146 = HEAP32[$145>>2]|0;
         $147 = $146 & 1;
         $148 = ($147|0)==(0);
         do {
          if ($148) {
           $149 = HEAP32[$ce$017>>2]|0;
           $150 = HEAP32[$149>>2]|0;
           $151 = ($150|0)==(2);
           if ($151) {
            $152 = (__ZNK6b2Body8IsBulletEv($132)|0);
            if (!($152)) {
             $153 = (__ZNK6b2Body8IsBulletEv($149)|0);
             if (!($153)) {
              break;
             }
            }
           }
           $154 = (($144) + 48|0);
           $155 = HEAP32[$154>>2]|0;
           $156 = (($155) + 38|0);
           $157 = HEAP8[$156>>0]|0;
           $158 = ($157<<24>>24)==(0);
           if ($158) {
            $159 = (($144) + 52|0);
            $160 = HEAP32[$159>>2]|0;
            $161 = (($160) + 38|0);
            $162 = HEAP8[$161>>0]|0;
            $163 = ($162<<24>>24)==(0);
            if ($163) {
             $164 = (($149) + 44|0);
             dest=$backup+0|0; src=$164+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
             $165 = (($149) + 4|0);
             $166 = HEAP16[$165>>1]|0;
             $167 = $166 & 1;
             $168 = ($167<<16>>16)==(0);
             if ($168) {
              __ZN6b2Body7AdvanceEf($149,$minAlpha$1);
             }
             $169 = HEAP32[$2>>2]|0;
             __ZN9b2Contact6UpdateEP17b2ContactListener($144,$169);
             $170 = (__ZNK9b2Contact9IsEnabledEv($144)|0);
             if (!($170)) {
              dest=$164+0|0; src=$backup+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
              __ZN6b2Body20SynchronizeTransformEv($149);
              break;
             }
             $171 = (__ZNK9b2Contact10IsTouchingEv($144)|0);
             if (!($171)) {
              dest=$164+0|0; src=$backup+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
              __ZN6b2Body20SynchronizeTransformEv($149);
              break;
             }
             $172 = HEAP32[$145>>2]|0;
             $173 = $172 | 1;
             HEAP32[$145>>2] = $173;
             __ZN8b2Island3AddEP9b2Contact($island,$144);
             $174 = HEAP16[$165>>1]|0;
             $175 = $174&65535;
             $176 = $175 & 1;
             $177 = ($176|0)==(0);
             if (!($177)) {
              break;
             }
             $178 = $175 | 1;
             $179 = $178&65535;
             HEAP16[$165>>1] = $179;
             $180 = HEAP32[$149>>2]|0;
             $181 = ($180|0)==(0);
             if (!($181)) {
              __ZN6b2Body8SetAwakeEb($149,1);
             }
             __ZN8b2Island3AddEP6b2Body($island,$149);
            }
           }
          }
         } while(0);
         $182 = (($ce$017) + 12|0);
         $ce$0 = HEAP32[$182>>2]|0;
         $183 = ($ce$0|0)==(0|0);
         if ($183) {
          break;
         } else {
          $ce$017 = $ce$0;
         }
        }
       }
      }
     } while(0);
     $184 = (($i$020) + 1)|0;
     $185 = ($184|0)<(2);
     if ($185) {
      $i$020 = $184;
     } else {
      break;
     }
    }
    $186 = 1.0 - $minAlpha$1;
    $187 = +HEAPF32[$step>>2];
    $188 = $186 * $187;
    HEAPF32[$subStep>>2] = $188;
    $189 = 1.0 / $188;
    HEAPF32[$25>>2] = $189;
    HEAPF32[$26>>2] = 1.0;
    HEAP32[$27>>2] = 20;
    $190 = HEAP32[$28>>2]|0;
    HEAP32[$29>>2] = $190;
    $191 = HEAP32[$30>>2]|0;
    HEAP32[$31>>2] = $191;
    HEAP8[$32>>0] = 0;
    $192 = (($106) + 8|0);
    $193 = HEAP32[$192>>2]|0;
    $194 = (($107) + 8|0);
    $195 = HEAP32[$194>>2]|0;
    __ZN8b2Island8SolveTOIERK10b2TimeStepii($island,$subStep,$193,$195);
    $196 = HEAP32[$33>>2]|0;
    $197 = ($196|0)>(0);
    if ($197) {
     $i6$028 = 0;
     while(1) {
      $198 = HEAP32[$35>>2]|0;
      $199 = (($198) + ($i6$028<<2)|0);
      $200 = HEAP32[$199>>2]|0;
      $201 = (($200) + 4|0);
      $202 = HEAP16[$201>>1]|0;
      $203 = $202&65535;
      $204 = $203 & 65534;
      $205 = $204&65535;
      HEAP16[$201>>1] = $205;
      $206 = HEAP32[$200>>2]|0;
      $207 = ($206|0)==(2);
      if ($207) {
       __ZN6b2Body19SynchronizeFixturesEv($200);
       $208 = (($200) + 128|0);
       $ce8$022 = HEAP32[$208>>2]|0;
       $209 = ($ce8$022|0)==(0|0);
       if (!($209)) {
        $ce8$023 = $ce8$022;
        while(1) {
         $210 = (($ce8$023) + 4|0);
         $211 = HEAP32[$210>>2]|0;
         $212 = (($211) + 4|0);
         $213 = HEAP32[$212>>2]|0;
         $214 = $213 & -34;
         HEAP32[$212>>2] = $214;
         $215 = (($ce8$023) + 12|0);
         $ce8$0 = HEAP32[$215>>2]|0;
         $216 = ($ce8$0|0)==(0|0);
         if ($216) {
          break;
         } else {
          $ce8$023 = $ce8$0;
         }
        }
       }
      }
      $217 = (($i6$028) + 1)|0;
      $218 = HEAP32[$33>>2]|0;
      $219 = ($217|0)<($218|0);
      if ($219) {
       $i6$028 = $217;
      } else {
       break;
      }
     }
    }
    __ZN16b2ContactManager15FindNewContactsEv($1);
    $220 = HEAP8[$34>>0]|0;
    $221 = ($220<<24>>24)==(0);
    if ($221) {
     continue;
    } else {
     label = 60;
     break;
    }
   }
  }
  __ZN9b2Contact10SetEnabledEb($minContact$1,0);
  dest=$108+0|0; src=$backup1+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$109+0|0; src=$backup2+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  __ZN6b2Body20SynchronizeTransformEv($106);
  __ZN6b2Body20SynchronizeTransformEv($107);
 }
 if ((label|0) == 27) {
  HEAP8[$4>>0] = 1;
  __ZN8b2IslandD2Ev($island);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 60) {
  HEAP8[$4>>0] = 0;
  __ZN8b2IslandD2Ev($island);
  STACKTOP = sp;return;
 }
}
function __ZN7b2World4StepEfiii($this,$dt,$velocityIterations,$positionIterations,$particleIterations) {
 $this = $this|0;
 $dt = +$dt;
 $velocityIterations = $velocityIterations|0;
 $positionIterations = $positionIterations|0;
 $particleIterations = $particleIterations|0;
 var $$pr = 0.0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0.0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0.0;
 var $44 = 0, $45 = 0, $46 = 0.0, $47 = 0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0.0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond3 = 0, $p$04 = 0;
 var $step = 0, $stepTimer = 0, $timer = 0, $timer1 = 0, $timer2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $stepTimer = sp + 24|0;
 $step = sp + 32|0;
 $timer = sp + 16|0;
 $timer1 = sp + 8|0;
 $timer2 = sp;
 __ZN7b2TimerC2Ev($stepTimer);
 $0 = (($this) + 102876|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 1;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $4 = (($this) + 102880|0);
  __ZN16b2ContactManager15FindNewContactsEv($4);
  $5 = HEAP32[$0>>2]|0;
  $6 = $5 & -2;
  HEAP32[$0>>2] = $6;
 }
 $7 = HEAP32[$0>>2]|0;
 $8 = $7 | 2;
 HEAP32[$0>>2] = $8;
 HEAPF32[$step>>2] = $dt;
 $9 = (($step) + 12|0);
 HEAP32[$9>>2] = $velocityIterations;
 $10 = (($step) + 16|0);
 HEAP32[$10>>2] = $positionIterations;
 $11 = (($step) + 20|0);
 HEAP32[$11>>2] = $particleIterations;
 $12 = $dt > 0.0;
 if ($12) {
  $13 = 1.0 / $dt;
  $14 = (($step) + 4|0);
  HEAPF32[$14>>2] = $13;
 } else {
  $15 = (($step) + 4|0);
  HEAPF32[$15>>2] = 0.0;
 }
 $16 = (($this) + 103000|0);
 $17 = +HEAPF32[$16>>2];
 $18 = $17 * $dt;
 $19 = (($step) + 8|0);
 HEAPF32[$19>>2] = $18;
 $20 = (($this) + 103004|0);
 $21 = HEAP8[$20>>0]|0;
 $22 = (($step) + 24|0);
 HEAP8[$22>>0] = $21;
 __ZN7b2TimerC2Ev($timer);
 $23 = (($this) + 102880|0);
 __ZN16b2ContactManager7CollideEv($23);
 $24 = (+__ZNK7b2Timer15GetMillisecondsEv($timer));
 $25 = (($this) + 103012|0);
 HEAPF32[$25>>2] = $24;
 $26 = (($this) + 103007|0);
 $27 = HEAP8[$26>>0]|0;
 $28 = ($27<<24>>24)!=(0);
 $29 = +HEAPF32[$step>>2];
 $30 = $29 > 0.0;
 $or$cond = $28 & $30;
 if ($or$cond) {
  __ZN7b2TimerC2Ev($timer1);
  $31 = (($this) + 102968|0);
  $32 = HEAP32[$31>>2]|0;
  $33 = ($32|0)==(0|0);
  if (!($33)) {
   $p$04 = $32;
   while(1) {
    __ZN16b2ParticleSystem5SolveERK10b2TimeStep($p$04,$step);
    $34 = (__ZN16b2ParticleSystem7GetNextEv($p$04)|0);
    $35 = ($34|0)==(0|0);
    if ($35) {
     break;
    } else {
     $p$04 = $34;
    }
   }
  }
  __ZN7b2World5SolveERK10b2TimeStep($this,$step);
  $36 = (+__ZNK7b2Timer15GetMillisecondsEv($timer1));
  $37 = (($this) + 103016|0);
  HEAPF32[$37>>2] = $36;
 }
 $38 = (($this) + 103005|0);
 $39 = HEAP8[$38>>0]|0;
 $40 = ($39<<24>>24)!=(0);
 $41 = +HEAPF32[$step>>2];
 $42 = $41 > 0.0;
 $or$cond3 = $40 & $42;
 if ($or$cond3) {
  __ZN7b2TimerC2Ev($timer2);
  __ZN7b2World8SolveTOIERK10b2TimeStep($this,$step);
  $43 = (+__ZNK7b2Timer15GetMillisecondsEv($timer2));
  $44 = (($this) + 103036|0);
  HEAPF32[$44>>2] = $43;
  $$pr = +HEAPF32[$step>>2];
  $46 = $$pr;
 } else {
  $46 = $41;
 }
 $45 = $46 > 0.0;
 if ($45) {
  $47 = (($step) + 4|0);
  $48 = +HEAPF32[$47>>2];
  HEAPF32[$16>>2] = $48;
 }
 $49 = HEAP32[$0>>2]|0;
 $50 = $49 & 4;
 $51 = ($50|0)==(0);
 if ($51) {
  $52 = HEAP32[$0>>2]|0;
  $53 = $52 & -3;
  HEAP32[$0>>2] = $53;
  $54 = (+__ZNK7b2Timer15GetMillisecondsEv($stepTimer));
  $55 = (($this) + 103008|0);
  HEAPF32[$55>>2] = $54;
  STACKTOP = sp;return;
 }
 __ZN7b2World11ClearForcesEv($this);
 $52 = HEAP32[$0>>2]|0;
 $53 = $52 & -3;
 HEAP32[$0>>2] = $53;
 $54 = (+__ZNK7b2Timer15GetMillisecondsEv($stepTimer));
 $55 = (($this) + 103008|0);
 HEAPF32[$55>>2] = $54;
 STACKTOP = sp;return;
}
function __ZN7b2World11ClearForcesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $body$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 102960|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 } else {
  $body$01 = $1;
 }
 while(1) {
  $3 = (($body$01) + 92|0);
  __ZN6b2Vec27SetZeroEv($3);
  $4 = (($body$01) + 100|0);
  HEAPF32[$4>>2] = 0.0;
  $5 = (__ZN6b2Body7GetNextEv($body$01)|0);
  $6 = ($5|0)==(0|0);
  if ($6) {
   break;
  } else {
   $body$01 = $5;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK7b2World9QueryAABBEP15b2QueryCallbackRK6b2AABB($this,$callback,$aabb) {
 $this = $this|0;
 $callback = $callback|0;
 $aabb = $aabb|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$01 = 0, $wrapper = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $wrapper = sp;
 $0 = (($this) + 102880|0);
 HEAP32[$wrapper>>2] = $0;
 $1 = (($wrapper) + 4|0);
 HEAP32[$1>>2] = $callback;
 __ZNK12b2BroadPhase5QueryI19b2WorldQueryWrapperEEvPT_RK6b2AABB($0,$wrapper,$aabb);
 $2 = (($this) + 102968|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $p$01 = $3;
 while(1) {
  $5 = HEAP32[$callback>>2]|0;
  $6 = (($5) + 16|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (FUNCTION_TABLE_iii[$7 & 63]($callback,$p$01)|0);
  if ($8) {
   __ZNK16b2ParticleSystem9QueryAABBEP15b2QueryCallbackRK6b2AABB($p$01,$callback,$aabb);
  }
  $9 = (__ZN16b2ParticleSystem7GetNextEv($p$01)|0);
  $10 = ($9|0)==(0|0);
  if ($10) {
   break;
  } else {
   $p$01 = $9;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK7b2World7RayCastEP17b2RayCastCallbackRK6b2Vec2S4_($this,$callback,$point1,$point2) {
 $this = $this|0;
 $callback = $callback|0;
 $point1 = $point1|0;
 $point2 = $point2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $input = 0, $p$01 = 0, $wrapper = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $wrapper = sp + 24|0;
 $input = sp;
 $0 = (($this) + 102880|0);
 HEAP32[$wrapper>>2] = $0;
 $1 = (($wrapper) + 4|0);
 HEAP32[$1>>2] = $callback;
 $2 = (($input) + 16|0);
 HEAPF32[$2>>2] = 1.0;
 $3 = $point1;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $input;
 $10 = $9;
 HEAP32[$10>>2] = $5;
 $11 = (($9) + 4)|0;
 $12 = $11;
 HEAP32[$12>>2] = $8;
 $13 = (($input) + 8|0);
 $14 = $point2;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14) + 4)|0;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = $13;
 $21 = $20;
 HEAP32[$21>>2] = $16;
 $22 = (($20) + 4)|0;
 $23 = $22;
 HEAP32[$23>>2] = $19;
 __ZNK12b2BroadPhase7RayCastI21b2WorldRayCastWrapperEEvPT_RK14b2RayCastInput($0,$wrapper,$input);
 $24 = (($this) + 102968|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = ($25|0)==(0|0);
 if ($26) {
  STACKTOP = sp;return;
 }
 $p$01 = $25;
 while(1) {
  $27 = HEAP32[$callback>>2]|0;
  $28 = (($27) + 16|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = (FUNCTION_TABLE_iii[$29 & 63]($callback,$p$01)|0);
  if ($30) {
   __ZNK16b2ParticleSystem7RayCastEP17b2RayCastCallbackRK6b2Vec2S4_($p$01,$callback,$point1,$point2);
  }
  $31 = (__ZN16b2ParticleSystem7GetNextEv($p$01)|0);
  $32 = ($31|0)==(0|0);
  if ($32) {
   break;
  } else {
   $p$01 = $31;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ContactManagerD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12b2BroadPhaseD2Ev($this);
 STACKTOP = sp;return;
}
function __ZNK7b2World8IsLockedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 102876|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2;
 $3 = ($2|0)!=(0);
 STACKTOP = sp;return ($3|0);
}
function __ZN8b2Island5ClearEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 36|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 32|0);
 HEAP32[$2>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN8b2Island3AddEP6b2Body($this,$body) {
 $this = $this|0;
 $body = $body|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($body) + 8|0);
 HEAP32[$2>>2] = $1;
 $3 = HEAP32[$0>>2]|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($3<<2)|0);
 HEAP32[$6>>2] = $body;
 $7 = HEAP32[$0>>2]|0;
 $8 = (($7) + 1)|0;
 HEAP32[$0>>2] = $8;
 STACKTOP = sp;return;
}
function __ZNK9b2Contact9IsEnabledEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 4;
 $3 = ($2|0)!=(0);
 STACKTOP = sp;return ($3|0);
}
function __ZNK9b2Contact10IsTouchingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 2;
 $3 = ($2|0)!=(0);
 STACKTOP = sp;return ($3|0);
}
function __ZN8b2Island3AddEP9b2Contact($this,$contact) {
 $this = $this|0;
 $contact = $contact|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1)|0;
 HEAP32[$0>>2] = $2;
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($1<<2)|0);
 HEAP32[$5>>2] = $contact;
 STACKTOP = sp;return;
}
function __ZN8b2Island3AddEP7b2Joint($this,$joint) {
 $this = $this|0;
 $joint = $joint|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1)|0;
 HEAP32[$0>>2] = $2;
 $3 = (($this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($1<<2)|0);
 HEAP32[$5>>2] = $joint;
 STACKTOP = sp;return;
}
function __ZN6b2Body7GetNextEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 112|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK6b2Body8IsBulletEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = $1 & 8;
 $3 = ($2<<16>>16)!=(0);
 STACKTOP = sp;return ($3|0);
}
function __ZN7b2Sweep7AdvanceEf($this,$alpha) {
 $this = $this|0;
 $alpha = +$alpha;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $2 = 0, $3 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = (($this) + 32|0);
 $3 = +HEAPF32[$2>>2];
 $4 = $alpha - $3;
 $5 = 1.0 - $3;
 $6 = $4 / $5;
 $7 = (($this) + 8|0);
 $8 = (($this) + 16|0);
 __ZmiRK6b2Vec2S1_($1,$8,$7);
 __ZmlfRK6b2Vec2($0,$6,$1);
 __ZN6b2Vec2pLERKS_($7,$0);
 $9 = (($this) + 28|0);
 $10 = +HEAPF32[$9>>2];
 $11 = (($this) + 24|0);
 $12 = +HEAPF32[$11>>2];
 $13 = $10 - $12;
 $14 = $6 * $13;
 $15 = $12 + $14;
 HEAPF32[$11>>2] = $15;
 HEAPF32[$2>>2] = $alpha;
 STACKTOP = sp;return;
}
function __ZNK9b2Contact14GetChildIndexAEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 56|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK9b2Contact14GetChildIndexBEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN10b2TOIInputC2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN15b2DistanceProxyC2Ev($this);
 $0 = (($this) + 28|0);
 __ZN15b2DistanceProxyC2Ev($0);
 STACKTOP = sp;return;
}
function __ZN6b2Body7AdvanceEf($this,$alpha) {
 $this = $this|0;
 $alpha = +$alpha;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = sp + 8|0;
 $2 = (($this) + 44|0);
 __ZN7b2Sweep7AdvanceEf($2,$alpha);
 $3 = (($this) + 60|0);
 $4 = (($this) + 52|0);
 $5 = $4;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $3;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 $15 = (($this) + 68|0);
 $16 = +HEAPF32[$15>>2];
 $17 = (($this) + 72|0);
 HEAPF32[$17>>2] = $16;
 $18 = (($this) + 20|0);
 __ZN5b2Rot3SetEf($18,$16);
 $19 = (($this) + 12|0);
 __Z5b2MulRK5b2RotRK6b2Vec2($1,$18,$2);
 __ZmiRK6b2Vec2S1_($0,$3,$1);
 $20 = $0;
 $21 = $20;
 $22 = HEAP32[$21>>2]|0;
 $23 = (($20) + 4)|0;
 $24 = $23;
 $25 = HEAP32[$24>>2]|0;
 $26 = $19;
 $27 = $26;
 HEAP32[$27>>2] = $22;
 $28 = (($26) + 4)|0;
 $29 = $28;
 HEAP32[$29>>2] = $25;
 STACKTOP = sp;return;
}
function __ZN9b2Contact10SetEnabledEb($this,$flag) {
 $this = $this|0;
 $flag = $flag|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & -5;
 $3 = $1 | 4;
 $storemerge = $flag ? $3 : $2;
 HEAP32[$0>>2] = $storemerge;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem7GetNextEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 408|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK12b2BroadPhase5QueryI19b2WorldQueryWrapperEEvPT_RK6b2AABB($this,$callback,$aabb) {
 $this = $this|0;
 $callback = $callback|0;
 $aabb = $aabb|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNK13b2DynamicTree5QueryI19b2WorldQueryWrapperEEvPT_RK6b2AABB($this,$callback,$aabb);
 STACKTOP = sp;return;
}
function __ZNK12b2BroadPhase7RayCastI21b2WorldRayCastWrapperEEvPT_RK14b2RayCastInput($this,$callback,$input) {
 $this = $this|0;
 $callback = $callback|0;
 $input = $input|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNK13b2DynamicTree7RayCastI21b2WorldRayCastWrapperEEvPT_RK14b2RayCastInput($this,$callback,$input);
 STACKTOP = sp;return;
}
function __ZN9b2Contact7GetNextEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK13b2DynamicTree5QueryI19b2WorldQueryWrapperEEvPT_RK6b2AABB($this,$callback,$aabb) {
 $this = $this|0;
 $callback = $callback|0;
 $aabb = $aabb|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $stack = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1040|0;
 $stack = sp;
 __ZN15b2GrowableStackIiLi256EEC2Ev($stack);
 __ZN15b2GrowableStackIiLi256EE4PushERKi($stack,$this);
 $0 = (__ZN15b2GrowableStackIiLi256EE8GetCountEv($stack)|0);
 $1 = ($0|0)>(0);
 if (!($1)) {
  __ZN15b2GrowableStackIiLi256EED2Ev($stack);
  STACKTOP = sp;return;
 }
 $2 = (($this) + 4|0);
 L4: while(1) {
  $3 = (__ZN15b2GrowableStackIiLi256EE3PopEv($stack)|0);
  $4 = ($3|0)==(-1);
  do {
   if (!($4)) {
    $7 = HEAP32[$2>>2]|0;
    $8 = (($7) + (($3*36)|0)|0);
    $9 = (__Z13b2TestOverlapRK6b2AABBS1_($8,$aabb)|0);
    if ($9) {
     $10 = (__ZNK10b2TreeNode6IsLeafEv($8)|0);
     if ($10) {
      $11 = (__ZN19b2WorldQueryWrapper13QueryCallbackEi($callback,$3)|0);
      if ($11) {
       break;
      } else {
       label = 9;
       break L4;
      }
     } else {
      $12 = ((($7) + (($3*36)|0)|0) + 24|0);
      __ZN15b2GrowableStackIiLi256EE4PushERKi($stack,$12);
      $13 = ((($7) + (($3*36)|0)|0) + 28|0);
      __ZN15b2GrowableStackIiLi256EE4PushERKi($stack,$13);
      break;
     }
    }
   }
  } while(0);
  $5 = (__ZN15b2GrowableStackIiLi256EE8GetCountEv($stack)|0);
  $6 = ($5|0)>(0);
  if (!($6)) {
   label = 9;
   break;
  }
 }
 if ((label|0) == 9) {
  __ZN15b2GrowableStackIiLi256EED2Ev($stack);
  STACKTOP = sp;return;
 }
}
function __ZNK13b2DynamicTree7RayCastI21b2WorldRayCastWrapperEEvPT_RK14b2RayCastInput($this,$callback,$input) {
 $this = $this|0;
 $callback = $callback|0;
 $input = $input|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $abs_v = 0, $c = 0, $h = 0, $maxFraction$0$ph7 = 0.0;
 var $p1 = 0, $p2 = 0, $r = 0, $segmentAABB = 0, $stack = 0, $subInput = 0, $t = 0, $t1 = 0, $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1216|0;
 $p1 = sp + 64|0;
 $p2 = sp + 56|0;
 $r = sp + 1200|0;
 $v = sp + 1192|0;
 $abs_v = sp + 1184|0;
 $segmentAABB = sp + 40|0;
 $t = sp + 1176|0;
 $0 = sp + 1168|0;
 $1 = sp + 1160|0;
 $2 = sp + 32|0;
 $stack = sp + 120|0;
 $c = sp + 112|0;
 $h = sp + 104|0;
 $3 = sp + 96|0;
 $subInput = sp + 8|0;
 $t1 = sp + 88|0;
 $4 = sp + 80|0;
 $5 = sp + 72|0;
 $6 = sp;
 $7 = $input;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 4)|0;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = $p1;
 $14 = $13;
 HEAP32[$14>>2] = $9;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = $12;
 $17 = (($input) + 8|0);
 $18 = $17;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = (($18) + 4)|0;
 $22 = $21;
 $23 = HEAP32[$22>>2]|0;
 $24 = $p2;
 $25 = $24;
 HEAP32[$25>>2] = $20;
 $26 = (($24) + 4)|0;
 $27 = $26;
 HEAP32[$27>>2] = $23;
 __ZmiRK6b2Vec2S1_($r,$p2,$p1);
 (+__ZN6b2Vec29NormalizeEv($r));
 __Z7b2CrossfRK6b2Vec2($v,1.0,$r);
 __Z5b2AbsRK6b2Vec2($abs_v,$v);
 $28 = (($input) + 16|0);
 $29 = +HEAPF32[$28>>2];
 ;HEAP32[$segmentAABB+0>>2]=0|0;HEAP32[$segmentAABB+4>>2]=0|0;HEAP32[$segmentAABB+8>>2]=0|0;HEAP32[$segmentAABB+12>>2]=0|0;
 __ZmiRK6b2Vec2S1_($1,$p2,$p1);
 __ZmlfRK6b2Vec2($0,$29,$1);
 __ZplRK6b2Vec2S1_($t,$p1,$0);
 __Z5b2MinRK6b2Vec2S1_($segmentAABB,$p1,$t);
 $30 = (($segmentAABB) + 8|0);
 __Z5b2MaxRK6b2Vec2S1_($2,$p1,$t);
 $31 = $2;
 $32 = $31;
 $33 = HEAP32[$32>>2]|0;
 $34 = (($31) + 4)|0;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = $30;
 $38 = $37;
 HEAP32[$38>>2] = $33;
 $39 = (($37) + 4)|0;
 $40 = $39;
 HEAP32[$40>>2] = $36;
 __ZN15b2GrowableStackIiLi256EEC2Ev($stack);
 __ZN15b2GrowableStackIiLi256EE4PushERKi($stack,$this);
 $41 = (__ZN15b2GrowableStackIiLi256EE8GetCountEv($stack)|0);
 $42 = ($41|0)>(0);
 if (!($42)) {
  __ZN15b2GrowableStackIiLi256EED2Ev($stack);
  STACKTOP = sp;return;
 }
 $43 = (($this) + 4|0);
 $44 = (($subInput) + 8|0);
 $45 = (($subInput) + 16|0);
 $maxFraction$0$ph7 = $29;
 L4: while(1) {
  L6: while(1) {
   $46 = (__ZN15b2GrowableStackIiLi256EE3PopEv($stack)|0);
   $47 = ($46|0)==(-1);
   do {
    if (!($47)) {
     $50 = HEAP32[$43>>2]|0;
     $51 = (($50) + (($46*36)|0)|0);
     $52 = (__Z13b2TestOverlapRK6b2AABBS1_($51,$segmentAABB)|0);
     if ($52) {
      __ZNK6b2AABB9GetCenterEv($c,$51);
      __ZNK6b2AABB10GetExtentsEv($h,$51);
      __ZmiRK6b2Vec2S1_($3,$p1,$c);
      $53 = (+__Z5b2DotRK6b2Vec2S1_($v,$3));
      $54 = (+__Z5b2AbsIfET_S0_($53));
      $55 = (+__Z5b2DotRK6b2Vec2S1_($abs_v,$h));
      $56 = $54 - $55;
      $57 = $56 > 0.0;
      if (!($57)) {
       $58 = (__ZNK10b2TreeNode6IsLeafEv($51)|0);
       if (!($58)) {
        $94 = ((($50) + (($46*36)|0)|0) + 24|0);
        __ZN15b2GrowableStackIiLi256EE4PushERKi($stack,$94);
        $95 = ((($50) + (($46*36)|0)|0) + 28|0);
        __ZN15b2GrowableStackIiLi256EE4PushERKi($stack,$95);
        break;
       }
       ;HEAP32[$subInput+0>>2]=0|0;HEAP32[$subInput+4>>2]=0|0;HEAP32[$subInput+8>>2]=0|0;HEAP32[$subInput+12>>2]=0|0;
       $59 = $input;
       $60 = $59;
       $61 = HEAP32[$60>>2]|0;
       $62 = (($59) + 4)|0;
       $63 = $62;
       $64 = HEAP32[$63>>2]|0;
       $65 = $subInput;
       $66 = $65;
       HEAP32[$66>>2] = $61;
       $67 = (($65) + 4)|0;
       $68 = $67;
       HEAP32[$68>>2] = $64;
       $69 = $17;
       $70 = $69;
       $71 = HEAP32[$70>>2]|0;
       $72 = (($69) + 4)|0;
       $73 = $72;
       $74 = HEAP32[$73>>2]|0;
       $75 = $44;
       $76 = $75;
       HEAP32[$76>>2] = $71;
       $77 = (($75) + 4)|0;
       $78 = $77;
       HEAP32[$78>>2] = $74;
       HEAPF32[$45>>2] = $maxFraction$0$ph7;
       $79 = (+__ZN21b2WorldRayCastWrapper15RayCastCallbackERK14b2RayCastInputi($callback,$subInput,$46));
       $80 = $79 == 0.0;
       if ($80) {
        label = 13;
        break L4;
       }
       $81 = $79 > 0.0;
       if ($81) {
        break L6;
       }
      }
     }
    }
   } while(0);
   $48 = (__ZN15b2GrowableStackIiLi256EE8GetCountEv($stack)|0);
   $49 = ($48|0)>(0);
   if (!($49)) {
    label = 13;
    break L4;
   }
  }
  __ZmiRK6b2Vec2S1_($5,$p2,$p1);
  __ZmlfRK6b2Vec2($4,$79,$5);
  __ZplRK6b2Vec2S1_($t1,$p1,$4);
  __Z5b2MinRK6b2Vec2S1_($segmentAABB,$p1,$t1);
  __Z5b2MaxRK6b2Vec2S1_($6,$p1,$t1);
  $82 = $6;
  $83 = $82;
  $84 = HEAP32[$83>>2]|0;
  $85 = (($82) + 4)|0;
  $86 = $85;
  $87 = HEAP32[$86>>2]|0;
  $88 = $30;
  $89 = $88;
  HEAP32[$89>>2] = $84;
  $90 = (($88) + 4)|0;
  $91 = $90;
  HEAP32[$91>>2] = $87;
  $92 = (__ZN15b2GrowableStackIiLi256EE8GetCountEv($stack)|0);
  $93 = ($92|0)>(0);
  if ($93) {
   $maxFraction$0$ph7 = $79;
  } else {
   label = 13;
   break;
  }
 }
 if ((label|0) == 13) {
  __ZN15b2GrowableStackIiLi256EED2Ev($stack);
  STACKTOP = sp;return;
 }
}
function __ZNK13b2DynamicTree10GetFatAABBEi($this,$proxyId) {
 $this = $this|0;
 $proxyId = $proxyId|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + (($proxyId*36)|0)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN15b2GrowableStackIiLi256EEC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP32[$this>>2] = $0;
 $1 = (($this) + 1028|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 1032|0);
 HEAP32[$2>>2] = 256;
 STACKTOP = sp;return;
}
function __ZN15b2GrowableStackIiLi256EE4PushERKi($this,$element) {
 $this = $this|0;
 $element = $element|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1028|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 1032|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  $5 = HEAP32[$this>>2]|0;
  $6 = $3 << 1;
  HEAP32[$2>>2] = $6;
  $7 = $3 << 3;
  $8 = (__Z7b2Alloci($7)|0);
  HEAP32[$this>>2] = $8;
  $9 = HEAP32[$0>>2]|0;
  $10 = $9 << 2;
  _memcpy(($8|0),($5|0),($10|0))|0;
  $11 = (($this) + 4|0);
  $12 = ($5|0)==($11|0);
  if (!($12)) {
   __Z6b2FreePv($5);
  }
 }
 $13 = HEAP32[$element>>2]|0;
 $14 = HEAP32[$0>>2]|0;
 $15 = HEAP32[$this>>2]|0;
 $16 = (($15) + ($14<<2)|0);
 HEAP32[$16>>2] = $13;
 $17 = HEAP32[$0>>2]|0;
 $18 = (($17) + 1)|0;
 HEAP32[$0>>2] = $18;
 STACKTOP = sp;return;
}
function __ZN15b2GrowableStackIiLi256EE8GetCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1028|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN15b2GrowableStackIiLi256EE3PopEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 1028|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 HEAP32[$0>>2] = $2;
 $3 = HEAP32[$this>>2]|0;
 $4 = (($3) + ($2<<2)|0);
 $5 = HEAP32[$4>>2]|0;
 STACKTOP = sp;return ($5|0);
}
function __ZN15b2GrowableStackIiLi256EED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = ($0|0)==($1|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 __Z6b2FreePv($0);
 HEAP32[$this>>2] = 0;
 STACKTOP = sp;return;
}
function __Z13b2TestOverlapRK6b2AABBS1_($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, $not$or$cond5 = 0, $or$cond = 0, $or$cond4 = 0, $or$cond5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = (($a) + 8|0);
 __ZmiRK6b2Vec2S1_($0,$b,$2);
 $3 = $0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (HEAP32[tempDoublePtr>>2]=$5,+HEAPF32[tempDoublePtr>>2]);
 $10 = (HEAP32[tempDoublePtr>>2]=$8,+HEAPF32[tempDoublePtr>>2]);
 $11 = (($b) + 8|0);
 __ZmiRK6b2Vec2S1_($1,$a,$11);
 $12 = $1;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = (($12) + 4)|0;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (HEAP32[tempDoublePtr>>2]=$14,+HEAPF32[tempDoublePtr>>2]);
 $19 = (HEAP32[tempDoublePtr>>2]=$17,+HEAPF32[tempDoublePtr>>2]);
 $20 = $9 > 0.0;
 $21 = $10 > 0.0;
 $or$cond = $20 | $21;
 $22 = $18 > 0.0;
 $or$cond4 = $or$cond | $22;
 $23 = $19 > 0.0;
 $or$cond5 = $or$cond4 | $23;
 $not$or$cond5 = $or$cond5 ^ 1;
 STACKTOP = sp;return ($not$or$cond5|0);
}
function __ZN19b2WorldQueryWrapper13QueryCallbackEi($this,$proxyId) {
 $this = $this|0;
 $proxyId = $proxyId|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (__ZNK12b2BroadPhase11GetUserDataEi($0,$proxyId)|0);
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($1) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (FUNCTION_TABLE_iii[$6 & 63]($3,$8)|0);
 STACKTOP = sp;return ($9|0);
}
function __ZNK6b2AABB9GetCenterEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 __ZplRK6b2Vec2S1_($0,$this,$1);
 __ZmlfRK6b2Vec2($agg$result,0.5,$0);
 STACKTOP = sp;return;
}
function __ZNK6b2AABB10GetExtentsEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 8|0);
 __ZmiRK6b2Vec2S1_($0,$1,$this);
 __ZmlfRK6b2Vec2($agg$result,0.5,$0);
 STACKTOP = sp;return;
}
function __ZN21b2WorldRayCastWrapper15RayCastCallbackERK14b2RayCastInputi($this,$input,$proxyId) {
 $this = $this|0;
 $input = $input|0;
 $proxyId = $proxyId|0;
 var $$0 = 0.0, $0 = 0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0.0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $output = 0, $point = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $output = sp + 24|0;
 $point = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = HEAP32[$this>>2]|0;
 $3 = (__ZNK12b2BroadPhase11GetUserDataEi($2,$proxyId)|0);
 $4 = (($3) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__ZNK9b2Fixture7RayCastEP15b2RayCastOutputRK14b2RayCastInputi($5,$output,$input,$7)|0);
 if ($8) {
  $9 = (($output) + 8|0);
  $10 = +HEAPF32[$9>>2];
  $11 = 1.0 - $10;
  __ZmlfRK6b2Vec2($0,$11,$input);
  $12 = (($input) + 8|0);
  __ZmlfRK6b2Vec2($1,$10,$12);
  __ZplRK6b2Vec2S1_($point,$0,$1);
  $13 = (($this) + 4|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = HEAP32[$14>>2]|0;
  $16 = (($15) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (+FUNCTION_TABLE_diiiid[$17 & 1]($14,$5,$point,$output,$10));
  $$0 = $18;
  STACKTOP = sp;return (+$$0);
 } else {
  $19 = (($input) + 16|0);
  $20 = +HEAPF32[$19>>2];
  $$0 = $20;
  STACKTOP = sp;return (+$$0);
 }
 return +(0.0);
}
function __ZNK12b2BroadPhase11GetUserDataEi($this,$proxyId) {
 $this = $this|0;
 $proxyId = $proxyId|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK13b2DynamicTree11GetUserDataEi($this,$proxyId)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNK9b2Fixture7RayCastEP15b2RayCastOutputRK14b2RayCastInputi($this,$output,$input,$childIndex) {
 $this = $this|0;
 $output = $output|0;
 $input = $input|0;
 $childIndex = $childIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__ZNK6b2Body12GetTransformEv($6)|0);
 $8 = (FUNCTION_TABLE_iiiiii[$4 & 15]($1,$output,$input,$7,$childIndex)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZNK13b2DynamicTree11GetUserDataEi($this,$proxyId) {
 $this = $this|0;
 $proxyId = $proxyId|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1) + (($proxyId*36)|0)|0) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($3|0);
}
function __ZN6b2BodyC2EPK9b2BodyDefP7b2World($this,$bd,$world) {
 $this = $this|0;
 $bd = $bd|0;
 $world = $world|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0, $103 = 0.0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0.0, $74 = 0, $75 = 0.0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0.0, $95 = 0, $96 = 0, $97 = 0.0, $98 = 0, $99 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = (($this) + 28|0);
 $2 = (($this) + 80|0);
 $3 = (($this) + 92|0);
 $4 = (($this) + 4|0);
 $5 = (($bd) + 39|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 $$ = $7 ? 0 : 8;
 HEAP16[$4>>1] = $$;
 $8 = (($bd) + 38|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 if (!($10)) {
  $11 = $$&65535;
  $12 = $11 | 16;
  $13 = $12&65535;
  HEAP16[$4>>1] = $13;
 }
 $14 = (($bd) + 36|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = ($15<<24>>24)==(0);
 if (!($16)) {
  $17 = HEAP16[$4>>1]|0;
  $18 = $17&65535;
  $19 = $18 | 4;
  $20 = $19&65535;
  HEAP16[$4>>1] = $20;
 }
 $21 = (($bd) + 37|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($22<<24>>24)==(0);
 if (!($23)) {
  $24 = HEAP16[$4>>1]|0;
  $25 = $24&65535;
  $26 = $25 | 2;
  $27 = $26&65535;
  HEAP16[$4>>1] = $27;
 }
 $28 = (($bd) + 40|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = ($29<<24>>24)==(0);
 if (!($30)) {
  $31 = HEAP16[$4>>1]|0;
  $32 = $31&65535;
  $33 = $32 | 32;
  $34 = $33&65535;
  HEAP16[$4>>1] = $34;
 }
 $35 = (($this) + 104|0);
 HEAP32[$35>>2] = $world;
 $36 = (($bd) + 4|0);
 $37 = $36;
 $38 = $37;
 $39 = HEAP32[$38>>2]|0;
 $40 = (($37) + 4)|0;
 $41 = $40;
 $42 = HEAP32[$41>>2]|0;
 $43 = $0;
 $44 = $43;
 HEAP32[$44>>2] = $39;
 $45 = (($43) + 4)|0;
 $46 = $45;
 HEAP32[$46>>2] = $42;
 $47 = (($this) + 20|0);
 $48 = (($bd) + 12|0);
 $49 = +HEAPF32[$48>>2];
 __ZN5b2Rot3SetEf($47,$49);
 ;HEAP32[$1+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$0+12>>2]|0;
 $50 = (($this) + 44|0);
 __ZN6b2Vec27SetZeroEv($50);
 $51 = (($this) + 52|0);
 $52 = $0;
 $53 = $52;
 $54 = HEAP32[$53>>2]|0;
 $55 = (($52) + 4)|0;
 $56 = $55;
 $57 = HEAP32[$56>>2]|0;
 $58 = $51;
 $59 = $58;
 HEAP32[$59>>2] = $54;
 $60 = (($58) + 4)|0;
 $61 = $60;
 HEAP32[$61>>2] = $57;
 $62 = (($this) + 60|0);
 $63 = $0;
 $64 = $63;
 $65 = HEAP32[$64>>2]|0;
 $66 = (($63) + 4)|0;
 $67 = $66;
 $68 = HEAP32[$67>>2]|0;
 $69 = $62;
 $70 = $69;
 HEAP32[$70>>2] = $65;
 $71 = (($69) + 4)|0;
 $72 = $71;
 HEAP32[$72>>2] = $68;
 $73 = +HEAPF32[$48>>2];
 $74 = (($this) + 68|0);
 HEAPF32[$74>>2] = $73;
 $75 = +HEAPF32[$48>>2];
 $76 = (($this) + 72|0);
 HEAPF32[$76>>2] = $75;
 $77 = (($this) + 76|0);
 HEAPF32[$77>>2] = 0.0;
 $78 = (($this) + 124|0);
 HEAP32[$78>>2] = 0;
 $79 = (($this) + 128|0);
 HEAP32[$79>>2] = 0;
 $80 = (($this) + 108|0);
 HEAP32[$80>>2] = 0;
 $81 = (($this) + 112|0);
 HEAP32[$81>>2] = 0;
 $82 = (($bd) + 16|0);
 $83 = $82;
 $84 = $83;
 $85 = HEAP32[$84>>2]|0;
 $86 = (($83) + 4)|0;
 $87 = $86;
 $88 = HEAP32[$87>>2]|0;
 $89 = $2;
 $90 = $89;
 HEAP32[$90>>2] = $85;
 $91 = (($89) + 4)|0;
 $92 = $91;
 HEAP32[$92>>2] = $88;
 $93 = (($bd) + 24|0);
 $94 = +HEAPF32[$93>>2];
 $95 = (($this) + 88|0);
 HEAPF32[$95>>2] = $94;
 $96 = (($bd) + 28|0);
 $97 = +HEAPF32[$96>>2];
 $98 = (($this) + 148|0);
 HEAPF32[$98>>2] = $97;
 $99 = (($bd) + 32|0);
 $100 = +HEAPF32[$99>>2];
 $101 = (($this) + 152|0);
 HEAPF32[$101>>2] = $100;
 $102 = (($bd) + 48|0);
 $103 = +HEAPF32[$102>>2];
 $104 = (($this) + 156|0);
 HEAPF32[$104>>2] = $103;
 __ZN6b2Vec27SetZeroEv($3);
 $105 = (($this) + 100|0);
 HEAPF32[$105>>2] = 0.0;
 $106 = (($this) + 160|0);
 HEAPF32[$106>>2] = 0.0;
 $107 = HEAP32[$bd>>2]|0;
 HEAP32[$this>>2] = $107;
 $108 = ($107|0)==(2);
 $109 = (($this) + 132|0);
 if ($108) {
  HEAPF32[$109>>2] = 1.0;
  $110 = (($this) + 136|0);
  HEAPF32[$110>>2] = 1.0;
  $112 = (($this) + 140|0);
  HEAPF32[$112>>2] = 0.0;
  $113 = (($this) + 144|0);
  HEAPF32[$113>>2] = 0.0;
  $114 = (($bd) + 44|0);
  $115 = HEAP32[$114>>2]|0;
  $116 = (($this) + 164|0);
  HEAP32[$116>>2] = $115;
  $117 = (($this) + 116|0);
  HEAP32[$117>>2] = 0;
  $118 = (($this) + 120|0);
  HEAP32[$118>>2] = 0;
  STACKTOP = sp;return;
 } else {
  HEAPF32[$109>>2] = 0.0;
  $111 = (($this) + 136|0);
  HEAPF32[$111>>2] = 0.0;
  $112 = (($this) + 140|0);
  HEAPF32[$112>>2] = 0.0;
  $113 = (($this) + 144|0);
  HEAPF32[$113>>2] = 0.0;
  $114 = (($bd) + 44|0);
  $115 = HEAP32[$114>>2]|0;
  $116 = (($this) + 164|0);
  HEAP32[$116>>2] = $115;
  $117 = (($this) + 116|0);
  HEAP32[$117>>2] = 0;
  $118 = (($this) + 120|0);
  HEAP32[$118>>2] = 0;
  STACKTOP = sp;return;
 }
}
function __ZN6b2BodyD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN6b2Body7SetTypeE10b2BodyType($this,$type) {
 $this = $this|0;
 $type = $type|0;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ce$06 = 0, $exitcond = 0, $f$0 = 0, $f$02 = 0, $f$03 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK7b2World8IsLockedEv($1)|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = HEAP32[$this>>2]|0;
 $4 = ($3|0)==($type|0);
 if ($4) {
  STACKTOP = sp;return;
 }
 HEAP32[$this>>2] = $type;
 __ZN6b2Body13ResetMassDataEv($this);
 $5 = HEAP32[$this>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $7 = (($this) + 80|0);
  __ZN6b2Vec27SetZeroEv($7);
  $8 = (($this) + 88|0);
  HEAPF32[$8>>2] = 0.0;
  $9 = (($this) + 72|0);
  $10 = +HEAPF32[$9>>2];
  $11 = (($this) + 68|0);
  HEAPF32[$11>>2] = $10;
  $12 = (($this) + 52|0);
  $13 = (($this) + 60|0);
  $14 = $13;
  $15 = $14;
  $16 = HEAP32[$15>>2]|0;
  $17 = (($14) + 4)|0;
  $18 = $17;
  $19 = HEAP32[$18>>2]|0;
  $20 = $12;
  $21 = $20;
  HEAP32[$21>>2] = $16;
  $22 = (($20) + 4)|0;
  $23 = $22;
  HEAP32[$23>>2] = $19;
  __ZN6b2Body19SynchronizeFixturesEv($this);
 }
 __ZN6b2Body8SetAwakeEb($this,1);
 $24 = (($this) + 92|0);
 __ZN6b2Vec27SetZeroEv($24);
 $25 = (($this) + 100|0);
 HEAPF32[$25>>2] = 0.0;
 $26 = (($this) + 128|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(0|0);
 if (!($28)) {
  $ce$06 = $27;
  while(1) {
   $29 = (($ce$06) + 12|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$0>>2]|0;
   $32 = (($31) + 102880|0);
   $33 = (($ce$06) + 4|0);
   $34 = HEAP32[$33>>2]|0;
   __ZN16b2ContactManager7DestroyEP9b2Contact($32,$34);
   $35 = ($30|0)==(0|0);
   if ($35) {
    break;
   } else {
    $ce$06 = $30;
   }
  }
 }
 HEAP32[$26>>2] = 0;
 $36 = HEAP32[$0>>2]|0;
 $37 = (($36) + 102880|0);
 $38 = (($this) + 116|0);
 $f$02 = HEAP32[$38>>2]|0;
 $39 = ($f$02|0)==(0|0);
 if ($39) {
  STACKTOP = sp;return;
 } else {
  $f$03 = $f$02;
 }
 while(1) {
  $40 = (($f$03) + 28|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)>(0);
  if ($42) {
   $43 = (($f$03) + 24|0);
   $i$01 = 0;
   while(1) {
    $44 = HEAP32[$43>>2]|0;
    $45 = ((($44) + (($i$01*28)|0)|0) + 24|0);
    $46 = HEAP32[$45>>2]|0;
    __ZN12b2BroadPhase10TouchProxyEi($37,$46);
    $47 = (($i$01) + 1)|0;
    $exitcond = ($47|0)==($41|0);
    if ($exitcond) {
     break;
    } else {
     $i$01 = $47;
    }
   }
  }
  $48 = (($f$03) + 4|0);
  $f$0 = HEAP32[$48>>2]|0;
  $49 = ($f$0|0)==(0|0);
  if ($49) {
   break;
  } else {
   $f$03 = $f$0;
  }
 }
 STACKTOP = sp;return;
}
function __ZN6b2Body13ResetMassDataEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0.0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0, $63 = 0.0, $64 = 0.0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0.0, $73 = 0.0, $74 = 0.0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $f$0 = 0, $f$03 = 0, $f$04 = 0, $localCenter = 0, $massData = 0;
 var $oldCenter = 0, $storemerge = 0.0, $switch = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $localCenter = sp + 16|0;
 $massData = sp + 48|0;
 $0 = sp + 40|0;
 $oldCenter = sp + 8|0;
 $1 = sp;
 $2 = sp + 32|0;
 $3 = sp + 24|0;
 $4 = (($this) + 132|0);
 $5 = (($this) + 136|0);
 $6 = (($this) + 140|0);
 $7 = (($this) + 144|0);
 $8 = (($this) + 44|0);
 ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;
 __ZN6b2Vec27SetZeroEv($8);
 $9 = HEAP32[$this>>2]|0;
 $switch = ($9>>>0)<(2);
 if ($switch) {
  $10 = (($this) + 52|0);
  $11 = (($this) + 12|0);
  $12 = $11;
  $13 = $12;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 4)|0;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  $18 = $10;
  $19 = $18;
  HEAP32[$19>>2] = $14;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $17;
  $22 = (($this) + 60|0);
  $23 = $11;
  $24 = $23;
  $25 = HEAP32[$24>>2]|0;
  $26 = (($23) + 4)|0;
  $27 = $26;
  $28 = HEAP32[$27>>2]|0;
  $29 = $22;
  $30 = $29;
  HEAP32[$30>>2] = $25;
  $31 = (($29) + 4)|0;
  $32 = $31;
  HEAP32[$32>>2] = $28;
  $33 = (($this) + 72|0);
  $34 = +HEAPF32[$33>>2];
  $35 = (($this) + 68|0);
  HEAPF32[$35>>2] = $34;
  STACKTOP = sp;return;
 }
 $36 = 10224;
 $37 = $36;
 $38 = HEAP32[$37>>2]|0;
 $39 = (($36) + 4)|0;
 $40 = $39;
 $41 = HEAP32[$40>>2]|0;
 $42 = $localCenter;
 $43 = $42;
 HEAP32[$43>>2] = $38;
 $44 = (($42) + 4)|0;
 $45 = $44;
 HEAP32[$45>>2] = $41;
 $46 = (($this) + 116|0);
 $f$03 = HEAP32[$46>>2]|0;
 $47 = ($f$03|0)==(0|0);
 if (!($47)) {
  $48 = (($massData) + 4|0);
  $49 = (($massData) + 12|0);
  $f$04 = $f$03;
  while(1) {
   $50 = +HEAPF32[$f$04>>2];
   $51 = $50 == 0.0;
   if (!($51)) {
    __ZNK9b2Fixture11GetMassDataEP10b2MassData($f$04,$massData);
    $52 = +HEAPF32[$massData>>2];
    $53 = +HEAPF32[$4>>2];
    $54 = $52 + $53;
    HEAPF32[$4>>2] = $54;
    $55 = +HEAPF32[$massData>>2];
    __ZmlfRK6b2Vec2($0,$55,$48);
    __ZN6b2Vec2pLERKS_($localCenter,$0);
    $56 = +HEAPF32[$49>>2];
    $57 = +HEAPF32[$6>>2];
    $58 = $56 + $57;
    HEAPF32[$6>>2] = $58;
   }
   $59 = (($f$04) + 4|0);
   $f$0 = HEAP32[$59>>2]|0;
   $60 = ($f$0|0)==(0|0);
   if ($60) {
    break;
   } else {
    $f$04 = $f$0;
   }
  }
 }
 $61 = +HEAPF32[$4>>2];
 $62 = $61 > 0.0;
 if ($62) {
  $63 = 1.0 / $61;
  HEAPF32[$5>>2] = $63;
  __ZN6b2Vec2mLEf($localCenter,$63);
 } else {
  HEAPF32[$4>>2] = 1.0;
  HEAPF32[$5>>2] = 1.0;
 }
 $64 = +HEAPF32[$6>>2];
 $65 = $64 > 0.0;
 if ($65) {
  $66 = (($this) + 4|0);
  $67 = HEAP16[$66>>1]|0;
  $68 = $67 & 16;
  $69 = ($68<<16>>16)==(0);
  if ($69) {
   $70 = +HEAPF32[$4>>2];
   $71 = (+__Z5b2DotRK6b2Vec2S1_($localCenter,$localCenter));
   $72 = $70 * $71;
   $73 = $64 - $72;
   HEAPF32[$6>>2] = $73;
   $74 = 1.0 / $73;
   $storemerge = $74;
  } else {
   label = 14;
  }
 } else {
  label = 14;
 }
 if ((label|0) == 14) {
  HEAPF32[$6>>2] = 0.0;
  $storemerge = 0.0;
 }
 HEAPF32[$7>>2] = $storemerge;
 $75 = (($this) + 60|0);
 $76 = $75;
 $77 = $76;
 $78 = HEAP32[$77>>2]|0;
 $79 = (($76) + 4)|0;
 $80 = $79;
 $81 = HEAP32[$80>>2]|0;
 $82 = $oldCenter;
 $83 = $82;
 HEAP32[$83>>2] = $78;
 $84 = (($82) + 4)|0;
 $85 = $84;
 HEAP32[$85>>2] = $81;
 $86 = $localCenter;
 $87 = $86;
 $88 = HEAP32[$87>>2]|0;
 $89 = (($86) + 4)|0;
 $90 = $89;
 $91 = HEAP32[$90>>2]|0;
 $92 = $8;
 $93 = $92;
 HEAP32[$93>>2] = $88;
 $94 = (($92) + 4)|0;
 $95 = $94;
 HEAP32[$95>>2] = $91;
 $96 = (($this) + 52|0);
 $97 = (($this) + 12|0);
 __Z5b2MulRK11b2TransformRK6b2Vec2($1,$97,$8);
 $98 = $1;
 $99 = $98;
 $100 = HEAP32[$99>>2]|0;
 $101 = (($98) + 4)|0;
 $102 = $101;
 $103 = HEAP32[$102>>2]|0;
 $104 = $75;
 $105 = $104;
 HEAP32[$105>>2] = $100;
 $106 = (($104) + 4)|0;
 $107 = $106;
 HEAP32[$107>>2] = $103;
 $108 = $96;
 $109 = $108;
 HEAP32[$109>>2] = $100;
 $110 = (($108) + 4)|0;
 $111 = $110;
 HEAP32[$111>>2] = $103;
 $112 = (($this) + 80|0);
 $113 = (($this) + 88|0);
 $114 = +HEAPF32[$113>>2];
 __ZmiRK6b2Vec2S1_($3,$75,$oldCenter);
 __Z7b2CrossfRK6b2Vec2($2,$114,$3);
 __ZN6b2Vec2pLERKS_($112,$2);
 STACKTOP = sp;return;
}
function __ZN6b2Body19SynchronizeFixturesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $f$0 = 0, $f$01 = 0, $f$02 = 0, $xf1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $xf1 = sp;
 $0 = sp + 16|0;
 $1 = (($xf1) + 8|0);
 $2 = (($this) + 68|0);
 $3 = +HEAPF32[$2>>2];
 __ZN5b2Rot3SetEf($1,$3);
 $4 = (($this) + 52|0);
 $5 = (($this) + 44|0);
 __Z5b2MulRK5b2RotRK6b2Vec2($0,$1,$5);
 __ZmiRK6b2Vec2S1_($xf1,$4,$0);
 $6 = (($this) + 104|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 102880|0);
 $9 = (($this) + 116|0);
 $f$01 = HEAP32[$9>>2]|0;
 $10 = ($f$01|0)==(0|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (($this) + 12|0);
 $f$02 = $f$01;
 while(1) {
  __ZN9b2Fixture11SynchronizeEP12b2BroadPhaseRK11b2TransformS4_($f$02,$8,$xf1,$11);
  $12 = (($f$02) + 4|0);
  $f$0 = HEAP32[$12>>2]|0;
  $13 = ($f$0|0)==(0|0);
  if ($13) {
   break;
  } else {
   $f$02 = $f$0;
  }
 }
 STACKTOP = sp;return;
}
function __ZN6b2Body13CreateFixtureEPK12b2FixtureDef($this,$def) {
 $this = $this|0;
 $def = $def|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK7b2World8IsLockedEv($1)|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (__ZN16b2BlockAllocator8AllocateEi($1,44)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  $5 = 0;
 } else {
  __ZN9b2FixtureC2Ev($3);
  $5 = $3;
 }
 __ZN9b2Fixture6CreateEP16b2BlockAllocatorP6b2BodyPK12b2FixtureDef($5,$1,$this,$def);
 $6 = (($this) + 4|0);
 $7 = HEAP16[$6>>1]|0;
 $8 = $7 & 32;
 $9 = ($8<<16>>16)==(0);
 if (!($9)) {
  $10 = HEAP32[$0>>2]|0;
  $11 = (($10) + 102880|0);
  $12 = (($this) + 12|0);
  __ZN9b2Fixture13CreateProxiesEP12b2BroadPhaseRK11b2Transform($5,$11,$12);
 }
 $13 = (($this) + 116|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($5) + 4|0);
 HEAP32[$15>>2] = $14;
 HEAP32[$13>>2] = $5;
 $16 = (($this) + 120|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 1)|0;
 HEAP32[$16>>2] = $18;
 $19 = (($5) + 8|0);
 HEAP32[$19>>2] = $this;
 $20 = +HEAPF32[$5>>2];
 $21 = $20 > 0.0;
 if ($21) {
  __ZN6b2Body13ResetMassDataEv($this);
 }
 $22 = HEAP32[$0>>2]|0;
 $23 = (($22) + 102876|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $24 | 1;
 HEAP32[$23>>2] = $25;
 $$0 = $5;
 STACKTOP = sp;return ($$0|0);
}
function __ZN6b2Body14DestroyFixtureEP9b2Fixture($this,$fixture) {
 $this = $this|0;
 $fixture = $fixture|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $edge$01 = 0, $node$03 = 0;
 var $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK7b2World8IsLockedEv($1)|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 116|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 L4: do {
  if (!($5)) {
   $9 = $4;$node$03 = $3;
   while(1) {
    $10 = ($9|0)==($fixture|0);
    $7 = (($9) + 4|0);
    if ($10) {
     break;
    }
    $6 = HEAP32[$7>>2]|0;
    $8 = ($6|0)==(0|0);
    if ($8) {
     break L4;
    } else {
     $9 = $6;$node$03 = $7;
    }
   }
   $11 = (($fixture) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   HEAP32[$node$03>>2] = $12;
  }
 } while(0);
 $13 = (($this) + 128|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 if (!($15)) {
  $edge$01 = $14;
  while(1) {
   $16 = (($edge$01) + 4|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($edge$01) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (__ZN9b2Contact11GetFixtureAEv($17)|0);
   $21 = (__ZN9b2Contact11GetFixtureBEv($17)|0);
   $22 = ($20|0)==($fixture|0);
   $23 = ($21|0)==($fixture|0);
   $or$cond = $22 | $23;
   if ($or$cond) {
    $24 = HEAP32[$0>>2]|0;
    $25 = (($24) + 102880|0);
    __ZN16b2ContactManager7DestroyEP9b2Contact($25,$17);
   }
   $26 = ($19|0)==(0|0);
   if ($26) {
    break;
   } else {
    $edge$01 = $19;
   }
  }
 }
 $27 = HEAP32[$0>>2]|0;
 $28 = (($this) + 4|0);
 $29 = HEAP16[$28>>1]|0;
 $30 = $29 & 32;
 $31 = ($30<<16>>16)==(0);
 if (!($31)) {
  $32 = (($27) + 102880|0);
  __ZN9b2Fixture14DestroyProxiesEP12b2BroadPhase($fixture,$32);
 }
 __ZN9b2Fixture7DestroyEP16b2BlockAllocator($fixture,$27);
 $33 = (($fixture) + 8|0);
 HEAP32[$33>>2] = 0;
 $34 = (($fixture) + 4|0);
 HEAP32[$34>>2] = 0;
 __ZN16b2BlockAllocator4FreeEPvi($27,$fixture,44);
 $35 = (($this) + 120|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = (($36) + -1)|0;
 HEAP32[$35>>2] = $37;
 __ZN6b2Body13ResetMassDataEv($this);
 STACKTOP = sp;return;
}
function __ZN6b2Body11SetMassDataEPK10b2MassData($this,$massData) {
 $this = $this|0;
 $massData = $massData|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $8 = 0, $9 = 0, $oldCenter = 0, $storemerge = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $oldCenter = sp + 8|0;
 $0 = sp;
 $1 = sp + 24|0;
 $2 = sp + 16|0;
 $3 = (($this) + 104|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZNK7b2World8IsLockedEv($4)|0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$this>>2]|0;
 $7 = ($6|0)==(2);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 136|0);
 $9 = (($this) + 140|0);
 HEAPF32[$9>>2] = 0.0;
 $10 = (($this) + 144|0);
 HEAPF32[$10>>2] = 0.0;
 $11 = +HEAPF32[$massData>>2];
 $12 = (($this) + 132|0);
 $13 = !($11 <= 0.0);
 $storemerge = $13 ? $11 : 1.0;
 HEAPF32[$12>>2] = $storemerge;
 $14 = 1.0 / $storemerge;
 HEAPF32[$8>>2] = $14;
 $15 = (($massData) + 12|0);
 $16 = +HEAPF32[$15>>2];
 $17 = $16 > 0.0;
 if ($17) {
  $18 = (($this) + 4|0);
  $19 = HEAP16[$18>>1]|0;
  $20 = $19 & 16;
  $21 = ($20<<16>>16)==(0);
  if ($21) {
   $22 = +HEAPF32[$12>>2];
   $23 = (($massData) + 4|0);
   $24 = (+__Z5b2DotRK6b2Vec2S1_($23,$23));
   $25 = $22 * $24;
   $26 = $16 - $25;
   HEAPF32[$9>>2] = $26;
   $27 = 1.0 / $26;
   HEAPF32[$10>>2] = $27;
  }
 }
 $28 = (($this) + 44|0);
 $29 = (($this) + 60|0);
 $30 = $29;
 $31 = $30;
 $32 = HEAP32[$31>>2]|0;
 $33 = (($30) + 4)|0;
 $34 = $33;
 $35 = HEAP32[$34>>2]|0;
 $36 = $oldCenter;
 $37 = $36;
 HEAP32[$37>>2] = $32;
 $38 = (($36) + 4)|0;
 $39 = $38;
 HEAP32[$39>>2] = $35;
 $40 = (($massData) + 4|0);
 $41 = $40;
 $42 = $41;
 $43 = HEAP32[$42>>2]|0;
 $44 = (($41) + 4)|0;
 $45 = $44;
 $46 = HEAP32[$45>>2]|0;
 $47 = $28;
 $48 = $47;
 HEAP32[$48>>2] = $43;
 $49 = (($47) + 4)|0;
 $50 = $49;
 HEAP32[$50>>2] = $46;
 $51 = (($this) + 52|0);
 $52 = (($this) + 12|0);
 __Z5b2MulRK11b2TransformRK6b2Vec2($0,$52,$28);
 $53 = $0;
 $54 = $53;
 $55 = HEAP32[$54>>2]|0;
 $56 = (($53) + 4)|0;
 $57 = $56;
 $58 = HEAP32[$57>>2]|0;
 $59 = $29;
 $60 = $59;
 HEAP32[$60>>2] = $55;
 $61 = (($59) + 4)|0;
 $62 = $61;
 HEAP32[$62>>2] = $58;
 $63 = $51;
 $64 = $63;
 HEAP32[$64>>2] = $55;
 $65 = (($63) + 4)|0;
 $66 = $65;
 HEAP32[$66>>2] = $58;
 $67 = (($this) + 80|0);
 $68 = (($this) + 88|0);
 $69 = +HEAPF32[$68>>2];
 __ZmiRK6b2Vec2S1_($2,$29,$oldCenter);
 __Z7b2CrossfRK6b2Vec2($1,$69,$2);
 __ZN6b2Vec2pLERKS_($67,$1);
 STACKTOP = sp;return;
}
function __ZNK6b2Body13ShouldCollideEPKS_($this,$other) {
 $this = $this|0;
 $other = $other|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $jn$0 = 0, $jn$01 = 0, $jn$02 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(2);
 if ($1) {
  label = 3;
 } else {
  $2 = HEAP32[$other>>2]|0;
  $3 = ($2|0)==(2);
  if ($3) {
   label = 3;
  } else {
   $$0 = 0;
  }
 }
 L3: do {
  if ((label|0) == 3) {
   $4 = (($this) + 124|0);
   $jn$01 = HEAP32[$4>>2]|0;
   $5 = ($jn$01|0)==(0|0);
   if ($5) {
    $$0 = 1;
   } else {
    $jn$02 = $jn$01;
    while(1) {
     $6 = HEAP32[$jn$02>>2]|0;
     $7 = ($6|0)==($other|0);
     if ($7) {
      $8 = (($jn$02) + 4|0);
      $9 = HEAP32[$8>>2]|0;
      $10 = (($9) + 61|0);
      $11 = HEAP8[$10>>0]|0;
      $12 = ($11<<24>>24)==(0);
      if ($12) {
       $$0 = 0;
       break L3;
      }
     }
     $13 = (($jn$02) + 12|0);
     $jn$0 = HEAP32[$13>>2]|0;
     $14 = ($jn$0|0)==(0|0);
     if ($14) {
      $$0 = 1;
      break;
     } else {
      $jn$02 = $jn$0;
     }
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN6b2Body12SetTransformERK6b2Vec2f($this,$position,$angle) {
 $this = $this|0;
 $position = $position|0;
 $angle = +$angle;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $f$0 = 0, $f$01 = 0, $f$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 104|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZNK7b2World8IsLockedEv($2)|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 12|0);
 $5 = (($this) + 20|0);
 __ZN5b2Rot3SetEf($5,$angle);
 $6 = $position;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $4;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 $16 = (($this) + 28|0);
 ;HEAP32[$16+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$16+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$16+12>>2]=HEAP32[$4+12>>2]|0;
 $17 = (($this) + 60|0);
 $18 = (($this) + 44|0);
 __Z5b2MulRK11b2TransformRK6b2Vec2($0,$4,$18);
 $19 = $0;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) + 4)|0;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 $25 = $17;
 $26 = $25;
 HEAP32[$26>>2] = $21;
 $27 = (($25) + 4)|0;
 $28 = $27;
 HEAP32[$28>>2] = $24;
 $29 = (($this) + 72|0);
 HEAPF32[$29>>2] = $angle;
 $30 = (($this) + 52|0);
 $31 = $17;
 $32 = $31;
 $33 = HEAP32[$32>>2]|0;
 $34 = (($31) + 4)|0;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = $30;
 $38 = $37;
 HEAP32[$38>>2] = $33;
 $39 = (($37) + 4)|0;
 $40 = $39;
 HEAP32[$40>>2] = $36;
 $41 = (($this) + 68|0);
 HEAPF32[$41>>2] = $angle;
 $42 = HEAP32[$1>>2]|0;
 $43 = (($42) + 102880|0);
 $44 = (($this) + 116|0);
 $f$01 = HEAP32[$44>>2]|0;
 $45 = ($f$01|0)==(0|0);
 if ($45) {
  STACKTOP = sp;return;
 } else {
  $f$02 = $f$01;
 }
 while(1) {
  __ZN9b2Fixture11SynchronizeEP12b2BroadPhaseRK11b2TransformS4_($f$02,$43,$4,$4);
  $46 = (($f$02) + 4|0);
  $f$0 = HEAP32[$46>>2]|0;
  $47 = ($f$0|0)==(0|0);
  if ($47) {
   break;
  } else {
   $f$02 = $f$0;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK9b2Fixture11GetMassDataEP10b2MassData($this,$massData) {
 $this = $this|0;
 $massData = $massData|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = +HEAPF32[$this>>2];
 FUNCTION_TABLE_viid[$4 & 31]($1,$massData,$5);
 STACKTOP = sp;return;
}
function __ZN16b2ContactManagerC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12b2BroadPhaseC2Ev($this);
 $0 = (($this) + 60|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 64|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 68|0);
 HEAP32[$2>>2] = 8224;
 $3 = (($this) + 72|0);
 HEAP32[$3>>2] = 8232;
 $4 = (($this) + 76|0);
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2ContactManager7DestroyEP9b2Contact($this,$c) {
 $this = $this|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN9b2Contact11GetFixtureAEv($c)|0);
 $1 = (__ZN9b2Contact11GetFixtureBEv($c)|0);
 $2 = (__ZN9b2Fixture7GetBodyEv($0)|0);
 $3 = (__ZN9b2Fixture7GetBodyEv($1)|0);
 $4 = (($this) + 72|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = (__ZNK9b2Contact10IsTouchingEv($c)|0);
  if ($7) {
   $8 = HEAP32[$5>>2]|0;
   $9 = (($8) + 12|0);
   $10 = HEAP32[$9>>2]|0;
   FUNCTION_TABLE_vii[$10 & 63]($5,$c);
  }
 }
 $11 = (($c) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = (($c) + 12|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($12) + 12|0);
  HEAP32[$16>>2] = $15;
 }
 $17 = (($c) + 12|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  $20 = HEAP32[$11>>2]|0;
  $21 = (($18) + 8|0);
  HEAP32[$21>>2] = $20;
 }
 $22 = (($this) + 60|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==($c|0);
 if ($24) {
  $25 = HEAP32[$17>>2]|0;
  HEAP32[$22>>2] = $25;
 }
 $26 = (($c) + 16|0);
 $27 = (($c) + 24|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ($28|0)==(0|0);
 if (!($29)) {
  $30 = (($c) + 28|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($28) + 12|0);
  HEAP32[$32>>2] = $31;
 }
 $33 = (($c) + 28|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if (!($35)) {
  $36 = HEAP32[$27>>2]|0;
  $37 = (($34) + 8|0);
  HEAP32[$37>>2] = $36;
 }
 $38 = (($2) + 128|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($26|0)==($39|0);
 if ($40) {
  $41 = HEAP32[$33>>2]|0;
  HEAP32[$38>>2] = $41;
 }
 $42 = (($c) + 32|0);
 $43 = (($c) + 40|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ($44|0)==(0|0);
 if (!($45)) {
  $46 = (($c) + 44|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = (($44) + 12|0);
  HEAP32[$48>>2] = $47;
 }
 $49 = (($c) + 44|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($50|0)==(0|0);
 if (!($51)) {
  $52 = HEAP32[$43>>2]|0;
  $53 = (($50) + 8|0);
  HEAP32[$53>>2] = $52;
 }
 $54 = (($3) + 128|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ($42|0)==($55|0);
 if (!($56)) {
  $58 = (($this) + 76|0);
  $59 = HEAP32[$58>>2]|0;
  __ZN9b2Contact7DestroyEPS_P16b2BlockAllocator($c,$59);
  $60 = (($this) + 64|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = (($61) + -1)|0;
  HEAP32[$60>>2] = $62;
  STACKTOP = sp;return;
 }
 $57 = HEAP32[$49>>2]|0;
 HEAP32[$54>>2] = $57;
 $58 = (($this) + 76|0);
 $59 = HEAP32[$58>>2]|0;
 __ZN9b2Contact7DestroyEPS_P16b2BlockAllocator($c,$59);
 $60 = (($this) + 64|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = (($61) + -1)|0;
 HEAP32[$60>>2] = $62;
 STACKTOP = sp;return;
}
function __ZN16b2ContactManager7CollideEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $c$0$be = 0, $c$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 72|0);
 $4 = (($this) + 68|0);
 $c$01 = $1;
 while(1) {
  $5 = (__ZN9b2Contact11GetFixtureAEv($c$01)|0);
  $6 = (__ZN9b2Contact11GetFixtureBEv($c$01)|0);
  $7 = (__ZNK9b2Contact14GetChildIndexAEv($c$01)|0);
  $8 = (__ZNK9b2Contact14GetChildIndexBEv($c$01)|0);
  $9 = (__ZN9b2Fixture7GetBodyEv($5)|0);
  $10 = (__ZN9b2Fixture7GetBodyEv($6)|0);
  $11 = (($c$01) + 4|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = $12 & 8;
  $14 = ($13|0)==(0);
  do {
   if ($14) {
    label = 11;
   } else {
    $15 = (__ZNK6b2Body13ShouldCollideEPKS_($10,$9)|0);
    if (!($15)) {
     $16 = (__ZN9b2Contact7GetNextEv($c$01)|0);
     __ZN16b2ContactManager7DestroyEP9b2Contact($this,$c$01);
     $c$0$be = $16;
     break;
    }
    $18 = HEAP32[$4>>2]|0;
    $19 = ($18|0)==(0|0);
    if (!($19)) {
     $20 = HEAP32[$18>>2]|0;
     $21 = (($20) + 8|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = (FUNCTION_TABLE_iiii[$22 & 15]($18,$5,$6)|0);
     if (!($23)) {
      $24 = (__ZN9b2Contact7GetNextEv($c$01)|0);
      __ZN16b2ContactManager7DestroyEP9b2Contact($this,$c$01);
      $c$0$be = $24;
      break;
     }
    }
    $25 = HEAP32[$11>>2]|0;
    $26 = $25 & -9;
    HEAP32[$11>>2] = $26;
    label = 11;
   }
  } while(0);
  do {
   if ((label|0) == 11) {
    label = 0;
    $27 = (__ZNK6b2Body7IsAwakeEv($9)|0);
    if ($27) {
     $28 = HEAP32[$9>>2]|0;
     $29 = ($28|0)!=(0);
     $34 = $29;
    } else {
     $34 = 0;
    }
    $30 = (__ZNK6b2Body7IsAwakeEv($10)|0);
    if ($30) {
     $31 = HEAP32[$10>>2]|0;
     $32 = ($31|0)!=(0);
     $33 = $32;
    } else {
     $33 = 0;
    }
    $brmerge = $34 | $33;
    if (!($brmerge)) {
     $35 = (__ZN9b2Contact7GetNextEv($c$01)|0);
     $c$0$be = $35;
     break;
    }
    $36 = (($5) + 24|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ((($37) + (($7*28)|0)|0) + 24|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = (($6) + 24|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ((($41) + (($8*28)|0)|0) + 24|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (__ZNK12b2BroadPhase11TestOverlapEii($this,$39,$43)|0);
    if ($44) {
     $46 = HEAP32[$3>>2]|0;
     __ZN9b2Contact6UpdateEP17b2ContactListener($c$01,$46);
     $47 = (__ZN9b2Contact7GetNextEv($c$01)|0);
     $c$0$be = $47;
     break;
    } else {
     $45 = (__ZN9b2Contact7GetNextEv($c$01)|0);
     __ZN16b2ContactManager7DestroyEP9b2Contact($this,$c$01);
     $c$0$be = $45;
     break;
    }
   }
  } while(0);
  $17 = ($c$0$be|0)==(0|0);
  if ($17) {
   break;
  } else {
   $c$01 = $c$0$be;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ContactManager15FindNewContactsEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12b2BroadPhase11UpdatePairsI16b2ContactManagerEEvPT_($this,$this);
 STACKTOP = sp;return;
}
function __ZN16b2ContactManager7AddPairEPvS0_($this,$proxyUserDataA,$proxyUserDataB) {
 $this = $this|0;
 $proxyUserDataA = $proxyUserDataA|0;
 $proxyUserDataB = $proxyUserDataB|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0, $edge$06 = 0, $or$cond = 0;
 var $or$cond1 = 0, $or$cond2 = 0, $or$cond3 = 0, $or$cond4 = 0, $or$cond5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($proxyUserDataA) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($proxyUserDataB) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($proxyUserDataA) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($proxyUserDataB) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (__ZN9b2Fixture7GetBodyEv($1)|0);
 $9 = (__ZN9b2Fixture7GetBodyEv($3)|0);
 $10 = ($8|0)==($9|0);
 if ($10) {
  STACKTOP = sp;return;
 }
 $11 = (__ZN6b2Body14GetContactListEv($9)|0);
 $12 = ($11|0)==(0|0);
 L4: do {
  if (!($12)) {
   $edge$06 = $11;
   while(1) {
    $13 = HEAP32[$edge$06>>2]|0;
    $14 = ($13|0)==($8|0);
    if ($14) {
     $15 = (($edge$06) + 4|0);
     $16 = HEAP32[$15>>2]|0;
     $17 = (__ZN9b2Contact11GetFixtureAEv($16)|0);
     $18 = (__ZN9b2Contact11GetFixtureBEv($16)|0);
     $19 = (__ZNK9b2Contact14GetChildIndexAEv($16)|0);
     $20 = (__ZNK9b2Contact14GetChildIndexBEv($16)|0);
     $21 = ($17|0)==($1|0);
     $22 = ($18|0)==($3|0);
     $or$cond = $21 & $22;
     $23 = ($19|0)==($5|0);
     $or$cond1 = $or$cond & $23;
     $24 = ($20|0)==($7|0);
     $or$cond2 = $or$cond1 & $24;
     if ($or$cond2) {
      label = 21;
      break;
     }
     $25 = ($17|0)==($3|0);
     $26 = ($18|0)==($1|0);
     $or$cond3 = $25 & $26;
     $27 = ($19|0)==($7|0);
     $or$cond4 = $or$cond3 & $27;
     $28 = ($20|0)==($5|0);
     $or$cond5 = $or$cond4 & $28;
     if ($or$cond5) {
      label = 21;
      break;
     }
    }
    $29 = (($edge$06) + 12|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = ($30|0)==(0|0);
    if ($31) {
     break L4;
    } else {
     $edge$06 = $30;
    }
   }
   if ((label|0) == 21) {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 $32 = (__ZNK6b2Body13ShouldCollideEPKS_($9,$8)|0);
 if (!($32)) {
  STACKTOP = sp;return;
 }
 $33 = (($this) + 68|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 if (!($35)) {
  $36 = HEAP32[$34>>2]|0;
  $37 = (($36) + 8|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (FUNCTION_TABLE_iiii[$38 & 15]($34,$1,$3)|0);
  if (!($39)) {
   STACKTOP = sp;return;
  }
 }
 $40 = (($this) + 76|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = (__ZN9b2Contact6CreateEP9b2FixtureiS1_iP16b2BlockAllocator($1,$5,$3,$7,$41)|0);
 $43 = ($42|0)==(0|0);
 if ($43) {
  STACKTOP = sp;return;
 }
 $44 = (__ZN9b2Contact11GetFixtureAEv($42)|0);
 $45 = (__ZN9b2Contact11GetFixtureBEv($42)|0);
 $46 = (__ZN9b2Fixture7GetBodyEv($44)|0);
 $47 = (__ZN9b2Fixture7GetBodyEv($45)|0);
 $48 = (($42) + 8|0);
 HEAP32[$48>>2] = 0;
 $49 = (($this) + 60|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = (($42) + 12|0);
 HEAP32[$51>>2] = $50;
 $52 = HEAP32[$49>>2]|0;
 $53 = ($52|0)==(0|0);
 if (!($53)) {
  $54 = (($52) + 8|0);
  HEAP32[$54>>2] = $42;
 }
 HEAP32[$49>>2] = $42;
 $55 = (($42) + 16|0);
 $56 = (($42) + 20|0);
 HEAP32[$56>>2] = $42;
 HEAP32[$55>>2] = $47;
 $57 = (($42) + 24|0);
 HEAP32[$57>>2] = 0;
 $58 = (($46) + 128|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($42) + 28|0);
 HEAP32[$60>>2] = $59;
 $61 = HEAP32[$58>>2]|0;
 $62 = ($61|0)==(0|0);
 if (!($62)) {
  $63 = (($61) + 8|0);
  HEAP32[$63>>2] = $55;
 }
 HEAP32[$58>>2] = $55;
 $64 = (($42) + 32|0);
 $65 = (($42) + 36|0);
 HEAP32[$65>>2] = $42;
 HEAP32[$64>>2] = $46;
 $66 = (($42) + 40|0);
 HEAP32[$66>>2] = 0;
 $67 = (($47) + 128|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = (($42) + 44|0);
 HEAP32[$69>>2] = $68;
 $70 = HEAP32[$67>>2]|0;
 $71 = ($70|0)==(0|0);
 if (!($71)) {
  $72 = (($70) + 8|0);
  HEAP32[$72>>2] = $64;
 }
 HEAP32[$67>>2] = $64;
 $73 = (__ZNK9b2Fixture8IsSensorEv($44)|0);
 if (!($73)) {
  $74 = (__ZNK9b2Fixture8IsSensorEv($45)|0);
  if (!($74)) {
   __ZN6b2Body8SetAwakeEb($46,1);
   __ZN6b2Body8SetAwakeEb($47,1);
  }
 }
 $75 = (($this) + 64|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($76) + 1)|0;
 HEAP32[$75>>2] = $77;
 STACKTOP = sp;return;
}
function __ZNK12b2BroadPhase11TestOverlapEii($this,$proxyIdA,$proxyIdB) {
 $this = $this|0;
 $proxyIdA = $proxyIdA|0;
 $proxyIdB = $proxyIdB|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK13b2DynamicTree10GetFatAABBEi($this,$proxyIdA)|0);
 $1 = (__ZNK13b2DynamicTree10GetFatAABBEi($this,$proxyIdB)|0);
 $2 = (__Z13b2TestOverlapRK6b2AABBS1_($0,$1)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12b2BroadPhase11UpdatePairsI16b2ContactManagerEEvPT_($this,$callback) {
 $this = $this|0;
 $callback = $callback|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $i$02 = 0, $i1$01 = 0, $i1$1 = 0, $i1$1$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 52|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)>(0);
 if ($4) {
  $5 = (($this) + 32|0);
  $6 = (($this) + 56|0);
  $i$02 = 0;
  while(1) {
   $7 = HEAP32[$5>>2]|0;
   $8 = (($7) + ($i$02<<2)|0);
   $9 = HEAP32[$8>>2]|0;
   HEAP32[$6>>2] = $9;
   $10 = ($9|0)==(-1);
   if (!($10)) {
    $11 = (__ZNK13b2DynamicTree10GetFatAABBEi($this,$9)|0);
    __ZNK13b2DynamicTree5QueryI12b2BroadPhaseEEvPT_RK6b2AABB($this,$this,$11);
   }
   $12 = (($i$02) + 1)|0;
   $13 = HEAP32[$2>>2]|0;
   $14 = ($12|0)<($13|0);
   if ($14) {
    $i$02 = $12;
   } else {
    break;
   }
  }
 }
 HEAP32[$2>>2] = 0;
 $15 = (($this) + 44|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$1>>2]|0;
 $18 = (($16) + ($17<<3)|0);
 HEAP32[$0>>2] = 26;
 __ZNSt3__16__sortIRPFbRK6b2PairS3_EPS1_EEvT0_S8_T_($16,$18,$0);
 $19 = HEAP32[$1>>2]|0;
 $20 = ($19|0)>(0);
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $i1$01 = 0;
 while(1) {
  $23 = HEAP32[$15>>2]|0;
  $24 = (($23) + ($i1$01<<3)|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (__ZNK13b2DynamicTree11GetUserDataEi($this,$25)|0);
  $27 = ((($23) + ($i1$01<<3)|0) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (__ZNK13b2DynamicTree11GetUserDataEi($this,$28)|0);
  __ZN16b2ContactManager7AddPairEPvS0_($callback,$26,$29);
  $30 = HEAP32[$1>>2]|0;
  $i1$1$in = $i1$01;
  while(1) {
   $i1$1 = (($i1$1$in) + 1)|0;
   $31 = ($i1$1|0)<($30|0);
   if (!($31)) {
    break;
   }
   $32 = HEAP32[$15>>2]|0;
   $33 = (($32) + ($i1$1<<3)|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = HEAP32[$24>>2]|0;
   $36 = ($34|0)==($35|0);
   if (!($36)) {
    break;
   }
   $37 = ((($32) + ($i1$1<<3)|0) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = HEAP32[$27>>2]|0;
   $40 = ($38|0)==($39|0);
   if ($40) {
    $i1$1$in = $i1$1;
   } else {
    break;
   }
  }
  $21 = HEAP32[$1>>2]|0;
  $22 = ($i1$1|0)<($21|0);
  if ($22) {
   $i1$01 = $i1$1;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK13b2DynamicTree5QueryI12b2BroadPhaseEEvPT_RK6b2AABB($this,$callback,$aabb) {
 $this = $this|0;
 $callback = $callback|0;
 $aabb = $aabb|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $stack = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1040|0;
 $stack = sp;
 __ZN15b2GrowableStackIiLi256EEC2Ev($stack);
 __ZN15b2GrowableStackIiLi256EE4PushERKi($stack,$this);
 $0 = (__ZN15b2GrowableStackIiLi256EE8GetCountEv($stack)|0);
 $1 = ($0|0)>(0);
 if (!($1)) {
  __ZN15b2GrowableStackIiLi256EED2Ev($stack);
  STACKTOP = sp;return;
 }
 $2 = (($this) + 4|0);
 L4: while(1) {
  $3 = (__ZN15b2GrowableStackIiLi256EE3PopEv($stack)|0);
  $4 = ($3|0)==(-1);
  do {
   if (!($4)) {
    $7 = HEAP32[$2>>2]|0;
    $8 = (($7) + (($3*36)|0)|0);
    $9 = (__Z13b2TestOverlapRK6b2AABBS1_($8,$aabb)|0);
    if ($9) {
     $10 = (__ZNK10b2TreeNode6IsLeafEv($8)|0);
     if ($10) {
      $11 = (__ZN12b2BroadPhase13QueryCallbackEi($callback,$3)|0);
      if ($11) {
       break;
      } else {
       label = 9;
       break L4;
      }
     } else {
      $12 = ((($7) + (($3*36)|0)|0) + 24|0);
      __ZN15b2GrowableStackIiLi256EE4PushERKi($stack,$12);
      $13 = ((($7) + (($3*36)|0)|0) + 28|0);
      __ZN15b2GrowableStackIiLi256EE4PushERKi($stack,$13);
      break;
     }
    }
   }
  } while(0);
  $5 = (__ZN15b2GrowableStackIiLi256EE8GetCountEv($stack)|0);
  $6 = ($5|0)>(0);
  if (!($6)) {
   label = 9;
   break;
  }
 }
 if ((label|0) == 9) {
  __ZN15b2GrowableStackIiLi256EED2Ev($stack);
  STACKTOP = sp;return;
 }
}
function __Z14b2PairLessThanRK6b2PairS1_($pair1,$pair2) {
 $pair1 = $pair1|0;
 $pair2 = $pair2|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$pair1>>2]|0;
 $1 = HEAP32[$pair2>>2]|0;
 $2 = ($0|0)<($1|0);
 if ($2) {
  $$0 = 1;
 } else {
  $3 = ($0|0)==($1|0);
  if ($3) {
   $4 = (($pair1) + 4|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($pair2) + 4|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($5|0)<($7|0);
   $$0 = $8;
  } else {
   $$0 = 0;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__16__sortIRPFbRK6b2PairS3_EPS1_EEvT0_S8_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__i$05 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0;
 var $__n_swaps$5 = 0, $__n_swaps$6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -8|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 3;
   switch ($4|0) {
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 4:  {
    label = 7;
    break L1;
    break;
   }
   case 5:  {
    label = 8;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 45;
    break L1;
    break;
   }
   default: {
   }
   }
   $37 = ($3|0)<(248);
   if ($37) {
    label = 10;
    break L1;
   }
   $38 = ($3|0)>(7992);
   $39 = (($4|0) / 2)&-1;
   $40 = (($$0) + ($39<<3)|0);
   if ($38) {
    $41 = (($4|0) / 4)&-1;
    $42 = (($$0) + ($41<<3)|0);
    $$sum = (($41) + ($39))|0;
    $43 = (($$0) + ($$sum<<3)|0);
    $44 = (__ZNSt3__17__sort5IRPFbRK6b2PairS3_EPS1_EEjT0_S8_S8_S8_S8_T_($$0,$42,$40,$43,$1,$__comp)|0);
    $__n_swaps$0 = $44;
   } else {
    $45 = (__ZNSt3__17__sort3IRPFbRK6b2PairS3_EPS1_EEjT0_S8_S8_T_($$0,$40,$1,$__comp)|0);
    $__n_swaps$0 = $45;
   }
   $46 = HEAP32[$__comp>>2]|0;
   $47 = (FUNCTION_TABLE_iii[$46 & 63]($$0,$40)|0);
   do {
    if ($47) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $48 = (($__j$0) + -8|0);
      $49 = ($$0|0)==($48|0);
      if ($49) {
       break;
      }
      $108 = HEAP32[$__comp>>2]|0;
      $109 = (FUNCTION_TABLE_iii[$108 & 63]($48,$40)|0);
      if ($109) {
       label = 28;
       break;
      } else {
       $__j$0 = $48;
      }
     }
     if ((label|0) == 28) {
      label = 0;
      $110 = $$0;
      $111 = $110;
      $112 = HEAP32[$111>>2]|0;
      $113 = (($110) + 4)|0;
      $114 = $113;
      $115 = HEAP32[$114>>2]|0;
      $116 = $48;
      $117 = $116;
      $118 = HEAP32[$117>>2]|0;
      $119 = (($116) + 4)|0;
      $120 = $119;
      $121 = HEAP32[$120>>2]|0;
      $122 = $$0;
      $123 = $122;
      HEAP32[$123>>2] = $118;
      $124 = (($122) + 4)|0;
      $125 = $124;
      HEAP32[$125>>2] = $121;
      $126 = $48;
      $127 = $126;
      HEAP32[$127>>2] = $112;
      $128 = (($126) + 4)|0;
      $129 = $128;
      HEAP32[$129>>2] = $115;
      $130 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $48;$__n_swaps$3 = $130;
      break;
     }
     $50 = (($$0) + 8|0);
     $51 = HEAP32[$__comp>>2]|0;
     $52 = (FUNCTION_TABLE_iii[$51 & 63]($$0,$1)|0);
     if ($52) {
      $__i$1 = $50;
     } else {
      $53 = ($50|0)==($1|0);
      if ($53) {
       label = 45;
       break L1;
      } else {
       $__i$05 = $50;
      }
      while(1) {
       $56 = HEAP32[$__comp>>2]|0;
       $57 = (FUNCTION_TABLE_iii[$56 & 63]($$0,$__i$05)|0);
       $54 = (($__i$05) + 8|0);
       if ($57) {
        break;
       }
       $55 = ($54|0)==($1|0);
       if ($55) {
        label = 45;
        break L1;
       } else {
        $__i$05 = $54;
       }
      }
      $58 = $__i$05;
      $59 = $58;
      $60 = HEAP32[$59>>2]|0;
      $61 = (($58) + 4)|0;
      $62 = $61;
      $63 = HEAP32[$62>>2]|0;
      $64 = $1;
      $65 = $64;
      $66 = HEAP32[$65>>2]|0;
      $67 = (($64) + 4)|0;
      $68 = $67;
      $69 = HEAP32[$68>>2]|0;
      $70 = $__i$05;
      $71 = $70;
      HEAP32[$71>>2] = $66;
      $72 = (($70) + 4)|0;
      $73 = $72;
      HEAP32[$73>>2] = $69;
      $74 = $1;
      $75 = $74;
      HEAP32[$75>>2] = $60;
      $76 = (($74) + 4)|0;
      $77 = $76;
      HEAP32[$77>>2] = $63;
      $78 = (($__i$05) + 8|0);
      $__i$1 = $78;
     }
     $79 = ($__i$1|0)==($1|0);
     if ($79) {
      label = 45;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $__i$2 = $__i$2$ph;
      while(1) {
       $80 = HEAP32[$__comp>>2]|0;
       $81 = (FUNCTION_TABLE_iii[$80 & 63]($$0,$__i$2)|0);
       $82 = (($__i$2) + 8|0);
       if ($81) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $82;
       }
      }
      while(1) {
       $83 = HEAP32[$__comp>>2]|0;
       $84 = (($__j$2) + -8|0);
       $85 = (FUNCTION_TABLE_iii[$83 & 63]($$0,$84)|0);
       if ($85) {
        $__j$2 = $84;
       } else {
        break;
       }
      }
      $86 = ($__i$2>>>0)<($84>>>0);
      if (!($86)) {
       $$0 = $__i$2;
       continue L3;
      }
      $87 = $__i$2;
      $88 = $87;
      $89 = HEAP32[$88>>2]|0;
      $90 = (($87) + 4)|0;
      $91 = $90;
      $92 = HEAP32[$91>>2]|0;
      $93 = $84;
      $94 = $93;
      $95 = HEAP32[$94>>2]|0;
      $96 = (($93) + 4)|0;
      $97 = $96;
      $98 = HEAP32[$97>>2]|0;
      $99 = $__i$2;
      $100 = $99;
      HEAP32[$100>>2] = $95;
      $101 = (($99) + 4)|0;
      $102 = $101;
      HEAP32[$102>>2] = $98;
      $103 = $84;
      $104 = $103;
      HEAP32[$104>>2] = $89;
      $105 = (($103) + 4)|0;
      $106 = $105;
      HEAP32[$106>>2] = $92;
      $107 = (($__i$2) + 8|0);
      $__i$2$ph = $107;$__j$1$ph = $84;
     }
    }
   } while(0);
   $131 = (($$0) + 8|0);
   $132 = ($131>>>0)<($__j$3>>>0);
   L34: do {
    if ($132) {
     $__i$3$ph = $131;$__j$4$ph = $__j$3;$__m$0$ph = $40;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $__i$3 = $__i$3$ph;
      while(1) {
       $133 = HEAP32[$__comp>>2]|0;
       $134 = (FUNCTION_TABLE_iii[$133 & 63]($__i$3,$__m$0$ph)|0);
       $135 = (($__i$3) + 8|0);
       if ($134) {
        $__i$3 = $135;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $136 = HEAP32[$__comp>>2]|0;
       $137 = (($__j$5) + -8|0);
       $138 = (FUNCTION_TABLE_iii[$136 & 63]($137,$__m$0$ph)|0);
       if ($138) {
        break;
       } else {
        $__j$5 = $137;
       }
      }
      $139 = ($__i$3>>>0)>($137>>>0);
      if ($139) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L34;
      }
      $140 = $__i$3;
      $141 = $140;
      $142 = HEAP32[$141>>2]|0;
      $143 = (($140) + 4)|0;
      $144 = $143;
      $145 = HEAP32[$144>>2]|0;
      $146 = $137;
      $147 = $146;
      $148 = HEAP32[$147>>2]|0;
      $149 = (($146) + 4)|0;
      $150 = $149;
      $151 = HEAP32[$150>>2]|0;
      $152 = $__i$3;
      $153 = $152;
      HEAP32[$153>>2] = $148;
      $154 = (($152) + 4)|0;
      $155 = $154;
      HEAP32[$155>>2] = $151;
      $156 = $137;
      $157 = $156;
      HEAP32[$157>>2] = $142;
      $158 = (($156) + 4)|0;
      $159 = $158;
      HEAP32[$159>>2] = $145;
      $160 = (($__n_swaps$4$ph) + 1)|0;
      $161 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $161 ? $137 : $__m$0$ph;
      $162 = (($__i$3) + 8|0);
      $__i$3$ph = $162;$__j$4$ph = $137;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $160;
     }
    } else {
     $__i$4 = $131;$__m$2 = $40;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $163 = ($__i$4|0)==($__m$2|0);
   if ($163) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $164 = HEAP32[$__comp>>2]|0;
    $165 = (FUNCTION_TABLE_iii[$164 & 63]($__m$2,$__i$4)|0);
    if ($165) {
     $166 = $__i$4;
     $167 = $166;
     $168 = HEAP32[$167>>2]|0;
     $169 = (($166) + 4)|0;
     $170 = $169;
     $171 = HEAP32[$170>>2]|0;
     $172 = $__m$2;
     $173 = $172;
     $174 = HEAP32[$173>>2]|0;
     $175 = (($172) + 4)|0;
     $176 = $175;
     $177 = HEAP32[$176>>2]|0;
     $178 = $__i$4;
     $179 = $178;
     HEAP32[$179>>2] = $174;
     $180 = (($178) + 4)|0;
     $181 = $180;
     HEAP32[$181>>2] = $177;
     $182 = $__m$2;
     $183 = $182;
     HEAP32[$183>>2] = $168;
     $184 = (($182) + 4)|0;
     $185 = $184;
     HEAP32[$185>>2] = $171;
     $186 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $186;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $187 = ($__n_swaps$6|0)==(0);
   if ($187) {
    $188 = (__ZNSt3__127__insertion_sort_incompleteIRPFbRK6b2PairS3_EPS1_EEbT0_S8_T_($$0,$__i$4,$__comp)|0);
    $189 = (($__i$4) + 8|0);
    $190 = (__ZNSt3__127__insertion_sort_incompleteIRPFbRK6b2PairS3_EPS1_EEbT0_S8_T_($189,$$01$ph,$__comp)|0);
    if ($190) {
     label = 40;
     break;
    }
    if ($188) {
     $$0 = $189;
     continue;
    }
   }
   $191 = $__i$4;
   $192 = (($191) - ($2))|0;
   $193 = (($0) - ($191))|0;
   $194 = ($192|0)<($193|0);
   if (!($194)) {
    label = 44;
    break;
   }
   __ZNSt3__16__sortIRPFbRK6b2PairS3_EPS1_EEvT0_S8_T_($$0,$__i$4,$__comp);
   $195 = (($__i$4) + 8|0);
   $$0 = $195;
  }
  if ((label|0) == 40) {
   label = 0;
   if ($188) {
    label = 45;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 44) {
   label = 0;
   $196 = (($__i$4) + 8|0);
   __ZNSt3__16__sortIRPFbRK6b2PairS3_EPS1_EEvT0_S8_T_($196,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = HEAP32[$__comp>>2]|0;
  $6 = (($$01$ph) + -8|0);
  $7 = (FUNCTION_TABLE_iii[$5 & 63]($6,$$0)|0);
  if (!($7)) {
   STACKTOP = sp;return;
  }
  $8 = $$0;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($8) + 4)|0;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = $6;
  $15 = $14;
  $16 = HEAP32[$15>>2]|0;
  $17 = (($14) + 4)|0;
  $18 = $17;
  $19 = HEAP32[$18>>2]|0;
  $20 = $$0;
  $21 = $20;
  HEAP32[$21>>2] = $16;
  $22 = (($20) + 4)|0;
  $23 = $22;
  HEAP32[$23>>2] = $19;
  $24 = $6;
  $25 = $24;
  HEAP32[$25>>2] = $10;
  $26 = (($24) + 4)|0;
  $27 = $26;
  HEAP32[$27>>2] = $13;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $28 = (($$0) + 8|0);
  $29 = (($$01$ph) + -8|0);
  (__ZNSt3__17__sort3IRPFbRK6b2PairS3_EPS1_EEjT0_S8_S8_T_($$0,$28,$29,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 7) {
  $30 = (($$0) + 8|0);
  $31 = (($$0) + 16|0);
  $32 = (($$01$ph) + -8|0);
  (__ZNSt3__17__sort4IRPFbRK6b2PairS3_EPS1_EEjT0_S8_S8_S8_T_($$0,$30,$31,$32,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 8) {
  $33 = (($$0) + 8|0);
  $34 = (($$0) + 16|0);
  $35 = (($$0) + 24|0);
  $36 = (($$01$ph) + -8|0);
  (__ZNSt3__17__sort5IRPFbRK6b2PairS3_EPS1_EEjT0_S8_S8_S8_S8_T_($$0,$33,$34,$35,$36,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 10) {
  __ZNSt3__118__insertion_sort_3IRPFbRK6b2PairS3_EPS1_EEvT0_S8_T_($$0,$$01$ph,$__comp);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 45) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__17__sort3IRPFbRK6b2PairS3_EPS1_EEjT0_S8_S8_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__c>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$0 & 63]($__y,$__x)|0);
 $2 = HEAP32[$__c>>2]|0;
 $3 = (FUNCTION_TABLE_iii[$2 & 63]($__z,$__y)|0);
 if (!($1)) {
  if (!($3)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $4 = $__y;
  $5 = $4;
  $6 = HEAP32[$5>>2]|0;
  $7 = (($4) + 4)|0;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = $__z;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $13 = (($10) + 4)|0;
  $14 = $13;
  $15 = HEAP32[$14>>2]|0;
  $16 = $__y;
  $17 = $16;
  HEAP32[$17>>2] = $12;
  $18 = (($16) + 4)|0;
  $19 = $18;
  HEAP32[$19>>2] = $15;
  $20 = $__z;
  $21 = $20;
  HEAP32[$21>>2] = $6;
  $22 = (($20) + 4)|0;
  $23 = $22;
  HEAP32[$23>>2] = $9;
  $24 = HEAP32[$__c>>2]|0;
  $25 = (FUNCTION_TABLE_iii[$24 & 63]($__y,$__x)|0);
  if (!($25)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $26 = $__x;
  $27 = $26;
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + 4)|0;
  $30 = $29;
  $31 = HEAP32[$30>>2]|0;
  $32 = $__y;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = (($32) + 4)|0;
  $36 = $35;
  $37 = HEAP32[$36>>2]|0;
  $38 = $__x;
  $39 = $38;
  HEAP32[$39>>2] = $34;
  $40 = (($38) + 4)|0;
  $41 = $40;
  HEAP32[$41>>2] = $37;
  $42 = $__y;
  $43 = $42;
  HEAP32[$43>>2] = $28;
  $44 = (($42) + 4)|0;
  $45 = $44;
  HEAP32[$45>>2] = $31;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $46 = $__x;
 $47 = $46;
 $48 = HEAP32[$47>>2]|0;
 $49 = (($46) + 4)|0;
 $50 = $49;
 $51 = HEAP32[$50>>2]|0;
 if ($3) {
  $52 = $__z;
  $53 = $52;
  $54 = HEAP32[$53>>2]|0;
  $55 = (($52) + 4)|0;
  $56 = $55;
  $57 = HEAP32[$56>>2]|0;
  $58 = $__x;
  $59 = $58;
  HEAP32[$59>>2] = $54;
  $60 = (($58) + 4)|0;
  $61 = $60;
  HEAP32[$61>>2] = $57;
  $62 = $__z;
  $63 = $62;
  HEAP32[$63>>2] = $48;
  $64 = (($62) + 4)|0;
  $65 = $64;
  HEAP32[$65>>2] = $51;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $66 = $__y;
 $67 = $66;
 $68 = HEAP32[$67>>2]|0;
 $69 = (($66) + 4)|0;
 $70 = $69;
 $71 = HEAP32[$70>>2]|0;
 $72 = $__x;
 $73 = $72;
 HEAP32[$73>>2] = $68;
 $74 = (($72) + 4)|0;
 $75 = $74;
 HEAP32[$75>>2] = $71;
 $76 = $__y;
 $77 = $76;
 HEAP32[$77>>2] = $48;
 $78 = (($76) + 4)|0;
 $79 = $78;
 HEAP32[$79>>2] = $51;
 $80 = HEAP32[$__c>>2]|0;
 $81 = (FUNCTION_TABLE_iii[$80 & 63]($__z,$__y)|0);
 if (!($81)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $82 = $__y;
 $83 = $82;
 $84 = HEAP32[$83>>2]|0;
 $85 = (($82) + 4)|0;
 $86 = $85;
 $87 = HEAP32[$86>>2]|0;
 $88 = $__z;
 $89 = $88;
 $90 = HEAP32[$89>>2]|0;
 $91 = (($88) + 4)|0;
 $92 = $91;
 $93 = HEAP32[$92>>2]|0;
 $94 = $__y;
 $95 = $94;
 HEAP32[$95>>2] = $90;
 $96 = (($94) + 4)|0;
 $97 = $96;
 HEAP32[$97>>2] = $93;
 $98 = $__z;
 $99 = $98;
 HEAP32[$99>>2] = $84;
 $100 = (($98) + 4)|0;
 $101 = $100;
 HEAP32[$101>>2] = $87;
 $$0 = 2;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17__sort4IRPFbRK6b2PairS3_EPS1_EEjT0_S8_S8_S8_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__17__sort3IRPFbRK6b2PairS3_EPS1_EEjT0_S8_S8_T_($__x1,$__x2,$__x3,$__c)|0);
 $1 = HEAP32[$__c>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$1 & 63]($__x4,$__x3)|0);
 if (!($2)) {
  $__r$0 = $0;
  STACKTOP = sp;return ($__r$0|0);
 }
 $3 = $__x3;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $__x4;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = $__x3;
 $16 = $15;
 HEAP32[$16>>2] = $11;
 $17 = (($15) + 4)|0;
 $18 = $17;
 HEAP32[$18>>2] = $14;
 $19 = $__x4;
 $20 = $19;
 HEAP32[$20>>2] = $5;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $8;
 $23 = (($0) + 1)|0;
 $24 = HEAP32[$__c>>2]|0;
 $25 = (FUNCTION_TABLE_iii[$24 & 63]($__x3,$__x2)|0);
 if (!($25)) {
  $__r$0 = $23;
  STACKTOP = sp;return ($__r$0|0);
 }
 $26 = $__x2;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($26) + 4)|0;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = $__x3;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = (($32) + 4)|0;
 $36 = $35;
 $37 = HEAP32[$36>>2]|0;
 $38 = $__x2;
 $39 = $38;
 HEAP32[$39>>2] = $34;
 $40 = (($38) + 4)|0;
 $41 = $40;
 HEAP32[$41>>2] = $37;
 $42 = $__x3;
 $43 = $42;
 HEAP32[$43>>2] = $28;
 $44 = (($42) + 4)|0;
 $45 = $44;
 HEAP32[$45>>2] = $31;
 $46 = (($0) + 2)|0;
 $47 = HEAP32[$__c>>2]|0;
 $48 = (FUNCTION_TABLE_iii[$47 & 63]($__x2,$__x1)|0);
 if (!($48)) {
  $__r$0 = $46;
  STACKTOP = sp;return ($__r$0|0);
 }
 $49 = $__x1;
 $50 = $49;
 $51 = HEAP32[$50>>2]|0;
 $52 = (($49) + 4)|0;
 $53 = $52;
 $54 = HEAP32[$53>>2]|0;
 $55 = $__x2;
 $56 = $55;
 $57 = HEAP32[$56>>2]|0;
 $58 = (($55) + 4)|0;
 $59 = $58;
 $60 = HEAP32[$59>>2]|0;
 $61 = $__x1;
 $62 = $61;
 HEAP32[$62>>2] = $57;
 $63 = (($61) + 4)|0;
 $64 = $63;
 HEAP32[$64>>2] = $60;
 $65 = $__x2;
 $66 = $65;
 HEAP32[$66>>2] = $51;
 $67 = (($65) + 4)|0;
 $68 = $67;
 HEAP32[$68>>2] = $54;
 $69 = (($0) + 3)|0;
 $__r$0 = $69;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__17__sort5IRPFbRK6b2PairS3_EPS1_EEjT0_S8_S8_S8_S8_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__17__sort4IRPFbRK6b2PairS3_EPS1_EEjT0_S8_S8_S8_T_($__x1,$__x2,$__x3,$__x4,$__c)|0);
 $1 = HEAP32[$__c>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$1 & 63]($__x5,$__x4)|0);
 if (!($2)) {
  $__r$0 = $0;
  STACKTOP = sp;return ($__r$0|0);
 }
 $3 = $__x4;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $__x5;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = $__x4;
 $16 = $15;
 HEAP32[$16>>2] = $11;
 $17 = (($15) + 4)|0;
 $18 = $17;
 HEAP32[$18>>2] = $14;
 $19 = $__x5;
 $20 = $19;
 HEAP32[$20>>2] = $5;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $8;
 $23 = (($0) + 1)|0;
 $24 = HEAP32[$__c>>2]|0;
 $25 = (FUNCTION_TABLE_iii[$24 & 63]($__x4,$__x3)|0);
 if (!($25)) {
  $__r$0 = $23;
  STACKTOP = sp;return ($__r$0|0);
 }
 $26 = $__x3;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($26) + 4)|0;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = $__x4;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = (($32) + 4)|0;
 $36 = $35;
 $37 = HEAP32[$36>>2]|0;
 $38 = $__x3;
 $39 = $38;
 HEAP32[$39>>2] = $34;
 $40 = (($38) + 4)|0;
 $41 = $40;
 HEAP32[$41>>2] = $37;
 $42 = $__x4;
 $43 = $42;
 HEAP32[$43>>2] = $28;
 $44 = (($42) + 4)|0;
 $45 = $44;
 HEAP32[$45>>2] = $31;
 $46 = (($0) + 2)|0;
 $47 = HEAP32[$__c>>2]|0;
 $48 = (FUNCTION_TABLE_iii[$47 & 63]($__x3,$__x2)|0);
 if (!($48)) {
  $__r$0 = $46;
  STACKTOP = sp;return ($__r$0|0);
 }
 $49 = $__x2;
 $50 = $49;
 $51 = HEAP32[$50>>2]|0;
 $52 = (($49) + 4)|0;
 $53 = $52;
 $54 = HEAP32[$53>>2]|0;
 $55 = $__x3;
 $56 = $55;
 $57 = HEAP32[$56>>2]|0;
 $58 = (($55) + 4)|0;
 $59 = $58;
 $60 = HEAP32[$59>>2]|0;
 $61 = $__x2;
 $62 = $61;
 HEAP32[$62>>2] = $57;
 $63 = (($61) + 4)|0;
 $64 = $63;
 HEAP32[$64>>2] = $60;
 $65 = $__x3;
 $66 = $65;
 HEAP32[$66>>2] = $51;
 $67 = (($65) + 4)|0;
 $68 = $67;
 HEAP32[$68>>2] = $54;
 $69 = (($0) + 3)|0;
 $70 = HEAP32[$__c>>2]|0;
 $71 = (FUNCTION_TABLE_iii[$70 & 63]($__x2,$__x1)|0);
 if (!($71)) {
  $__r$0 = $69;
  STACKTOP = sp;return ($__r$0|0);
 }
 $72 = $__x1;
 $73 = $72;
 $74 = HEAP32[$73>>2]|0;
 $75 = (($72) + 4)|0;
 $76 = $75;
 $77 = HEAP32[$76>>2]|0;
 $78 = $__x2;
 $79 = $78;
 $80 = HEAP32[$79>>2]|0;
 $81 = (($78) + 4)|0;
 $82 = $81;
 $83 = HEAP32[$82>>2]|0;
 $84 = $__x1;
 $85 = $84;
 HEAP32[$85>>2] = $80;
 $86 = (($84) + 4)|0;
 $87 = $86;
 HEAP32[$87>>2] = $83;
 $88 = $__x2;
 $89 = $88;
 HEAP32[$89>>2] = $74;
 $90 = (($88) + 4)|0;
 $91 = $90;
 HEAP32[$91>>2] = $77;
 $92 = (($0) + 4)|0;
 $__r$0 = $92;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IRPFbRK6b2PairS3_EPS1_EEvT0_S8_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $__i$02 = 0, $__j$01 = 0, $__j$01$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__t = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t = sp;
 $0 = (($__first) + 16|0);
 $1 = (($__first) + 8|0);
 (__ZNSt3__17__sort3IRPFbRK6b2PairS3_EPS1_EEjT0_S8_S8_T_($__first,$1,$0,$__comp)|0);
 $2 = (($__first) + 24|0);
 $3 = ($2|0)==($__last|0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $__i$02 = $2;$__j$01 = $0;
 }
 while(1) {
  $4 = HEAP32[$__comp>>2]|0;
  $5 = (FUNCTION_TABLE_iii[$4 & 63]($__i$02,$__j$01)|0);
  if ($5) {
   $6 = $__i$02;
   $7 = $6;
   $8 = HEAP32[$7>>2]|0;
   $9 = (($6) + 4)|0;
   $10 = $9;
   $11 = HEAP32[$10>>2]|0;
   $12 = $__t;
   $13 = $12;
   HEAP32[$13>>2] = $8;
   $14 = (($12) + 4)|0;
   $15 = $14;
   HEAP32[$15>>2] = $11;
   $__j$1 = $__i$02;$__k$0 = $__j$01;
   while(1) {
    $16 = $__k$0;
    $17 = $16;
    $18 = HEAP32[$17>>2]|0;
    $19 = (($16) + 4)|0;
    $20 = $19;
    $21 = HEAP32[$20>>2]|0;
    $22 = $__j$1;
    $23 = $22;
    HEAP32[$23>>2] = $18;
    $24 = (($22) + 4)|0;
    $25 = $24;
    HEAP32[$25>>2] = $21;
    $26 = ($__k$0|0)==($__first|0);
    if ($26) {
     break;
    }
    $27 = HEAP32[$__comp>>2]|0;
    $28 = (($__k$0) + -8|0);
    $29 = (FUNCTION_TABLE_iii[$27 & 63]($__t,$28)|0);
    if ($29) {
     $__j$1$phi = $__k$0;$__k$0 = $28;$__j$1 = $__j$1$phi;
    } else {
     break;
    }
   }
   $30 = $__t;
   $31 = $30;
   $32 = HEAP32[$31>>2]|0;
   $33 = (($30) + 4)|0;
   $34 = $33;
   $35 = HEAP32[$34>>2]|0;
   $36 = $__k$0;
   $37 = $36;
   HEAP32[$37>>2] = $32;
   $38 = (($36) + 4)|0;
   $39 = $38;
   HEAP32[$39>>2] = $35;
  }
  $40 = (($__i$02) + 8|0);
  $41 = ($40|0)==($__last|0);
  if ($41) {
   break;
  } else {
   $__j$01$phi = $__i$02;$__i$02 = $40;$__j$01 = $__j$01$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIRPFbRK6b2PairS3_EPS1_EEbT0_S8_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $9 = 0, $__count$03 = 0, $__count$1 = 0, $__i$04 = 0, $__j$02 = 0, $__j$02$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__t = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t = sp;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 3;
 switch ($3|0) {
 case 4:  {
  $29 = (($__first) + 8|0);
  $30 = (($__first) + 16|0);
  $31 = (($__last) + -8|0);
  (__ZNSt3__17__sort4IRPFbRK6b2PairS3_EPS1_EEjT0_S8_S8_S8_T_($__first,$29,$30,$31,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $27 = (($__first) + 8|0);
  $28 = (($__last) + -8|0);
  (__ZNSt3__17__sort3IRPFbRK6b2PairS3_EPS1_EEjT0_S8_S8_T_($__first,$27,$28,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = HEAP32[$__comp>>2]|0;
  $5 = (($__last) + -8|0);
  $6 = (FUNCTION_TABLE_iii[$4 & 63]($5,$__first)|0);
  if (!($6)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $7 = $__first;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) + 4)|0;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $13 = $5;
  $14 = $13;
  $15 = HEAP32[$14>>2]|0;
  $16 = (($13) + 4)|0;
  $17 = $16;
  $18 = HEAP32[$17>>2]|0;
  $19 = $__first;
  $20 = $19;
  HEAP32[$20>>2] = $15;
  $21 = (($19) + 4)|0;
  $22 = $21;
  HEAP32[$22>>2] = $18;
  $23 = $5;
  $24 = $23;
  HEAP32[$24>>2] = $9;
  $25 = (($23) + 4)|0;
  $26 = $25;
  HEAP32[$26>>2] = $12;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $32 = (($__first) + 8|0);
  $33 = (($__first) + 16|0);
  $34 = (($__first) + 24|0);
  $35 = (($__last) + -8|0);
  (__ZNSt3__17__sort5IRPFbRK6b2PairS3_EPS1_EEjT0_S8_S8_S8_S8_T_($__first,$32,$33,$34,$35,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $36 = (($__first) + 16|0);
  $37 = (($__first) + 8|0);
  (__ZNSt3__17__sort3IRPFbRK6b2PairS3_EPS1_EEjT0_S8_S8_T_($__first,$37,$36,$__comp)|0);
  $38 = (($__first) + 24|0);
  $39 = ($38|0)==($__last|0);
  if ($39) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $__count$03 = 0;$__i$04 = $38;$__j$02 = $36;
  }
  while(1) {
   $40 = HEAP32[$__comp>>2]|0;
   $41 = (FUNCTION_TABLE_iii[$40 & 63]($__i$04,$__j$02)|0);
   if ($41) {
    $42 = $__i$04;
    $43 = $42;
    $44 = HEAP32[$43>>2]|0;
    $45 = (($42) + 4)|0;
    $46 = $45;
    $47 = HEAP32[$46>>2]|0;
    $48 = $__t;
    $49 = $48;
    HEAP32[$49>>2] = $44;
    $50 = (($48) + 4)|0;
    $51 = $50;
    HEAP32[$51>>2] = $47;
    $__j$1 = $__i$04;$__k$0 = $__j$02;
    while(1) {
     $52 = $__k$0;
     $53 = $52;
     $54 = HEAP32[$53>>2]|0;
     $55 = (($52) + 4)|0;
     $56 = $55;
     $57 = HEAP32[$56>>2]|0;
     $58 = $__j$1;
     $59 = $58;
     HEAP32[$59>>2] = $54;
     $60 = (($58) + 4)|0;
     $61 = $60;
     HEAP32[$61>>2] = $57;
     $62 = ($__k$0|0)==($__first|0);
     if ($62) {
      break;
     }
     $63 = HEAP32[$__comp>>2]|0;
     $64 = (($__k$0) + -8|0);
     $65 = (FUNCTION_TABLE_iii[$63 & 63]($__t,$64)|0);
     if ($65) {
      $__j$1$phi = $__k$0;$__k$0 = $64;$__j$1 = $__j$1$phi;
     } else {
      break;
     }
    }
    $66 = $__t;
    $67 = $66;
    $68 = HEAP32[$67>>2]|0;
    $69 = (($66) + 4)|0;
    $70 = $69;
    $71 = HEAP32[$70>>2]|0;
    $72 = $__k$0;
    $73 = $72;
    HEAP32[$73>>2] = $68;
    $74 = (($72) + 4)|0;
    $75 = $74;
    HEAP32[$75>>2] = $71;
    $76 = (($__count$03) + 1)|0;
    $77 = ($76|0)==(8);
    if ($77) {
     break;
    } else {
     $__count$1 = $76;
    }
   } else {
    $__count$1 = $__count$03;
   }
   $80 = (($__i$04) + 8|0);
   $81 = ($80|0)==($__last|0);
   if ($81) {
    $$0 = 1;
    label = 15;
    break;
   } else {
    $__j$02$phi = $__i$04;$__count$03 = $__count$1;$__i$04 = $80;$__j$02 = $__j$02$phi;
   }
  }
  if ((label|0) == 15) {
   STACKTOP = sp;return ($$0|0);
  }
  $78 = (($__i$04) + 8|0);
  $79 = ($78|0)==($__last|0);
  $$0 = $79;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return (0)|0;
}
function __ZN16b2VoronoiDiagramC2EP16b2StackAllocatori($this,$allocator,$generatorCapacity) {
 $this = $this|0;
 $allocator = $allocator|0;
 $generatorCapacity = $generatorCapacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $allocator;
 $0 = $generatorCapacity << 4;
 $1 = (__ZN16b2StackAllocator8AllocateEi($allocator,$0)|0);
 $2 = (($this) + 4|0);
 HEAP32[$2>>2] = $1;
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = $generatorCapacity;
 $4 = (($this) + 12|0);
 ;HEAP32[$4+0>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZN16b2VoronoiDiagramD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = HEAP32[$this>>2]|0;
  __ZN16b2StackAllocator4FreeEPv($3,$1);
 }
 $4 = HEAP32[$this>>2]|0;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 __ZN16b2StackAllocator4FreeEPv($4,$6);
 STACKTOP = sp;return;
}
function __ZN16b2VoronoiDiagram12AddGeneratorERK6b2Vec2ib($this,$center,$tag,$necessary) {
 $this = $this|0;
 $center = $center|0;
 $tag = $tag|0;
 $necessary = $necessary|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1)|0;
 HEAP32[$0>>2] = $2;
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($1<<4)|0);
 $6 = $center;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $5;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 $16 = ((($4) + ($1<<4)|0) + 8|0);
 HEAP32[$16>>2] = $tag;
 $17 = ((($4) + ($1<<4)|0) + 12|0);
 $18 = $necessary&1;
 HEAP8[$17>>0] = $18;
 STACKTOP = sp;return;
}
function __ZN16b2VoronoiDiagram8GenerateEff($this,$radius,$margin) {
 $this = $this|0;
 $radius = +$radius;
 $margin = +$margin;
 var $$lcssa = 0, $$lcssa34 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0.0, $111 = 0, $112 = 0, $113 = 0.0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0.0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0.0, $219 = 0.0, $22 = 0, $220 = 0.0, $221 = 0;
 var $222 = 0.0, $223 = 0.0, $224 = 0.0, $225 = 0.0, $226 = 0.0, $227 = 0, $228 = 0.0, $229 = 0.0, $23 = 0, $230 = 0.0, $231 = 0.0, $232 = 0.0, $233 = 0.0, $234 = 0.0, $235 = 0.0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0;
 var $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$035 = 0, $k$041 = 0;
 var $k1$031 = 0, $lower = 0, $queue = 0, $upper = 0, $x11$010 = 0, $x8$019 = 0, $y10$014 = 0, $y7$023 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0;
 $lower = sp + 32|0;
 $upper = sp + 24|0;
 $0 = sp + 16|0;
 $1 = sp + 8|0;
 $queue = sp + 256|0;
 $2 = sp;
 $3 = sp + 248|0;
 $4 = sp + 232|0;
 $5 = sp + 216|0;
 $6 = sp + 200|0;
 $7 = sp + 184|0;
 $8 = sp + 168|0;
 $9 = sp + 152|0;
 $10 = sp + 136|0;
 $11 = sp + 120|0;
 $12 = sp + 104|0;
 $13 = sp + 88|0;
 $14 = sp + 72|0;
 $15 = sp + 56|0;
 $16 = sp + 40|0;
 $17 = 1.0 / $radius;
 __ZN6b2Vec2C2Eff($lower,3.4028234663852886E+38,3.4028234663852886E+38);
 __ZN6b2Vec2C2Eff($upper,-3.4028234663852886E+38,-3.4028234663852886E+38);
 $18 = (($this) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)>(0);
 if ($20) {
  $21 = (($this) + 4|0);
  $k$041 = 0;
  while(1) {
   $22 = HEAP32[$21>>2]|0;
   $23 = ((($22) + ($k$041<<4)|0) + 12|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = ($24<<24>>24)==(0);
   if (!($25)) {
    $26 = (($22) + ($k$041<<4)|0);
    __Z5b2MinRK6b2Vec2S1_($0,$lower,$26);
    $27 = $0;
    $28 = $27;
    $29 = HEAP32[$28>>2]|0;
    $30 = (($27) + 4)|0;
    $31 = $30;
    $32 = HEAP32[$31>>2]|0;
    $33 = $lower;
    $34 = $33;
    HEAP32[$34>>2] = $29;
    $35 = (($33) + 4)|0;
    $36 = $35;
    HEAP32[$36>>2] = $32;
    __Z5b2MaxRK6b2Vec2S1_($1,$upper,$26);
    $37 = $1;
    $38 = $37;
    $39 = HEAP32[$38>>2]|0;
    $40 = (($37) + 4)|0;
    $41 = $40;
    $42 = HEAP32[$41>>2]|0;
    $43 = $upper;
    $44 = $43;
    HEAP32[$44>>2] = $39;
    $45 = (($43) + 4)|0;
    $46 = $45;
    HEAP32[$46>>2] = $42;
   }
   $47 = (($k$041) + 1)|0;
   $48 = HEAP32[$18>>2]|0;
   $49 = ($47|0)<($48|0);
   if ($49) {
    $k$041 = $47;
   } else {
    break;
   }
  }
 }
 $50 = +HEAPF32[$lower>>2];
 $51 = $50 - $margin;
 HEAPF32[$lower>>2] = $51;
 $52 = (($lower) + 4|0);
 $53 = +HEAPF32[$52>>2];
 $54 = $53 - $margin;
 HEAPF32[$52>>2] = $54;
 $55 = +HEAPF32[$upper>>2];
 $56 = $55 + $margin;
 HEAPF32[$upper>>2] = $56;
 $57 = (($upper) + 4|0);
 $58 = +HEAPF32[$57>>2];
 $59 = $58 + $margin;
 HEAPF32[$57>>2] = $59;
 $60 = +HEAPF32[$upper>>2];
 $61 = +HEAPF32[$lower>>2];
 $62 = $60 - $61;
 $63 = $17 * $62;
 $64 = (~~(($63)));
 $65 = (($64) + 1)|0;
 $66 = (($this) + 16|0);
 HEAP32[$66>>2] = $65;
 $67 = +HEAPF32[$57>>2];
 $68 = +HEAPF32[$52>>2];
 $69 = $67 - $68;
 $70 = $17 * $69;
 $71 = (~~(($70)));
 $72 = (($71) + 1)|0;
 $73 = (($this) + 20|0);
 HEAP32[$73>>2] = $72;
 $74 = HEAP32[$this>>2]|0;
 $75 = HEAP32[$66>>2]|0;
 $76 = $75 << 2;
 $77 = Math_imul($76, $72)|0;
 $78 = (__ZN16b2StackAllocator8AllocateEi($74,$77)|0);
 $79 = (($this) + 24|0);
 HEAP32[$79>>2] = $78;
 $80 = HEAP32[$66>>2]|0;
 $81 = HEAP32[$73>>2]|0;
 $82 = Math_imul($81, $80)|0;
 $83 = ($82|0)>(0);
 if ($83) {
  $84 = HEAP32[$66>>2]|0;
  $85 = HEAP32[$73>>2]|0;
  $86 = Math_imul($85, $84)|0;
  $i$035 = 0;
  while(1) {
   $87 = HEAP32[$79>>2]|0;
   $88 = (($87) + ($i$035<<2)|0);
   HEAP32[$88>>2] = 0;
   $89 = (($i$035) + 1)|0;
   $90 = ($89|0)<($86|0);
   if ($90) {
    $i$035 = $89;
   } else {
    $$lcssa = $84;$$lcssa34 = $85;
    break;
   }
  }
 } else {
  $$lcssa = $80;$$lcssa34 = $81;
 }
 $91 = HEAP32[$this>>2]|0;
 $92 = $$lcssa << 2;
 $93 = Math_imul($92, $$lcssa34)|0;
 __ZN12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEEC2EP16b2StackAllocatori($queue,$91,$93);
 $94 = HEAP32[$18>>2]|0;
 $95 = ($94|0)>(0);
 if ($95) {
  $96 = (($this) + 4|0);
  $k1$031 = 0;
  while(1) {
   $98 = HEAP32[$96>>2]|0;
   $99 = (($98) + ($k1$031<<4)|0);
   __ZmiRK6b2Vec2S1_($3,$99,$lower);
   __ZmlfRK6b2Vec2($2,$17,$3);
   $100 = $2;
   $101 = $100;
   $102 = HEAP32[$101>>2]|0;
   $103 = (($100) + 4)|0;
   $104 = $103;
   $105 = HEAP32[$104>>2]|0;
   $106 = $99;
   $107 = $106;
   HEAP32[$107>>2] = $102;
   $108 = (($106) + 4)|0;
   $109 = $108;
   HEAP32[$109>>2] = $105;
   $110 = +HEAPF32[$99>>2];
   $111 = (~~(($110)));
   $112 = ((($98) + ($k1$031<<4)|0) + 4|0);
   $113 = +HEAPF32[$112>>2];
   $114 = (~~(($113)));
   $115 = $114 | $111;
   $116 = ($115|0)>(-1);
   if ($116) {
    $117 = HEAP32[$66>>2]|0;
    $118 = ($111|0)<($117|0);
    if ($118) {
     $119 = HEAP32[$73>>2]|0;
     $120 = ($114|0)<($119|0);
     if ($120) {
      $121 = Math_imul($117, $114)|0;
      $122 = (($121) + ($111))|0;
      __ZN16b2VoronoiDiagram20b2VoronoiDiagramTaskC2EiiiPNS_9GeneratorE($4,$111,$114,$122,$99);
      __ZN12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE4PushERKS1_($queue,$4);
     }
    }
   }
   $123 = (($k1$031) + 1)|0;
   $124 = HEAP32[$18>>2]|0;
   $125 = ($123|0)<($124|0);
   if ($125) {
    $k1$031 = $123;
   } else {
    break;
   }
  }
 }
 $97 = (__ZNK12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE5EmptyEv($queue)|0);
 if (!($97)) {
  while(1) {
   $128 = (__ZNK12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE5FrontEv($queue)|0);
   $129 = HEAP32[$128>>2]|0;
   $130 = (($128) + 4|0);
   $131 = HEAP32[$130>>2]|0;
   $132 = (($128) + 8|0);
   $133 = HEAP32[$132>>2]|0;
   $134 = (($128) + 12|0);
   $135 = HEAP32[$134>>2]|0;
   __ZN12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE3PopEv($queue);
   $136 = HEAP32[$79>>2]|0;
   $137 = (($136) + ($133<<2)|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = ($138|0)==(0|0);
   if ($139) {
    HEAP32[$137>>2] = $135;
    $140 = ($129|0)>(0);
    if ($140) {
     $141 = (($129) + -1)|0;
     $142 = (($133) + -1)|0;
     __ZN16b2VoronoiDiagram20b2VoronoiDiagramTaskC2EiiiPNS_9GeneratorE($5,$141,$131,$142,$135);
     __ZN12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE4PushERKS1_($queue,$5);
    }
    $143 = ($131|0)>(0);
    if ($143) {
     $144 = (($131) + -1)|0;
     $145 = HEAP32[$66>>2]|0;
     $146 = (($133) - ($145))|0;
     __ZN16b2VoronoiDiagram20b2VoronoiDiagramTaskC2EiiiPNS_9GeneratorE($6,$129,$144,$146,$135);
     __ZN12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE4PushERKS1_($queue,$6);
    }
    $147 = HEAP32[$66>>2]|0;
    $148 = (($147) + -1)|0;
    $149 = ($129|0)<($148|0);
    if ($149) {
     $150 = (($129) + 1)|0;
     $151 = (($133) + 1)|0;
     __ZN16b2VoronoiDiagram20b2VoronoiDiagramTaskC2EiiiPNS_9GeneratorE($7,$150,$131,$151,$135);
     __ZN12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE4PushERKS1_($queue,$7);
    }
    $152 = HEAP32[$73>>2]|0;
    $153 = (($152) + -1)|0;
    $154 = ($131|0)<($153|0);
    if ($154) {
     $156 = (($131) + 1)|0;
     $157 = HEAP32[$66>>2]|0;
     $158 = (($157) + ($133))|0;
     __ZN16b2VoronoiDiagram20b2VoronoiDiagramTaskC2EiiiPNS_9GeneratorE($8,$129,$156,$158,$135);
     __ZN12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE4PushERKS1_($queue,$8);
    }
   }
   $155 = (__ZNK12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE5EmptyEv($queue)|0);
   if ($155) {
    break;
   }
  }
 }
 $126 = HEAP32[$73>>2]|0;
 $127 = ($126|0)>(0);
 if ($127) {
  $y7$023 = 0;
  while(1) {
   $159 = HEAP32[$66>>2]|0;
   $160 = (($159) + -1)|0;
   $161 = ($160|0)>(0);
   if ($161) {
    $166 = $159;$x8$019 = 0;
    while(1) {
     $165 = Math_imul($166, $y7$023)|0;
     $167 = (($165) + ($x8$019))|0;
     $168 = HEAP32[$79>>2]|0;
     $169 = (($168) + ($167<<2)|0);
     $170 = HEAP32[$169>>2]|0;
     $171 = (($167) + 1)|0;
     $172 = (($168) + ($171<<2)|0);
     $173 = HEAP32[$172>>2]|0;
     $174 = ($170|0)==($173|0);
     if (!($174)) {
      __ZN16b2VoronoiDiagram20b2VoronoiDiagramTaskC2EiiiPNS_9GeneratorE($9,$x8$019,$y7$023,$167,$173);
      __ZN12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE4PushERKS1_($queue,$9);
      $175 = (($x8$019) + 1)|0;
      __ZN16b2VoronoiDiagram20b2VoronoiDiagramTaskC2EiiiPNS_9GeneratorE($10,$175,$y7$023,$171,$170);
      __ZN12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE4PushERKS1_($queue,$10);
     }
     $176 = (($x8$019) + 1)|0;
     $177 = HEAP32[$66>>2]|0;
     $178 = (($177) + -1)|0;
     $179 = ($176|0)<($178|0);
     if ($179) {
      $166 = $177;$x8$019 = $176;
     } else {
      break;
     }
    }
   }
   $180 = (($y7$023) + 1)|0;
   $181 = HEAP32[$73>>2]|0;
   $182 = ($180|0)<($181|0);
   if ($182) {
    $y7$023 = $180;
   } else {
    break;
   }
  }
 }
 $162 = HEAP32[$73>>2]|0;
 $163 = (($162) + -1)|0;
 $164 = ($163|0)>(0);
 if ($164) {
  $y10$014 = 0;
  while(1) {
   $183 = HEAP32[$66>>2]|0;
   $184 = ($183|0)>(0);
   if ($184) {
    $185 = (($y10$014) + 1)|0;
    $188 = $183;$x11$010 = 0;
    while(1) {
     $187 = Math_imul($188, $y10$014)|0;
     $189 = (($187) + ($x11$010))|0;
     $190 = HEAP32[$79>>2]|0;
     $191 = (($190) + ($189<<2)|0);
     $192 = HEAP32[$191>>2]|0;
     $193 = (($189) + ($188))|0;
     $194 = (($190) + ($193<<2)|0);
     $195 = HEAP32[$194>>2]|0;
     $196 = ($192|0)==($195|0);
     if (!($196)) {
      __ZN16b2VoronoiDiagram20b2VoronoiDiagramTaskC2EiiiPNS_9GeneratorE($11,$x11$010,$y10$014,$189,$195);
      __ZN12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE4PushERKS1_($queue,$11);
      $197 = HEAP32[$66>>2]|0;
      $198 = (($197) + ($189))|0;
      __ZN16b2VoronoiDiagram20b2VoronoiDiagramTaskC2EiiiPNS_9GeneratorE($12,$x11$010,$185,$198,$192);
      __ZN12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE4PushERKS1_($queue,$12);
     }
     $199 = (($x11$010) + 1)|0;
     $200 = HEAP32[$66>>2]|0;
     $201 = ($199|0)<($200|0);
     if ($201) {
      $188 = $200;$x11$010 = $199;
     } else {
      break;
     }
    }
   }
   $202 = (($y10$014) + 1)|0;
   $203 = HEAP32[$73>>2]|0;
   $204 = (($203) + -1)|0;
   $205 = ($202|0)<($204|0);
   if ($205) {
    $y10$014 = $202;
   } else {
    break;
   }
  }
 }
 $186 = (__ZNK12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE5EmptyEv($queue)|0);
 if ($186) {
  __ZN12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEED2Ev($queue);
  STACKTOP = sp;return;
 }
 while(1) {
  $206 = (__ZNK12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE5FrontEv($queue)|0);
  $207 = HEAP32[$206>>2]|0;
  $208 = (($206) + 4|0);
  $209 = HEAP32[$208>>2]|0;
  $210 = (($206) + 8|0);
  $211 = HEAP32[$210>>2]|0;
  $212 = (($206) + 12|0);
  $213 = HEAP32[$212>>2]|0;
  __ZN12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE3PopEv($queue);
  $214 = HEAP32[$79>>2]|0;
  $215 = (($214) + ($211<<2)|0);
  $216 = HEAP32[$215>>2]|0;
  $217 = ($216|0)==($213|0);
  if (!($217)) {
   $218 = +HEAPF32[$216>>2];
   $219 = (+($207|0));
   $220 = $218 - $219;
   $221 = (($216) + 4|0);
   $222 = +HEAPF32[$221>>2];
   $223 = (+($209|0));
   $224 = $222 - $223;
   $225 = +HEAPF32[$213>>2];
   $226 = $225 - $219;
   $227 = (($213) + 4|0);
   $228 = +HEAPF32[$227>>2];
   $229 = $228 - $223;
   $230 = $220 * $220;
   $231 = $224 * $224;
   $232 = $230 + $231;
   $233 = $226 * $226;
   $234 = $229 * $229;
   $235 = $233 + $234;
   $236 = $232 > $235;
   if ($236) {
    HEAP32[$215>>2] = $213;
    $238 = ($207|0)>(0);
    if ($238) {
     $239 = (($207) + -1)|0;
     $240 = (($211) + -1)|0;
     __ZN16b2VoronoiDiagram20b2VoronoiDiagramTaskC2EiiiPNS_9GeneratorE($13,$239,$209,$240,$213);
     __ZN12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE4PushERKS1_($queue,$13);
    }
    $241 = ($209|0)>(0);
    if ($241) {
     $242 = (($209) + -1)|0;
     $243 = HEAP32[$66>>2]|0;
     $244 = (($211) - ($243))|0;
     __ZN16b2VoronoiDiagram20b2VoronoiDiagramTaskC2EiiiPNS_9GeneratorE($14,$207,$242,$244,$213);
     __ZN12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE4PushERKS1_($queue,$14);
    }
    $245 = HEAP32[$66>>2]|0;
    $246 = (($245) + -1)|0;
    $247 = ($207|0)<($246|0);
    if ($247) {
     $248 = (($207) + 1)|0;
     $249 = (($211) + 1)|0;
     __ZN16b2VoronoiDiagram20b2VoronoiDiagramTaskC2EiiiPNS_9GeneratorE($15,$248,$209,$249,$213);
     __ZN12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE4PushERKS1_($queue,$15);
    }
    $250 = HEAP32[$73>>2]|0;
    $251 = (($250) + -1)|0;
    $252 = ($209|0)<($251|0);
    if ($252) {
     $253 = (($209) + 1)|0;
     $254 = HEAP32[$66>>2]|0;
     $255 = (($254) + ($211))|0;
     __ZN16b2VoronoiDiagram20b2VoronoiDiagramTaskC2EiiiPNS_9GeneratorE($16,$207,$253,$255,$213);
     __ZN12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE4PushERKS1_($queue,$16);
    }
   }
  }
  $237 = (__ZNK12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE5EmptyEv($queue)|0);
  if ($237) {
   break;
  }
 }
 __ZN12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEED2Ev($queue);
 STACKTOP = sp;return;
}
function __ZNK16b2VoronoiDiagram8GetNodesERNS_12NodeCallbackE($this,$callback) {
 $this = $this|0;
 $callback = $callback|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond1 = 0, $x$02 = 0, $y$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 $3 = ($2|0)>(0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 16|0);
 $5 = (($this) + 24|0);
 $y$03 = 0;
 while(1) {
  $6 = HEAP32[$4>>2]|0;
  $7 = (($6) + -1)|0;
  $8 = ($7|0)>(0);
  if ($8) {
   $10 = $6;$x$02 = 0;
   while(1) {
    $9 = Math_imul($10, $y$03)|0;
    $11 = (($9) + ($x$02))|0;
    $12 = HEAP32[$5>>2]|0;
    $13 = (($12) + ($11<<2)|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = (($11) + 1)|0;
    $16 = (($12) + ($15<<2)|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($11) + ($10))|0;
    $19 = (($12) + ($18<<2)|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = (($15) + ($10))|0;
    $22 = (($12) + ($21<<2)|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($17|0)==($20|0);
    do {
     if (!($24)) {
      $25 = ($14|0)==($17|0);
      $26 = ($14|0)==($20|0);
      $or$cond = $25 | $26;
      do {
       if (!($or$cond)) {
        $27 = (($14) + 12|0);
        $28 = HEAP8[$27>>0]|0;
        $29 = ($28<<24>>24)==(0);
        if ($29) {
         $30 = (($17) + 12|0);
         $31 = HEAP8[$30>>0]|0;
         $32 = ($31<<24>>24)==(0);
         if ($32) {
          $33 = (($20) + 12|0);
          $34 = HEAP8[$33>>0]|0;
          $35 = ($34<<24>>24)==(0);
          if ($35) {
           break;
          }
         }
        }
        $36 = HEAP32[$callback>>2]|0;
        $37 = (($36) + 8|0);
        $38 = HEAP32[$37>>2]|0;
        $39 = (($14) + 8|0);
        $40 = HEAP32[$39>>2]|0;
        $41 = (($17) + 8|0);
        $42 = HEAP32[$41>>2]|0;
        $43 = (($20) + 8|0);
        $44 = HEAP32[$43>>2]|0;
        FUNCTION_TABLE_viiii[$38 & 31]($callback,$40,$42,$44);
       }
      } while(0);
      $45 = ($23|0)==($17|0);
      $46 = ($23|0)==($20|0);
      $or$cond1 = $45 | $46;
      if (!($or$cond1)) {
       $47 = (($17) + 12|0);
       $48 = HEAP8[$47>>0]|0;
       $49 = ($48<<24>>24)==(0);
       if ($49) {
        $50 = (($23) + 12|0);
        $51 = HEAP8[$50>>0]|0;
        $52 = ($51<<24>>24)==(0);
        if ($52) {
         $53 = (($20) + 12|0);
         $54 = HEAP8[$53>>0]|0;
         $55 = ($54<<24>>24)==(0);
         if ($55) {
          break;
         }
        }
       }
       $56 = HEAP32[$callback>>2]|0;
       $57 = (($56) + 8|0);
       $58 = HEAP32[$57>>2]|0;
       $59 = (($17) + 8|0);
       $60 = HEAP32[$59>>2]|0;
       $61 = (($23) + 8|0);
       $62 = HEAP32[$61>>2]|0;
       $63 = (($20) + 8|0);
       $64 = HEAP32[$63>>2]|0;
       FUNCTION_TABLE_viiii[$58 & 31]($callback,$60,$62,$64);
      }
     }
    } while(0);
    $65 = (($x$02) + 1)|0;
    $66 = HEAP32[$4>>2]|0;
    $67 = (($66) + -1)|0;
    $68 = ($65|0)<($67|0);
    if ($68) {
     $10 = $66;$x$02 = $65;
    } else {
     break;
    }
   }
  }
  $69 = (($y$03) + 1)|0;
  $70 = HEAP32[$0>>2]|0;
  $71 = (($70) + -1)|0;
  $72 = ($69|0)<($71|0);
  if ($72) {
   $y$03 = $69;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEEC2EP16b2StackAllocatori($this,$allocator,$capacity) {
 $this = $this|0;
 $allocator = $allocator|0;
 $capacity = $capacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $allocator;
 $0 = $capacity << 4;
 $1 = (__ZN16b2StackAllocator8AllocateEi($allocator,$0)|0);
 $2 = (($this) + 4|0);
 HEAP32[$2>>2] = $1;
 $3 = (($this) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = (($this) + 12|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 16|0);
 HEAP32[$5>>2] = $capacity;
 STACKTOP = sp;return;
}
function __ZNK12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE5EmptyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN16b2VoronoiDiagram20b2VoronoiDiagramTaskC2EiiiPNS_9GeneratorE($this,$x,$y,$i,$g) {
 $this = $this|0;
 $x = $x|0;
 $y = $y|0;
 $i = $i|0;
 $g = $g|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $x;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $y;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $i;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = $g;
 STACKTOP = sp;return;
}
function __ZN12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE4PushERKS1_($this,$item) {
 $this = $this|0;
 $item = $item|0;
 var $$lcssa = 0, $$lcssa1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $storemerge = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)<($3|0);
 if (!($4)) {
  $5 = (($this) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$0>>2]|0;
  $8 = ($6|0)<($7|0);
  if ($8) {
   $9 = (($this) + 4|0);
   $11 = $6;$i$02 = $6;
   while(1) {
    $10 = (($i$02) - ($11))|0;
    $12 = HEAP32[$9>>2]|0;
    $13 = (($12) + ($10<<4)|0);
    $14 = (($12) + ($i$02<<4)|0);
    ;HEAP32[$13+0>>2]=HEAP32[$14+0>>2]|0;HEAP32[$13+4>>2]=HEAP32[$14+4>>2]|0;HEAP32[$13+8>>2]=HEAP32[$14+8>>2]|0;HEAP32[$13+12>>2]=HEAP32[$14+12>>2]|0;
    $15 = (($i$02) + 1)|0;
    $16 = HEAP32[$0>>2]|0;
    $17 = ($15|0)<($16|0);
    $18 = HEAP32[$5>>2]|0;
    if ($17) {
     $11 = $18;$i$02 = $15;
    } else {
     $$lcssa = $16;$$lcssa1 = $18;
     break;
    }
   }
  } else {
   $$lcssa = $7;$$lcssa1 = $6;
  }
  $19 = (($$lcssa) - ($$lcssa1))|0;
  HEAP32[$0>>2] = $19;
  HEAP32[$5>>2] = 0;
  $20 = HEAP32[$0>>2]|0;
  $21 = HEAP32[$2>>2]|0;
  $22 = ($20|0)<($21|0);
  if (!($22)) {
   $23 = ($21|0)>(0);
   $24 = $21 << 1;
   $storemerge = $23 ? $24 : 1;
   HEAP32[$2>>2] = $storemerge;
   $25 = HEAP32[$this>>2]|0;
   $26 = (($this) + 4|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = $storemerge << 4;
   $29 = (__ZN16b2StackAllocator10ReallocateEPvi($25,$27,$28)|0);
   HEAP32[$26>>2] = $29;
  }
 }
 $30 = HEAP32[$0>>2]|0;
 $31 = (($this) + 4|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + ($30<<4)|0);
 ;HEAP32[$33+0>>2]=HEAP32[$item+0>>2]|0;HEAP32[$33+4>>2]=HEAP32[$item+4>>2]|0;HEAP32[$33+8>>2]=HEAP32[$item+8>>2]|0;HEAP32[$33+12>>2]=HEAP32[$item+12>>2]|0;
 $34 = HEAP32[$0>>2]|0;
 $35 = (($34) + 1)|0;
 HEAP32[$0>>2] = $35;
 STACKTOP = sp;return;
}
function __ZN12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEED2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 __ZN16b2StackAllocator4FreeEPv($0,$2);
 STACKTOP = sp;return;
}
function __ZNK12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE5FrontEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($1<<4)|0);
 STACKTOP = sp;return ($4|0);
}
function __ZN12b2StackQueueIN16b2VoronoiDiagram20b2VoronoiDiagramTaskEE3PopEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 1)|0;
 HEAP32[$0>>2] = $2;
 STACKTOP = sp;return;
}
function __ZN15b2ParticleGroupC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 40|0);
 $1 = (($this) + 48|0);
 $2 = (($this) + 60|0);
 $3 = (($this) + 16|0);
 ;HEAP32[$this+0>>2]=0|0;HEAP32[$this+4>>2]=0|0;HEAP32[$this+8>>2]=0|0;HEAP32[$this+12>>2]=0|0;
 HEAPF32[$3>>2] = 1.0;
 $4 = (($this) + 20|0);
 HEAP32[$4>>2] = 0;
 $5 = (($this) + 24|0);
 HEAP32[$5>>2] = 0;
 $6 = (($this) + 28|0);
 HEAP32[$6>>2] = -1;
 $7 = (($this) + 32|0);
 HEAPF32[$7>>2] = 0.0;
 $8 = (($this) + 36|0);
 HEAPF32[$8>>2] = 0.0;
 $9 = 10224;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = $0;
 $16 = $15;
 HEAP32[$16>>2] = $11;
 $17 = (($15) + 4)|0;
 $18 = $17;
 HEAP32[$18>>2] = $14;
 $19 = 10224;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($19) + 4)|0;
 $23 = $22;
 $24 = HEAP32[$23>>2]|0;
 $25 = $1;
 $26 = $25;
 HEAP32[$26>>2] = $21;
 $27 = (($25) + 4)|0;
 $28 = $27;
 HEAP32[$28>>2] = $24;
 $29 = (($this) + 56|0);
 HEAPF32[$29>>2] = 0.0;
 __ZN11b2Transform11SetIdentityEv($2);
 $30 = (($this) + 76|0);
 HEAP32[$30>>2] = 0;
 STACKTOP = sp;return;
}
function __ZNK15b2ParticleGroup16UpdateStatisticsEv($this) {
 $this = $this|0;
 var $$lcssa2 = 0.0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0;
 var $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0.0, $9 = 0, $i$03 = 0, $i1$01 = 0, $p = 0, $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 24|0;
 $1 = sp + 16|0;
 $p = sp + 8|0;
 $v = sp;
 $2 = (($this) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$this>>2]|0;
 $5 = (($4) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($3|0)==($6|0);
 if ($7) {
  STACKTOP = sp;return;
 }
 $8 = (+__ZNK16b2ParticleSystem15GetParticleMassEv($4));
 $9 = (($this) + 32|0);
 HEAPF32[$9>>2] = 0.0;
 $10 = (($this) + 40|0);
 __ZN6b2Vec27SetZeroEv($10);
 $11 = (($this) + 48|0);
 __ZN6b2Vec27SetZeroEv($11);
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($this) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($13|0)<($15|0);
 $17 = +HEAPF32[$9>>2];
 if ($16) {
  $19 = $17;$i$03 = $13;
  while(1) {
   $18 = $8 + $19;
   HEAPF32[$9>>2] = $18;
   $20 = HEAP32[$this>>2]|0;
   $21 = (($20) + 96|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (($22) + ($i$03<<3)|0);
   __ZmlfRK6b2Vec2($0,$8,$23);
   __ZN6b2Vec2pLERKS_($10,$0);
   $24 = HEAP32[$this>>2]|0;
   $25 = (($24) + 104|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (($26) + ($i$03<<3)|0);
   __ZmlfRK6b2Vec2($1,$8,$27);
   __ZN6b2Vec2pLERKS_($11,$1);
   $28 = (($i$03) + 1)|0;
   $29 = HEAP32[$14>>2]|0;
   $30 = ($28|0)<($29|0);
   $31 = +HEAPF32[$9>>2];
   if ($30) {
    $19 = $31;$i$03 = $28;
   } else {
    $$lcssa2 = $31;
    break;
   }
  }
 } else {
  $$lcssa2 = $17;
 }
 $32 = $$lcssa2 > 0.0;
 if ($32) {
  $33 = 1.0 / $$lcssa2;
  __ZN6b2Vec2mLEf($10,$33);
  $34 = +HEAPF32[$9>>2];
  $35 = 1.0 / $34;
  __ZN6b2Vec2mLEf($11,$35);
 }
 $36 = (($this) + 36|0);
 HEAPF32[$36>>2] = 0.0;
 $37 = (($this) + 56|0);
 HEAPF32[$37>>2] = 0.0;
 $38 = HEAP32[$12>>2]|0;
 $39 = HEAP32[$14>>2]|0;
 $40 = ($38|0)<($39|0);
 if ($40) {
  $i1$01 = $38;
  while(1) {
   $41 = HEAP32[$this>>2]|0;
   $42 = (($41) + 96|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = (($43) + ($i1$01<<3)|0);
   __ZmiRK6b2Vec2S1_($p,$44,$10);
   $45 = HEAP32[$this>>2]|0;
   $46 = (($45) + 104|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = (($47) + ($i1$01<<3)|0);
   __ZmiRK6b2Vec2S1_($v,$48,$11);
   $49 = (+__Z5b2DotRK6b2Vec2S1_($p,$p));
   $50 = $8 * $49;
   $51 = +HEAPF32[$36>>2];
   $52 = $51 + $50;
   HEAPF32[$36>>2] = $52;
   $53 = (+__Z7b2CrossRK6b2Vec2S1_($p,$v));
   $54 = $8 * $53;
   $55 = +HEAPF32[$37>>2];
   $56 = $55 + $54;
   HEAPF32[$37>>2] = $56;
   $57 = (($i1$01) + 1)|0;
   $58 = HEAP32[$14>>2]|0;
   $59 = ($57|0)<($58|0);
   if ($59) {
    $i1$01 = $57;
   } else {
    break;
   }
  }
 }
 $60 = +HEAPF32[$36>>2];
 $61 = $60 > 0.0;
 if ($61) {
  $62 = 1.0 / $60;
  $63 = +HEAPF32[$37>>2];
  $64 = $62 * $63;
  HEAPF32[$37>>2] = $64;
 }
 $65 = HEAP32[$this>>2]|0;
 $66 = (($65) + 4|0);
 $67 = HEAP32[$66>>2]|0;
 HEAP32[$2>>2] = $67;
 STACKTOP = sp;return;
}
function __ZN15b2ParticleGroup10ApplyForceERK6b2Vec2($this,$force) {
 $this = $this|0;
 $force = $force|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN16b2ParticleSystem10ApplyForceEiiRK6b2Vec2($0,$2,$4,$force);
 STACKTOP = sp;return;
}
function __ZN15b2ParticleGroup18ApplyLinearImpulseERK6b2Vec2($this,$impulse) {
 $this = $this|0;
 $impulse = $impulse|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN16b2ParticleSystem18ApplyLinearImpulseEiiRK6b2Vec2($0,$2,$4,$impulse);
 STACKTOP = sp;return;
}
function __ZN15b2ParticleGroup16DestroyParticlesEb($this,$callDestructionListener) {
 $this = $this|0;
 $callDestructionListener = $callDestructionListener|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + 400|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZNK7b2World8IsLockedEv($2)|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5|0)<($7|0);
 if ($8) {
  $i$01 = $5;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $9 = HEAP32[$this>>2]|0;
  __ZN16b2ParticleSystem15DestroyParticleEib($9,$i$01,$callDestructionListener);
  $10 = (($i$01) + 1)|0;
  $11 = HEAP32[$6>>2]|0;
  $12 = ($10|0)<($11|0);
  if ($12) {
   $i$01 = $10;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN11b2Transform11SetIdentityEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN6b2Vec27SetZeroEv($this);
 $0 = (($this) + 8|0);
 __ZN5b2Rot11SetIdentityEv($0);
 STACKTOP = sp;return;
}
function __ZNK16b2ParticleSystem15GetParticleMassEv($this) {
 $this = $this|0;
 var $0 = 0.0, $1 = 0, $2 = 0.0, $3 = 0.0, $4 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+__ZNK16b2ParticleSystem17GetParticleStrideEv($this));
 $1 = (($this) + 320|0);
 $2 = +HEAPF32[$1>>2];
 $3 = $0 * $2;
 $4 = $0 * $3;
 STACKTOP = sp;return (+$4);
}
function __ZN5b2Rot11SetIdentityEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF32[$this>>2] = 0.0;
 $0 = (($this) + 4|0);
 HEAPF32[$0>>2] = 1.0;
 STACKTOP = sp;return;
}
function __ZNK16b2ParticleSystem17GetParticleStrideEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0.0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = +HEAPF32[$0>>2];
 $2 = $1 * 0.75;
 STACKTOP = sp;return (+$2);
}
function __ZN16b2ParticleSystem22InsideBoundsEnumeratorC2EjjPKNS_5ProxyES3_($this,$lower,$upper,$first,$last) {
 $this = $this|0;
 $lower = $lower|0;
 $upper = $upper|0;
 $first = $first|0;
 $last = $last|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $lower & 1048575;
 HEAP32[$this>>2] = $0;
 $1 = $upper & 1048575;
 $2 = (($this) + 4|0);
 HEAP32[$2>>2] = $1;
 $3 = $lower & -1048576;
 $4 = (($this) + 8|0);
 HEAP32[$4>>2] = $3;
 $5 = $upper & -1048576;
 $6 = (($this) + 12|0);
 HEAP32[$6>>2] = $5;
 $7 = (($this) + 16|0);
 HEAP32[$7>>2] = $first;
 $8 = (($this) + 20|0);
 HEAP32[$8>>2] = $last;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem22InsideBoundsEnumerator7GetNextEv($this) {
 $this = $this|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1>>>0)<($3>>>0);
 if (!($4)) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = HEAP32[$this>>2]|0;
 $6 = (($this) + 4|0);
 $8 = $1;
 while(1) {
  $7 = (($8) + 4|0);
  $9 = HEAP32[$7>>2]|0;
  $10 = $9 & 1048575;
  $11 = ($10>>>0)<($5>>>0);
  if (!($11)) {
   $12 = HEAP32[$6>>2]|0;
   $13 = ($10>>>0)>($12>>>0);
   if (!($13)) {
    break;
   }
  }
  $16 = HEAP32[$0>>2]|0;
  $17 = (($16) + 8|0);
  HEAP32[$0>>2] = $17;
  $18 = HEAP32[$2>>2]|0;
  $19 = ($17>>>0)<($18>>>0);
  if ($19) {
   $8 = $17;
  } else {
   $$0 = -1;
   label = 7;
   break;
  }
 }
 if ((label|0) == 7) {
  STACKTOP = sp;return ($$0|0);
 }
 $14 = (($8) + 8|0);
 HEAP32[$0>>2] = $14;
 $15 = HEAP32[$8>>2]|0;
 $$0 = $15;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16b2ParticleSystemC2EPK19b2ParticleSystemDefP7b2World($this,$def,$world) {
 $this = $this|0;
 $def = $def|0;
 $world = $world|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0.0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 52|0);
 __ZN15b2SlabAllocatorI16b2ParticleHandleEC2Ej($0,256);
 $1 = (($this) + 80|0);
 __ZN16b2ParticleSystem21UserOverridableBufferIP16b2ParticleHandleEC2Ev($1);
 $2 = (($this) + 88|0);
 __ZN16b2ParticleSystem21UserOverridableBufferIjEC2Ev($2);
 $3 = (($this) + 96|0);
 __ZN16b2ParticleSystem21UserOverridableBufferI6b2Vec2EC2Ev($3);
 $4 = (($this) + 104|0);
 __ZN16b2ParticleSystem21UserOverridableBufferI6b2Vec2EC2Ev($4);
 $5 = (($this) + 136|0);
 __ZN16b2ParticleSystem21UserOverridableBufferI15b2ParticleColorEC2Ev($5);
 $6 = (($this) + 148|0);
 __ZN16b2ParticleSystem21UserOverridableBufferIPvEC2Ev($6);
 $7 = (($this) + 160|0);
 __ZN16b2ParticleSystem21UserOverridableBufferIiEC2Ev($7);
 $8 = (($this) + 168|0);
 __ZN16b2ParticleSystem21UserOverridableBufferIiEC2Ev($8);
 $9 = (($this) + 176|0);
 __ZN16b2ParticleSystem21UserOverridableBufferIiEC2Ev($9);
 $10 = (($this) + 184|0);
 __ZN16b2GrowableBufferIiEC2ER16b2BlockAllocator($10,$world);
 $11 = (($this) + 200|0);
 __ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEEC2ER16b2BlockAllocator($11,$world);
 $12 = (($this) + 216|0);
 __ZN16b2GrowableBufferI17b2ParticleContactEC2ER16b2BlockAllocator($12,$world);
 $13 = (($this) + 232|0);
 __ZN16b2GrowableBufferI21b2ParticleBodyContactEC2ER16b2BlockAllocator($13,$world);
 $14 = (($this) + 248|0);
 __ZN16b2GrowableBufferI14b2ParticlePairEC2ER16b2BlockAllocator($14,$world);
 $15 = (($this) + 264|0);
 __ZN16b2GrowableBufferI15b2ParticleTriadEC2ER16b2BlockAllocator($15,$world);
 $16 = (($this) + 280|0);
 __ZN16b2ParticleSystem21UserOverridableBufferIiEC2Ev($16);
 $17 = (($this) + 288|0);
 __ZN16b2ParticleSystem21UserOverridableBufferIiEC2Ev($17);
 $18 = (($this) + 316|0);
 __ZN19b2ParticleSystemDefC2Ev($18);
 HEAP8[$this>>0] = 0;
 $19 = (($this) + 4|0);
 HEAP32[$19>>2] = 0;
 $20 = (($this) + 8|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 12|0);
 HEAP8[$21>>0] = 0;
 $22 = (($this) + 16|0);
 HEAP32[$22>>2] = 0;
 $23 = (($this) + 20|0);
 HEAP8[$23>>0] = 0;
 $24 = (($this) + 21|0);
 HEAP8[$24>>0] = 0;
 $25 = (($this) + 24|0);
 HEAP32[$25>>2] = 0;
 $26 = HEAP8[$def>>0]|0;
 $27 = ($26<<24>>24)!=(0);
 __ZN16b2ParticleSystem21SetStrictContactCheckEb($this,$27);
 $28 = (($def) + 4|0);
 $29 = +HEAPF32[$28>>2];
 __ZN16b2ParticleSystem10SetDensityEf($this,$29);
 $30 = (($def) + 8|0);
 $31 = +HEAPF32[$30>>2];
 __ZN16b2ParticleSystem15SetGravityScaleEf($this,$31);
 $32 = (($def) + 12|0);
 $33 = +HEAPF32[$32>>2];
 __ZN16b2ParticleSystem9SetRadiusEf($this,$33);
 $34 = (($def) + 16|0);
 $35 = HEAP32[$34>>2]|0;
 __ZN16b2ParticleSystem19SetMaxParticleCountEi($this,$35);
 $36 = (($this) + 44|0);
 HEAP32[$36>>2] = 0;
 $37 = (($this) + 48|0);
 HEAP32[$37>>2] = 0;
 $38 = (($this) + 112|0);
 $39 = (($this) + 144|0);
 HEAP32[$39>>2] = 0;
 $40 = (($this) + 308|0);
 HEAP32[$40>>2] = 0;
 $41 = (($this) + 312|0);
 HEAP32[$41>>2] = 0;
 ;HEAP32[$38+0>>2]=0|0;HEAP32[$38+4>>2]=0|0;HEAP32[$38+8>>2]=0|0;HEAP32[$38+12>>2]=0|0;HEAP32[$38+16>>2]=0|0;HEAP32[$38+20>>2]=0|0;
 dest=$18+0|0; src=$def+0|0; stop=dest+84|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $42 = (($this) + 400|0);
 HEAP32[$42>>2] = $world;
 $43 = (($this) + 156|0);
 HEAP32[$43>>2] = 0;
 $44 = (($this) + 296|0);
 $45 = $44;
 $46 = $45;
 HEAP32[$46>>2] = 0;
 $47 = (($45) + 4)|0;
 $48 = $47;
 HEAP32[$48>>2] = 0;
 $49 = (($this) + 304|0);
 HEAP8[$49>>0] = 0;
 $50 = (($this) + 392|0);
 $51 = HEAP8[$50>>0]|0;
 $52 = ($51<<24>>24)!=(0);
 __ZN16b2ParticleSystem19SetDestructionByAgeEb($this,$52);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem19SetDestructionByAgeEb($this,$enable) {
 $this = $this|0;
 $enable = $enable|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ($enable) {
  (__ZN16b2ParticleSystem23GetExpirationTimeBufferEv($this)|0);
 }
 $0 = (($this) + 392|0);
 $1 = $enable&1;
 HEAP8[$0>>0] = $1;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystemD2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 312|0);
 while(1) {
  $1 = HEAP32[$0>>2]|0;
  $2 = ($1|0)==(0|0);
  if ($2) {
   break;
  }
  __ZN16b2ParticleSystem20DestroyParticleGroupEP15b2ParticleGroup($this,$1);
 }
 $3 = (($this) + 80|0);
 __ZN16b2ParticleSystem25FreeUserOverridableBufferIP16b2ParticleHandleEEvPNS_21UserOverridableBufferIT_EE($this,$3);
 $4 = (($this) + 88|0);
 __ZN16b2ParticleSystem25FreeUserOverridableBufferIjEEvPNS_21UserOverridableBufferIT_EE($this,$4);
 $5 = (($this) + 160|0);
 __ZN16b2ParticleSystem25FreeUserOverridableBufferIiEEvPNS_21UserOverridableBufferIT_EE($this,$5);
 $6 = (($this) + 168|0);
 __ZN16b2ParticleSystem25FreeUserOverridableBufferIiEEvPNS_21UserOverridableBufferIT_EE($this,$6);
 $7 = (($this) + 176|0);
 __ZN16b2ParticleSystem25FreeUserOverridableBufferIiEEvPNS_21UserOverridableBufferIT_EE($this,$7);
 $8 = (($this) + 96|0);
 __ZN16b2ParticleSystem25FreeUserOverridableBufferI6b2Vec2EEvPNS_21UserOverridableBufferIT_EE($this,$8);
 $9 = (($this) + 104|0);
 __ZN16b2ParticleSystem25FreeUserOverridableBufferI6b2Vec2EEvPNS_21UserOverridableBufferIT_EE($this,$9);
 $10 = (($this) + 136|0);
 __ZN16b2ParticleSystem25FreeUserOverridableBufferI15b2ParticleColorEEvPNS_21UserOverridableBufferIT_EE($this,$10);
 $11 = (($this) + 148|0);
 __ZN16b2ParticleSystem25FreeUserOverridableBufferIPvEEvPNS_21UserOverridableBufferIT_EE($this,$11);
 $12 = (($this) + 280|0);
 __ZN16b2ParticleSystem25FreeUserOverridableBufferIiEEvPNS_21UserOverridableBufferIT_EE($this,$12);
 $13 = (($this) + 288|0);
 __ZN16b2ParticleSystem25FreeUserOverridableBufferIiEEvPNS_21UserOverridableBufferIT_EE($this,$13);
 $14 = (($this) + 112|0);
 $15 = (($this) + 48|0);
 $16 = HEAP32[$15>>2]|0;
 __ZN16b2ParticleSystem10FreeBufferI6b2Vec2EEvPPT_i($this,$14,$16);
 $17 = (($this) + 116|0);
 $18 = HEAP32[$15>>2]|0;
 __ZN16b2ParticleSystem10FreeBufferIfEEvPPT_i($this,$17,$18);
 $19 = (($this) + 120|0);
 $20 = HEAP32[$15>>2]|0;
 __ZN16b2ParticleSystem10FreeBufferIfEEvPPT_i($this,$19,$20);
 $21 = (($this) + 124|0);
 $22 = HEAP32[$15>>2]|0;
 __ZN16b2ParticleSystem10FreeBufferIfEEvPPT_i($this,$21,$22);
 $23 = (($this) + 128|0);
 $24 = HEAP32[$15>>2]|0;
 __ZN16b2ParticleSystem10FreeBufferI6b2Vec2EEvPPT_i($this,$23,$24);
 $25 = (($this) + 132|0);
 $26 = HEAP32[$15>>2]|0;
 __ZN16b2ParticleSystem10FreeBufferIfEEvPPT_i($this,$25,$26);
 $27 = (($this) + 144|0);
 $28 = HEAP32[$15>>2]|0;
 __ZN16b2ParticleSystem10FreeBufferIP15b2ParticleGroupEEvPPT_i($this,$27,$28);
 $29 = (($this) + 264|0);
 __ZN16b2GrowableBufferI15b2ParticleTriadED2Ev($29);
 $30 = (($this) + 248|0);
 __ZN16b2GrowableBufferI14b2ParticlePairED2Ev($30);
 $31 = (($this) + 232|0);
 __ZN16b2GrowableBufferI21b2ParticleBodyContactED2Ev($31);
 $32 = (($this) + 216|0);
 __ZN16b2GrowableBufferI17b2ParticleContactED2Ev($32);
 $33 = (($this) + 200|0);
 __ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEED2Ev($33);
 $34 = (($this) + 184|0);
 __ZN16b2GrowableBufferIiED2Ev($34);
 $35 = (($this) + 52|0);
 __ZN15b2SlabAllocatorI16b2ParticleHandleED2Ev($35);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem20DestroyParticleGroupEP15b2ParticleGroup($this,$group) {
 $this = $this|0;
 $group = $group|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 400|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 102992|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + 16|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_vii[$7 & 63]($3,$group);
 }
 __ZN16b2ParticleSystem13SetGroupFlagsEP15b2ParticleGroupj($this,$group,0);
 $8 = (($group) + 4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($group) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9|0)<($11|0);
 if ($12) {
  $13 = (($this) + 144|0);
  $14 = HEAP32[$10>>2]|0;
  $i$01 = $9;
  while(1) {
   $15 = HEAP32[$13>>2]|0;
   $16 = (($15) + ($i$01<<2)|0);
   HEAP32[$16>>2] = 0;
   $17 = (($i$01) + 1)|0;
   $18 = ($17|0)<($14|0);
   if ($18) {
    $i$01 = $17;
   } else {
    break;
   }
  }
 }
 $19 = (($group) + 20|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(0|0);
 if (!($21)) {
  $22 = (($group) + 24|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = (($20) + 24|0);
  HEAP32[$24>>2] = $23;
 }
 $25 = (($group) + 24|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if (!($27)) {
  $28 = HEAP32[$19>>2]|0;
  $29 = (($26) + 20|0);
  HEAP32[$29>>2] = $28;
 }
 $30 = (($this) + 312|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==($group|0);
 if (!($32)) {
  $34 = (($this) + 308|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = (($35) + -1)|0;
  HEAP32[$34>>2] = $36;
  $37 = HEAP32[$0>>2]|0;
  __ZN16b2BlockAllocator4FreeEPvi($37,$group,80);
  STACKTOP = sp;return;
 }
 $33 = HEAP32[$25>>2]|0;
 HEAP32[$30>>2] = $33;
 $34 = (($this) + 308|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + -1)|0;
 HEAP32[$34>>2] = $36;
 $37 = HEAP32[$0>>2]|0;
 __ZN16b2BlockAllocator4FreeEPvi($37,$group,80);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem23ReallocateHandleBuffersEi($this,$newCapacity) {
 $this = $this|0;
 $newCapacity = $newCapacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 80|0);
 $1 = (($this) + 48|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN16b2ParticleSystem16ReallocateBufferIP16b2ParticleHandleEEPT_PNS_21UserOverridableBufferIS3_EEiib($this,$0,$2,$newCapacity,1)|0);
 HEAP32[$0>>2] = $3;
 $4 = (($this) + 52|0);
 $5 = HEAP32[$1>>2]|0;
 $6 = (($newCapacity) - ($5))|0;
 __ZN15b2SlabAllocatorI16b2ParticleHandleE15SetItemsPerSlabEj($4,$6);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem14GetColorBufferEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 136|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN16b2ParticleSystem13RequestBufferI15b2ParticleColorEEPT_S3_($this,$1)|0);
 HEAP32[$0>>2] = $2;
 STACKTOP = sp;return ($2|0);
}
function __ZN16b2ParticleSystem34ReallocateInternalAllocatedBuffersEi($this,$capacity) {
 $this = $this|0;
 $capacity = $capacity|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 332|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZL13LimitCapacityii($capacity,$1)|0);
 $3 = (($this) + 88|0);
 $4 = (($this) + 92|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (__ZL13LimitCapacityii($2,$5)|0);
 $7 = (($this) + 96|0);
 $8 = (($this) + 100|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (__ZL13LimitCapacityii($6,$9)|0);
 $11 = (($this) + 104|0);
 $12 = (($this) + 108|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (__ZL13LimitCapacityii($10,$13)|0);
 $15 = (($this) + 136|0);
 $16 = (($this) + 140|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (__ZL13LimitCapacityii($14,$17)|0);
 $19 = (($this) + 148|0);
 $20 = (($this) + 152|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (__ZL13LimitCapacityii($18,$21)|0);
 $23 = (($this) + 48|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)<($22|0);
 if (!($25)) {
  STACKTOP = sp;return;
 }
 __ZN16b2ParticleSystem23ReallocateHandleBuffersEi($this,$22);
 $26 = HEAP32[$23>>2]|0;
 $27 = (__ZN16b2ParticleSystem16ReallocateBufferIjEEPT_PNS_21UserOverridableBufferIS1_EEiib($this,$3,$26,$22,0)|0);
 HEAP32[$3>>2] = $27;
 $28 = (($this) + 156|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)>(0);
 $31 = (($this) + 160|0);
 $32 = HEAP32[$23>>2]|0;
 $33 = (__ZN16b2ParticleSystem16ReallocateBufferIiEEPT_PNS_21UserOverridableBufferIS1_EEiib($this,$31,$32,$22,$30)|0);
 HEAP32[$31>>2] = $33;
 $34 = (($this) + 168|0);
 $35 = HEAP32[$23>>2]|0;
 $36 = (__ZN16b2ParticleSystem16ReallocateBufferIiEEPT_PNS_21UserOverridableBufferIS1_EEiib($this,$34,$35,$22,$30)|0);
 HEAP32[$34>>2] = $36;
 $37 = (($this) + 176|0);
 $38 = HEAP32[$23>>2]|0;
 $39 = (__ZN16b2ParticleSystem16ReallocateBufferIiEEPT_PNS_21UserOverridableBufferIS1_EEiib($this,$37,$38,$22,$30)|0);
 HEAP32[$37>>2] = $39;
 $40 = HEAP32[$23>>2]|0;
 $41 = (__ZN16b2ParticleSystem16ReallocateBufferI6b2Vec2EEPT_PNS_21UserOverridableBufferIS2_EEiib($this,$7,$40,$22,0)|0);
 HEAP32[$7>>2] = $41;
 $42 = HEAP32[$23>>2]|0;
 $43 = (__ZN16b2ParticleSystem16ReallocateBufferI6b2Vec2EEPT_PNS_21UserOverridableBufferIS2_EEiib($this,$11,$42,$22,0)|0);
 HEAP32[$11>>2] = $43;
 $44 = (($this) + 112|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = HEAP32[$23>>2]|0;
 $47 = (__ZN16b2ParticleSystem16ReallocateBufferI6b2Vec2EEPT_S3_iiib($this,$45,0,$46,$22,0)|0);
 HEAP32[$44>>2] = $47;
 $48 = (($this) + 116|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = HEAP32[$23>>2]|0;
 $51 = (__ZN16b2ParticleSystem16ReallocateBufferIfEEPT_S2_iiib($this,$49,0,$50,$22,0)|0);
 HEAP32[$48>>2] = $51;
 $52 = (($this) + 120|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = HEAP32[$23>>2]|0;
 $55 = (__ZN16b2ParticleSystem16ReallocateBufferIfEEPT_S2_iiib($this,$53,0,$54,$22,1)|0);
 HEAP32[$52>>2] = $55;
 $56 = (($this) + 124|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = HEAP32[$23>>2]|0;
 $59 = (__ZN16b2ParticleSystem16ReallocateBufferIfEEPT_S2_iiib($this,$57,0,$58,$22,0)|0);
 HEAP32[$56>>2] = $59;
 $60 = (($this) + 128|0);
 $61 = HEAP32[$60>>2]|0;
 $62 = HEAP32[$23>>2]|0;
 $63 = (__ZN16b2ParticleSystem16ReallocateBufferI6b2Vec2EEPT_S3_iiib($this,$61,0,$62,$22,1)|0);
 HEAP32[$60>>2] = $63;
 $64 = (($this) + 132|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = HEAP32[$23>>2]|0;
 $67 = (__ZN16b2ParticleSystem16ReallocateBufferIfEEPT_S2_iiib($this,$65,0,$66,$22,1)|0);
 HEAP32[$64>>2] = $67;
 $68 = HEAP32[$23>>2]|0;
 $69 = (__ZN16b2ParticleSystem16ReallocateBufferI15b2ParticleColorEEPT_PNS_21UserOverridableBufferIS2_EEiib($this,$15,$68,$22,1)|0);
 HEAP32[$15>>2] = $69;
 $70 = (($this) + 144|0);
 $71 = HEAP32[$70>>2]|0;
 $72 = HEAP32[$23>>2]|0;
 $73 = (__ZN16b2ParticleSystem16ReallocateBufferIP15b2ParticleGroupEEPT_S4_iiib($this,$71,0,$72,$22,0)|0);
 HEAP32[$70>>2] = $73;
 $74 = HEAP32[$23>>2]|0;
 $75 = (__ZN16b2ParticleSystem16ReallocateBufferIPvEEPT_PNS_21UserOverridableBufferIS2_EEiib($this,$19,$74,$22,1)|0);
 HEAP32[$19>>2] = $75;
 $76 = (($this) + 280|0);
 $77 = HEAP32[$23>>2]|0;
 $78 = (__ZN16b2ParticleSystem16ReallocateBufferIiEEPT_PNS_21UserOverridableBufferIS1_EEiib($this,$76,$77,$22,1)|0);
 HEAP32[$76>>2] = $78;
 $79 = (($this) + 288|0);
 $80 = HEAP32[$23>>2]|0;
 $81 = (__ZN16b2ParticleSystem16ReallocateBufferIiEEPT_PNS_21UserOverridableBufferIS1_EEiib($this,$79,$80,$22,1)|0);
 HEAP32[$79>>2] = $81;
 HEAP32[$23>>2] = $22;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem14CreateParticleERK13b2ParticleDef($this,$def) {
 $this = $this|0;
 $def = $def|0;
 var $$ = 0, $$0 = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0.0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 400|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK7b2World8IsLockedEv($1)|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 48|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)<($6|0);
 if (!($7)) {
  $8 = ($4|0)==(0);
  $9 = $4 << 1;
  $$ = $8 ? 256 : $9;
  __ZN16b2ParticleSystem34ReallocateInternalAllocatedBuffersEi($this,$$);
 }
 $10 = HEAP32[$3>>2]|0;
 $11 = HEAP32[$5>>2]|0;
 $12 = ($10|0)<($11|0);
 do {
  if (!($12)) {
   $13 = (($this) + 392|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = ($14<<24>>24)==(0);
   if ($15) {
    $$0 = -1;
    STACKTOP = sp;return ($$0|0);
   } else {
    __ZN16b2ParticleSystem21DestroyOldestParticleEib($this,0,0);
    __ZN16b2ParticleSystem11SolveZombieEv($this);
    break;
   }
  }
 } while(0);
 $16 = HEAP32[$3>>2]|0;
 $17 = (($16) + 1)|0;
 HEAP32[$3>>2] = $17;
 $18 = (($this) + 88|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = (($19) + ($16<<2)|0);
 HEAP32[$20>>2] = 0;
 $21 = (($this) + 160|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if (!($23)) {
  $24 = (($22) + ($16<<2)|0);
  HEAP32[$24>>2] = 0;
 }
 $25 = (($this) + 168|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if (!($27)) {
  $28 = (($26) + ($16<<2)|0);
  HEAP32[$28>>2] = 0;
 }
 $29 = (($this) + 176|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0|0);
 if (!($31)) {
  $32 = (($30) + ($16<<2)|0);
  HEAP32[$32>>2] = 0;
 }
 $33 = (($this) + 96|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + ($16<<3)|0);
 $36 = (($def) + 4|0);
 $37 = $36;
 $38 = $37;
 $39 = HEAP32[$38>>2]|0;
 $40 = (($37) + 4)|0;
 $41 = $40;
 $42 = HEAP32[$41>>2]|0;
 $43 = $35;
 $44 = $43;
 HEAP32[$44>>2] = $39;
 $45 = (($43) + 4)|0;
 $46 = $45;
 HEAP32[$46>>2] = $42;
 $47 = (($this) + 104|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($48) + ($16<<3)|0);
 $50 = (($def) + 12|0);
 $51 = $50;
 $52 = $51;
 $53 = HEAP32[$52>>2]|0;
 $54 = (($51) + 4)|0;
 $55 = $54;
 $56 = HEAP32[$55>>2]|0;
 $57 = $49;
 $58 = $57;
 HEAP32[$58>>2] = $53;
 $59 = (($57) + 4)|0;
 $60 = $59;
 HEAP32[$60>>2] = $56;
 $61 = (($this) + 116|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($62) + ($16<<2)|0);
 HEAPF32[$63>>2] = 0.0;
 $64 = (($this) + 112|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($65) + ($16<<3)|0);
 $67 = 10224;
 $68 = $67;
 $69 = HEAP32[$68>>2]|0;
 $70 = (($67) + 4)|0;
 $71 = $70;
 $72 = HEAP32[$71>>2]|0;
 $73 = $66;
 $74 = $73;
 HEAP32[$74>>2] = $69;
 $75 = (($73) + 4)|0;
 $76 = $75;
 HEAP32[$76>>2] = $72;
 $77 = (($this) + 120|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = ($78|0)==(0|0);
 if (!($79)) {
  $80 = (($78) + ($16<<2)|0);
  HEAPF32[$80>>2] = 0.0;
 }
 $81 = (($this) + 132|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = ($82|0)==(0|0);
 if (!($83)) {
  $84 = (($82) + ($16<<2)|0);
  HEAPF32[$84>>2] = 0.0;
 }
 $85 = (($this) + 136|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = ($86|0)==(0|0);
 if ($87) {
  $88 = (($def) + 20|0);
  $89 = (__ZNK15b2ParticleColor6IsZeroEv($88)|0);
  if (!($89)) {
   label = 19;
  }
 } else {
  label = 19;
 }
 if ((label|0) == 19) {
  $90 = HEAP32[$85>>2]|0;
  $91 = (__ZN16b2ParticleSystem13RequestBufferI15b2ParticleColorEEPT_S3_($this,$90)|0);
  HEAP32[$85>>2] = $91;
  $92 = (($91) + ($16<<2)|0);
  $93 = (($def) + 20|0);
  (__ZN15b2ParticleColoraSERKS_($92,$93)|0);
 }
 $94 = (($this) + 148|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = ($95|0)==(0|0);
 if ($96) {
  $97 = (($def) + 28|0);
  $98 = HEAP32[$97>>2]|0;
  $99 = ($98|0)==(0|0);
  if (!($99)) {
   label = 22;
  }
 } else {
  label = 22;
 }
 if ((label|0) == 22) {
  $100 = HEAP32[$94>>2]|0;
  $101 = (__ZN16b2ParticleSystem13RequestBufferIPvEEPT_S3_($this,$100)|0);
  HEAP32[$94>>2] = $101;
  $102 = (($def) + 28|0);
  $103 = HEAP32[$102>>2]|0;
  $104 = (($101) + ($16<<2)|0);
  HEAP32[$104>>2] = $103;
 }
 $105 = (($this) + 80|0);
 $106 = HEAP32[$105>>2]|0;
 $107 = ($106|0)==(0|0);
 if (!($107)) {
  $108 = (($106) + ($16<<2)|0);
  HEAP32[$108>>2] = 0;
 }
 $109 = (($this) + 200|0);
 $110 = (__ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEE6AppendEv($109)|0);
 $111 = (($def) + 24|0);
 $112 = +HEAPF32[$111>>2];
 $113 = $112 > 0.0;
 $114 = (($this) + 280|0);
 $115 = HEAP32[$114>>2]|0;
 $$not = ($115|0)!=(0|0);
 $brmerge = $$not | $113;
 if ($brmerge) {
  if ($113) {
   $119 = $112;
  } else {
   $116 = (__ZNK16b2ParticleSystem23GetQuantizedTimeElapsedEv($this)|0);
   $117 = (0 - ($116))|0;
   $118 = (+__ZNK16b2ParticleSystem24ExpirationTimeToLifetimeEi($this,$117));
   $119 = $118;
  }
  __ZN16b2ParticleSystem19SetParticleLifetimeEif($this,$16,$119);
  $120 = (($this) + 288|0);
  $121 = HEAP32[$120>>2]|0;
  $122 = (($121) + ($16<<2)|0);
  HEAP32[$122>>2] = $16;
 }
 HEAP32[$110>>2] = $16;
 $123 = (($def) + 32|0);
 $124 = HEAP32[$123>>2]|0;
 $125 = (($this) + 144|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = (($126) + ($16<<2)|0);
 HEAP32[$127>>2] = $124;
 $128 = ($124|0)==(0|0);
 do {
  if (!($128)) {
   $129 = (($124) + 4|0);
   $130 = HEAP32[$129>>2]|0;
   $131 = (($124) + 8|0);
   $132 = HEAP32[$131>>2]|0;
   $133 = ($130|0)<($132|0);
   if ($133) {
    __ZN16b2ParticleSystem12RotateBufferEiii($this,$130,$132,$16);
    HEAP32[$131>>2] = $17;
    break;
   } else {
    HEAP32[$129>>2] = $16;
    HEAP32[$131>>2] = $17;
    break;
   }
  }
 } while(0);
 $134 = HEAP32[$def>>2]|0;
 __ZN16b2ParticleSystem16SetParticleFlagsEij($this,$16,$134);
 $$0 = $16;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16b2ParticleSystem21DestroyOldestParticleEib($this,$index,$callDestructionListener) {
 $this = $this|0;
 $index = $index|0;
 $callDestructionListener = $callDestructionListener|0;
 var $$neg = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK16b2ParticleSystem16GetParticleCountEv($this)|0);
 $$neg = $index ^ -1;
 $1 = (($0) + ($$neg))|0;
 $2 = (($this) + 288|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($1<<2)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + ($index<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 280|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($5<<2)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (+($11|0));
 $13 = $12 > 0.0;
 $14 = $13 ? $5 : $7;
 __ZN16b2ParticleSystem15DestroyParticleEib($this,$14,$callDestructionListener);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem11SolveZombieEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0.0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0.0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $allParticleFlags$0$lcssa = 0, $allParticleFlags$055 = 0, $allParticleFlags$1 = 0, $firstIndex$0$lcssa = 0, $firstIndex$04 = 0, $firstIndex$1 = 0;
 var $group$014 = 0, $group8$03 = 0, $i$052 = 0, $i7$07 = 0, $k$047 = 0, $k2$040 = 0, $k3$034 = 0, $k5$028 = 0, $k6$022 = 0, $lastIndex$0$lcssa = 0, $lastIndex$05 = 0, $lastIndex$1 = 0, $modified$0$off0$lcssa = 0, $modified$0$off06 = 0, $modified$1$off0 = 0, $newCount$0$lcssa = 0, $newCount$056 = 0, $newCount$1 = 0, $or$cond = 0, $readOffset$019 = 0;
 var $writeOffset$018 = 0, $writeOffset$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 400|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 76|0);
 $3 = (($this) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 << 2;
 $6 = (__ZN16b2StackAllocator8AllocateEi($2,$5)|0);
 $7 = HEAP32[$3>>2]|0;
 $8 = ($7|0)>(0);
 if ($8) {
  $9 = (($this) + 88|0);
  $10 = (($this) + 80|0);
  $11 = (($this) + 160|0);
  $12 = (($this) + 168|0);
  $13 = (($this) + 176|0);
  $14 = (($this) + 96|0);
  $15 = (($this) + 104|0);
  $16 = (($this) + 144|0);
  $17 = (($this) + 21|0);
  $18 = (($this) + 120|0);
  $19 = (($this) + 132|0);
  $20 = (($this) + 136|0);
  $21 = (($this) + 148|0);
  $22 = (($this) + 280|0);
  $23 = (($this) + 112|0);
  $24 = (($this) + 80|0);
  $25 = (($this) + 52|0);
  $allParticleFlags$055 = 0;$i$052 = 0;$newCount$056 = 0;
  while(1) {
   $29 = HEAP32[$9>>2]|0;
   $30 = (($29) + ($i$052<<2)|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = $31 & 2;
   $33 = ($32|0)==(0);
   if ($33) {
    $51 = (($6) + ($i$052<<2)|0);
    HEAP32[$51>>2] = $newCount$056;
    $52 = ($i$052|0)==($newCount$056|0);
    if (!($52)) {
     $53 = HEAP32[$10>>2]|0;
     $54 = ($53|0)==(0|0);
     if (!($54)) {
      $55 = (($53) + ($i$052<<2)|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = ($56|0)==(0|0);
      if (!($57)) {
       __ZN16b2ParticleHandle8SetIndexEi($56,$newCount$056);
      }
      $58 = HEAP32[$10>>2]|0;
      $59 = (($58) + ($newCount$056<<2)|0);
      HEAP32[$59>>2] = $56;
     }
     $60 = HEAP32[$9>>2]|0;
     $61 = (($60) + ($i$052<<2)|0);
     $62 = HEAP32[$61>>2]|0;
     $63 = (($60) + ($newCount$056<<2)|0);
     HEAP32[$63>>2] = $62;
     $64 = HEAP32[$11>>2]|0;
     $65 = ($64|0)==(0|0);
     if (!($65)) {
      $66 = (($64) + ($i$052<<2)|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = (($64) + ($newCount$056<<2)|0);
      HEAP32[$68>>2] = $67;
     }
     $69 = HEAP32[$12>>2]|0;
     $70 = ($69|0)==(0|0);
     if (!($70)) {
      $71 = (($69) + ($i$052<<2)|0);
      $72 = HEAP32[$71>>2]|0;
      $73 = (($69) + ($newCount$056<<2)|0);
      HEAP32[$73>>2] = $72;
     }
     $74 = HEAP32[$13>>2]|0;
     $75 = ($74|0)==(0|0);
     if (!($75)) {
      $76 = (($74) + ($i$052<<2)|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (($74) + ($newCount$056<<2)|0);
      HEAP32[$78>>2] = $77;
     }
     $79 = HEAP32[$14>>2]|0;
     $80 = (($79) + ($newCount$056<<3)|0);
     $81 = (($79) + ($i$052<<3)|0);
     $82 = $81;
     $83 = $82;
     $84 = HEAP32[$83>>2]|0;
     $85 = (($82) + 4)|0;
     $86 = $85;
     $87 = HEAP32[$86>>2]|0;
     $88 = $80;
     $89 = $88;
     HEAP32[$89>>2] = $84;
     $90 = (($88) + 4)|0;
     $91 = $90;
     HEAP32[$91>>2] = $87;
     $92 = HEAP32[$15>>2]|0;
     $93 = (($92) + ($newCount$056<<3)|0);
     $94 = (($92) + ($i$052<<3)|0);
     $95 = $94;
     $96 = $95;
     $97 = HEAP32[$96>>2]|0;
     $98 = (($95) + 4)|0;
     $99 = $98;
     $100 = HEAP32[$99>>2]|0;
     $101 = $93;
     $102 = $101;
     HEAP32[$102>>2] = $97;
     $103 = (($101) + 4)|0;
     $104 = $103;
     HEAP32[$104>>2] = $100;
     $105 = HEAP32[$16>>2]|0;
     $106 = (($105) + ($i$052<<2)|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = (($105) + ($newCount$056<<2)|0);
     HEAP32[$108>>2] = $107;
     $109 = HEAP8[$17>>0]|0;
     $110 = ($109<<24>>24)==(0);
     if (!($110)) {
      $111 = HEAP32[$23>>2]|0;
      $112 = (($111) + ($newCount$056<<3)|0);
      $113 = (($111) + ($i$052<<3)|0);
      $114 = $113;
      $115 = $114;
      $116 = HEAP32[$115>>2]|0;
      $117 = (($114) + 4)|0;
      $118 = $117;
      $119 = HEAP32[$118>>2]|0;
      $120 = $112;
      $121 = $120;
      HEAP32[$121>>2] = $116;
      $122 = (($120) + 4)|0;
      $123 = $122;
      HEAP32[$123>>2] = $119;
     }
     $124 = HEAP32[$18>>2]|0;
     $125 = ($124|0)==(0|0);
     if (!($125)) {
      $126 = (($124) + ($i$052<<2)|0);
      $127 = +HEAPF32[$126>>2];
      $128 = (($124) + ($newCount$056<<2)|0);
      HEAPF32[$128>>2] = $127;
     }
     $129 = HEAP32[$19>>2]|0;
     $130 = ($129|0)==(0|0);
     if (!($130)) {
      $131 = (($129) + ($i$052<<2)|0);
      $132 = +HEAPF32[$131>>2];
      $133 = (($129) + ($newCount$056<<2)|0);
      HEAPF32[$133>>2] = $132;
     }
     $134 = HEAP32[$20>>2]|0;
     $135 = ($134|0)==(0|0);
     if (!($135)) {
      $136 = (($134) + ($newCount$056<<2)|0);
      $137 = (($134) + ($i$052<<2)|0);
      (__ZN15b2ParticleColoraSERKS_($136,$137)|0);
     }
     $138 = HEAP32[$21>>2]|0;
     $139 = ($138|0)==(0|0);
     if (!($139)) {
      $140 = (($138) + ($i$052<<2)|0);
      $141 = HEAP32[$140>>2]|0;
      $142 = (($138) + ($newCount$056<<2)|0);
      HEAP32[$142>>2] = $141;
     }
     $143 = HEAP32[$22>>2]|0;
     $144 = ($143|0)==(0|0);
     if (!($144)) {
      $145 = (($143) + ($i$052<<2)|0);
      $146 = HEAP32[$145>>2]|0;
      $147 = (($143) + ($newCount$056<<2)|0);
      HEAP32[$147>>2] = $146;
     }
    }
    $148 = (($newCount$056) + 1)|0;
    $149 = $31 | $allParticleFlags$055;
    $allParticleFlags$1 = $149;$newCount$1 = $148;
   } else {
    $34 = HEAP32[$0>>2]|0;
    $35 = (($34) + 102992|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = $31 & 512;
    $38 = ($37|0)!=(0);
    $39 = ($36|0)!=(0|0);
    $or$cond = $38 & $39;
    if ($or$cond) {
     $40 = HEAP32[$36>>2]|0;
     $41 = (($40) + 20|0);
     $42 = HEAP32[$41>>2]|0;
     FUNCTION_TABLE_viii[$42 & 15]($36,$this,$i$052);
    }
    $43 = HEAP32[$24>>2]|0;
    $44 = ($43|0)==(0|0);
    if (!($44)) {
     $45 = (($43) + ($i$052<<2)|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = ($46|0)==(0|0);
     if (!($47)) {
      __ZN16b2ParticleHandle8SetIndexEi($46,-1);
      $48 = HEAP32[$24>>2]|0;
      $49 = (($48) + ($i$052<<2)|0);
      HEAP32[$49>>2] = 0;
      __ZN15b2SlabAllocatorI16b2ParticleHandleE4FreeEPS0_($25,$46);
     }
    }
    $50 = (($6) + ($i$052<<2)|0);
    HEAP32[$50>>2] = -1;
    $allParticleFlags$1 = $allParticleFlags$055;$newCount$1 = $newCount$056;
   }
   $150 = (($i$052) + 1)|0;
   $151 = HEAP32[$3>>2]|0;
   $152 = ($150|0)<($151|0);
   if ($152) {
    $allParticleFlags$055 = $allParticleFlags$1;$i$052 = $150;$newCount$056 = $newCount$1;
   } else {
    $allParticleFlags$0$lcssa = $allParticleFlags$1;$newCount$0$lcssa = $newCount$1;
    break;
   }
  }
 } else {
  $allParticleFlags$0$lcssa = 0;$newCount$0$lcssa = 0;
 }
 $26 = (($this) + 200|0);
 $27 = (__ZNK16b2GrowableBufferIN16b2ParticleSystem5ProxyEE8GetCountEv($26)|0);
 $28 = ($27|0)>(0);
 if ($28) {
  $k$047 = 0;
  while(1) {
   $153 = (__ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEE5BeginEv($26)|0);
   $154 = (($153) + ($k$047<<3)|0);
   $155 = HEAP32[$154>>2]|0;
   $156 = (($6) + ($155<<2)|0);
   $157 = HEAP32[$156>>2]|0;
   HEAP32[$154>>2] = $157;
   $158 = (($k$047) + 1)|0;
   $159 = (__ZNK16b2GrowableBufferIN16b2ParticleSystem5ProxyEE8GetCountEv($26)|0);
   $160 = ($158|0)<($159|0);
   if ($160) {
    $k$047 = $158;
   } else {
    break;
   }
  }
 }
 (__ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEE8RemoveIfIPFbRKS1_EEEPS1_T_($26,7)|0);
 $161 = (($this) + 216|0);
 $162 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($161)|0);
 $163 = ($162|0)>(0);
 if ($163) {
  $k2$040 = 0;
  while(1) {
   $164 = (__ZN16b2GrowableBufferI17b2ParticleContactEixEi($161,$k2$040)|0);
   $165 = (__ZNK17b2ParticleContact9GetIndexAEv($164)|0);
   $166 = (($6) + ($165<<2)|0);
   $167 = HEAP32[$166>>2]|0;
   $168 = (__ZNK17b2ParticleContact9GetIndexBEv($164)|0);
   $169 = (($6) + ($168<<2)|0);
   $170 = HEAP32[$169>>2]|0;
   __ZN17b2ParticleContact10SetIndicesEii($164,$167,$170);
   $171 = (($k2$040) + 1)|0;
   $172 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($161)|0);
   $173 = ($171|0)<($172|0);
   if ($173) {
    $k2$040 = $171;
   } else {
    break;
   }
  }
 }
 (__ZN16b2GrowableBufferI17b2ParticleContactE8RemoveIfIPFbRKS0_EEEPS0_T_($161,8)|0);
 $174 = (($this) + 232|0);
 $175 = (__ZNK16b2GrowableBufferI21b2ParticleBodyContactE8GetCountEv($174)|0);
 $176 = ($175|0)>(0);
 if ($176) {
  $k3$034 = 0;
  while(1) {
   $177 = (__ZN16b2GrowableBufferI21b2ParticleBodyContactEixEi($174,$k3$034)|0);
   $178 = HEAP32[$177>>2]|0;
   $179 = (($6) + ($178<<2)|0);
   $180 = HEAP32[$179>>2]|0;
   HEAP32[$177>>2] = $180;
   $181 = (($k3$034) + 1)|0;
   $182 = (__ZNK16b2GrowableBufferI21b2ParticleBodyContactE8GetCountEv($174)|0);
   $183 = ($181|0)<($182|0);
   if ($183) {
    $k3$034 = $181;
   } else {
    break;
   }
  }
 }
 (__ZN16b2GrowableBufferI21b2ParticleBodyContactE8RemoveIfIPFbRKS0_EEEPS0_T_($174,9)|0);
 $184 = (($this) + 248|0);
 $185 = (__ZNK16b2GrowableBufferI14b2ParticlePairE8GetCountEv($184)|0);
 $186 = ($185|0)>(0);
 if ($186) {
  $k5$028 = 0;
  while(1) {
   $187 = (__ZN16b2GrowableBufferI14b2ParticlePairEixEi($184,$k5$028)|0);
   $188 = HEAP32[$187>>2]|0;
   $189 = (($6) + ($188<<2)|0);
   $190 = HEAP32[$189>>2]|0;
   HEAP32[$187>>2] = $190;
   $191 = (($187) + 4|0);
   $192 = HEAP32[$191>>2]|0;
   $193 = (($6) + ($192<<2)|0);
   $194 = HEAP32[$193>>2]|0;
   HEAP32[$191>>2] = $194;
   $195 = (($k5$028) + 1)|0;
   $196 = (__ZNK16b2GrowableBufferI14b2ParticlePairE8GetCountEv($184)|0);
   $197 = ($195|0)<($196|0);
   if ($197) {
    $k5$028 = $195;
   } else {
    break;
   }
  }
 }
 (__ZN16b2GrowableBufferI14b2ParticlePairE8RemoveIfIPFbRKS0_EEEPS0_T_($184,10)|0);
 $198 = (($this) + 264|0);
 $199 = (__ZNK16b2GrowableBufferI15b2ParticleTriadE8GetCountEv($198)|0);
 $200 = ($199|0)>(0);
 if ($200) {
  $k6$022 = 0;
  while(1) {
   $201 = (__ZN16b2GrowableBufferI15b2ParticleTriadEixEi($198,$k6$022)|0);
   $202 = HEAP32[$201>>2]|0;
   $203 = (($6) + ($202<<2)|0);
   $204 = HEAP32[$203>>2]|0;
   HEAP32[$201>>2] = $204;
   $205 = (($201) + 4|0);
   $206 = HEAP32[$205>>2]|0;
   $207 = (($6) + ($206<<2)|0);
   $208 = HEAP32[$207>>2]|0;
   HEAP32[$205>>2] = $208;
   $209 = (($201) + 8|0);
   $210 = HEAP32[$209>>2]|0;
   $211 = (($6) + ($210<<2)|0);
   $212 = HEAP32[$211>>2]|0;
   HEAP32[$209>>2] = $212;
   $213 = (($k6$022) + 1)|0;
   $214 = (__ZNK16b2GrowableBufferI15b2ParticleTriadE8GetCountEv($198)|0);
   $215 = ($213|0)<($214|0);
   if ($215) {
    $k6$022 = $213;
   } else {
    break;
   }
  }
 }
 (__ZN16b2GrowableBufferI15b2ParticleTriadE8RemoveIfIPFbRKS0_EEEPS0_T_($198,11)|0);
 $216 = (($this) + 288|0);
 $217 = HEAP32[$216>>2]|0;
 $218 = ($217|0)==(0|0);
 if (!($218)) {
  $219 = HEAP32[$3>>2]|0;
  $220 = ($219|0)>(0);
  if ($220) {
   $221 = HEAP32[$216>>2]|0;
   $readOffset$019 = 0;$writeOffset$018 = 0;
   while(1) {
    $222 = (($221) + ($readOffset$019<<2)|0);
    $223 = HEAP32[$222>>2]|0;
    $224 = (($6) + ($223<<2)|0);
    $225 = HEAP32[$224>>2]|0;
    $226 = ($225|0)==(-1);
    if ($226) {
     $writeOffset$1 = $writeOffset$018;
    } else {
     $227 = (($writeOffset$018) + 1)|0;
     $228 = (($221) + ($writeOffset$018<<2)|0);
     HEAP32[$228>>2] = $225;
     $writeOffset$1 = $227;
    }
    $229 = (($readOffset$019) + 1)|0;
    $230 = HEAP32[$3>>2]|0;
    $231 = ($229|0)<($230|0);
    if ($231) {
     $readOffset$019 = $229;$writeOffset$018 = $writeOffset$1;
    } else {
     break;
    }
   }
  }
 }
 $232 = (($this) + 312|0);
 $233 = HEAP32[$232>>2]|0;
 $234 = ($233|0)==(0|0);
 if (!($234)) {
  $group$014 = $233;
  while(1) {
   $235 = (($group$014) + 4|0);
   $236 = HEAP32[$235>>2]|0;
   $237 = (($group$014) + 8|0);
   $238 = HEAP32[$237>>2]|0;
   $239 = ($236|0)<($238|0);
   if ($239) {
    $240 = HEAP32[$237>>2]|0;
    $firstIndex$04 = $newCount$0$lcssa;$i7$07 = $236;$lastIndex$05 = 0;$modified$0$off06 = 0;
    while(1) {
     $241 = (($6) + ($i7$07<<2)|0);
     $242 = HEAP32[$241>>2]|0;
     $243 = ($242|0)>(-1);
     if ($243) {
      $244 = (__Z5b2MinIiET_S0_S0_($firstIndex$04,$242)|0);
      $245 = (($242) + 1)|0;
      $246 = (__Z5b2MaxIiET_S0_S0_($lastIndex$05,$245)|0);
      $firstIndex$1 = $244;$lastIndex$1 = $246;$modified$1$off0 = $modified$0$off06;
     } else {
      $firstIndex$1 = $firstIndex$04;$lastIndex$1 = $lastIndex$05;$modified$1$off0 = 1;
     }
     $247 = (($i7$07) + 1)|0;
     $248 = ($247|0)<($240|0);
     if ($248) {
      $firstIndex$04 = $firstIndex$1;$i7$07 = $247;$lastIndex$05 = $lastIndex$1;$modified$0$off06 = $modified$1$off0;
     } else {
      $firstIndex$0$lcssa = $firstIndex$1;$lastIndex$0$lcssa = $lastIndex$1;$modified$0$off0$lcssa = $modified$1$off0;
      break;
     }
    }
   } else {
    $firstIndex$0$lcssa = $newCount$0$lcssa;$lastIndex$0$lcssa = 0;$modified$0$off0$lcssa = 0;
   }
   $249 = ($firstIndex$0$lcssa|0)<($lastIndex$0$lcssa|0);
   if ($249) {
    HEAP32[$235>>2] = $firstIndex$0$lcssa;
    HEAP32[$237>>2] = $lastIndex$0$lcssa;
    if ($modified$0$off0$lcssa) {
     $250 = (($group$014) + 12|0);
     $251 = HEAP32[$250>>2]|0;
     $252 = $251 & 1;
     $253 = ($252|0)==(0);
     if (!($253)) {
      $254 = $251 | 16;
      __ZN16b2ParticleSystem13SetGroupFlagsEP15b2ParticleGroupj($this,$group$014,$254);
     }
    }
   } else {
    HEAP32[$235>>2] = 0;
    HEAP32[$237>>2] = 0;
    $255 = (($group$014) + 12|0);
    $256 = HEAP32[$255>>2]|0;
    $257 = $256 & 4;
    $258 = ($257|0)==(0);
    if ($258) {
     $259 = $256 | 8;
     __ZN16b2ParticleSystem13SetGroupFlagsEP15b2ParticleGroupj($this,$group$014,$259);
    }
   }
   $260 = (__ZN15b2ParticleGroup7GetNextEv($group$014)|0);
   $261 = ($260|0)==(0|0);
   if ($261) {
    break;
   } else {
    $group$014 = $260;
   }
  }
 }
 HEAP32[$3>>2] = $newCount$0$lcssa;
 $262 = HEAP32[$0>>2]|0;
 $263 = (($262) + 76|0);
 __ZN16b2StackAllocator4FreeEPv($263,$6);
 $264 = (($this) + 8|0);
 HEAP32[$264>>2] = $allParticleFlags$0$lcssa;
 $265 = (($this) + 12|0);
 HEAP8[$265>>0] = 0;
 $266 = HEAP32[$232>>2]|0;
 $267 = ($266|0)==(0|0);
 if ($267) {
  STACKTOP = sp;return;
 } else {
  $group8$03 = $266;
 }
 while(1) {
  $268 = (__ZN15b2ParticleGroup7GetNextEv($group8$03)|0);
  $269 = (($group8$03) + 12|0);
  $270 = HEAP32[$269>>2]|0;
  $271 = $270 & 8;
  $272 = ($271|0)==(0);
  if (!($272)) {
   __ZN16b2ParticleSystem20DestroyParticleGroupEP15b2ParticleGroup($this,$group8$03);
  }
  $273 = ($268|0)==(0|0);
  if ($273) {
   break;
  } else {
   $group8$03 = $268;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem19SetParticleLifetimeEif($this,$index,$lifetime) {
 $this = $this|0;
 $index = $index|0;
 $lifetime = +$lifetime;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 288|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 $3 = (($this) + 280|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZN16b2ParticleSystem13RequestBufferIiEEPT_S2_($this,$4)|0);
 HEAP32[$3>>2] = $5;
 $6 = HEAP32[$0>>2]|0;
 $7 = (__ZN16b2ParticleSystem13RequestBufferIiEEPT_S2_($this,$6)|0);
 HEAP32[$0>>2] = $7;
 if ($2) {
  $8 = (__ZNK16b2ParticleSystem16GetParticleCountEv($this)|0);
  $9 = ($8|0)>(0);
  if ($9) {
   $10 = HEAP32[$0>>2]|0;
   $i$01 = 0;
   while(1) {
    $11 = (($10) + ($i$01<<2)|0);
    HEAP32[$11>>2] = $i$01;
    $12 = (($i$01) + 1)|0;
    $exitcond = ($12|0)==($8|0);
    if ($exitcond) {
     break;
    } else {
     $i$01 = $12;
    }
   }
  }
 }
 $13 = (($this) + 396|0);
 $14 = +HEAPF32[$13>>2];
 $15 = $lifetime / $14;
 $16 = (~~(($15)));
 $17 = ($16|0)>(0);
 if ($17) {
  $18 = (__ZNK16b2ParticleSystem23GetQuantizedTimeElapsedEv($this)|0);
  $19 = (($18) + ($16))|0;
  $23 = $19;
 } else {
  $23 = $16;
 }
 $20 = HEAP32[$3>>2]|0;
 $21 = (($20) + ($index<<2)|0);
 $22 = HEAP32[$21>>2]|0;
 $24 = ($23|0)==($22|0);
 if ($24) {
  STACKTOP = sp;return;
 }
 HEAP32[$21>>2] = $23;
 $25 = (($this) + 304|0);
 HEAP8[$25>>0] = 1;
 STACKTOP = sp;return;
}
function __ZNK16b2ParticleSystem24ExpirationTimeToLifetimeEi($this,$expirationTime) {
 $this = $this|0;
 $expirationTime = $expirationTime|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($expirationTime|0)>(0);
 if ($0) {
  $1 = (__ZNK16b2ParticleSystem23GetQuantizedTimeElapsedEv($this)|0);
  $2 = (($expirationTime) - ($1))|0;
  $4 = $2;
 } else {
  $4 = $expirationTime;
 }
 $3 = (+($4|0));
 $5 = (($this) + 396|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $3 * $6;
 STACKTOP = sp;return (+$7);
}
function __ZNK16b2ParticleSystem23GetQuantizedTimeElapsedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 296|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 STACKTOP = sp;return ($6|0);
}
function __ZN16b2ParticleSystem12RotateBufferEiii($this,$start,$mid,$end) {
 $this = $this|0;
 $start = $start|0;
 $mid = $mid|0;
 $end = $end|0;
 var $$sum = 0, $$sum34 = 0, $$sum35 = 0, $$sum36 = 0, $$sum37 = 0, $$sum38 = 0, $$sum39 = 0, $$sum40 = 0, $$sum41 = 0, $$sum42 = 0, $$sum43 = 0, $$sum44 = 0, $$sum45 = 0, $$sum46 = 0, $$sum47 = 0, $$sum48 = 0, $$sum49 = 0, $$sum50 = 0, $$sum51 = 0, $$sum52 = 0;
 var $$sum53 = 0, $$sum54 = 0, $$sum55 = 0, $$sum56 = 0, $$sum57 = 0, $$sum58 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0;
 var $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0;
 var $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0;
 var $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond79 = 0, $group$059 = 0, $i$077 = 0, $i1$074 = 0, $k$072 = 0, $k2$069 = 0, $k3$066 = 0;
 var $k5$063 = 0, $k6$060 = 0, $newIndices = 0, $or$cond = 0, $or$cond20 = 0, $or$cond21 = 0, $or$cond22 = 0, $or$cond23 = 0, $or$cond24 = 0, $or$cond25 = 0, $or$cond26 = 0, $or$cond27 = 0, $or$cond28 = 0, $or$cond29 = 0, $or$cond30 = 0, $or$cond31 = 0, $or$cond32 = 0, $or$cond33 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $newIndices = sp;
 $0 = ($start|0)==($mid|0);
 $1 = ($mid|0)==($end|0);
 $or$cond = $0 | $1;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 HEAP32[$newIndices>>2] = $start;
 $2 = (($newIndices) + 4|0);
 HEAP32[$2>>2] = $mid;
 $3 = (($newIndices) + 8|0);
 HEAP32[$3>>2] = $end;
 $4 = (($this) + 88|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($start<<2)|0);
 $7 = (($5) + ($mid<<2)|0);
 $8 = (($5) + ($end<<2)|0);
 $9 = ($start|0)==($mid|0);
 $10 = ($mid|0)==($end|0);
 $or$cond20 = $9 | $10;
 do {
  if (!($or$cond20)) {
   $$sum = (($start) + 1)|0;
   $11 = ($$sum|0)==($mid|0);
   if ($11) {
    (__ZNSt3__113__rotate_leftIPjEET_S2_S2_($6,$8)|0);
    break;
   }
   $$sum34 = (($mid) + 1)|0;
   $12 = ($$sum34|0)==($end|0);
   if ($12) {
    (__ZNSt3__114__rotate_rightIPjEET_S2_S2_($6,$8)|0);
    break;
   } else {
    (__ZNSt3__112__rotate_gcdIPjEET_S2_S2_S2_($6,$7,$8)|0);
    break;
   }
  }
 } while(0);
 $13 = (($this) + 160|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0|0);
 do {
  if (!($15)) {
   $16 = (($14) + ($start<<2)|0);
   $17 = (($14) + ($mid<<2)|0);
   $18 = (($14) + ($end<<2)|0);
   $19 = ($start|0)==($mid|0);
   $20 = ($mid|0)==($end|0);
   $or$cond21 = $19 | $20;
   if (!($or$cond21)) {
    $$sum35 = (($start) + 1)|0;
    $21 = ($$sum35|0)==($mid|0);
    if ($21) {
     (__ZNSt3__113__rotate_leftIPiEET_S2_S2_($16,$18)|0);
     break;
    }
    $$sum36 = (($mid) + 1)|0;
    $22 = ($$sum36|0)==($end|0);
    if ($22) {
     (__ZNSt3__114__rotate_rightIPiEET_S2_S2_($16,$18)|0);
     break;
    } else {
     (__ZNSt3__112__rotate_gcdIPiEET_S2_S2_S2_($16,$17,$18)|0);
     break;
    }
   }
  }
 } while(0);
 $23 = (($this) + 168|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = ($24|0)==(0|0);
 do {
  if (!($25)) {
   $26 = (($24) + ($start<<2)|0);
   $27 = (($24) + ($mid<<2)|0);
   $28 = (($24) + ($end<<2)|0);
   $29 = ($start|0)==($mid|0);
   $30 = ($mid|0)==($end|0);
   $or$cond22 = $29 | $30;
   if (!($or$cond22)) {
    $$sum37 = (($start) + 1)|0;
    $31 = ($$sum37|0)==($mid|0);
    if ($31) {
     (__ZNSt3__113__rotate_leftIPiEET_S2_S2_($26,$28)|0);
     break;
    }
    $$sum38 = (($mid) + 1)|0;
    $32 = ($$sum38|0)==($end|0);
    if ($32) {
     (__ZNSt3__114__rotate_rightIPiEET_S2_S2_($26,$28)|0);
     break;
    } else {
     (__ZNSt3__112__rotate_gcdIPiEET_S2_S2_S2_($26,$27,$28)|0);
     break;
    }
   }
  }
 } while(0);
 $33 = (($this) + 176|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = ($34|0)==(0|0);
 do {
  if (!($35)) {
   $36 = (($34) + ($start<<2)|0);
   $37 = (($34) + ($mid<<2)|0);
   $38 = (($34) + ($end<<2)|0);
   $39 = ($start|0)==($mid|0);
   $40 = ($mid|0)==($end|0);
   $or$cond23 = $39 | $40;
   if (!($or$cond23)) {
    $$sum39 = (($start) + 1)|0;
    $41 = ($$sum39|0)==($mid|0);
    if ($41) {
     (__ZNSt3__113__rotate_leftIPiEET_S2_S2_($36,$38)|0);
     break;
    }
    $$sum40 = (($mid) + 1)|0;
    $42 = ($$sum40|0)==($end|0);
    if ($42) {
     (__ZNSt3__114__rotate_rightIPiEET_S2_S2_($36,$38)|0);
     break;
    } else {
     (__ZNSt3__112__rotate_gcdIPiEET_S2_S2_S2_($36,$37,$38)|0);
     break;
    }
   }
  }
 } while(0);
 $43 = (($this) + 96|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($44) + ($start<<3)|0);
 $46 = (($44) + ($mid<<3)|0);
 $47 = (($44) + ($end<<3)|0);
 $48 = ($start|0)==($mid|0);
 $49 = ($mid|0)==($end|0);
 $or$cond24 = $48 | $49;
 do {
  if (!($or$cond24)) {
   $$sum41 = (($start) + 1)|0;
   $50 = ($$sum41|0)==($mid|0);
   if ($50) {
    (__ZNSt3__113__rotate_leftIP6b2Vec2EET_S3_S3_($45,$47)|0);
    break;
   }
   $$sum42 = (($mid) + 1)|0;
   $51 = ($$sum42|0)==($end|0);
   if ($51) {
    (__ZNSt3__114__rotate_rightIP6b2Vec2EET_S3_S3_($45,$47)|0);
    break;
   } else {
    (__ZNSt3__112__rotate_gcdIP6b2Vec2EET_S3_S3_S3_($45,$46,$47)|0);
    break;
   }
  }
 } while(0);
 $52 = (($this) + 104|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($53) + ($start<<3)|0);
 $55 = (($53) + ($mid<<3)|0);
 $56 = (($53) + ($end<<3)|0);
 $57 = ($start|0)==($mid|0);
 $58 = ($mid|0)==($end|0);
 $or$cond25 = $57 | $58;
 do {
  if (!($or$cond25)) {
   $$sum43 = (($start) + 1)|0;
   $59 = ($$sum43|0)==($mid|0);
   if ($59) {
    (__ZNSt3__113__rotate_leftIP6b2Vec2EET_S3_S3_($54,$56)|0);
    break;
   }
   $$sum44 = (($mid) + 1)|0;
   $60 = ($$sum44|0)==($end|0);
   if ($60) {
    (__ZNSt3__114__rotate_rightIP6b2Vec2EET_S3_S3_($54,$56)|0);
    break;
   } else {
    (__ZNSt3__112__rotate_gcdIP6b2Vec2EET_S3_S3_S3_($54,$55,$56)|0);
    break;
   }
  }
 } while(0);
 $61 = (($this) + 144|0);
 $62 = HEAP32[$61>>2]|0;
 $63 = (($62) + ($start<<2)|0);
 $64 = (($62) + ($mid<<2)|0);
 $65 = (($62) + ($end<<2)|0);
 $66 = ($start|0)==($mid|0);
 $67 = ($mid|0)==($end|0);
 $or$cond26 = $66 | $67;
 do {
  if (!($or$cond26)) {
   $$sum45 = (($start) + 1)|0;
   $68 = ($$sum45|0)==($mid|0);
   if ($68) {
    (__ZNSt3__113__rotate_leftIPP15b2ParticleGroupEET_S4_S4_($63,$65)|0);
    break;
   }
   $$sum46 = (($mid) + 1)|0;
   $69 = ($$sum46|0)==($end|0);
   if ($69) {
    (__ZNSt3__114__rotate_rightIPP15b2ParticleGroupEET_S4_S4_($63,$65)|0);
    break;
   } else {
    (__ZNSt3__112__rotate_gcdIPP15b2ParticleGroupEET_S4_S4_S4_($63,$64,$65)|0);
    break;
   }
  }
 } while(0);
 $70 = (($this) + 21|0);
 $71 = HEAP8[$70>>0]|0;
 $72 = ($71<<24>>24)==(0);
 do {
  if (!($72)) {
   $73 = (($this) + 112|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = (($74) + ($start<<3)|0);
   $76 = (($74) + ($mid<<3)|0);
   $77 = (($74) + ($end<<3)|0);
   $78 = ($start|0)==($mid|0);
   $79 = ($mid|0)==($end|0);
   $or$cond27 = $78 | $79;
   if (!($or$cond27)) {
    $$sum47 = (($start) + 1)|0;
    $80 = ($$sum47|0)==($mid|0);
    if ($80) {
     (__ZNSt3__113__rotate_leftIP6b2Vec2EET_S3_S3_($75,$77)|0);
     break;
    }
    $$sum48 = (($mid) + 1)|0;
    $81 = ($$sum48|0)==($end|0);
    if ($81) {
     (__ZNSt3__114__rotate_rightIP6b2Vec2EET_S3_S3_($75,$77)|0);
     break;
    } else {
     (__ZNSt3__112__rotate_gcdIP6b2Vec2EET_S3_S3_S3_($75,$76,$77)|0);
     break;
    }
   }
  }
 } while(0);
 $82 = (($this) + 120|0);
 $83 = HEAP32[$82>>2]|0;
 $84 = ($83|0)==(0|0);
 do {
  if (!($84)) {
   $85 = (($83) + ($start<<2)|0);
   $86 = (($83) + ($mid<<2)|0);
   $87 = (($83) + ($end<<2)|0);
   $88 = ($start|0)==($mid|0);
   $89 = ($mid|0)==($end|0);
   $or$cond28 = $88 | $89;
   if (!($or$cond28)) {
    $$sum49 = (($start) + 1)|0;
    $90 = ($$sum49|0)==($mid|0);
    if ($90) {
     (__ZNSt3__113__rotate_leftIPfEET_S2_S2_($85,$87)|0);
     break;
    }
    $$sum50 = (($mid) + 1)|0;
    $91 = ($$sum50|0)==($end|0);
    if ($91) {
     (__ZNSt3__114__rotate_rightIPfEET_S2_S2_($85,$87)|0);
     break;
    } else {
     (__ZNSt3__112__rotate_gcdIPfEET_S2_S2_S2_($85,$86,$87)|0);
     break;
    }
   }
  }
 } while(0);
 $92 = (($this) + 132|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = ($93|0)==(0|0);
 do {
  if (!($94)) {
   $95 = (($93) + ($start<<2)|0);
   $96 = (($93) + ($mid<<2)|0);
   $97 = (($93) + ($end<<2)|0);
   $98 = ($start|0)==($mid|0);
   $99 = ($mid|0)==($end|0);
   $or$cond29 = $98 | $99;
   if (!($or$cond29)) {
    $$sum51 = (($start) + 1)|0;
    $100 = ($$sum51|0)==($mid|0);
    if ($100) {
     (__ZNSt3__113__rotate_leftIPfEET_S2_S2_($95,$97)|0);
     break;
    }
    $$sum52 = (($mid) + 1)|0;
    $101 = ($$sum52|0)==($end|0);
    if ($101) {
     (__ZNSt3__114__rotate_rightIPfEET_S2_S2_($95,$97)|0);
     break;
    } else {
     (__ZNSt3__112__rotate_gcdIPfEET_S2_S2_S2_($95,$96,$97)|0);
     break;
    }
   }
  }
 } while(0);
 $102 = (($this) + 136|0);
 $103 = HEAP32[$102>>2]|0;
 $104 = ($103|0)==(0|0);
 if (!($104)) {
  $105 = ($start|0)==($mid|0);
  $106 = ($mid|0)==($end|0);
  $or$cond30 = $105 | $106;
  if (!($or$cond30)) {
   $107 = (($103) + ($mid<<2)|0);
   $108 = (($103) + ($end<<2)|0);
   $109 = (($103) + ($start<<2)|0);
   (__ZNSt3__116__rotate_forwardIP15b2ParticleColorEET_S3_S3_S3_($109,$107,$108)|0);
  }
 }
 $110 = (($this) + 148|0);
 $111 = HEAP32[$110>>2]|0;
 $112 = ($111|0)==(0|0);
 do {
  if (!($112)) {
   $113 = (($111) + ($start<<2)|0);
   $114 = (($111) + ($mid<<2)|0);
   $115 = (($111) + ($end<<2)|0);
   $116 = ($start|0)==($mid|0);
   $117 = ($mid|0)==($end|0);
   $or$cond31 = $116 | $117;
   if (!($or$cond31)) {
    $$sum53 = (($start) + 1)|0;
    $118 = ($$sum53|0)==($mid|0);
    if ($118) {
     (__ZNSt3__113__rotate_leftIPPvEET_S3_S3_($113,$115)|0);
     break;
    }
    $$sum54 = (($mid) + 1)|0;
    $119 = ($$sum54|0)==($end|0);
    if ($119) {
     (__ZNSt3__114__rotate_rightIPPvEET_S3_S3_($113,$115)|0);
     break;
    } else {
     (__ZNSt3__112__rotate_gcdIPPvEET_S3_S3_S3_($113,$114,$115)|0);
     break;
    }
   }
  }
 } while(0);
 $120 = (($this) + 80|0);
 $121 = HEAP32[$120>>2]|0;
 $122 = ($121|0)==(0|0);
 if (!($122)) {
  $123 = (($121) + ($start<<2)|0);
  $124 = (($121) + ($mid<<2)|0);
  $125 = (($121) + ($end<<2)|0);
  $126 = ($start|0)==($mid|0);
  $127 = ($mid|0)==($end|0);
  $or$cond32 = $126 | $127;
  do {
   if (!($or$cond32)) {
    $$sum55 = (($start) + 1)|0;
    $128 = ($$sum55|0)==($mid|0);
    if ($128) {
     (__ZNSt3__113__rotate_leftIPP16b2ParticleHandleEET_S4_S4_($123,$125)|0);
     break;
    }
    $$sum56 = (($mid) + 1)|0;
    $129 = ($$sum56|0)==($end|0);
    if ($129) {
     (__ZNSt3__114__rotate_rightIPP16b2ParticleHandleEET_S4_S4_($123,$125)|0);
     break;
    } else {
     (__ZNSt3__112__rotate_gcdIPP16b2ParticleHandleEET_S4_S4_S4_($123,$124,$125)|0);
     break;
    }
   }
  } while(0);
  $130 = ($start|0)<($end|0);
  if ($130) {
   $i$077 = $start;
   while(1) {
    $131 = HEAP32[$120>>2]|0;
    $132 = (($131) + ($i$077<<2)|0);
    $133 = HEAP32[$132>>2]|0;
    $134 = ($133|0)==(0|0);
    if (!($134)) {
     $135 = (__ZNK16b2ParticleHandle8GetIndexEv($133)|0);
     $136 = (__ZZN16b2ParticleSystem12RotateBufferEiiiENK10NewIndicesixEi($newIndices,$135)|0);
     __ZN16b2ParticleHandle8SetIndexEi($133,$136);
    }
    $137 = (($i$077) + 1)|0;
    $exitcond79 = ($137|0)==($end|0);
    if ($exitcond79) {
     break;
    } else {
     $i$077 = $137;
    }
   }
  }
 }
 $138 = (($this) + 280|0);
 $139 = HEAP32[$138>>2]|0;
 $140 = ($139|0)==(0|0);
 if (!($140)) {
  $141 = (($139) + ($start<<2)|0);
  $142 = (($139) + ($mid<<2)|0);
  $143 = (($139) + ($end<<2)|0);
  $144 = ($start|0)==($mid|0);
  $145 = ($mid|0)==($end|0);
  $or$cond33 = $144 | $145;
  do {
   if (!($or$cond33)) {
    $$sum57 = (($start) + 1)|0;
    $146 = ($$sum57|0)==($mid|0);
    if ($146) {
     (__ZNSt3__113__rotate_leftIPiEET_S2_S2_($141,$143)|0);
     break;
    }
    $$sum58 = (($mid) + 1)|0;
    $147 = ($$sum58|0)==($end|0);
    if ($147) {
     (__ZNSt3__114__rotate_rightIPiEET_S2_S2_($141,$143)|0);
     break;
    } else {
     (__ZNSt3__112__rotate_gcdIPiEET_S2_S2_S2_($141,$142,$143)|0);
     break;
    }
   }
  } while(0);
  $148 = (__ZNK16b2ParticleSystem16GetParticleCountEv($this)|0);
  $149 = (($this) + 288|0);
  $150 = HEAP32[$149>>2]|0;
  $151 = ($148|0)>(0);
  if ($151) {
   $i1$074 = 0;
   while(1) {
    $155 = (($150) + ($i1$074<<2)|0);
    $156 = HEAP32[$155>>2]|0;
    $157 = (__ZZN16b2ParticleSystem12RotateBufferEiiiENK10NewIndicesixEi($newIndices,$156)|0);
    HEAP32[$155>>2] = $157;
    $158 = (($i1$074) + 1)|0;
    $exitcond = ($158|0)==($148|0);
    if ($exitcond) {
     break;
    } else {
     $i1$074 = $158;
    }
   }
  }
 }
 $152 = (($this) + 200|0);
 $153 = (__ZNK16b2GrowableBufferIN16b2ParticleSystem5ProxyEE8GetCountEv($152)|0);
 $154 = ($153|0)>(0);
 if ($154) {
  $k$072 = 0;
  while(1) {
   $162 = (__ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEE5BeginEv($152)|0);
   $163 = (($162) + ($k$072<<3)|0);
   $164 = HEAP32[$163>>2]|0;
   $165 = (__ZZN16b2ParticleSystem12RotateBufferEiiiENK10NewIndicesixEi($newIndices,$164)|0);
   HEAP32[$163>>2] = $165;
   $166 = (($k$072) + 1)|0;
   $167 = (__ZNK16b2GrowableBufferIN16b2ParticleSystem5ProxyEE8GetCountEv($152)|0);
   $168 = ($166|0)<($167|0);
   if ($168) {
    $k$072 = $166;
   } else {
    break;
   }
  }
 }
 $159 = (($this) + 216|0);
 $160 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($159)|0);
 $161 = ($160|0)>(0);
 if ($161) {
  $k2$069 = 0;
  while(1) {
   $172 = (__ZN16b2GrowableBufferI17b2ParticleContactEixEi($159,$k2$069)|0);
   $173 = (__ZNK17b2ParticleContact9GetIndexAEv($172)|0);
   $174 = (__ZZN16b2ParticleSystem12RotateBufferEiiiENK10NewIndicesixEi($newIndices,$173)|0);
   $175 = (__ZNK17b2ParticleContact9GetIndexBEv($172)|0);
   $176 = (__ZZN16b2ParticleSystem12RotateBufferEiiiENK10NewIndicesixEi($newIndices,$175)|0);
   __ZN17b2ParticleContact10SetIndicesEii($172,$174,$176);
   $177 = (($k2$069) + 1)|0;
   $178 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($159)|0);
   $179 = ($177|0)<($178|0);
   if ($179) {
    $k2$069 = $177;
   } else {
    break;
   }
  }
 }
 $169 = (($this) + 232|0);
 $170 = (__ZNK16b2GrowableBufferI21b2ParticleBodyContactE8GetCountEv($169)|0);
 $171 = ($170|0)>(0);
 if ($171) {
  $k3$066 = 0;
  while(1) {
   $183 = (__ZN16b2GrowableBufferI21b2ParticleBodyContactEixEi($169,$k3$066)|0);
   $184 = HEAP32[$183>>2]|0;
   $185 = (__ZZN16b2ParticleSystem12RotateBufferEiiiENK10NewIndicesixEi($newIndices,$184)|0);
   HEAP32[$183>>2] = $185;
   $186 = (($k3$066) + 1)|0;
   $187 = (__ZNK16b2GrowableBufferI21b2ParticleBodyContactE8GetCountEv($169)|0);
   $188 = ($186|0)<($187|0);
   if ($188) {
    $k3$066 = $186;
   } else {
    break;
   }
  }
 }
 $180 = (($this) + 248|0);
 $181 = (__ZNK16b2GrowableBufferI14b2ParticlePairE8GetCountEv($180)|0);
 $182 = ($181|0)>(0);
 if ($182) {
  $k5$063 = 0;
  while(1) {
   $192 = (__ZN16b2GrowableBufferI14b2ParticlePairEixEi($180,$k5$063)|0);
   $193 = HEAP32[$192>>2]|0;
   $194 = (__ZZN16b2ParticleSystem12RotateBufferEiiiENK10NewIndicesixEi($newIndices,$193)|0);
   HEAP32[$192>>2] = $194;
   $195 = (($192) + 4|0);
   $196 = HEAP32[$195>>2]|0;
   $197 = (__ZZN16b2ParticleSystem12RotateBufferEiiiENK10NewIndicesixEi($newIndices,$196)|0);
   HEAP32[$195>>2] = $197;
   $198 = (($k5$063) + 1)|0;
   $199 = (__ZNK16b2GrowableBufferI14b2ParticlePairE8GetCountEv($180)|0);
   $200 = ($198|0)<($199|0);
   if ($200) {
    $k5$063 = $198;
   } else {
    break;
   }
  }
 }
 $189 = (($this) + 264|0);
 $190 = (__ZNK16b2GrowableBufferI15b2ParticleTriadE8GetCountEv($189)|0);
 $191 = ($190|0)>(0);
 if ($191) {
  $k6$060 = 0;
  while(1) {
   $201 = (__ZN16b2GrowableBufferI15b2ParticleTriadEixEi($189,$k6$060)|0);
   $202 = HEAP32[$201>>2]|0;
   $203 = (__ZZN16b2ParticleSystem12RotateBufferEiiiENK10NewIndicesixEi($newIndices,$202)|0);
   HEAP32[$201>>2] = $203;
   $204 = (($201) + 4|0);
   $205 = HEAP32[$204>>2]|0;
   $206 = (__ZZN16b2ParticleSystem12RotateBufferEiiiENK10NewIndicesixEi($newIndices,$205)|0);
   HEAP32[$204>>2] = $206;
   $207 = (($201) + 8|0);
   $208 = HEAP32[$207>>2]|0;
   $209 = (__ZZN16b2ParticleSystem12RotateBufferEiiiENK10NewIndicesixEi($newIndices,$208)|0);
   HEAP32[$207>>2] = $209;
   $210 = (($k6$060) + 1)|0;
   $211 = (__ZNK16b2GrowableBufferI15b2ParticleTriadE8GetCountEv($189)|0);
   $212 = ($210|0)<($211|0);
   if ($212) {
    $k6$060 = $210;
   } else {
    break;
   }
  }
 }
 $213 = (($this) + 312|0);
 $214 = HEAP32[$213>>2]|0;
 $215 = ($214|0)==(0|0);
 if ($215) {
  STACKTOP = sp;return;
 } else {
  $group$059 = $214;
 }
 while(1) {
  $216 = (($group$059) + 4|0);
  $217 = HEAP32[$216>>2]|0;
  $218 = (__ZZN16b2ParticleSystem12RotateBufferEiiiENK10NewIndicesixEi($newIndices,$217)|0);
  HEAP32[$216>>2] = $218;
  $219 = (($group$059) + 8|0);
  $220 = HEAP32[$219>>2]|0;
  $221 = (($220) + -1)|0;
  $222 = (__ZZN16b2ParticleSystem12RotateBufferEiiiENK10NewIndicesixEi($newIndices,$221)|0);
  $223 = (($222) + 1)|0;
  HEAP32[$219>>2] = $223;
  $224 = (__ZN15b2ParticleGroup7GetNextEv($group$059)|0);
  $225 = ($224|0)==(0|0);
  if ($225) {
   break;
  } else {
   $group$059 = $224;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem16SetParticleFlagsEij($this,$index,$newFlags) {
 $this = $this|0;
 $index = $index|0;
 $newFlags = $newFlags|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($index<<2)|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $newFlags ^ -1;
 $5 = $3 & $4;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = (($this) + 12|0);
  HEAP8[$7>>0] = 1;
 }
 $8 = (($this) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 ^ -1;
 $11 = $10 & $newFlags;
 $12 = ($11|0)==(0);
 if ($12) {
  HEAP32[$2>>2] = $newFlags;
  STACKTOP = sp;return;
 }
 $13 = $newFlags & 128;
 $14 = ($13|0)==(0);
 if (!($14)) {
  $15 = (($this) + 128|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (__ZN16b2ParticleSystem13RequestBufferI6b2Vec2EEPT_S3_($this,$16)|0);
  HEAP32[$15>>2] = $17;
 }
 $18 = $newFlags & 256;
 $19 = ($18|0)==(0);
 if (!($19)) {
  $20 = (($this) + 136|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (__ZN16b2ParticleSystem13RequestBufferI15b2ParticleColorEEPT_S3_($this,$21)|0);
  HEAP32[$20>>2] = $22;
 }
 $23 = HEAP32[$8>>2]|0;
 $24 = $23 | $newFlags;
 HEAP32[$8>>2] = $24;
 HEAP32[$2>>2] = $newFlags;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem15DestroyParticleEib($this,$index,$callDestructionListener) {
 $this = $this|0;
 $index = $index|0;
 $callDestructionListener = $callDestructionListener|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$ = $callDestructionListener ? 514 : 2;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($index<<2)|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 | $$;
 __ZN16b2ParticleSystem16SetParticleFlagsEij($this,$index,$4);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem23DestroyParticlesInShapeERK7b2ShapeRK11b2Transformb($this,$shape,$xf,$callDestructionListener) {
 $this = $this|0;
 $shape = $shape|0;
 $xf = $xf|0;
 $callDestructionListener = $callDestructionListener|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $aabb = 0, $callback = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $callback = sp + 16|0;
 $aabb = sp;
 $0 = (($this) + 400|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK7b2World8IsLockedEv($1)|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 __ZZN16b2ParticleSystem23DestroyParticlesInShapeERK7b2ShapeRK11b2TransformbEN31DestroyParticlesInShapeCallbackC2EPS_S2_S5_b($callback,$this,$shape,$xf,$callDestructionListener);
 $3 = HEAP32[$shape>>2]|0;
 $4 = (($3) + 28|0);
 $5 = HEAP32[$4>>2]|0;
 FUNCTION_TABLE_viiii[$5 & 31]($shape,$aabb,$xf,0);
 $6 = HEAP32[$0>>2]|0;
 __ZNK7b2World9QueryAABBEP15b2QueryCallbackRK6b2AABB($6,$callback,$aabb);
 $7 = (__ZZN16b2ParticleSystem23DestroyParticlesInShapeERK7b2ShapeRK11b2TransformbEN31DestroyParticlesInShapeCallback9DestroyedEv($callback)|0);
 $$0 = $7;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16b2ParticleSystem22CreateParticleForGroupERK18b2ParticleGroupDefRK11b2TransformRK6b2Vec2($this,$groupDef,$xf,$p) {
 $this = $this|0;
 $groupDef = $groupDef|0;
 $xf = $xf|0;
 $p = $p|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $particleDef = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $particleDef = sp + 32|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = sp + 24|0;
 $3 = sp + 16|0;
 __ZN13b2ParticleDefC2Ev($particleDef);
 $4 = HEAP32[$groupDef>>2]|0;
 HEAP32[$particleDef>>2] = $4;
 $5 = (($particleDef) + 4|0);
 __Z5b2MulRK11b2TransformRK6b2Vec2($0,$xf,$p);
 $6 = $0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $5;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 $16 = (($particleDef) + 12|0);
 $17 = (($groupDef) + 20|0);
 $18 = (($groupDef) + 28|0);
 $19 = +HEAPF32[$18>>2];
 $20 = (($groupDef) + 8|0);
 __ZmiRK6b2Vec2S1_($3,$5,$20);
 __Z7b2CrossfRK6b2Vec2($2,$19,$3);
 __ZplRK6b2Vec2S1_($1,$17,$2);
 $21 = $1;
 $22 = $21;
 $23 = HEAP32[$22>>2]|0;
 $24 = (($21) + 4)|0;
 $25 = $24;
 $26 = HEAP32[$25>>2]|0;
 $27 = $16;
 $28 = $27;
 HEAP32[$28>>2] = $23;
 $29 = (($27) + 4)|0;
 $30 = $29;
 HEAP32[$30>>2] = $26;
 $31 = (($particleDef) + 20|0);
 $32 = (($groupDef) + 32|0);
 (__ZN15b2ParticleColoraSERKS_($31,$32)|0);
 $33 = (($groupDef) + 64|0);
 $34 = +HEAPF32[$33>>2];
 $35 = (($particleDef) + 24|0);
 HEAPF32[$35>>2] = $34;
 $36 = (($groupDef) + 68|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($particleDef) + 28|0);
 HEAP32[$38>>2] = $37;
 $39 = (__ZN16b2ParticleSystem14CreateParticleERK13b2ParticleDef($this,$particleDef)|0);
 STACKTOP = sp;return ($39|0);
}
function __ZN16b2ParticleSystem34CreateParticlesStrokeShapeForGroupEPK7b2ShapeRK18b2ParticleGroupDefRK11b2Transform($this,$shape,$groupDef,$xf) {
 $this = $this|0;
 $shape = $shape|0;
 $groupDef = $groupDef|0;
 $xf = $xf|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0.0, $20 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $childIndex$02 = 0, $d = 0, $edge = 0, $exitcond = 0, $p = 0, $positionOnEdge$03 = 0.0, $positionOnEdge$1$lcssa = 0.0, $positionOnEdge$11 = 0.0, $stride$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $edge = sp + 24|0;
 $d = sp + 16|0;
 $p = sp + 8|0;
 $0 = sp;
 $1 = (($groupDef) + 52|0);
 $2 = +HEAPF32[$1>>2];
 $3 = $2 == 0.0;
 if ($3) {
  $4 = (+__ZNK16b2ParticleSystem17GetParticleStrideEv($this));
  $stride$0 = $4;
 } else {
  $stride$0 = $2;
 }
 $5 = HEAP32[$shape>>2]|0;
 $6 = (($5) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (FUNCTION_TABLE_ii[$7 & 15]($shape)|0);
 $9 = ($8|0)>(0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = (($edge) + 20|0);
 $11 = (($edge) + 12|0);
 $childIndex$02 = 0;$positionOnEdge$03 = 0.0;
 while(1) {
  __ZN11b2EdgeShapeC2Ev($edge);
  $12 = (__ZNK7b2Shape7GetTypeEv($shape)|0);
  $13 = ($12|0)==(1);
  if ($13) {
   (__ZN11b2EdgeShapeaSERKS_($edge,$shape)|0);
  } else {
   __ZNK12b2ChainShape12GetChildEdgeEP11b2EdgeShapei($shape,$edge,$childIndex$02);
  }
  __ZmiRK6b2Vec2S1_($d,$10,$11);
  $14 = (+__ZNK6b2Vec26LengthEv($d));
  $15 = $positionOnEdge$03 < $14;
  if ($15) {
   $positionOnEdge$11 = $positionOnEdge$03;
   while(1) {
    $16 = $positionOnEdge$11 / $14;
    __ZmlfRK6b2Vec2($0,$16,$d);
    __ZplRK6b2Vec2S1_($p,$11,$0);
    (__ZN16b2ParticleSystem22CreateParticleForGroupERK18b2ParticleGroupDefRK11b2TransformRK6b2Vec2($this,$groupDef,$xf,$p)|0);
    $17 = $stride$0 + $positionOnEdge$11;
    $18 = $17 < $14;
    if ($18) {
     $positionOnEdge$11 = $17;
    } else {
     $positionOnEdge$1$lcssa = $17;
     break;
    }
   }
  } else {
   $positionOnEdge$1$lcssa = $positionOnEdge$03;
  }
  $19 = $positionOnEdge$1$lcssa - $14;
  $20 = (($childIndex$02) + 1)|0;
  $exitcond = ($20|0)==($8|0);
  if ($exitcond) {
   break;
  } else {
   $childIndex$02 = $20;$positionOnEdge$03 = $19;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem32CreateParticlesFillShapeForGroupEPK7b2ShapeRK18b2ParticleGroupDefRK11b2Transform($this,$shape,$groupDef,$xf) {
 $this = $this|0;
 $shape = $shape|0;
 $groupDef = $groupDef|0;
 $xf = $xf|0;
 var $0 = 0, $1 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0.0;
 var $27 = 0.0, $28 = 0, $29 = 0.0, $3 = 0.0, $30 = 0.0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0.0, $aabb = 0, $identity = 0, $p = 0, $stride$0 = 0.0, $x$01 = 0.0, $y$02 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $identity = sp + 24|0;
 $aabb = sp + 8|0;
 $p = sp;
 $0 = (($groupDef) + 52|0);
 $1 = +HEAPF32[$0>>2];
 $2 = $1 == 0.0;
 if ($2) {
  $3 = (+__ZNK16b2ParticleSystem17GetParticleStrideEv($this));
  $stride$0 = $3;
 } else {
  $stride$0 = $1;
 }
 __ZN11b2Transform11SetIdentityEv($identity);
 $4 = HEAP32[$shape>>2]|0;
 $5 = (($4) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 FUNCTION_TABLE_viiii[$6 & 31]($shape,$aabb,$identity,0);
 $7 = (($aabb) + 4|0);
 $8 = +HEAPF32[$7>>2];
 $9 = $8 / $stride$0;
 $10 = (+Math_floor((+$9)));
 $11 = $stride$0 * $10;
 $12 = (($aabb) + 12|0);
 $13 = +HEAPF32[$12>>2];
 $14 = $11 < $13;
 if (!($14)) {
  STACKTOP = sp;return;
 }
 $15 = (($aabb) + 8|0);
 $y$02 = $11;
 while(1) {
  $16 = +HEAPF32[$aabb>>2];
  $17 = $16 / $stride$0;
  $18 = (+Math_floor((+$17)));
  $19 = $stride$0 * $18;
  $20 = +HEAPF32[$15>>2];
  $21 = $19 < $20;
  if ($21) {
   $x$01 = $19;
   while(1) {
    __ZN6b2Vec2C2Eff($p,$x$01,$y$02);
    $22 = HEAP32[$shape>>2]|0;
    $23 = (($22) + 16|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = (FUNCTION_TABLE_iiii[$24 & 15]($shape,$identity,$p)|0);
    if ($25) {
     (__ZN16b2ParticleSystem22CreateParticleForGroupERK18b2ParticleGroupDefRK11b2TransformRK6b2Vec2($this,$groupDef,$xf,$p)|0);
    }
    $26 = $stride$0 + $x$01;
    $27 = +HEAPF32[$15>>2];
    $28 = $26 < $27;
    if ($28) {
     $x$01 = $26;
    } else {
     break;
    }
   }
  }
  $29 = $stride$0 + $y$02;
  $30 = +HEAPF32[$12>>2];
  $31 = $29 < $30;
  if ($31) {
   $y$02 = $29;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem32CreateParticlesWithShapeForGroupEPK7b2ShapeRK18b2ParticleGroupDefRK11b2Transform($this,$shape,$groupDef,$xf) {
 $this = $this|0;
 $shape = $shape|0;
 $groupDef = $groupDef|0;
 $xf = $xf|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK7b2Shape7GetTypeEv($shape)|0);
 if ((($0|0) == 3) | (($0|0) == 1)) {
  __ZN16b2ParticleSystem34CreateParticlesStrokeShapeForGroupEPK7b2ShapeRK18b2ParticleGroupDefRK11b2Transform($this,$shape,$groupDef,$xf);
  STACKTOP = sp;return;
 } else if ((($0|0) == 0) | (($0|0) == 2)) {
  __ZN16b2ParticleSystem32CreateParticlesFillShapeForGroupEPK7b2ShapeRK18b2ParticleGroupDefRK11b2Transform($this,$shape,$groupDef,$xf);
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function __ZN16b2ParticleSystem33CreateParticlesWithShapesForGroupEPKPK7b2ShapeiRK18b2ParticleGroupDefRK11b2Transform($this,$shapes,$shapeCount,$groupDef,$xf) {
 $this = $this|0;
 $shapes = $shapes|0;
 $shapeCount = $shapeCount|0;
 $groupDef = $groupDef|0;
 $xf = $xf|0;
 var $compositeShape = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $compositeShape = sp;
 __ZZN16b2ParticleSystem33CreateParticlesWithShapesForGroupEPKPK7b2ShapeiRK18b2ParticleGroupDefRK11b2TransformEN14CompositeShapeC2ES4_i($compositeShape,$shapes,$shapeCount);
 __ZN16b2ParticleSystem32CreateParticlesFillShapeForGroupEPK7b2ShapeRK18b2ParticleGroupDefRK11b2Transform($this,$compositeShape,$groupDef,$xf);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem19CreateParticleGroupERK18b2ParticleGroupDef($this,$groupDef) {
 $this = $this|0;
 $groupDef = $groupDef|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0.0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0.0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $exitcond = 0, $filter = 0, $i$02 = 0, $i1$01 = 0, $p = 0, $transform = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $transform = sp + 16|0;
 $p = sp;
 $filter = sp + 8|0;
 $0 = (($this) + 400|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK7b2World8IsLockedEv($1)|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($groupDef) + 8|0);
 $4 = (($groupDef) + 16|0);
 $5 = +HEAPF32[$4>>2];
 __ZN11b2Transform3SetERK6b2Vec2f($transform,$3,$5);
 $6 = (($this) + 44|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($groupDef) + 40|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  __ZN16b2ParticleSystem32CreateParticlesWithShapeForGroupEPK7b2ShapeRK18b2ParticleGroupDefRK11b2Transform($this,$9,$groupDef,$transform);
 }
 $11 = (($groupDef) + 44|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = (($groupDef) + 48|0);
  $15 = HEAP32[$14>>2]|0;
  __ZN16b2ParticleSystem33CreateParticlesWithShapesForGroupEPKPK7b2ShapeiRK18b2ParticleGroupDefRK11b2Transform($this,$12,$15,$groupDef,$transform);
 }
 $16 = (($groupDef) + 56|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if (!($18)) {
  $19 = HEAP32[$16>>2]|0;
  $20 = ($19|0)>(0);
  if ($20) {
   $21 = (($groupDef) + 60|0);
   $i$02 = 0;
   while(1) {
    $22 = HEAP32[$21>>2]|0;
    $23 = (($22) + ($i$02<<3)|0);
    $24 = $23;
    $25 = $24;
    $26 = HEAP32[$25>>2]|0;
    $27 = (($24) + 4)|0;
    $28 = $27;
    $29 = HEAP32[$28>>2]|0;
    $30 = $p;
    $31 = $30;
    HEAP32[$31>>2] = $26;
    $32 = (($30) + 4)|0;
    $33 = $32;
    HEAP32[$33>>2] = $29;
    (__ZN16b2ParticleSystem22CreateParticleForGroupERK18b2ParticleGroupDefRK11b2TransformRK6b2Vec2($this,$groupDef,$transform,$p)|0);
    $34 = (($i$02) + 1)|0;
    $35 = HEAP32[$16>>2]|0;
    $36 = ($34|0)<($35|0);
    if ($36) {
     $i$02 = $34;
    } else {
     break;
    }
   }
  }
 }
 $37 = HEAP32[$6>>2]|0;
 $38 = HEAP32[$0>>2]|0;
 $39 = (__ZN16b2BlockAllocator8AllocateEi($38,80)|0);
 $40 = ($39|0)==(0|0);
 if ($40) {
  $41 = 0;
 } else {
  __ZN15b2ParticleGroupC2Ev($39);
  $41 = $39;
 }
 HEAP32[$41>>2] = $this;
 $42 = (($41) + 4|0);
 HEAP32[$42>>2] = $7;
 $43 = (($41) + 8|0);
 HEAP32[$43>>2] = $37;
 $44 = (($groupDef) + 36|0);
 $45 = +HEAPF32[$44>>2];
 $46 = (($41) + 16|0);
 HEAPF32[$46>>2] = $45;
 $47 = (($groupDef) + 68|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($41) + 76|0);
 HEAP32[$49>>2] = $48;
 $50 = (($41) + 60|0);
 ;HEAP32[$50+0>>2]=HEAP32[$transform+0>>2]|0;HEAP32[$50+4>>2]=HEAP32[$transform+4>>2]|0;HEAP32[$50+8>>2]=HEAP32[$transform+8>>2]|0;HEAP32[$50+12>>2]=HEAP32[$transform+12>>2]|0;
 $51 = (($41) + 20|0);
 HEAP32[$51>>2] = 0;
 $52 = (($this) + 312|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = (($41) + 24|0);
 HEAP32[$54>>2] = $53;
 $55 = HEAP32[$52>>2]|0;
 $56 = ($55|0)==(0|0);
 if (!($56)) {
  $57 = (($55) + 20|0);
  HEAP32[$57>>2] = $41;
 }
 HEAP32[$52>>2] = $41;
 $58 = (($this) + 308|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = (($59) + 1)|0;
 HEAP32[$58>>2] = $60;
 $61 = ($7|0)<($37|0);
 if ($61) {
  $62 = (($this) + 144|0);
  $i1$01 = $7;
  while(1) {
   $63 = HEAP32[$62>>2]|0;
   $64 = (($63) + ($i1$01<<2)|0);
   HEAP32[$64>>2] = $41;
   $65 = (($i1$01) + 1)|0;
   $exitcond = ($65|0)==($37|0);
   if ($exitcond) {
    break;
   } else {
    $i1$01 = $65;
   }
  }
 }
 $66 = (($groupDef) + 4|0);
 $67 = HEAP32[$66>>2]|0;
 __ZN16b2ParticleSystem13SetGroupFlagsEP15b2ParticleGroupj($this,$41,$67);
 __ZN16b2ParticleSystem16ConnectionFilterC2Ev($filter);
 __ZN16b2ParticleSystem14UpdateContactsEb($this,1);
 __ZN16b2ParticleSystem20UpdatePairsAndTriadsEiiRKNS_16ConnectionFilterE($this,$7,$37,$filter);
 $68 = (($groupDef) + 72|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($69|0)==(0|0);
 if ($70) {
  $$0 = $41;
  STACKTOP = sp;return ($$0|0);
 }
 __ZN16b2ParticleSystem18JoinParticleGroupsEP15b2ParticleGroupS1_($this,$69,$41);
 $71 = HEAP32[$68>>2]|0;
 $$0 = $71;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16b2ParticleSystem13SetGroupFlagsEP15b2ParticleGroupj($this,$group,$newFlags) {
 $this = $this|0;
 $group = $group|0;
 $newFlags = $newFlags|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($group) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 ^ $newFlags;
 $3 = $2 << 4;
 $4 = $3 & 16;
 $5 = $4 | $newFlags;
 $6 = $5 ^ -1;
 $7 = $1 & $6;
 $8 = ($7|0)==(0);
 if (!($8)) {
  $9 = (($this) + 20|0);
  HEAP8[$9>>0] = 1;
 }
 $10 = (($this) + 16|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 ^ -1;
 $13 = $5 & $12;
 $14 = ($13|0)==(0);
 if ($14) {
  HEAP32[$0>>2] = $5;
  STACKTOP = sp;return;
 }
 $15 = $newFlags & 1;
 $16 = ($15|0)==(0);
 if (!($16)) {
  $17 = (($this) + 132|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (__ZN16b2ParticleSystem13RequestBufferIfEEPT_S2_($this,$18)|0);
  HEAP32[$17>>2] = $19;
 }
 $20 = HEAP32[$10>>2]|0;
 $21 = $20 | $5;
 HEAP32[$10>>2] = $21;
 HEAP32[$0>>2] = $5;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem14UpdateContactsEb($this,$exceptZombie) {
 $this = $this|0;
 $exceptZombie = $exceptZombie|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $particlePairs = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $particlePairs = sp;
 $0 = (($this) + 200|0);
 __ZNK16b2ParticleSystem13UpdateProxiesER16b2GrowableBufferINS_5ProxyEE($this,$0);
 __ZNK16b2ParticleSystem11SortProxiesER16b2GrowableBufferINS_5ProxyEE(0,$0);
 $1 = (($this) + 400|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 76|0);
 __ZN17b2ParticlePairSetC2EP16b2StackAllocator($particlePairs,$3);
 __ZNK16b2ParticleSystem31NotifyContactListenerPreContactEP17b2ParticlePairSet($this,$particlePairs);
 $4 = (($this) + 216|0);
 __ZNK16b2ParticleSystem12FindContactsER16b2GrowableBufferI17b2ParticleContactE($this,$4);
 __ZN16b2ParticleSystem14FilterContactsER16b2GrowableBufferI17b2ParticleContactE($this,$4);
 __ZN16b2ParticleSystem32NotifyContactListenerPostContactER17b2ParticlePairSet($this,$particlePairs);
 if (!($exceptZombie)) {
  __ZN12_GLOBAL__N_117FixedSetAllocatorD2Ev($particlePairs);
  STACKTOP = sp;return;
 }
 (__ZN16b2GrowableBufferI17b2ParticleContactE8RemoveIfIPFbRKS0_EEEPS0_T_($4,12)|0);
 __ZN12_GLOBAL__N_117FixedSetAllocatorD2Ev($particlePairs);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem20UpdatePairsAndTriadsEiiRKNS_16ConnectionFilterE($this,$firstIndex,$lastIndex,$filter) {
 $this = $this|0;
 $firstIndex = $firstIndex|0;
 $lastIndex = $lastIndex|0;
 $filter = $filter|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0.0;
 var $116 = 0.0, $117 = 0.0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $callback = 0, $diagram = 0, $exitcond = 0, $i$010 = 0, $i1$06 = 0, $k$07 = 0, $notlhs = 0, $notrhs = 0;
 var $or$cond$not = 0, $or$cond2 = 0, $or$cond2$not = 0, $or$cond3 = 0, $or$cond5 = 0, $particleFlags$011 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $0 = sp + 48|0;
 $1 = sp + 40|0;
 $diagram = sp + 12|0;
 $callback = sp;
 $2 = ($lastIndex|0)>($firstIndex|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 88|0);
 $4 = HEAP32[$3>>2]|0;
 $i$010 = $firstIndex;$particleFlags$011 = 0;
 while(1) {
  $5 = (($4) + ($i$010<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $6 | $particleFlags$011;
  $8 = (($i$010) + 1)|0;
  $exitcond = ($8|0)==($lastIndex|0);
  if ($exitcond) {
   break;
  } else {
   $i$010 = $8;$particleFlags$011 = $7;
  }
 }
 $9 = $7 & 1032;
 $10 = ($9|0)==(0);
 if (!($10)) {
  $11 = (($this) + 216|0);
  $12 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($11)|0);
  $13 = ($12|0)>(0);
  if ($13) {
   $14 = (($this) + 88|0);
   $15 = (($this) + 144|0);
   $16 = (($this) + 248|0);
   $17 = (($this) + 96|0);
   $k$07 = 0;
   while(1) {
    $18 = (__ZN16b2GrowableBufferI17b2ParticleContactEixEi($11,$k$07)|0);
    $19 = (__ZNK17b2ParticleContact9GetIndexAEv($18)|0);
    $20 = (__ZNK17b2ParticleContact9GetIndexBEv($18)|0);
    $21 = HEAP32[$14>>2]|0;
    $22 = (($21) + ($19<<2)|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($21) + ($20<<2)|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = HEAP32[$15>>2]|0;
    $27 = (($26) + ($19<<2)|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (($26) + ($20<<2)|0);
    $30 = HEAP32[$29>>2]|0;
    $notlhs = ($19|0)<($firstIndex|0);
    $notrhs = ($19|0)>=($lastIndex|0);
    $or$cond$not = $notrhs | $notlhs;
    $31 = ($20|0)<($firstIndex|0);
    $or$cond2 = $or$cond$not | $31;
    $or$cond2$not = $or$cond2 ^ 1;
    $32 = ($20|0)<($lastIndex|0);
    $or$cond3 = $32 & $or$cond2$not;
    do {
     if ($or$cond3) {
      $33 = $25 | $23;
      $34 = $33 & 2;
      $35 = ($34|0)!=(0);
      $36 = $33 & 1032;
      $37 = ($36|0)==(0);
      $or$cond5 = $35 | $37;
      if (!($or$cond5)) {
       $38 = HEAP32[$filter>>2]|0;
       $39 = (($38) + 8|0);
       $40 = HEAP32[$39>>2]|0;
       $41 = (FUNCTION_TABLE_iii[$40 & 63]($filter,$19)|0);
       if (!($41)) {
        $42 = HEAP32[$filter>>2]|0;
        $43 = (($42) + 8|0);
        $44 = HEAP32[$43>>2]|0;
        $45 = (FUNCTION_TABLE_iii[$44 & 63]($filter,$20)|0);
        if (!($45)) {
         break;
        }
       }
       $46 = (__ZL22ParticleCanBeConnectedjP15b2ParticleGroup($23,$28)|0);
       if ($46) {
        $47 = (__ZL22ParticleCanBeConnectedjP15b2ParticleGroup($25,$30)|0);
        if ($47) {
         $48 = HEAP32[$filter>>2]|0;
         $49 = (($48) + 12|0);
         $50 = HEAP32[$49>>2]|0;
         $51 = (FUNCTION_TABLE_iiii[$50 & 15]($filter,$19,$20)|0);
         if ($51) {
          $52 = (__ZN16b2GrowableBufferI14b2ParticlePairE6AppendEv($16)|0);
          HEAP32[$52>>2] = $19;
          $53 = (($52) + 4|0);
          HEAP32[$53>>2] = $20;
          $54 = (__ZNK17b2ParticleContact8GetFlagsEv($18)|0);
          $55 = (($52) + 8|0);
          HEAP32[$55>>2] = $54;
          $56 = ($28|0)==(0|0);
          if ($56) {
           $62 = 1.0;
          } else {
           $57 = (($28) + 16|0);
           $58 = +HEAPF32[$57>>2];
           $62 = $58;
          }
          $59 = ($30|0)==(0|0);
          if ($59) {
           $63 = 1.0;
          } else {
           $60 = (($30) + 16|0);
           $61 = +HEAPF32[$60>>2];
           $63 = $61;
          }
          $64 = (+__Z5b2MinIfET_S0_S0_($62,$63));
          $65 = (($52) + 12|0);
          HEAPF32[$65>>2] = $64;
          $66 = HEAP32[$17>>2]|0;
          $67 = (($66) + ($19<<3)|0);
          $68 = (($66) + ($20<<3)|0);
          $69 = (+__Z10b2DistanceRK6b2Vec2S1_($67,$68));
          $70 = (($52) + 16|0);
          HEAPF32[$70>>2] = $69;
         }
        }
       }
      }
     }
    } while(0);
    $71 = (($k$07) + 1)|0;
    $72 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($11)|0);
    $73 = ($71|0)<($72|0);
    if ($73) {
     $k$07 = $71;
    } else {
     break;
    }
   }
  }
  $74 = (($this) + 248|0);
  $75 = (__ZN16b2GrowableBufferI14b2ParticlePairE5BeginEv($74)|0);
  $76 = (__ZN16b2GrowableBufferI14b2ParticlePairE3EndEv($74)|0);
  HEAP32[$0>>2] = 27;
  $77 = $76;
  $78 = $75;
  $79 = (($77) - ($78))|0;
  $80 = (($79|0) / 20)&-1;
  $81 = ($79|0)>(2560);
  if ($81) {
   __ZNSt3__120get_temporary_bufferI14b2ParticlePairEENS_4pairIPT_iEEi($1,$80);
   $82 = HEAP32[$1>>2]|0;
   $83 = (($1) + 4|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = $82;$86 = $84;
  } else {
   $85 = 0;$86 = 0;
  }
  __ZNSt3__113__stable_sortIRPFbRK14b2ParticlePairS3_EPS1_EEvT0_S8_T_NS_15iterator_traitsIS8_E15difference_typeEPNSB_10value_typeEi($75,$76,$0,$80,$85,$86);
  $87 = ($85|0)==(0|0);
  if (!($87)) {
   __ZdlPv($85);
  }
  (__ZN16b2GrowableBufferI14b2ParticlePairE6UniqueIPFbRKS0_S4_EEEPS0_T_($74,28)|0);
 }
 $88 = $7 & 16;
 $89 = ($88|0)==(0);
 if ($89) {
  STACKTOP = sp;return;
 }
 $90 = (($this) + 400|0);
 $91 = HEAP32[$90>>2]|0;
 $92 = (($91) + 76|0);
 $93 = (($lastIndex) - ($firstIndex))|0;
 __ZN16b2VoronoiDiagramC2EP16b2StackAllocatori($diagram,$92,$93);
 $94 = ($lastIndex|0)>($firstIndex|0);
 if ($94) {
  $95 = (($this) + 88|0);
  $96 = (($this) + 144|0);
  $97 = (($this) + 96|0);
  $i1$06 = $firstIndex;
  while(1) {
   $98 = HEAP32[$95>>2]|0;
   $99 = (($98) + ($i1$06<<2)|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = $100 & 2;
   $102 = ($101|0)==(0);
   if ($102) {
    $103 = HEAP32[$96>>2]|0;
    $104 = (($103) + ($i1$06<<2)|0);
    $105 = HEAP32[$104>>2]|0;
    $106 = (__ZL22ParticleCanBeConnectedjP15b2ParticleGroup($100,$105)|0);
    if ($106) {
     $107 = HEAP32[$97>>2]|0;
     $108 = HEAP32[$filter>>2]|0;
     $109 = (($108) + 8|0);
     $110 = HEAP32[$109>>2]|0;
     $111 = (FUNCTION_TABLE_iii[$110 & 63]($filter,$i1$06)|0);
     $112 = (($107) + ($i1$06<<3)|0);
     __ZN16b2VoronoiDiagram12AddGeneratorERK6b2Vec2ib($diagram,$112,$i1$06,$111);
    }
   }
   $113 = (($i1$06) + 1)|0;
   $114 = ($113|0)<($lastIndex|0);
   if ($114) {
    $i1$06 = $113;
   } else {
    break;
   }
  }
 }
 $115 = (+__ZNK16b2ParticleSystem17GetParticleStrideEv($this));
 $116 = $115 * 0.5;
 $117 = $115 * 2.0;
 __ZN16b2VoronoiDiagram8GenerateEff($diagram,$116,$117);
 __ZZN16b2ParticleSystem20UpdatePairsAndTriadsEiiRKNS_16ConnectionFilterEEN20UpdateTriadsCallbackC2EPS_PS1_($callback,$this,$filter);
 __ZNK16b2VoronoiDiagram8GetNodesERNS_12NodeCallbackE($diagram,$callback);
 $118 = (($this) + 264|0);
 $119 = (__ZN16b2GrowableBufferI15b2ParticleTriadE5BeginEv($118)|0);
 $120 = (__ZN16b2GrowableBufferI15b2ParticleTriadE3EndEv($118)|0);
 HEAP32[$0>>2] = 29;
 $121 = $120;
 $122 = $119;
 $123 = (($121) - ($122))|0;
 $124 = (($123|0) / 60)&-1;
 $125 = ($123|0)>(7680);
 if ($125) {
  __ZNSt3__120get_temporary_bufferI15b2ParticleTriadEENS_4pairIPT_iEEi($1,$124);
  $126 = HEAP32[$1>>2]|0;
  $127 = (($1) + 4|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = $126;$130 = $128;
 } else {
  $129 = 0;$130 = 0;
 }
 __ZNSt3__113__stable_sortIRPFbRK15b2ParticleTriadS3_EPS1_EEvT0_S8_T_NS_15iterator_traitsIS8_E15difference_typeEPNSB_10value_typeEi($119,$120,$0,$124,$129,$130);
 $131 = ($129|0)==(0|0);
 if (!($131)) {
  __ZdlPv($129);
 }
 (__ZN16b2GrowableBufferI15b2ParticleTriadE6UniqueIPFbRKS0_S4_EEEPS0_T_($118,30)|0);
 __ZN16b2VoronoiDiagramD2Ev($diagram);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem18JoinParticleGroupsEP15b2ParticleGroupS1_($this,$groupA,$groupB) {
 $this = $this|0;
 $groupA = $groupA|0;
 $groupB = $groupB|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $filter = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $filter = sp;
 $0 = (($this) + 400|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZNK7b2World8IsLockedEv($1)|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($groupB) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($groupB) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 __ZN16b2ParticleSystem12RotateBufferEiii($this,$4,$6,$8);
 $9 = (($groupA) + 4|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($groupA) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$3>>2]|0;
 __ZN16b2ParticleSystem12RotateBufferEiii($this,$10,$12,$13);
 $14 = HEAP32[$3>>2]|0;
 __ZZN16b2ParticleSystem18JoinParticleGroupsEP15b2ParticleGroupS1_EN24JoinParticleGroupsFilterC2Ei($filter,$14);
 __ZN16b2ParticleSystem14UpdateContactsEb($this,1);
 $15 = HEAP32[$9>>2]|0;
 $16 = HEAP32[$5>>2]|0;
 __ZN16b2ParticleSystem20UpdatePairsAndTriadsEiiRKNS_16ConnectionFilterE($this,$15,$16,$filter);
 $17 = HEAP32[$3>>2]|0;
 $18 = HEAP32[$5>>2]|0;
 $19 = ($17|0)<($18|0);
 if ($19) {
  $20 = (($this) + 144|0);
  $21 = HEAP32[$5>>2]|0;
  $i$01 = $17;
  while(1) {
   $22 = HEAP32[$20>>2]|0;
   $23 = (($22) + ($i$01<<2)|0);
   HEAP32[$23>>2] = $groupA;
   $24 = (($i$01) + 1)|0;
   $25 = ($24|0)<($21|0);
   if ($25) {
    $i$01 = $24;
   } else {
    break;
   }
  }
 }
 $26 = (($groupA) + 12|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($groupB) + 12|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = $29 | $27;
 __ZN16b2ParticleSystem13SetGroupFlagsEP15b2ParticleGroupj($this,$groupA,$30);
 $31 = HEAP32[$5>>2]|0;
 HEAP32[$11>>2] = $31;
 $32 = HEAP32[$5>>2]|0;
 HEAP32[$3>>2] = $32;
 __ZN16b2ParticleSystem20DestroyParticleGroupEP15b2ParticleGroup($this,$groupB);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem41UpdatePairsAndTriadsWithReactiveParticlesEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $filter = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $filter = sp;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 __ZZN16b2ParticleSystem41UpdatePairsAndTriadsWithReactiveParticlesEvEN14ReactiveFilterC2EPj($filter,$1);
 $2 = (($this) + 44|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN16b2ParticleSystem20UpdatePairsAndTriadsEiiRKNS_16ConnectionFilterE($this,0,$3,$filter);
 $4 = HEAP32[$2>>2]|0;
 $5 = ($4|0)>(0);
 if (!($5)) {
  $13 = (($this) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $14 & -4097;
  HEAP32[$13>>2] = $15;
  STACKTOP = sp;return;
 }
 $6 = HEAP32[$0>>2]|0;
 $i$01 = 0;
 while(1) {
  $7 = (($6) + ($i$01<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $8 & -4097;
  HEAP32[$7>>2] = $9;
  $10 = (($i$01) + 1)|0;
  $11 = HEAP32[$2>>2]|0;
  $12 = ($10|0)<($11|0);
  if ($12) {
   $i$01 = $10;
  } else {
   break;
  }
 }
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14 & -4097;
 HEAP32[$13>>2] = $15;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem18ComparePairIndicesERK14b2ParticlePairS2_($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$a>>2]|0;
 $1 = HEAP32[$b>>2]|0;
 $2 = ($0|0)==($1|0);
 if ($2) {
  $5 = (($a) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($b) + 4|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($6|0)<($8|0);
  $$0 = $9;
  STACKTOP = sp;return ($$0|0);
 } else {
  $3 = (($0) - ($1))|0;
  $4 = ($3|0)<(0);
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function __ZN16b2ParticleSystem16MatchPairIndicesERK14b2ParticlePairS2_($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$a>>2]|0;
 $1 = HEAP32[$b>>2]|0;
 $2 = ($0|0)==($1|0);
 if (!($2)) {
  $8 = 0;
  STACKTOP = sp;return ($8|0);
 }
 $3 = (($a) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($b) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 $8 = $7;
 STACKTOP = sp;return ($8|0);
}
function __ZN16b2ParticleSystem19CompareTriadIndicesERK15b2ParticleTriadS2_($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$a>>2]|0;
 $1 = HEAP32[$b>>2]|0;
 $2 = ($0|0)==($1|0);
 if (!($2)) {
  $3 = (($0) - ($1))|0;
  $4 = ($3|0)<(0);
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (($a) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($b) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($6|0)==($8|0);
 if ($9) {
  $12 = (($a) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($b) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($13|0)<($15|0);
  $$0 = $16;
  STACKTOP = sp;return ($$0|0);
 } else {
  $10 = (($6) - ($8))|0;
  $11 = ($10|0)<(0);
  $$0 = $11;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function __ZN16b2ParticleSystem17MatchTriadIndicesERK15b2ParticleTriadS2_($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$a>>2]|0;
 $1 = HEAP32[$b>>2]|0;
 $2 = ($0|0)==($1|0);
 if (!($2)) {
  $13 = 0;
  STACKTOP = sp;return ($13|0);
 }
 $3 = (($a) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($b) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)==($6|0);
 if (!($7)) {
  $13 = 0;
  STACKTOP = sp;return ($13|0);
 }
 $8 = (($a) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($b) + 8|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($9|0)==($11|0);
 $13 = $12;
 STACKTOP = sp;return ($13|0);
}
function __ZN16b2ParticleSystem13ComputeWeightEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0;
 var $27 = 0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $k$02 = 0, $k1$01 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 116|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 44|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 << 2;
 _memset(($1|0),0,($4|0))|0;
 $5 = (($this) + 232|0);
 $6 = (__ZNK16b2GrowableBufferI21b2ParticleBodyContactE8GetCountEv($5)|0);
 $7 = ($6|0)>(0);
 if ($7) {
  $k$02 = 0;
  while(1) {
   $11 = (__ZN16b2GrowableBufferI21b2ParticleBodyContactEixEi($5,$k$02)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($11) + 12|0);
   $14 = +HEAPF32[$13>>2];
   $15 = HEAP32[$0>>2]|0;
   $16 = (($15) + ($12<<2)|0);
   $17 = +HEAPF32[$16>>2];
   $18 = $14 + $17;
   HEAPF32[$16>>2] = $18;
   $19 = (($k$02) + 1)|0;
   $20 = (__ZNK16b2GrowableBufferI21b2ParticleBodyContactE8GetCountEv($5)|0);
   $21 = ($19|0)<($20|0);
   if ($21) {
    $k$02 = $19;
   } else {
    break;
   }
  }
 }
 $8 = (($this) + 216|0);
 $9 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($8)|0);
 $10 = ($9|0)>(0);
 if ($10) {
  $k1$01 = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $22 = (__ZN16b2GrowableBufferI17b2ParticleContactEixEi($8,$k1$01)|0);
  $23 = (__ZNK17b2ParticleContact9GetIndexAEv($22)|0);
  $24 = (__ZNK17b2ParticleContact9GetIndexBEv($22)|0);
  $25 = (+__ZNK17b2ParticleContact9GetWeightEv($22));
  $26 = HEAP32[$0>>2]|0;
  $27 = (($26) + ($23<<2)|0);
  $28 = +HEAPF32[$27>>2];
  $29 = $25 + $28;
  HEAPF32[$27>>2] = $29;
  $30 = HEAP32[$0>>2]|0;
  $31 = (($30) + ($24<<2)|0);
  $32 = +HEAPF32[$31>>2];
  $33 = $25 + $32;
  HEAPF32[$31>>2] = $33;
  $34 = (($k1$01) + 1)|0;
  $35 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($8)|0);
  $36 = ($34|0)<($35|0);
  if ($36) {
   $k1$01 = $34;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem12ComputeDepthEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0, $113 = 0, $114 = 0, $115 = 0.0;
 var $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0.0, $136 = 0, $137 = 0.0, $138 = 0.0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0.0, $72 = 0.0, $73 = 0, $74 = 0, $75 = 0.0;
 var $76 = 0.0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0, $91 = 0.0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0.0, $99 = 0.0, $contactGroupsCount$0$lcssa = 0, $contactGroupsCount$033 = 0, $contactGroupsCount$1 = 0, $exitcond = 0, $exitcond38 = 0, $exitcond39 = 0, $exitcond40 = 0, $group$027 = 0, $groupsToUpdateCount$0$lcssa = 0, $groupsToUpdateCount$028 = 0, $groupsToUpdateCount$1 = 0, $i13$04 = 0, $i15$03 = 0, $i5$018 = 0;
 var $i7$013 = 0, $k$032 = 0, $k1$022 = 0, $k9$08 = 0, $or$cond = 0, $scevgep = 0, $smax = 0, $storemerge = 0.0, $t$012 = 0, $updated$0$off09 = 0, $updated$1$off0 = 0, $updated$2$off0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 400|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 76|0);
 $3 = (($this) + 216|0);
 $4 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($3)|0);
 $5 = ($4*24)|0;
 $6 = (__ZN16b2StackAllocator8AllocateEi($2,$5)|0);
 $7 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($3)|0);
 $8 = ($7|0)>(0);
 if ($8) {
  $9 = (($this) + 144|0);
  $contactGroupsCount$033 = 0;$k$032 = 0;
  while(1) {
   $10 = (__ZN16b2GrowableBufferI17b2ParticleContactEixEi($3,$k$032)|0);
   $11 = (__ZNK17b2ParticleContact9GetIndexAEv($10)|0);
   $12 = HEAP32[$9>>2]|0;
   $13 = (($12) + ($11<<2)|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ($14|0)==(0|0);
   if ($15) {
    $contactGroupsCount$1 = $contactGroupsCount$033;
   } else {
    $16 = (__ZNK17b2ParticleContact9GetIndexBEv($10)|0);
    $17 = (($12) + ($16<<2)|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($14|0)==($18|0);
    if ($19) {
     $20 = (($14) + 12|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = $21 & 16;
     $23 = ($22|0)==(0);
     if ($23) {
      $contactGroupsCount$1 = $contactGroupsCount$033;
     } else {
      $24 = (($contactGroupsCount$033) + 1)|0;
      $25 = (($6) + (($contactGroupsCount$033*24)|0)|0);
      ;HEAP32[$25+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$25+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$25+8>>2]=HEAP32[$10+8>>2]|0;HEAP32[$25+12>>2]=HEAP32[$10+12>>2]|0;HEAP32[$25+16>>2]=HEAP32[$10+16>>2]|0;HEAP32[$25+20>>2]=HEAP32[$10+20>>2]|0;
      $contactGroupsCount$1 = $24;
     }
    } else {
     $contactGroupsCount$1 = $contactGroupsCount$033;
    }
   }
   $26 = (($k$032) + 1)|0;
   $27 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($3)|0);
   $28 = ($26|0)<($27|0);
   if ($28) {
    $contactGroupsCount$033 = $contactGroupsCount$1;$k$032 = $26;
   } else {
    $contactGroupsCount$0$lcssa = $contactGroupsCount$1;
    break;
   }
  }
 } else {
  $contactGroupsCount$0$lcssa = 0;
 }
 $29 = HEAP32[$0>>2]|0;
 $30 = (($29) + 76|0);
 $31 = (($this) + 308|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = $32 << 2;
 $34 = (__ZN16b2StackAllocator8AllocateEi($30,$33)|0);
 $35 = (($this) + 312|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0|0);
 if ($37) {
  $groupsToUpdateCount$0$lcssa = 0;
 } else {
  $38 = (($this) + 124|0);
  $group$027 = $36;$groupsToUpdateCount$028 = 0;
  while(1) {
   $41 = (($group$027) + 12|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = $42 & 16;
   $44 = ($43|0)==(0);
   if ($44) {
    $groupsToUpdateCount$1 = $groupsToUpdateCount$028;
   } else {
    $45 = (($groupsToUpdateCount$028) + 1)|0;
    $46 = (($34) + ($groupsToUpdateCount$028<<2)|0);
    HEAP32[$46>>2] = $group$027;
    $47 = HEAP32[$41>>2]|0;
    $48 = $47 & -17;
    __ZN16b2ParticleSystem13SetGroupFlagsEP15b2ParticleGroupj($this,$group$027,$48);
    $49 = (($group$027) + 4|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = (($group$027) + 8|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = ($50|0)<($52|0);
    if ($53) {
     $54 = HEAP32[$38>>2]|0;
     $55 = HEAP32[$51>>2]|0;
     $scevgep = (($54) + ($50<<2)|0);
     $56 = (($50) + 1)|0;
     $57 = ($55|0)>($56|0);
     $smax = $57 ? $55 : $56;
     $58 = (($smax) - ($50))|0;
     $59 = $58 << 2;
     _memset(($scevgep|0),0,($59|0))|0;
     $groupsToUpdateCount$1 = $45;
    } else {
     $groupsToUpdateCount$1 = $45;
    }
   }
   $60 = (__ZN15b2ParticleGroup7GetNextEv($group$027)|0);
   $61 = ($60|0)==(0|0);
   if ($61) {
    $groupsToUpdateCount$0$lcssa = $groupsToUpdateCount$1;
    break;
   } else {
    $group$027 = $60;$groupsToUpdateCount$028 = $groupsToUpdateCount$1;
   }
  }
 }
 $39 = ($contactGroupsCount$0$lcssa|0)>(0);
 if ($39) {
  $40 = (($this) + 124|0);
  $k1$022 = 0;
  while(1) {
   $65 = (($6) + (($k1$022*24)|0)|0);
   $66 = (__ZNK17b2ParticleContact9GetIndexAEv($65)|0);
   $67 = (__ZNK17b2ParticleContact9GetIndexBEv($65)|0);
   $68 = (+__ZNK17b2ParticleContact9GetWeightEv($65));
   $69 = HEAP32[$40>>2]|0;
   $70 = (($69) + ($66<<2)|0);
   $71 = +HEAPF32[$70>>2];
   $72 = $68 + $71;
   HEAPF32[$70>>2] = $72;
   $73 = HEAP32[$40>>2]|0;
   $74 = (($73) + ($67<<2)|0);
   $75 = +HEAPF32[$74>>2];
   $76 = $68 + $75;
   HEAPF32[$74>>2] = $76;
   $77 = (($k1$022) + 1)|0;
   $exitcond40 = ($77|0)==($contactGroupsCount$0$lcssa|0);
   if ($exitcond40) {
    break;
   } else {
    $k1$022 = $77;
   }
  }
 }
 $62 = ($groupsToUpdateCount$0$lcssa|0)>(0);
 if ($62) {
  $63 = (($this) + 124|0);
  $64 = (($this) + 132|0);
  $i5$018 = 0;
  while(1) {
   $78 = (($34) + ($i5$018<<2)|0);
   $79 = HEAP32[$78>>2]|0;
   $80 = (($79) + 4|0);
   $81 = HEAP32[$80>>2]|0;
   $82 = (($79) + 8|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = ($81|0)<($83|0);
   if ($84) {
    $85 = HEAP32[$63>>2]|0;
    $86 = HEAP32[$64>>2]|0;
    $87 = HEAP32[$82>>2]|0;
    $i7$013 = $81;
    while(1) {
     $88 = (($85) + ($i7$013<<2)|0);
     $89 = +HEAPF32[$88>>2];
     $90 = $89 < 0.80000001192092896;
     $91 = $90 ? 0.0 : 3.4028234663852886E+38;
     $92 = (($86) + ($i7$013<<2)|0);
     HEAPF32[$92>>2] = $91;
     $93 = (($i7$013) + 1)|0;
     $94 = ($93|0)<($87|0);
     if ($94) {
      $i7$013 = $93;
     } else {
      break;
     }
    }
   }
   $95 = (($i5$018) + 1)|0;
   $exitcond39 = ($95|0)==($groupsToUpdateCount$0$lcssa|0);
   if ($exitcond39) {
    break;
   } else {
    $i5$018 = $95;
   }
  }
 }
 $96 = (($this) + 44|0);
 $97 = HEAP32[$96>>2]|0;
 $98 = (+($97|0));
 $99 = (+Math_sqrt((+$98)));
 $100 = (~~(($99)));
 $101 = ($100|0)>(0);
 L35: do {
  if ($101) {
   $102 = ($contactGroupsCount$0$lcssa|0)>(0);
   $103 = (($this) + 132|0);
   $t$012 = 0;
   while(1) {
    if ($102) {
     $k9$08 = 0;$updated$0$off09 = 0;
    } else {
     break L35;
    }
    while(1) {
     $107 = (($6) + (($k9$08*24)|0)|0);
     $108 = (__ZNK17b2ParticleContact9GetIndexAEv($107)|0);
     $109 = (__ZNK17b2ParticleContact9GetIndexBEv($107)|0);
     $110 = (+__ZNK17b2ParticleContact9GetWeightEv($107));
     $111 = 1.0 - $110;
     $112 = HEAP32[$103>>2]|0;
     $113 = (($112) + ($108<<2)|0);
     $114 = (($112) + ($109<<2)|0);
     $115 = +HEAPF32[$114>>2];
     $116 = $111 + $115;
     $117 = +HEAPF32[$113>>2];
     $118 = $111 + $117;
     $119 = $117 > $116;
     if ($119) {
      HEAPF32[$113>>2] = $116;
      $updated$1$off0 = 1;
     } else {
      $updated$1$off0 = $updated$0$off09;
     }
     $120 = +HEAPF32[$114>>2];
     $121 = $120 > $118;
     if ($121) {
      HEAPF32[$114>>2] = $118;
      $updated$2$off0 = 1;
     } else {
      $updated$2$off0 = $updated$1$off0;
     }
     $122 = (($k9$08) + 1)|0;
     $exitcond38 = ($122|0)==($contactGroupsCount$0$lcssa|0);
     if ($exitcond38) {
      break;
     } else {
      $k9$08 = $122;$updated$0$off09 = $updated$2$off0;
     }
    }
    $123 = (($t$012) + 1)|0;
    $124 = ($123|0)<($100|0);
    $or$cond = $updated$2$off0 & $124;
    if ($or$cond) {
     $t$012 = $123;
    } else {
     break;
    }
   }
  }
 } while(0);
 $104 = ($groupsToUpdateCount$0$lcssa|0)>(0);
 if (!($104)) {
  $142 = HEAP32[$0>>2]|0;
  $143 = (($142) + 76|0);
  __ZN16b2StackAllocator4FreeEPv($143,$34);
  $144 = HEAP32[$0>>2]|0;
  $145 = (($144) + 76|0);
  __ZN16b2StackAllocator4FreeEPv($145,$6);
  STACKTOP = sp;return;
 }
 $105 = (($this) + 132|0);
 $106 = (($this) + 32|0);
 $i13$04 = 0;
 while(1) {
  $125 = (($34) + ($i13$04<<2)|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = (($126) + 4|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = (($126) + 8|0);
  $130 = HEAP32[$129>>2]|0;
  $131 = ($128|0)<($130|0);
  if ($131) {
   $132 = HEAP32[$105>>2]|0;
   $133 = HEAP32[$129>>2]|0;
   $i15$03 = $128;
   while(1) {
    $134 = (($132) + ($i15$03<<2)|0);
    $135 = +HEAPF32[$134>>2];
    $136 = $135 < 3.4028234663852886E+38;
    if ($136) {
     $137 = +HEAPF32[$106>>2];
     $138 = $135 * $137;
     $storemerge = $138;
    } else {
     $storemerge = 0.0;
    }
    HEAPF32[$134>>2] = $storemerge;
    $139 = (($i15$03) + 1)|0;
    $140 = ($139|0)<($133|0);
    if ($140) {
     $i15$03 = $139;
    } else {
     break;
    }
   }
  }
  $141 = (($i13$04) + 1)|0;
  $exitcond = ($141|0)==($groupsToUpdateCount$0$lcssa|0);
  if ($exitcond) {
   break;
  } else {
   $i13$04 = $141;
  }
 }
 $142 = HEAP32[$0>>2]|0;
 $143 = (($142) + 76|0);
 __ZN16b2StackAllocator4FreeEPv($143,$34);
 $144 = HEAP32[$0>>2]|0;
 $145 = (($144) + 76|0);
 __ZN16b2StackAllocator4FreeEPv($145,$6);
 STACKTOP = sp;return;
}
function __ZNK16b2ParticleSystem25GetInsideBoundsEnumeratorERK6b2AABB($agg$result,$this,$aabb) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $aabb = $aabb|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0.0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, $lowerTag = 0, $upperTag = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $lowerTag = sp + 4|0;
 $upperTag = sp;
 $1 = (($this) + 36|0);
 $2 = +HEAPF32[$1>>2];
 $3 = +HEAPF32[$aabb>>2];
 $4 = $2 * $3;
 $5 = $4 + -1.0;
 $6 = (($aabb) + 4|0);
 $7 = +HEAPF32[$6>>2];
 $8 = $2 * $7;
 $9 = $8 + -1.0;
 $10 = (__ZL10computeTagff($5,$9)|0);
 HEAP32[$lowerTag>>2] = $10;
 $11 = +HEAPF32[$1>>2];
 $12 = (($aabb) + 8|0);
 $13 = +HEAPF32[$12>>2];
 $14 = $11 * $13;
 $15 = $14 + 1.0;
 $16 = (($aabb) + 12|0);
 $17 = +HEAPF32[$16>>2];
 $18 = $11 * $17;
 $19 = $18 + 1.0;
 $20 = (__ZL10computeTagff($15,$19)|0);
 HEAP32[$upperTag>>2] = $20;
 $21 = (($this) + 200|0);
 $22 = (__ZNK16b2GrowableBufferIN16b2ParticleSystem5ProxyEE5BeginEv($21)|0);
 $23 = (__ZNK16b2GrowableBufferIN16b2ParticleSystem5ProxyEE3EndEv($21)|0);
 $24 = (__ZNSt3__113__lower_boundIRNS_6__lessIN16b2ParticleSystem5ProxyEjEEPKS3_jEET0_S8_S8_RKT1_T_($22,$23,$lowerTag,$0)|0);
 $25 = (__ZNSt3__113__upper_boundIRNS_6__lessIjN16b2ParticleSystem5ProxyEEEPKS3_jEET0_S8_S8_RKT1_T_($24,$23,$upperTag,$0)|0);
 $26 = HEAP32[$lowerTag>>2]|0;
 $27 = HEAP32[$upperTag>>2]|0;
 __ZN16b2ParticleSystem22InsideBoundsEnumeratorC2EjjPKNS_5ProxyES3_($agg$result,$26,$27,$24,$25);
 STACKTOP = sp;return;
}
function __ZNK16b2ParticleSystem22FindContacts_ReferenceER16b2GrowableBufferI17b2ParticleContactE($this,$contacts) {
 $this = $this|0;
 $contacts = $contacts|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $a$012 = 0, $b$01 = 0, $b1$08 = 0, $c$011 = 0, $c$1$lcssa = 0;
 var $c$12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 200|0);
 $1 = (__ZNK16b2GrowableBufferIN16b2ParticleSystem5ProxyEE5BeginEv($0)|0);
 $2 = (__ZNK16b2GrowableBufferIN16b2ParticleSystem5ProxyEE3EndEv($0)|0);
 __ZN16b2GrowableBufferI17b2ParticleContactE8SetCountEi($contacts,0);
 $3 = ($1>>>0)<($2>>>0);
 if ($3) {
  $a$012 = $1;$c$011 = $1;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $6 = (($a$012) + 4|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = (__ZL18computeRelativeTagjii($7,1,0)|0);
  $4 = (($a$012) + 8|0);
  $9 = ($4>>>0)<($2>>>0);
  L5: do {
   if ($9) {
    $b$01 = $4;
    while(1) {
     $10 = (($b$01) + 4|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = ($8>>>0)<($11>>>0);
     if ($12) {
      break L5;
     }
     $13 = HEAP32[$a$012>>2]|0;
     $14 = HEAP32[$b$01>>2]|0;
     __ZNK16b2ParticleSystem10AddContactEiiR16b2GrowableBufferI17b2ParticleContactE($this,$13,$14,$contacts);
     $15 = (($b$01) + 8|0);
     $16 = ($15>>>0)<($2>>>0);
     if ($16) {
      $b$01 = $15;
     } else {
      break;
     }
    }
   }
  } while(0);
  $17 = HEAP32[$6>>2]|0;
  $18 = (__ZL18computeRelativeTagjii($17,-1,1)|0);
  $19 = ($c$011>>>0)<($2>>>0);
  L11: do {
   if ($19) {
    $c$12 = $c$011;
    while(1) {
     $22 = (($c$12) + 4|0);
     $23 = HEAP32[$22>>2]|0;
     $24 = ($18>>>0)>($23>>>0);
     $20 = (($c$12) + 8|0);
     if (!($24)) {
      $c$1$lcssa = $c$12;
      break L11;
     }
     $21 = ($20>>>0)<($2>>>0);
     if ($21) {
      $c$12 = $20;
     } else {
      $c$1$lcssa = $20;
      break;
     }
    }
   } else {
    $c$1$lcssa = $c$011;
   }
  } while(0);
  $25 = HEAP32[$6>>2]|0;
  $26 = (__ZL18computeRelativeTagjii($25,1,1)|0);
  $27 = ($c$1$lcssa>>>0)<($2>>>0);
  L16: do {
   if ($27) {
    $b1$08 = $c$1$lcssa;
    while(1) {
     $28 = (($b1$08) + 4|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = ($26>>>0)<($29>>>0);
     if ($30) {
      break L16;
     }
     $31 = HEAP32[$a$012>>2]|0;
     $32 = HEAP32[$b1$08>>2]|0;
     __ZNK16b2ParticleSystem10AddContactEiiR16b2GrowableBufferI17b2ParticleContactE($this,$31,$32,$contacts);
     $33 = (($b1$08) + 8|0);
     $34 = ($33>>>0)<($2>>>0);
     if ($34) {
      $b1$08 = $33;
     } else {
      break;
     }
    }
   }
  } while(0);
  $5 = ($4>>>0)<($2>>>0);
  if ($5) {
   $a$012 = $4;$c$011 = $c$1$lcssa;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK16b2ParticleSystem23UpdateProxies_ReferenceER16b2GrowableBufferINS_5ProxyEE($this,$proxies) {
 $this = $this|0;
 $proxies = $proxies|0;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0, $proxy$01 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (__ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEE3EndEv($proxies)|0);
 $1 = (__ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEE5BeginEv($proxies)|0);
 $2 = ($1>>>0)<($0>>>0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 96|0);
 $4 = (($this) + 36|0);
 $proxy$01 = $1;
 while(1) {
  $5 = HEAP32[$proxy$01>>2]|0;
  $6 = HEAP32[$3>>2]|0;
  $7 = (($6) + ($5<<3)|0);
  $8 = +HEAPF32[$7>>2];
  $9 = ((($6) + ($5<<3)|0) + 4|0);
  $10 = +HEAPF32[$9>>2];
  $11 = +HEAPF32[$4>>2];
  $12 = $8 * $11;
  $13 = $10 * $11;
  $14 = (__ZL10computeTagff($12,$13)|0);
  $15 = (($proxy$01) + 4|0);
  HEAP32[$15>>2] = $14;
  $16 = (($proxy$01) + 8|0);
  $17 = ($16>>>0)<($0>>>0);
  if ($17) {
   $proxy$01 = $16;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK16b2ParticleSystem11SortProxiesER16b2GrowableBufferINS_5ProxyEE($this,$proxies) {
 $this = $this|0;
 $proxies = $proxies|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEE5BeginEv($proxies)|0);
 $2 = (__ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEE3EndEv($proxies)|0);
 __ZNSt3__16__sortIRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEvT0_S7_T_($1,$2,$0);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem14FilterContactsER16b2GrowableBufferI17b2ParticleContactE($this,$contacts) {
 $this = $this|0;
 $contacts = $contacts|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = (__ZNK16b2ParticleSystem24GetParticleContactFilterEv($this)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 __ZN32b2ParticleContactRemovePredicateC2EP16b2ParticleSystemP15b2ContactFilter($0,$this,$1);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 (__ZN16b2GrowableBufferI17b2ParticleContactE8RemoveIfI32b2ParticleContactRemovePredicateEEPS0_T_($contacts,$$byval_copy)|0);
 STACKTOP = sp;return;
}
function __ZNK16b2ParticleSystem31NotifyContactListenerPreContactEP17b2ParticlePairSet($this,$particlePairs) {
 $this = $this|0;
 $particlePairs = $particlePairs|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK16b2ParticleSystem26GetParticleContactListenerEv($this)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 216|0);
 $3 = (__ZNK16b2GrowableBufferI17b2ParticleContactE5BeginEv($2)|0);
 $4 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($2)|0);
 $5 = (__ZNK16b2ParticleSystem14GetFlagsBufferEv($this)|0);
 __ZN17b2ParticlePairSet10InitializeEPK17b2ParticleContactiPKj($particlePairs,$3,$4,$5);
 STACKTOP = sp;return;
}
function __ZN17b2ParticlePairSet10InitializeEPK17b2ParticleContactiPKj($this,$contacts,$numContacts,$particleFlagsBuffer) {
 $this = $this|0;
 $contacts = $contacts|0;
 $numContacts = $numContacts|0;
 $particleFlagsBuffer = $particleFlagsBuffer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, $insertedContacts$0$lcssa = 0, $insertedContacts$02 = 0, $insertedContacts$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN12_GLOBAL__N_117FixedSetAllocator5ClearEv($this);
 $1 = (__ZN12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIiiEEE8AllocateEi($this,$numContacts)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (__ZN12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIiiEEE9GetBufferEv($this)|0);
 $4 = ($numContacts|0)>(0);
 if ($4) {
  $i$01 = 0;$insertedContacts$02 = 0;
  while(1) {
   $5 = (($contacts) + (($i$01*24)|0)|0);
   $6 = (__ZNK17b2ParticleContact9GetIndexAEv($5)|0);
   $7 = ($6|0)==(-1);
   if ($7) {
    $insertedContacts$1 = $insertedContacts$02;
   } else {
    $8 = (__ZNK17b2ParticleContact9GetIndexBEv($5)|0);
    $9 = ($8|0)==(-1);
    if ($9) {
     $insertedContacts$1 = $insertedContacts$02;
    } else {
     $10 = (($particleFlagsBuffer) + ($6<<2)|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = (($particleFlagsBuffer) + ($8<<2)|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = $13 | $11;
     $15 = $14 & 32768;
     $16 = ($15|0)==(0);
     if ($16) {
      $insertedContacts$1 = $insertedContacts$02;
     } else {
      $17 = (($3) + ($i$01<<3)|0);
      HEAP32[$17>>2] = $6;
      $18 = (__ZNK17b2ParticleContact9GetIndexBEv($5)|0);
      $19 = ((($3) + ($i$01<<3)|0) + 4|0);
      HEAP32[$19>>2] = $18;
      $20 = (($insertedContacts$02) + 1)|0;
      $insertedContacts$1 = $20;
     }
    }
   }
   $21 = (($i$01) + 1)|0;
   $exitcond = ($21|0)==($numContacts|0);
   if ($exitcond) {
    $insertedContacts$0$lcssa = $insertedContacts$1;
    break;
   } else {
    $i$01 = $21;$insertedContacts$02 = $insertedContacts$1;
   }
  }
 } else {
  $insertedContacts$0$lcssa = 0;
 }
 __ZN12_GLOBAL__N_117FixedSetAllocator8SetCountEi($this,$insertedContacts$0$lcssa);
 $22 = (($3) + ($insertedContacts$0$lcssa<<3)|0);
 HEAP32[$0>>2] = 31;
 __ZNSt3__16__sortIRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEvT0_SA_T_($3,$22,$0);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem32NotifyContactListenerPostContactER17b2ParticlePairSet($this,$particlePairs) {
 $this = $this|0;
 $particlePairs = $particlePairs|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $contact$02 = 0, $exitcond = 0, $i$01 = 0, $pair = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $pair = sp;
 $0 = (__ZNK16b2ParticleSystem26GetParticleContactListenerEv($this)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 216|0);
 $3 = (__ZN16b2GrowableBufferI17b2ParticleContactE3EndEv($2)|0);
 $4 = (__ZN16b2GrowableBufferI17b2ParticleContactE5BeginEv($2)|0);
 $5 = ($4>>>0)<($3>>>0);
 if ($5) {
  $6 = (($pair) + 4|0);
  $contact$02 = $4;
  while(1) {
   $7 = (__ZNK17b2ParticleContact9GetIndexAEv($contact$02)|0);
   HEAP32[$pair>>2] = $7;
   $8 = (__ZNK17b2ParticleContact9GetIndexBEv($contact$02)|0);
   HEAP32[$6>>2] = $8;
   $9 = (__ZNK17b2ParticlePairSet4FindERKN12_GLOBAL__N_115LightweightPairIiiEE($particlePairs,$pair)|0);
   $10 = ($9|0)>(-1);
   if ($10) {
    __ZN12_GLOBAL__N_117FixedSetAllocator10InvalidateEi($particlePairs,$9);
   } else {
    $11 = HEAP32[$0>>2]|0;
    $12 = (($11) + 24|0);
    $13 = HEAP32[$12>>2]|0;
    FUNCTION_TABLE_viii[$13 & 15]($0,$this,$contact$02);
   }
   $14 = (($contact$02) + 24|0);
   $15 = ($14>>>0)<($3>>>0);
   if ($15) {
    $contact$02 = $14;
   } else {
    break;
   }
  }
 }
 $16 = (__ZNK12_GLOBAL__N_117FixedSetAllocator8GetCountEv($particlePairs)|0);
 $17 = (__ZN12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIiiEEE9GetBufferEv($particlePairs)|0);
 $18 = (__ZNK12_GLOBAL__N_117FixedSetAllocator14GetValidBufferEv($particlePairs)|0);
 $19 = ($16|0)>(0);
 if (!($19)) {
  STACKTOP = sp;return;
 }
 $i$01 = 0;
 while(1) {
  $20 = (($18) + ($i$01)|0);
  $21 = HEAP8[$20>>0]|0;
  $22 = ($21<<24>>24)==(0);
  if (!($22)) {
   $23 = HEAP32[$0>>2]|0;
   $24 = (($23) + 28|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = (($17) + ($i$01<<3)|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = ((($17) + ($i$01<<3)|0) + 4|0);
   $29 = HEAP32[$28>>2]|0;
   FUNCTION_TABLE_viiii[$25 & 31]($0,$this,$27,$29);
  }
  $30 = (($i$01) + 1)|0;
  $exitcond = ($30|0)==($16|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $30;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem19DetectStuckParticleEi($this,$particle) {
 $this = $this|0;
 $particle = $particle|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 156|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)<(1);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 176|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($particle<<2)|0);
 $6 = (($this) + 160|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($particle<<2)|0);
 $9 = (($this) + 168|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + ($particle<<2)|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + 1)|0;
 HEAP32[$11>>2] = $13;
 $14 = ($13|0)==(2);
 if ($14) {
  $15 = HEAP32[$5>>2]|0;
  $16 = (($15) + 1)|0;
  HEAP32[$5>>2] = $16;
  $17 = HEAP32[$0>>2]|0;
  $18 = ($15|0)<($17|0);
  if (!($18)) {
   $19 = (($this) + 184|0);
   $20 = (__ZN16b2GrowableBufferIiE6AppendEv($19)|0);
   HEAP32[$20>>2] = $particle;
  }
 }
 $21 = (($this) + 4|0);
 $22 = HEAP32[$21>>2]|0;
 HEAP32[$8>>2] = $22;
 STACKTOP = sp;return;
}
function __ZNK16b2ParticleSystem11ComputeAABBEP6b2AABB($this,$aabb) {
 $this = $this|0;
 $aabb = $aabb|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0.0, $44 = 0.0;
 var $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$03 = 0, $p = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $p = sp + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = (__ZNK16b2ParticleSystem16GetParticleCountEv($this)|0);
 HEAPF32[$aabb>>2] = 3.4028234663852886E+38;
 $3 = (($aabb) + 4|0);
 HEAPF32[$3>>2] = 3.4028234663852886E+38;
 $4 = (($aabb) + 8|0);
 HEAPF32[$4>>2] = -3.4028234663852886E+38;
 $5 = (($aabb) + 12|0);
 HEAPF32[$5>>2] = -3.4028234663852886E+38;
 $6 = ($2|0)>(0);
 if ($6) {
  $7 = (($this) + 96|0);
  $i$03 = 0;
  while(1) {
   $8 = HEAP32[$7>>2]|0;
   $9 = (($8) + ($i$03<<3)|0);
   $10 = $9;
   $11 = $10;
   $12 = HEAP32[$11>>2]|0;
   $13 = (($10) + 4)|0;
   $14 = $13;
   $15 = HEAP32[$14>>2]|0;
   $16 = $p;
   $17 = $16;
   HEAP32[$17>>2] = $12;
   $18 = (($16) + 4)|0;
   $19 = $18;
   HEAP32[$19>>2] = $15;
   __Z5b2MinRK6b2Vec2S1_($0,$aabb,$p);
   $20 = $0;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = $aabb;
   $27 = $26;
   HEAP32[$27>>2] = $22;
   $28 = (($26) + 4)|0;
   $29 = $28;
   HEAP32[$29>>2] = $25;
   __Z5b2MaxRK6b2Vec2S1_($1,$4,$p);
   $30 = $1;
   $31 = $30;
   $32 = HEAP32[$31>>2]|0;
   $33 = (($30) + 4)|0;
   $34 = $33;
   $35 = HEAP32[$34>>2]|0;
   $36 = $4;
   $37 = $36;
   HEAP32[$37>>2] = $32;
   $38 = (($36) + 4)|0;
   $39 = $38;
   HEAP32[$39>>2] = $35;
   $40 = (($i$03) + 1)|0;
   $exitcond = ($40|0)==($2|0);
   if ($exitcond) {
    break;
   } else {
    $i$03 = $40;
   }
  }
 }
 $41 = (($this) + 32|0);
 $42 = +HEAPF32[$41>>2];
 $43 = +HEAPF32[$aabb>>2];
 $44 = $43 - $42;
 HEAPF32[$aabb>>2] = $44;
 $45 = +HEAPF32[$41>>2];
 $46 = +HEAPF32[$3>>2];
 $47 = $46 - $45;
 HEAPF32[$3>>2] = $47;
 $48 = +HEAPF32[$41>>2];
 $49 = +HEAPF32[$4>>2];
 $50 = $48 + $49;
 HEAPF32[$4>>2] = $50;
 $51 = +HEAPF32[$41>>2];
 $52 = +HEAPF32[$5>>2];
 $53 = $51 + $52;
 HEAPF32[$5>>2] = $53;
 STACKTOP = sp;return;
}
function __ZN18FixtureParticleSet10InitializeEPK21b2ParticleBodyContactiPKj($this,$bodyContacts,$numBodyContacts,$particleFlagsBuffer) {
 $this = $this|0;
 $bodyContacts = $bodyContacts|0;
 $numBodyContacts = $numBodyContacts|0;
 $particleFlagsBuffer = $particleFlagsBuffer|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $exitcond = 0, $i$01 = 0, $insertedContacts$0$lcssa = 0, $insertedContacts$02 = 0, $insertedContacts$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 __ZN12_GLOBAL__N_117FixedSetAllocator5ClearEv($this);
 $1 = (__ZN12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIP9b2FixtureiEEE8AllocateEi($this,$numBodyContacts)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = (__ZN12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIP9b2FixtureiEEE9GetBufferEv($this)|0);
 $4 = ($numBodyContacts|0)>(0);
 if ($4) {
  $i$01 = 0;$insertedContacts$02 = 0;
  while(1) {
   $5 = (($bodyContacts) + (($i$01*28)|0)|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(-1);
   if ($7) {
    $insertedContacts$1 = $insertedContacts$02;
   } else {
    $8 = (($particleFlagsBuffer) + ($6<<2)|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = $9 & 16384;
    $11 = ($10|0)==(0);
    if ($11) {
     $insertedContacts$1 = $insertedContacts$02;
    } else {
     $12 = ((($bodyContacts) + (($i$01*28)|0)|0) + 8|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (($3) + ($i$01<<3)|0);
     HEAP32[$14>>2] = $13;
     $15 = HEAP32[$5>>2]|0;
     $16 = ((($3) + ($i$01<<3)|0) + 4|0);
     HEAP32[$16>>2] = $15;
     $17 = (($insertedContacts$02) + 1)|0;
     $insertedContacts$1 = $17;
    }
   }
   $18 = (($i$01) + 1)|0;
   $exitcond = ($18|0)==($numBodyContacts|0);
   if ($exitcond) {
    $insertedContacts$0$lcssa = $insertedContacts$1;
    break;
   } else {
    $i$01 = $18;$insertedContacts$02 = $insertedContacts$1;
   }
  }
 } else {
  $insertedContacts$0$lcssa = 0;
 }
 __ZN12_GLOBAL__N_117FixedSetAllocator8SetCountEi($this,$insertedContacts$0$lcssa);
 $19 = (($3) + ($insertedContacts$0$lcssa<<3)|0);
 HEAP32[$0>>2] = 32;
 __ZNSt3__16__sortIRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEvT0_SC_T_($3,$19,$0);
 STACKTOP = sp;return;
}
function __ZNK16b2ParticleSystem35NotifyBodyContactListenerPreContactEP18FixtureParticleSet($this,$fixtureSet) {
 $this = $this|0;
 $fixtureSet = $fixtureSet|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK16b2ParticleSystem25GetFixtureContactListenerEv($this)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 232|0);
 $3 = (__ZNK16b2GrowableBufferI21b2ParticleBodyContactE5BeginEv($2)|0);
 $4 = (__ZNK16b2GrowableBufferI21b2ParticleBodyContactE8GetCountEv($2)|0);
 $5 = (__ZNK16b2ParticleSystem14GetFlagsBufferEv($this)|0);
 __ZN18FixtureParticleSet10InitializeEPK21b2ParticleBodyContactiPKj($fixtureSet,$3,$4,$5);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem36NotifyBodyContactListenerPostContactER18FixtureParticleSet($this,$fixtureSet) {
 $this = $this|0;
 $fixtureSet = $fixtureSet|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $contact$02 = 0, $exitcond = 0, $fixtureParticleToFind = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $fixtureParticleToFind = sp;
 $0 = (__ZNK16b2ParticleSystem25GetFixtureContactListenerEv($this)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 232|0);
 $3 = (__ZN16b2GrowableBufferI21b2ParticleBodyContactE5BeginEv($2)|0);
 $4 = (__ZN16b2GrowableBufferI21b2ParticleBodyContactE3EndEv($2)|0);
 $5 = ($3|0)==($4|0);
 if (!($5)) {
  $6 = (($fixtureParticleToFind) + 4|0);
  $contact$02 = $3;
  while(1) {
   $7 = (($contact$02) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   HEAP32[$fixtureParticleToFind>>2] = $8;
   $9 = HEAP32[$contact$02>>2]|0;
   HEAP32[$6>>2] = $9;
   $10 = (__ZNK18FixtureParticleSet4FindERKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEE($fixtureSet,$fixtureParticleToFind)|0);
   $11 = ($10|0)>(-1);
   if ($11) {
    __ZN12_GLOBAL__N_117FixedSetAllocator10InvalidateEi($fixtureSet,$10);
   } else {
    $12 = HEAP32[$0>>2]|0;
    $13 = (($12) + 16|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_viii[$14 & 15]($0,$this,$contact$02);
   }
   $15 = (($contact$02) + 28|0);
   $16 = (__ZN16b2GrowableBufferI21b2ParticleBodyContactE3EndEv($2)|0);
   $17 = ($15|0)==($16|0);
   if ($17) {
    break;
   } else {
    $contact$02 = $15;
   }
  }
 }
 $18 = (__ZN12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIP9b2FixtureiEEE9GetBufferEv($fixtureSet)|0);
 $19 = (__ZNK12_GLOBAL__N_117FixedSetAllocator14GetValidBufferEv($fixtureSet)|0);
 $20 = (__ZNK12_GLOBAL__N_117FixedSetAllocator8GetCountEv($fixtureSet)|0);
 $21 = ($20|0)>(0);
 if (!($21)) {
  STACKTOP = sp;return;
 }
 $i$01 = 0;
 while(1) {
  $22 = (($19) + ($i$01)|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = ($23<<24>>24)==(0);
  if (!($24)) {
   $25 = HEAP32[$0>>2]|0;
   $26 = (($25) + 20|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($18) + ($i$01<<3)|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ((($18) + ($i$01<<3)|0) + 4|0);
   $31 = HEAP32[$30>>2]|0;
   FUNCTION_TABLE_viiii[$27 & 31]($0,$29,$this,$31);
  }
  $32 = (($i$01) + 1)|0;
  $exitcond = ($32|0)==($20|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $32;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem18UpdateBodyContactsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $aabb = 0, $callback = 0, $exitcond = 0, $fixtureSet = 0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $fixtureSet = sp + 32|0;
 $callback = sp + 16|0;
 $aabb = sp;
 $0 = (($this) + 400|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + 76|0);
 __ZN18FixtureParticleSetC2EP16b2StackAllocator($fixtureSet,$2);
 __ZNK16b2ParticleSystem35NotifyBodyContactListenerPreContactEP18FixtureParticleSet($this,$fixtureSet);
 $3 = (($this) + 156|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(0);
 if ($5) {
  $6 = (__ZNK16b2ParticleSystem16GetParticleCountEv($this)|0);
  $7 = ($6|0)>(0);
  if ($7) {
   $8 = (($this) + 168|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (($this) + 4|0);
   $11 = (($this) + 160|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($this) + 176|0);
   $i$02 = 0;
   while(1) {
    $14 = (($9) + ($i$02<<2)|0);
    HEAP32[$14>>2] = 0;
    $15 = HEAP32[$10>>2]|0;
    $16 = (($12) + ($i$02<<2)|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = (($17) + 1)|0;
    $19 = ($15|0)>($18|0);
    if ($19) {
     $20 = HEAP32[$13>>2]|0;
     $21 = (($20) + ($i$02<<2)|0);
     HEAP32[$21>>2] = 0;
    }
    $22 = (($i$02) + 1)|0;
    $exitcond = ($22|0)==($6|0);
    if ($exitcond) {
     break;
    } else {
     $i$02 = $22;
    }
   }
  }
 }
 $23 = (($this) + 232|0);
 __ZN16b2GrowableBufferI21b2ParticleBodyContactE8SetCountEi($23,0);
 $24 = (($this) + 184|0);
 __ZN16b2GrowableBufferIiE8SetCountEi($24,0);
 $25 = (__ZNK16b2ParticleSystem23GetFixtureContactFilterEv($this)|0);
 __ZZN16b2ParticleSystem18UpdateBodyContactsEvEN26UpdateBodyContactsCallbackC2EPS_P15b2ContactFilter($callback,$this,$25);
 __ZNK16b2ParticleSystem11ComputeAABBEP6b2AABB($this,$aabb);
 $26 = HEAP32[$0>>2]|0;
 __ZNK7b2World9QueryAABBEP15b2QueryCallbackRK6b2AABB($26,$callback,$aabb);
 $27 = (($this) + 316|0);
 $28 = HEAP8[$27>>0]|0;
 $29 = ($28<<24>>24)==(0);
 if ($29) {
  __ZN16b2ParticleSystem36NotifyBodyContactListenerPostContactER18FixtureParticleSet($this,$fixtureSet);
  __ZN12_GLOBAL__N_117FixedSetAllocatorD2Ev($fixtureSet);
  STACKTOP = sp;return;
 }
 __ZN16b2ParticleSystem26RemoveSpuriousBodyContactsEv($this);
 __ZN16b2ParticleSystem36NotifyBodyContactListenerPostContactER18FixtureParticleSet($this,$fixtureSet);
 __ZN12_GLOBAL__N_117FixedSetAllocatorD2Ev($fixtureSet);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem26RemoveSpuriousBodyContactsEv($this) {
 $this = $this|0;
 var $$byval_copy = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $discarded = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $$byval_copy = sp + 24|0;
 $discarded = sp + 16|0;
 $0 = sp;
 $1 = (($this) + 232|0);
 $2 = (__ZN16b2GrowableBufferI21b2ParticleBodyContactE5BeginEv($1)|0);
 $3 = (__ZN16b2GrowableBufferI21b2ParticleBodyContactE3EndEv($1)|0);
 HEAP32[$$byval_copy>>2] = 33;
 __ZNSt3__16__sortIRPFbRK21b2ParticleBodyContactS3_EPS1_EEvT0_S8_T_($2,$3,$$byval_copy);
 HEAP32[$discarded>>2] = 0;
 $4 = (__ZN16b2GrowableBufferI21b2ParticleBodyContactE5BeginEv($1)|0);
 $5 = (__ZN16b2GrowableBufferI21b2ParticleBodyContactE3EndEv($1)|0);
 __ZN36b2ParticleBodyContactRemovePredicateC2EP16b2ParticleSystemPi($0,$this,$discarded);
 ;HEAP32[$$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$$byval_copy+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$$byval_copy+12>>2]=HEAP32[$0+12>>2]|0;
 (__ZNSt3__19remove_ifIP21b2ParticleBodyContact36b2ParticleBodyContactRemovePredicateEET_S4_S4_T0_($4,$5,$$byval_copy)|0);
 $6 = (__ZNK16b2GrowableBufferI21b2ParticleBodyContactE8GetCountEv($1)|0);
 $7 = HEAP32[$discarded>>2]|0;
 $8 = (($6) - ($7))|0;
 __ZN16b2GrowableBufferI21b2ParticleBodyContactE8SetCountEi($1,$8);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem18BodyContactCompareERK21b2ParticleBodyContactS2_($lhs,$rhs) {
 $lhs = $lhs|0;
 $rhs = $rhs|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$lhs>>2]|0;
 $1 = HEAP32[$rhs>>2]|0;
 $2 = ($0|0)==($1|0);
 if ($2) {
  $3 = (($lhs) + 12|0);
  $4 = +HEAPF32[$3>>2];
  $5 = (($rhs) + 12|0);
  $6 = +HEAPF32[$5>>2];
  $7 = $4 > $6;
  $$0 = $7;
  STACKTOP = sp;return ($$0|0);
 } else {
  $8 = ($0|0)<($1|0);
  $$0 = $8;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function __ZN16b2ParticleSystem14SolveCollisionERK10b2TimeStep($this,$step) {
 $this = $this|0;
 $step = $step|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $aabb = 0, $callback = 0, $i$04 = 0, $p1 = 0, $p2 = 0, $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $aabb = sp + 32|0;
 $v = sp + 24|0;
 $p1 = sp + 16|0;
 $p2 = sp + 112|0;
 $0 = sp + 104|0;
 $1 = sp + 8|0;
 $2 = sp + 96|0;
 $3 = sp;
 $4 = sp + 88|0;
 $callback = sp + 48|0;
 HEAPF32[$aabb>>2] = 3.4028234663852886E+38;
 $5 = (($aabb) + 4|0);
 HEAPF32[$5>>2] = 3.4028234663852886E+38;
 $6 = (($aabb) + 8|0);
 HEAPF32[$6>>2] = -3.4028234663852886E+38;
 $7 = (($aabb) + 12|0);
 HEAPF32[$7>>2] = -3.4028234663852886E+38;
 $8 = (($this) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)>(0);
 if (!($10)) {
  __ZZN16b2ParticleSystem14SolveCollisionERK10b2TimeStepEN22SolveCollisionCallbackC2EPS_S2_($callback,$this,$step);
  $61 = (($this) + 400|0);
  $62 = HEAP32[$61>>2]|0;
  __ZNK7b2World9QueryAABBEP15b2QueryCallbackRK6b2AABB($62,$callback,$aabb);
  STACKTOP = sp;return;
 }
 $11 = (($this) + 104|0);
 $12 = (($this) + 96|0);
 $i$04 = 0;
 while(1) {
  $13 = HEAP32[$11>>2]|0;
  $14 = (($13) + ($i$04<<3)|0);
  $15 = $14;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  $18 = (($15) + 4)|0;
  $19 = $18;
  $20 = HEAP32[$19>>2]|0;
  $21 = $v;
  $22 = $21;
  HEAP32[$22>>2] = $17;
  $23 = (($21) + 4)|0;
  $24 = $23;
  HEAP32[$24>>2] = $20;
  $25 = HEAP32[$12>>2]|0;
  $26 = (($25) + ($i$04<<3)|0);
  $27 = $26;
  $28 = $27;
  $29 = HEAP32[$28>>2]|0;
  $30 = (($27) + 4)|0;
  $31 = $30;
  $32 = HEAP32[$31>>2]|0;
  $33 = $p1;
  $34 = $33;
  HEAP32[$34>>2] = $29;
  $35 = (($33) + 4)|0;
  $36 = $35;
  HEAP32[$36>>2] = $32;
  $37 = +HEAPF32[$step>>2];
  __ZmlfRK6b2Vec2($0,$37,$v);
  __ZplRK6b2Vec2S1_($p2,$p1,$0);
  __Z5b2MinRK6b2Vec2S1_($2,$p1,$p2);
  __Z5b2MinRK6b2Vec2S1_($1,$aabb,$2);
  $38 = $1;
  $39 = $38;
  $40 = HEAP32[$39>>2]|0;
  $41 = (($38) + 4)|0;
  $42 = $41;
  $43 = HEAP32[$42>>2]|0;
  $44 = $aabb;
  $45 = $44;
  HEAP32[$45>>2] = $40;
  $46 = (($44) + 4)|0;
  $47 = $46;
  HEAP32[$47>>2] = $43;
  __Z5b2MaxRK6b2Vec2S1_($4,$p1,$p2);
  __Z5b2MaxRK6b2Vec2S1_($3,$6,$4);
  $48 = $3;
  $49 = $48;
  $50 = HEAP32[$49>>2]|0;
  $51 = (($48) + 4)|0;
  $52 = $51;
  $53 = HEAP32[$52>>2]|0;
  $54 = $6;
  $55 = $54;
  HEAP32[$55>>2] = $50;
  $56 = (($54) + 4)|0;
  $57 = $56;
  HEAP32[$57>>2] = $53;
  $58 = (($i$04) + 1)|0;
  $59 = HEAP32[$8>>2]|0;
  $60 = ($58|0)<($59|0);
  if ($60) {
   $i$04 = $58;
  } else {
   break;
  }
 }
 __ZZN16b2ParticleSystem14SolveCollisionERK10b2TimeStepEN22SolveCollisionCallbackC2EPS_S2_($callback,$this,$step);
 $61 = (($this) + 400|0);
 $62 = HEAP32[$61>>2]|0;
 __ZNK7b2World9QueryAABBEP15b2QueryCallbackRK6b2AABB($62,$callback,$aabb);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem12SolveBarrierERK10b2TimeStep($this,$step) {
 $this = $this|0;
 $step = $step|0;
 var $$pr = 0.0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0.0;
 var $115 = 0.0, $116 = 0, $117 = 0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0, $123 = 0.0, $124 = 0.0, $125 = 0.0, $126 = 0.0, $127 = 0, $128 = 0.0, $129 = 0.0, $13 = 0, $130 = 0.0, $131 = 0.0, $132 = 0.0;
 var $133 = 0.0, $134 = 0.0, $135 = 0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0.0, $145 = 0, $146 = 0, $147 = 0.0, $148 = 0.0, $149 = 0.0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0.0, $153 = 0, $154 = 0.0, $155 = 0.0, $156 = 0, $157 = 0, $158 = 0.0, $159 = 0, $16 = 0, $160 = 0.0, $161 = 0.0, $162 = 0, $163 = 0.0, $164 = 0.0, $165 = 0, $166 = 0, $167 = 0.0, $168 = 0.0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $aabb = 0, $dv = 0, $enumerator = 0, $f = 0, $i$025 = 0, $k$023 = 0, $or$cond = 0;
 var $or$cond20 = 0, $or$cond21 = 0, $or$cond22 = 0, $or$cond3 = 0, $or$cond5 = 0, $or$cond7 = 0, $pa = 0, $pb = 0, $pba = 0, $pc = 0, $pca = 0, $qba = 0, $qca = 0, $s$0 = 0.0, $t1 = 0, $t2 = 0, $va = 0, $vb = 0, $vba = 0, $vc = 0;
 var $vca = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0;
 $pa = sp + 56|0;
 $pb = sp + 48|0;
 $aabb = sp + 32|0;
 $0 = sp + 24|0;
 $va = sp + 256|0;
 $vb = sp + 248|0;
 $pba = sp + 240|0;
 $vba = sp + 232|0;
 $enumerator = sp + 208|0;
 $pc = sp + 16|0;
 $vc = sp + 200|0;
 $pca = sp + 192|0;
 $vca = sp + 184|0;
 $qba = sp + 8|0;
 $qca = sp;
 $1 = sp + 176|0;
 $2 = sp + 168|0;
 $t1 = sp + 164|0;
 $t2 = sp + 160|0;
 $3 = sp + 152|0;
 $4 = sp + 144|0;
 $5 = sp + 136|0;
 $6 = sp + 128|0;
 $dv = sp + 120|0;
 $7 = sp + 112|0;
 $8 = sp + 104|0;
 $f = sp + 96|0;
 $9 = sp + 88|0;
 $10 = sp + 80|0;
 $11 = sp + 72|0;
 $12 = sp + 64|0;
 $13 = (($this) + 44|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)>(0);
 if ($15) {
  $16 = (($this) + 88|0);
  $17 = (($this) + 104|0);
  $i$025 = 0;
  while(1) {
   $18 = HEAP32[$16>>2]|0;
   $19 = (($18) + ($i$025<<2)|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = $20 & 1028;
   $22 = ($21|0)==(1028);
   if ($22) {
    $23 = HEAP32[$17>>2]|0;
    $24 = (($23) + ($i$025<<3)|0);
    __ZN6b2Vec27SetZeroEv($24);
   }
   $25 = (($i$025) + 1)|0;
   $26 = HEAP32[$13>>2]|0;
   $27 = ($25|0)<($26|0);
   if ($27) {
    $i$025 = $25;
   } else {
    break;
   }
  }
 }
 $28 = +HEAPF32[$step>>2];
 $29 = $28 * 2.5;
 $30 = (($this) + 248|0);
 $31 = (__ZNK16b2GrowableBufferI14b2ParticlePairE8GetCountEv($30)|0);
 $32 = ($31|0)>(0);
 if (!($32)) {
  STACKTOP = sp;return;
 }
 $33 = (($this) + 96|0);
 $34 = (($aabb) + 8|0);
 $35 = (($this) + 144|0);
 $36 = (($step) + 4|0);
 $37 = (($this) + 104|0);
 $k$023 = 0;
 while(1) {
  $38 = (__ZN16b2GrowableBufferI14b2ParticlePairEixEi($30,$k$023)|0);
  $39 = (($38) + 8|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = $40 & 1024;
  $42 = ($41|0)==(0);
  if (!($42)) {
   $43 = HEAP32[$38>>2]|0;
   $44 = (($38) + 4|0);
   $45 = HEAP32[$44>>2]|0;
   $46 = HEAP32[$33>>2]|0;
   $47 = (($46) + ($43<<3)|0);
   $48 = $47;
   $49 = $48;
   $50 = HEAP32[$49>>2]|0;
   $51 = (($48) + 4)|0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = $pa;
   $55 = $54;
   HEAP32[$55>>2] = $50;
   $56 = (($54) + 4)|0;
   $57 = $56;
   HEAP32[$57>>2] = $53;
   $58 = HEAP32[$33>>2]|0;
   $59 = (($58) + ($45<<3)|0);
   $60 = $59;
   $61 = $60;
   $62 = HEAP32[$61>>2]|0;
   $63 = (($60) + 4)|0;
   $64 = $63;
   $65 = HEAP32[$64>>2]|0;
   $66 = $pb;
   $67 = $66;
   HEAP32[$67>>2] = $62;
   $68 = (($66) + 4)|0;
   $69 = $68;
   HEAP32[$69>>2] = $65;
   __Z5b2MinRK6b2Vec2S1_($aabb,$pa,$pb);
   __Z5b2MaxRK6b2Vec2S1_($0,$pa,$pb);
   $70 = $0;
   $71 = $70;
   $72 = HEAP32[$71>>2]|0;
   $73 = (($70) + 4)|0;
   $74 = $73;
   $75 = HEAP32[$74>>2]|0;
   $76 = $34;
   $77 = $76;
   HEAP32[$77>>2] = $72;
   $78 = (($76) + 4)|0;
   $79 = $78;
   HEAP32[$79>>2] = $75;
   $80 = HEAP32[$35>>2]|0;
   $81 = (($80) + ($43<<2)|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = (($80) + ($45<<2)|0);
   $84 = HEAP32[$83>>2]|0;
   __ZNK16b2ParticleSystem17GetLinearVelocityEP15b2ParticleGroupiRK6b2Vec2($va,$this,$82,$43,$pa);
   __ZNK16b2ParticleSystem17GetLinearVelocityEP15b2ParticleGroupiRK6b2Vec2($vb,$this,$84,$45,$pb);
   __ZmiRK6b2Vec2S1_($pba,$pb,$pa);
   __ZmiRK6b2Vec2S1_($vba,$vb,$va);
   __ZNK16b2ParticleSystem25GetInsideBoundsEnumeratorERK6b2AABB($enumerator,$this,$aabb);
   $85 = (__ZN16b2ParticleSystem22InsideBoundsEnumerator7GetNextEv($enumerator)|0);
   $86 = ($85|0)>(-1);
   if ($86) {
    $89 = $85;
    while(1) {
     $87 = HEAP32[$33>>2]|0;
     $88 = (($87) + ($89<<3)|0);
     $90 = $88;
     $91 = $90;
     $92 = HEAP32[$91>>2]|0;
     $93 = (($90) + 4)|0;
     $94 = $93;
     $95 = HEAP32[$94>>2]|0;
     $96 = $pc;
     $97 = $96;
     HEAP32[$97>>2] = $92;
     $98 = (($96) + 4)|0;
     $99 = $98;
     HEAP32[$99>>2] = $95;
     $100 = HEAP32[$35>>2]|0;
     $101 = (($100) + ($89<<2)|0);
     $102 = HEAP32[$101>>2]|0;
     $103 = ($82|0)==($102|0);
     $104 = ($84|0)==($102|0);
     $or$cond20 = $103 | $104;
     L18: do {
      if (!($or$cond20)) {
       __ZNK16b2ParticleSystem17GetLinearVelocityEP15b2ParticleGroupiRK6b2Vec2($vc,$this,$102,$89,$pc);
       __ZmiRK6b2Vec2S1_($pca,$pc,$pa);
       __ZmiRK6b2Vec2S1_($vca,$vc,$va);
       $105 = (+__Z7b2CrossRK6b2Vec2S1_($vba,$vca));
       $106 = (+__Z7b2CrossRK6b2Vec2S1_($pba,$vca));
       $107 = (+__Z7b2CrossRK6b2Vec2S1_($pca,$vba));
       $108 = $106 - $107;
       $109 = (+__Z7b2CrossRK6b2Vec2S1_($pba,$pca));
       $110 = $105 == 0.0;
       do {
        if ($110) {
         $111 = $108 == 0.0;
         if ($111) {
          break L18;
         }
         $114 = -$109;
         $115 = $114 / $108;
         $116 = $115 >= 0.0;
         $117 = $115 < $29;
         $or$cond21 = $116 & $117;
         if (!($or$cond21)) {
          break L18;
         }
         __ZmlfRK6b2Vec2($1,$115,$vba);
         __ZplRK6b2Vec2S1_($qba,$pba,$1);
         __ZmlfRK6b2Vec2($2,$115,$vca);
         __ZplRK6b2Vec2S1_($qca,$pca,$2);
         $118 = (+__Z5b2DotRK6b2Vec2S1_($qba,$qca));
         $119 = (+__Z5b2DotRK6b2Vec2S1_($qba,$qba));
         $120 = $118 / $119;
         $121 = $120 >= 0.0;
         $122 = $120 <= 1.0;
         $or$cond = $121 & $122;
         if ($or$cond) {
          $s$0 = $120;
         } else {
          break L18;
         }
        } else {
         $123 = $108 * $108;
         $124 = $109 * 4.0;
         $125 = $105 * $124;
         $126 = $123 - $125;
         $127 = $126 < 0.0;
         if ($127) {
          break L18;
         }
         $128 = (+Math_sqrt((+$126)));
         $129 = -$108;
         $130 = $129 - $128;
         $131 = $105 * 2.0;
         $132 = $130 / $131;
         HEAPF32[$t1>>2] = $132;
         $133 = $128 - $108;
         $134 = $133 / $131;
         HEAPF32[$t2>>2] = $134;
         $135 = $132 > $134;
         if ($135) {
          __Z6b2SwapIfEvRT_S1_($t1,$t2);
          $$pr = +HEAPF32[$t1>>2];
          $136 = $$pr;
         } else {
          $136 = $132;
         }
         __ZmlfRK6b2Vec2($3,$136,$vba);
         __ZplRK6b2Vec2S1_($qba,$pba,$3);
         __ZmlfRK6b2Vec2($4,$136,$vca);
         __ZplRK6b2Vec2S1_($qca,$pca,$4);
         $137 = (+__Z5b2DotRK6b2Vec2S1_($qba,$qca));
         $138 = (+__Z5b2DotRK6b2Vec2S1_($qba,$qba));
         $139 = $137 / $138;
         $140 = !($136 >= 0.0);
         if (!($140)) {
          $141 = $136 < $29;
          $142 = $139 >= 0.0;
          $or$cond3 = $141 & $142;
          $143 = $139 <= 1.0;
          $or$cond5 = $or$cond3 & $143;
          if ($or$cond5) {
           $s$0 = $139;
           break;
          }
         }
         $144 = +HEAPF32[$t2>>2];
         $145 = $144 >= 0.0;
         $146 = $144 < $29;
         $or$cond22 = $145 & $146;
         if (!($or$cond22)) {
          break L18;
         }
         __ZmlfRK6b2Vec2($5,$144,$vba);
         __ZplRK6b2Vec2S1_($qba,$pba,$5);
         __ZmlfRK6b2Vec2($6,$144,$vca);
         __ZplRK6b2Vec2S1_($qca,$pca,$6);
         $147 = (+__Z5b2DotRK6b2Vec2S1_($qba,$qca));
         $148 = (+__Z5b2DotRK6b2Vec2S1_($qba,$qba));
         $149 = $147 / $148;
         $150 = $149 >= 0.0;
         $151 = $149 <= 1.0;
         $or$cond7 = $150 & $151;
         if ($or$cond7) {
          $s$0 = $149;
         } else {
          break L18;
         }
        }
       } while(0);
       __ZmlfRK6b2Vec2($8,$s$0,$vba);
       __ZplRK6b2Vec2S1_($7,$va,$8);
       __ZmiRK6b2Vec2S1_($dv,$7,$vc);
       $152 = (+__ZNK16b2ParticleSystem15GetParticleMassEv($this));
       __ZmlfRK6b2Vec2($f,$152,$dv);
       $153 = (__ZNK16b2ParticleSystem12IsRigidGroupEP15b2ParticleGroup($this,$102)|0);
       if ($153) {
        $154 = (+__ZNK15b2ParticleGroup7GetMassEv($102));
        $155 = (+__ZNK15b2ParticleGroup10GetInertiaEv($102));
        $156 = $154 > 0.0;
        if ($156) {
         $157 = (($102) + 48|0);
         $158 = 1.0 / $154;
         __ZmlfRK6b2Vec2($9,$158,$f);
         __ZN6b2Vec2pLERKS_($157,$9);
        }
        $159 = $155 > 0.0;
        if ($159) {
         __ZNK15b2ParticleGroup9GetCenterEv($11,$102);
         __ZmiRK6b2Vec2S1_($10,$pc,$11);
         $160 = (+__Z7b2CrossRK6b2Vec2S1_($10,$f));
         $161 = $160 / $155;
         $162 = (($102) + 56|0);
         $163 = +HEAPF32[$162>>2];
         $164 = $161 + $163;
         HEAPF32[$162>>2] = $164;
        }
       } else {
        $165 = HEAP32[$37>>2]|0;
        $166 = (($165) + ($89<<3)|0);
        __ZN6b2Vec2pLERKS_($166,$dv);
       }
       $167 = +HEAPF32[$36>>2];
       $168 = -$167;
       __ZmlfRK6b2Vec2($12,$168,$f);
       __ZN16b2ParticleSystem18ParticleApplyForceEiRK6b2Vec2($this,$89,$12);
      }
     } while(0);
     $112 = (__ZN16b2ParticleSystem22InsideBoundsEnumerator7GetNextEv($enumerator)|0);
     $113 = ($112|0)>(-1);
     if ($113) {
      $89 = $112;
     } else {
      break;
     }
    }
   }
  }
  $169 = (($k$023) + 1)|0;
  $170 = (__ZNK16b2GrowableBufferI14b2ParticlePairE8GetCountEv($30)|0);
  $171 = ($169|0)<($170|0);
  if ($171) {
   $k$023 = $169;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem18ParticleApplyForceEiRK6b2Vec2($this,$index,$force) {
 $this = $this|0;
 $index = $index|0;
 $force = $force|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZL18IsSignificantForceRK6b2Vec2($force)|0);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 $1 = (($this) + 88|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($index<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZNK16b2ParticleSystem17ForceCanBeAppliedEj($this,$4)|0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 __ZN16b2ParticleSystem18PrepareForceBufferEv($this);
 $6 = (($this) + 112|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($index<<3)|0);
 __ZN6b2Vec2pLERKS_($8,$force);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem5SolveERK10b2TimeStep($this,$step) {
 $this = $this|0;
 $step = $step|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0.0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $i$01 = 0, $subStep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $subStep = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 280|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  __ZN16b2ParticleSystem14SolveLifetimesERK10b2TimeStep($this,$step);
 }
 $7 = (($this) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 2;
 $10 = ($9|0)==(0);
 if (!($10)) {
  __ZN16b2ParticleSystem11SolveZombieEv($this);
 }
 $11 = (($this) + 12|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if (!($13)) {
  __ZN16b2ParticleSystem22UpdateAllParticleFlagsEv($this);
 }
 $14 = (($this) + 20|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = ($15<<24>>24)==(0);
 if (!($16)) {
  __ZN16b2ParticleSystem19UpdateAllGroupFlagsEv($this);
 }
 $17 = HEAP8[$this>>0]|0;
 $18 = ($17<<24>>24)==(0);
 if (!($18)) {
  STACKTOP = sp;return;
 }
 $19 = (($this) + 24|0);
 HEAP32[$19>>2] = 0;
 $20 = (($step) + 20|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)>(0);
 if (!($22)) {
  STACKTOP = sp;return;
 }
 $23 = (($this) + 4|0);
 $24 = (($subStep) + 4|0);
 $25 = (($this) + 16|0);
 $26 = (($this) + 21|0);
 $27 = (($this) + 96|0);
 $28 = (($this) + 104|0);
 while(1) {
  $29 = HEAP32[$23>>2]|0;
  $30 = (($29) + 1)|0;
  HEAP32[$23>>2] = $30;
  ;HEAP32[$subStep+0>>2]=HEAP32[$step+0>>2]|0;HEAP32[$subStep+4>>2]=HEAP32[$step+4>>2]|0;HEAP32[$subStep+8>>2]=HEAP32[$step+8>>2]|0;HEAP32[$subStep+12>>2]=HEAP32[$step+12>>2]|0;HEAP32[$subStep+16>>2]=HEAP32[$step+16>>2]|0;HEAP32[$subStep+20>>2]=HEAP32[$step+20>>2]|0;HEAP32[$subStep+24>>2]=HEAP32[$step+24>>2]|0;
  $31 = HEAP32[$20>>2]|0;
  $32 = (+($31|0));
  $33 = +HEAPF32[$subStep>>2];
  $34 = $33 / $32;
  HEAPF32[$subStep>>2] = $34;
  $35 = HEAP32[$20>>2]|0;
  $36 = (+($35|0));
  $37 = +HEAPF32[$24>>2];
  $38 = $37 * $36;
  HEAPF32[$24>>2] = $38;
  __ZN16b2ParticleSystem14UpdateContactsEb($this,0);
  __ZN16b2ParticleSystem18UpdateBodyContactsEv($this);
  __ZN16b2ParticleSystem13ComputeWeightEv($this);
  $39 = HEAP32[$25>>2]|0;
  $40 = $39 & 16;
  $41 = ($40|0)==(0);
  if (!($41)) {
   __ZN16b2ParticleSystem12ComputeDepthEv($this);
  }
  $42 = HEAP32[$7>>2]|0;
  $43 = $42 & 4096;
  $44 = ($43|0)==(0);
  if (!($44)) {
   __ZN16b2ParticleSystem41UpdatePairsAndTriadsWithReactiveParticlesEv($this);
  }
  $45 = HEAP8[$26>>0]|0;
  $46 = ($45<<24>>24)==(0);
  if (!($46)) {
   __ZN16b2ParticleSystem10SolveForceERK10b2TimeStep($this,$subStep);
  }
  $47 = HEAP32[$7>>2]|0;
  $48 = $47 & 32;
  $49 = ($48|0)==(0);
  if (!($49)) {
   __ZN16b2ParticleSystem12SolveViscousEv($this);
  }
  $50 = HEAP32[$7>>2]|0;
  $51 = $50 & 8192;
  $52 = ($51|0)==(0);
  if (!($52)) {
   __ZN16b2ParticleSystem14SolveRepulsiveERK10b2TimeStep($this,$subStep);
  }
  $53 = HEAP32[$7>>2]|0;
  $54 = $53 & 64;
  $55 = ($54|0)==(0);
  if (!($55)) {
   __ZN16b2ParticleSystem11SolvePowderERK10b2TimeStep($this,$subStep);
  }
  $56 = HEAP32[$7>>2]|0;
  $57 = $56 & 128;
  $58 = ($57|0)==(0);
  if (!($58)) {
   __ZN16b2ParticleSystem12SolveTensileERK10b2TimeStep($this,$subStep);
  }
  $59 = HEAP32[$25>>2]|0;
  $60 = $59 & 1;
  $61 = ($60|0)==(0);
  if (!($61)) {
   __ZN16b2ParticleSystem10SolveSolidERK10b2TimeStep($this,$subStep);
  }
  $62 = HEAP32[$7>>2]|0;
  $63 = $62 & 256;
  $64 = ($63|0)==(0);
  if (!($64)) {
   __ZN16b2ParticleSystem16SolveColorMixingEv($this);
  }
  __ZN16b2ParticleSystem12SolveGravityERK10b2TimeStep($this,$subStep);
  $65 = HEAP32[$7>>2]|0;
  $66 = $65 & 2048;
  $67 = ($66|0)==(0);
  if (!($67)) {
   __ZN16b2ParticleSystem19SolveStaticPressureERK10b2TimeStep($this,$subStep);
  }
  __ZN16b2ParticleSystem13SolvePressureERK10b2TimeStep($this,$subStep);
  __ZN16b2ParticleSystem12SolveDampingERK10b2TimeStep($this,$subStep);
  $68 = HEAP32[$7>>2]|0;
  $69 = $68 & 2048;
  $70 = ($69|0)==(0);
  if (!($70)) {
   __ZN16b2ParticleSystem17SolveExtraDampingEv($this);
  }
  $71 = HEAP32[$7>>2]|0;
  $72 = $71 & 16;
  $73 = ($72|0)==(0);
  if (!($73)) {
   __ZN16b2ParticleSystem12SolveElasticERK10b2TimeStep($this,$subStep);
  }
  $74 = HEAP32[$7>>2]|0;
  $75 = $74 & 8;
  $76 = ($75|0)==(0);
  if (!($76)) {
   __ZN16b2ParticleSystem11SolveSpringERK10b2TimeStep($this,$subStep);
  }
  __ZN16b2ParticleSystem13LimitVelocityERK10b2TimeStep($this,$subStep);
  $77 = HEAP32[$25>>2]|0;
  $78 = $77 & 2;
  $79 = ($78|0)==(0);
  if (!($79)) {
   __ZN16b2ParticleSystem17SolveRigidDampingEv($this);
  }
  $80 = HEAP32[$7>>2]|0;
  $81 = $80 & 1024;
  $82 = ($81|0)==(0);
  if (!($82)) {
   __ZN16b2ParticleSystem12SolveBarrierERK10b2TimeStep($this,$subStep);
  }
  __ZN16b2ParticleSystem14SolveCollisionERK10b2TimeStep($this,$subStep);
  $83 = HEAP32[$25>>2]|0;
  $84 = $83 & 2;
  $85 = ($84|0)==(0);
  if (!($85)) {
   __ZN16b2ParticleSystem10SolveRigidERK10b2TimeStep($this,$subStep);
  }
  $86 = HEAP32[$7>>2]|0;
  $87 = $86 & 4;
  $88 = ($87|0)==(0);
  if (!($88)) {
   __ZN16b2ParticleSystem9SolveWallEv($this);
  }
  $89 = HEAP32[$1>>2]|0;
  $90 = ($89|0)>(0);
  if ($90) {
   $91 = +HEAPF32[$subStep>>2];
   $i$01 = 0;
   while(1) {
    $92 = HEAP32[$27>>2]|0;
    $93 = (($92) + ($i$01<<3)|0);
    $94 = HEAP32[$28>>2]|0;
    $95 = (($94) + ($i$01<<3)|0);
    __ZmlfRK6b2Vec2($0,$91,$95);
    __ZN6b2Vec2pLERKS_($93,$0);
    $96 = (($i$01) + 1)|0;
    $97 = HEAP32[$1>>2]|0;
    $98 = ($96|0)<($97|0);
    if ($98) {
     $i$01 = $96;
    } else {
     break;
    }
   }
  }
  $99 = HEAP32[$19>>2]|0;
  $100 = (($99) + 1)|0;
  HEAP32[$19>>2] = $100;
  $101 = HEAP32[$20>>2]|0;
  $102 = ($100|0)<($101|0);
  if (!($102)) {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem14SolveLifetimesERK10b2TimeStep($this,$step) {
 $this = $this|0;
 $step = $step|0;
 var $0 = 0, $1 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$03 = 0, $i$03$in = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = +HEAPF32[$step>>2];
 $2 = (__ZNK16b2ParticleSystem24LifetimeToExpirationTimeEf($this,$1)|0);
 $3 = tempRet0;
 $4 = (($this) + 296|0);
 $5 = $4;
 $6 = $5;
 HEAP32[$6>>2] = $2;
 $7 = (($5) + 4)|0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (__ZNK16b2ParticleSystem23GetQuantizedTimeElapsedEv($this)|0);
 $10 = (($this) + 280|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 288|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (__ZNK16b2ParticleSystem16GetParticleCountEv($this)|0);
 $15 = (($this) + 304|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)==(0);
 if (!($17)) {
  __ZN12_GLOBAL__N_124ExpirationTimeComparatorC2EPKi($0,$11);
  $18 = (($13) + ($14<<2)|0);
  __ZNSt3__16__sortIRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEvT0_S5_T_($13,$18,$0);
  HEAP8[$15>>0] = 0;
 }
 $19 = ($14|0)>(0);
 if ($19) {
  $i$03$in = $14;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $i$03 = (($i$03$in) + -1)|0;
  $20 = (($13) + ($i$03<<2)|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = (($11) + ($21<<2)|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($9|0)<($23|0);
  $25 = ($23|0)<(1);
  $or$cond = $24 | $25;
  if ($or$cond) {
   label = 6;
   break;
  }
  __ZN16b2ParticleSystem15DestroyParticleEi($this,$21);
  $26 = ($i$03|0)>(0);
  if ($26) {
   $i$03$in = $i$03;
  } else {
   label = 6;
   break;
  }
 }
 if ((label|0) == 6) {
  STACKTOP = sp;return;
 }
}
function __ZN16b2ParticleSystem22UpdateAllParticleFlagsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(0);
 if (!($3)) {
  $13 = (($this) + 12|0);
  HEAP8[$13>>0] = 0;
  STACKTOP = sp;return;
 }
 $4 = (($this) + 88|0);
 $5 = HEAP32[$4>>2]|0;
 $i$01 = 0;
 while(1) {
  $6 = (($5) + ($i$01<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = HEAP32[$0>>2]|0;
  $9 = $8 | $7;
  HEAP32[$0>>2] = $9;
  $10 = (($i$01) + 1)|0;
  $11 = HEAP32[$1>>2]|0;
  $12 = ($10|0)<($11|0);
  if ($12) {
   $i$01 = $10;
  } else {
   break;
  }
 }
 $13 = (($this) + 12|0);
 HEAP8[$13>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem19UpdateAllGroupFlagsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $group$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 312|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $10 = (($this) + 20|0);
  HEAP8[$10>>0] = 0;
  STACKTOP = sp;return;
 } else {
  $group$01 = $2;
 }
 while(1) {
  $4 = (($group$01) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$0>>2]|0;
  $7 = $6 | $5;
  HEAP32[$0>>2] = $7;
  $8 = (__ZNK15b2ParticleGroup7GetNextEv($group$01)|0);
  $9 = ($8|0)==(0|0);
  if ($9) {
   break;
  } else {
   $group$01 = $8;
  }
 }
 $10 = (($this) + 20|0);
 HEAP8[$10>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem10SolveForceERK10b2TimeStep($this,$step) {
 $this = $this|0;
 $step = $step|0;
 var $0 = 0, $1 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0.0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = +HEAPF32[$step>>2];
 $2 = (+__ZNK16b2ParticleSystem18GetParticleInvMassEv($this));
 $3 = $1 * $2;
 $4 = (($this) + 44|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)>(0);
 if (!($6)) {
  $16 = (($this) + 21|0);
  HEAP8[$16>>0] = 0;
  STACKTOP = sp;return;
 }
 $7 = (($this) + 104|0);
 $8 = (($this) + 112|0);
 $i$01 = 0;
 while(1) {
  $9 = HEAP32[$7>>2]|0;
  $10 = (($9) + ($i$01<<3)|0);
  $11 = HEAP32[$8>>2]|0;
  $12 = (($11) + ($i$01<<3)|0);
  __ZmlfRK6b2Vec2($0,$3,$12);
  __ZN6b2Vec2pLERKS_($10,$0);
  $13 = (($i$01) + 1)|0;
  $14 = HEAP32[$4>>2]|0;
  $15 = ($13|0)<($14|0);
  if ($15) {
   $i$01 = $13;
  } else {
   break;
  }
 }
 $16 = (($this) + 21|0);
 HEAP8[$16>>0] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem12SolveViscousEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0.0, $26 = 0;
 var $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0.0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0.0, $44 = 0;
 var $45 = 0, $46 = 0.0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $f = 0, $f7 = 0, $k$02 = 0, $k1$01 = 0, $p = 0, $v = 0, $v6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $p = sp;
 $v = sp + 56|0;
 $0 = sp + 48|0;
 $f = sp + 40|0;
 $1 = sp + 32|0;
 $2 = sp + 24|0;
 $v6 = sp + 16|0;
 $f7 = sp + 8|0;
 $3 = (($this) + 352|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($this) + 232|0);
 $6 = (__ZNK16b2GrowableBufferI21b2ParticleBodyContactE8GetCountEv($5)|0);
 $7 = ($6|0)>(0);
 if ($7) {
  $8 = (($this) + 88|0);
  $9 = (($this) + 96|0);
  $10 = (($this) + 104|0);
  $k$02 = 0;
  while(1) {
   $15 = (__ZN16b2GrowableBufferI21b2ParticleBodyContactEixEi($5,$k$02)|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = HEAP32[$8>>2]|0;
   $18 = (($17) + ($16<<2)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = $19 & 32;
   $21 = ($20|0)==(0);
   if (!($21)) {
    $22 = (($15) + 4|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($15) + 12|0);
    $25 = +HEAPF32[$24>>2];
    $26 = (($15) + 24|0);
    $27 = +HEAPF32[$26>>2];
    $28 = HEAP32[$9>>2]|0;
    $29 = (($28) + ($16<<3)|0);
    $30 = $29;
    $31 = $30;
    $32 = HEAP32[$31>>2]|0;
    $33 = (($30) + 4)|0;
    $34 = $33;
    $35 = HEAP32[$34>>2]|0;
    $36 = $p;
    $37 = $36;
    HEAP32[$37>>2] = $32;
    $38 = (($36) + 4)|0;
    $39 = $38;
    HEAP32[$39>>2] = $35;
    __ZNK6b2Body31GetLinearVelocityFromWorldPointERK6b2Vec2($0,$23,$p);
    $40 = HEAP32[$10>>2]|0;
    $41 = (($40) + ($16<<3)|0);
    __ZmiRK6b2Vec2S1_($v,$0,$41);
    $42 = $4 * $27;
    $43 = $25 * $42;
    __ZmlfRK6b2Vec2($f,$43,$v);
    $44 = HEAP32[$10>>2]|0;
    $45 = (($44) + ($16<<3)|0);
    $46 = (+__ZNK16b2ParticleSystem18GetParticleInvMassEv($this));
    __ZmlfRK6b2Vec2($1,$46,$f);
    __ZN6b2Vec2pLERKS_($45,$1);
    __ZNK6b2Vec2ngEv($2,$f);
    __ZN6b2Body18ApplyLinearImpulseERK6b2Vec2S2_b($23,$2,$p,1);
   }
   $47 = (($k$02) + 1)|0;
   $48 = (__ZNK16b2GrowableBufferI21b2ParticleBodyContactE8GetCountEv($5)|0);
   $49 = ($47|0)<($48|0);
   if ($49) {
    $k$02 = $47;
   } else {
    break;
   }
  }
 }
 $11 = (($this) + 216|0);
 $12 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($11)|0);
 $13 = ($12|0)>(0);
 if (!($13)) {
  STACKTOP = sp;return;
 }
 $14 = (($this) + 104|0);
 $k1$01 = 0;
 while(1) {
  $50 = (__ZN16b2GrowableBufferI17b2ParticleContactEixEi($11,$k1$01)|0);
  $51 = (__ZNK17b2ParticleContact8GetFlagsEv($50)|0);
  $52 = $51 & 32;
  $53 = ($52|0)==(0);
  if (!($53)) {
   $54 = (__ZNK17b2ParticleContact9GetIndexAEv($50)|0);
   $55 = (__ZNK17b2ParticleContact9GetIndexBEv($50)|0);
   $56 = (+__ZNK17b2ParticleContact9GetWeightEv($50));
   $57 = HEAP32[$14>>2]|0;
   $58 = (($57) + ($55<<3)|0);
   $59 = (($57) + ($54<<3)|0);
   __ZmiRK6b2Vec2S1_($v6,$58,$59);
   $60 = $4 * $56;
   __ZmlfRK6b2Vec2($f7,$60,$v6);
   $61 = HEAP32[$14>>2]|0;
   $62 = (($61) + ($54<<3)|0);
   __ZN6b2Vec2pLERKS_($62,$f7);
   $63 = HEAP32[$14>>2]|0;
   $64 = (($63) + ($55<<3)|0);
   __ZN6b2Vec2mIERKS_($64,$f7);
  }
  $65 = (($k1$01) + 1)|0;
  $66 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($11)|0);
  $67 = ($65|0)<($66|0);
  if ($67) {
   $k1$01 = $65;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem14SolveRepulsiveERK10b2TimeStep($this,$step) {
 $this = $this|0;
 $step = $step|0;
 var $0 = 0, $1 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0.0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0.0, $30 = 0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $f = 0, $k$01 = 0, $n = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $n = sp;
 $f = sp + 8|0;
 $0 = (($this) + 364|0);
 $1 = +HEAPF32[$0>>2];
 $2 = (+__ZNK16b2ParticleSystem19GetCriticalVelocityERK10b2TimeStep($this,$step));
 $3 = $1 * $2;
 $4 = (($this) + 216|0);
 $5 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($4)|0);
 $6 = ($5|0)>(0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 144|0);
 $8 = (($this) + 104|0);
 $k$01 = 0;
 while(1) {
  $9 = (__ZN16b2GrowableBufferI17b2ParticleContactEixEi($4,$k$01)|0);
  $10 = (__ZNK17b2ParticleContact8GetFlagsEv($9)|0);
  $11 = $10 & 8192;
  $12 = ($11|0)==(0);
  if (!($12)) {
   $13 = (__ZNK17b2ParticleContact9GetIndexAEv($9)|0);
   $14 = (__ZNK17b2ParticleContact9GetIndexBEv($9)|0);
   $15 = HEAP32[$7>>2]|0;
   $16 = (($15) + ($13<<2)|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($15) + ($14<<2)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($17|0)==($19|0);
   if (!($20)) {
    $21 = (+__ZNK17b2ParticleContact9GetWeightEv($9));
    $22 = (__ZNK17b2ParticleContact9GetNormalEv($9)|0);
    $23 = $22;
    $24 = $23;
    $25 = HEAP32[$24>>2]|0;
    $26 = (($23) + 4)|0;
    $27 = $26;
    $28 = HEAP32[$27>>2]|0;
    $29 = $n;
    $30 = $29;
    HEAP32[$30>>2] = $25;
    $31 = (($29) + 4)|0;
    $32 = $31;
    HEAP32[$32>>2] = $28;
    $33 = $3 * $21;
    __ZmlfRK6b2Vec2($f,$33,$n);
    $34 = HEAP32[$8>>2]|0;
    $35 = (($34) + ($13<<3)|0);
    __ZN6b2Vec2mIERKS_($35,$f);
    $36 = HEAP32[$8>>2]|0;
    $37 = (($36) + ($14<<3)|0);
    __ZN6b2Vec2pLERKS_($37,$f);
   }
  }
  $38 = (($k$01) + 1)|0;
  $39 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($4)|0);
  $40 = ($38|0)<($39|0);
  if ($40) {
   $k$01 = $38;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem11SolvePowderERK10b2TimeStep($this,$step) {
 $this = $this|0;
 $step = $step|0;
 var $0 = 0, $1 = 0.0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0.0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0.0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $f = 0, $k$01 = 0, $n = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $n = sp;
 $f = sp + 8|0;
 $0 = (($this) + 368|0);
 $1 = +HEAPF32[$0>>2];
 $2 = (+__ZNK16b2ParticleSystem19GetCriticalVelocityERK10b2TimeStep($this,$step));
 $3 = $1 * $2;
 $4 = (($this) + 216|0);
 $5 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($4)|0);
 $6 = ($5|0)>(0);
 if (!($6)) {
  STACKTOP = sp;return;
 }
 $7 = (($this) + 104|0);
 $k$01 = 0;
 while(1) {
  $8 = (__ZN16b2GrowableBufferI17b2ParticleContactEixEi($4,$k$01)|0);
  $9 = (__ZNK17b2ParticleContact8GetFlagsEv($8)|0);
  $10 = $9 & 64;
  $11 = ($10|0)==(0);
  if (!($11)) {
   $12 = (+__ZNK17b2ParticleContact9GetWeightEv($8));
   $13 = $12 > 0.25;
   if ($13) {
    $14 = (__ZNK17b2ParticleContact9GetIndexAEv($8)|0);
    $15 = (__ZNK17b2ParticleContact9GetIndexBEv($8)|0);
    $16 = (__ZNK17b2ParticleContact9GetNormalEv($8)|0);
    $17 = $16;
    $18 = $17;
    $19 = HEAP32[$18>>2]|0;
    $20 = (($17) + 4)|0;
    $21 = $20;
    $22 = HEAP32[$21>>2]|0;
    $23 = $n;
    $24 = $23;
    HEAP32[$24>>2] = $19;
    $25 = (($23) + 4)|0;
    $26 = $25;
    HEAP32[$26>>2] = $22;
    $27 = $12 + -0.25;
    $28 = $3 * $27;
    __ZmlfRK6b2Vec2($f,$28,$n);
    $29 = HEAP32[$7>>2]|0;
    $30 = (($29) + ($14<<3)|0);
    __ZN6b2Vec2mIERKS_($30,$f);
    $31 = HEAP32[$7>>2]|0;
    $32 = (($31) + ($15<<3)|0);
    __ZN6b2Vec2pLERKS_($32,$f);
   }
  }
  $33 = (($k$01) + 1)|0;
  $34 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($4)|0);
  $35 = ($33|0)<($34|0);
  if ($35) {
   $k$01 = $33;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem12SolveTensileERK10b2TimeStep($this,$step) {
 $this = $this|0;
 $step = $step|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0.0, $42 = 0.0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0.0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0.0, $84 = 0, $85 = 0.0, $86 = 0.0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0;
 var $96 = 0.0, $97 = 0, $98 = 0, $99 = 0, $f = 0, $i$06 = 0, $k$03 = 0, $k1$02 = 0, $n = 0, $n6 = 0, $s = 0, $weightedNormal = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $n = sp + 8|0;
 $weightedNormal = sp + 32|0;
 $n6 = sp;
 $s = sp + 24|0;
 $f = sp + 16|0;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if ($2) {
  $3 = (($this) + 128|0);
  $i$06 = 0;
  while(1) {
   $8 = HEAP32[$3>>2]|0;
   $9 = (($8) + ($i$06<<3)|0);
   $10 = 10224;
   $11 = $10;
   $12 = HEAP32[$11>>2]|0;
   $13 = (($10) + 4)|0;
   $14 = $13;
   $15 = HEAP32[$14>>2]|0;
   $16 = $9;
   $17 = $16;
   HEAP32[$17>>2] = $12;
   $18 = (($16) + 4)|0;
   $19 = $18;
   HEAP32[$19>>2] = $15;
   $20 = (($i$06) + 1)|0;
   $21 = HEAP32[$0>>2]|0;
   $22 = ($20|0)<($21|0);
   if ($22) {
    $i$06 = $20;
   } else {
    break;
   }
  }
 }
 $4 = (($this) + 216|0);
 $5 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($4)|0);
 $6 = ($5|0)>(0);
 if ($6) {
  $7 = (($this) + 128|0);
  $k$03 = 0;
  while(1) {
   $23 = (__ZN16b2GrowableBufferI17b2ParticleContactEixEi($4,$k$03)|0);
   $24 = (__ZNK17b2ParticleContact8GetFlagsEv($23)|0);
   $25 = $24 & 128;
   $26 = ($25|0)==(0);
   if (!($26)) {
    $27 = (__ZNK17b2ParticleContact9GetIndexAEv($23)|0);
    $28 = (__ZNK17b2ParticleContact9GetIndexBEv($23)|0);
    $29 = (+__ZNK17b2ParticleContact9GetWeightEv($23));
    $30 = (__ZNK17b2ParticleContact9GetNormalEv($23)|0);
    $31 = $30;
    $32 = $31;
    $33 = HEAP32[$32>>2]|0;
    $34 = (($31) + 4)|0;
    $35 = $34;
    $36 = HEAP32[$35>>2]|0;
    $37 = $n;
    $38 = $37;
    HEAP32[$38>>2] = $33;
    $39 = (($37) + 4)|0;
    $40 = $39;
    HEAP32[$40>>2] = $36;
    $41 = 1.0 - $29;
    $42 = $29 * $41;
    __ZmlfRK6b2Vec2($weightedNormal,$42,$n);
    $43 = HEAP32[$7>>2]|0;
    $44 = (($43) + ($27<<3)|0);
    __ZN6b2Vec2mIERKS_($44,$weightedNormal);
    $45 = HEAP32[$7>>2]|0;
    $46 = (($45) + ($28<<3)|0);
    __ZN6b2Vec2pLERKS_($46,$weightedNormal);
   }
   $47 = (($k$03) + 1)|0;
   $48 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($4)|0);
   $49 = ($47|0)<($48|0);
   if ($49) {
    $k$03 = $47;
   } else {
    break;
   }
  }
 }
 $50 = (+__ZNK16b2ParticleSystem19GetCriticalVelocityERK10b2TimeStep($this,$step));
 $51 = (($this) + 356|0);
 $52 = +HEAPF32[$51>>2];
 $53 = $50 * $52;
 $54 = (($this) + 360|0);
 $55 = +HEAPF32[$54>>2];
 $56 = $50 * $55;
 $57 = $50 * 0.5;
 $58 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($4)|0);
 $59 = ($58|0)>(0);
 if (!($59)) {
  STACKTOP = sp;return;
 }
 $60 = (($this) + 116|0);
 $61 = (($this) + 128|0);
 $62 = (($this) + 104|0);
 $k1$02 = 0;
 while(1) {
  $63 = (__ZN16b2GrowableBufferI17b2ParticleContactEixEi($4,$k1$02)|0);
  $64 = (__ZNK17b2ParticleContact8GetFlagsEv($63)|0);
  $65 = $64 & 128;
  $66 = ($65|0)==(0);
  if (!($66)) {
   $67 = (__ZNK17b2ParticleContact9GetIndexAEv($63)|0);
   $68 = (__ZNK17b2ParticleContact9GetIndexBEv($63)|0);
   $69 = (+__ZNK17b2ParticleContact9GetWeightEv($63));
   $70 = (__ZNK17b2ParticleContact9GetNormalEv($63)|0);
   $71 = $70;
   $72 = $71;
   $73 = HEAP32[$72>>2]|0;
   $74 = (($71) + 4)|0;
   $75 = $74;
   $76 = HEAP32[$75>>2]|0;
   $77 = $n6;
   $78 = $77;
   HEAP32[$78>>2] = $73;
   $79 = (($77) + 4)|0;
   $80 = $79;
   HEAP32[$80>>2] = $76;
   $81 = HEAP32[$60>>2]|0;
   $82 = (($81) + ($67<<2)|0);
   $83 = +HEAPF32[$82>>2];
   $84 = (($81) + ($68<<2)|0);
   $85 = +HEAPF32[$84>>2];
   $86 = $83 + $85;
   $87 = HEAP32[$61>>2]|0;
   $88 = (($87) + ($68<<3)|0);
   $89 = (($87) + ($67<<3)|0);
   __ZmiRK6b2Vec2S1_($s,$88,$89);
   $90 = $86 + -2.0;
   $91 = $53 * $90;
   $92 = (+__Z5b2DotRK6b2Vec2S1_($s,$n6));
   $93 = $56 * $92;
   $94 = $91 + $93;
   $95 = (+__Z5b2MinIfET_S0_S0_($94,$57));
   $96 = $69 * $95;
   __ZmlfRK6b2Vec2($f,$96,$n6);
   $97 = HEAP32[$62>>2]|0;
   $98 = (($97) + ($67<<3)|0);
   __ZN6b2Vec2mIERKS_($98,$f);
   $99 = HEAP32[$62>>2]|0;
   $100 = (($99) + ($68<<3)|0);
   __ZN6b2Vec2pLERKS_($100,$f);
  }
  $101 = (($k1$02) + 1)|0;
  $102 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($4)|0);
  $103 = ($101|0)<($102|0);
  if ($103) {
   $k1$02 = $101;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem10SolveSolidERK10b2TimeStep($this,$step) {
 $this = $this|0;
 $step = $step|0;
 var $0 = 0, $1 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0.0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0.0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $f = 0, $k$01 = 0, $n = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $n = sp;
 $f = sp + 8|0;
 $0 = (($step) + 4|0);
 $1 = +HEAPF32[$0>>2];
 $2 = (($this) + 372|0);
 $3 = +HEAPF32[$2>>2];
 $4 = $1 * $3;
 $5 = (($this) + 216|0);
 $6 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($5)|0);
 $7 = ($6|0)>(0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 144|0);
 $9 = (($this) + 132|0);
 $10 = (($this) + 104|0);
 $k$01 = 0;
 while(1) {
  $11 = (__ZN16b2GrowableBufferI17b2ParticleContactEixEi($5,$k$01)|0);
  $12 = (__ZNK17b2ParticleContact9GetIndexAEv($11)|0);
  $13 = (__ZNK17b2ParticleContact9GetIndexBEv($11)|0);
  $14 = HEAP32[$8>>2]|0;
  $15 = (($14) + ($12<<2)|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($14) + ($13<<2)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($16|0)==($18|0);
  if (!($19)) {
   $20 = (+__ZNK17b2ParticleContact9GetWeightEv($11));
   $21 = (__ZNK17b2ParticleContact9GetNormalEv($11)|0);
   $22 = $21;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = (($22) + 4)|0;
   $26 = $25;
   $27 = HEAP32[$26>>2]|0;
   $28 = $n;
   $29 = $28;
   HEAP32[$29>>2] = $24;
   $30 = (($28) + 4)|0;
   $31 = $30;
   HEAP32[$31>>2] = $27;
   $32 = HEAP32[$9>>2]|0;
   $33 = (($32) + ($12<<2)|0);
   $34 = +HEAPF32[$33>>2];
   $35 = (($32) + ($13<<2)|0);
   $36 = +HEAPF32[$35>>2];
   $37 = $34 + $36;
   $38 = $4 * $37;
   $39 = $20 * $38;
   __ZmlfRK6b2Vec2($f,$39,$n);
   $40 = HEAP32[$10>>2]|0;
   $41 = (($40) + ($12<<3)|0);
   __ZN6b2Vec2mIERKS_($41,$f);
   $42 = HEAP32[$10>>2]|0;
   $43 = (($42) + ($13<<3)|0);
   __ZN6b2Vec2pLERKS_($43,$f);
  }
  $44 = (($k$01) + 1)|0;
  $45 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($5)|0);
  $46 = ($44|0)<($45|0);
  if ($46) {
   $k$01 = $44;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem16SolveColorMixingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0.0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $k$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 388|0);
 $1 = +HEAPF32[$0>>2];
 $2 = $1 * 128.0;
 $3 = (~~(($2)));
 $4 = ($3|0)==(0);
 if ($4) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 216|0);
 $6 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($5)|0);
 $7 = ($6|0)>(0);
 if (!($7)) {
  STACKTOP = sp;return;
 }
 $8 = (($this) + 88|0);
 $9 = (($this) + 136|0);
 $10 = HEAP8[9496>>0]|0;
 $11 = $10&255;
 $k$01 = 0;
 while(1) {
  $12 = (__ZN16b2GrowableBufferI17b2ParticleContactEixEi($5,$k$01)|0);
  $13 = (__ZNK17b2ParticleContact9GetIndexAEv($12)|0);
  $14 = (__ZNK17b2ParticleContact9GetIndexBEv($12)|0);
  $15 = HEAP32[$8>>2]|0;
  $16 = (($15) + ($13<<2)|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($15) + ($14<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = $17 & 256;
  $21 = $20 & $19;
  $22 = ($21|0)==(0);
  if (!($22)) {
   $23 = HEAP32[$9>>2]|0;
   $24 = (($23) + ($14<<2)|0);
   $25 = HEAP8[$24>>0]|0;
   $26 = $25&255;
   $27 = (($23) + ($13<<2)|0);
   $28 = HEAP8[$27>>0]|0;
   $29 = $28&255;
   $30 = (($26) - ($29))|0;
   $31 = Math_imul($30, $3)|0;
   $32 = $31 >> $11;
   $33 = ((($23) + ($14<<2)|0) + 1|0);
   $34 = HEAP8[$33>>0]|0;
   $35 = $34&255;
   $36 = ((($23) + ($13<<2)|0) + 1|0);
   $37 = HEAP8[$36>>0]|0;
   $38 = $37&255;
   $39 = (($35) - ($38))|0;
   $40 = Math_imul($39, $3)|0;
   $41 = $40 >> $11;
   $42 = ((($23) + ($14<<2)|0) + 2|0);
   $43 = HEAP8[$42>>0]|0;
   $44 = $43&255;
   $45 = ((($23) + ($13<<2)|0) + 2|0);
   $46 = HEAP8[$45>>0]|0;
   $47 = $46&255;
   $48 = (($44) - ($47))|0;
   $49 = Math_imul($48, $3)|0;
   $50 = $49 >> $11;
   $51 = ((($23) + ($14<<2)|0) + 3|0);
   $52 = HEAP8[$51>>0]|0;
   $53 = $52&255;
   $54 = ((($23) + ($13<<2)|0) + 3|0);
   $55 = HEAP8[$54>>0]|0;
   $56 = $55&255;
   $57 = (($53) - ($56))|0;
   $58 = Math_imul($57, $3)|0;
   $59 = $58 >> $11;
   $60 = (($32) + ($29))|0;
   $61 = $60&255;
   HEAP8[$27>>0] = $61;
   $62 = HEAP8[$36>>0]|0;
   $63 = $62&255;
   $64 = (($63) + ($41))|0;
   $65 = $64&255;
   HEAP8[$36>>0] = $65;
   $66 = HEAP8[$45>>0]|0;
   $67 = $66&255;
   $68 = (($67) + ($50))|0;
   $69 = $68&255;
   HEAP8[$45>>0] = $69;
   $70 = HEAP8[$54>>0]|0;
   $71 = $70&255;
   $72 = (($71) + ($59))|0;
   $73 = $72&255;
   HEAP8[$54>>0] = $73;
   $74 = HEAP8[$24>>0]|0;
   $75 = $74&255;
   $76 = (($75) - ($32))|0;
   $77 = $76&255;
   HEAP8[$24>>0] = $77;
   $78 = HEAP8[$33>>0]|0;
   $79 = $78&255;
   $80 = (($79) - ($41))|0;
   $81 = $80&255;
   HEAP8[$33>>0] = $81;
   $82 = HEAP8[$42>>0]|0;
   $83 = $82&255;
   $84 = (($83) - ($50))|0;
   $85 = $84&255;
   HEAP8[$42>>0] = $85;
   $86 = HEAP8[$51>>0]|0;
   $87 = $86&255;
   $88 = (($87) - ($59))|0;
   $89 = $88&255;
   HEAP8[$51>>0] = $89;
  }
  $90 = (($k$01) + 1)|0;
  $91 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($5)|0);
  $92 = ($90|0)<($91|0);
  if ($92) {
   $k$01 = $90;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem12SolveGravityERK10b2TimeStep($this,$step) {
 $this = $this|0;
 $step = $step|0;
 var $0 = 0, $1 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0.0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $gravity = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $gravity = sp + 8|0;
 $0 = sp;
 $1 = +HEAPF32[$step>>2];
 $2 = (($this) + 324|0);
 $3 = +HEAPF32[$2>>2];
 $4 = $1 * $3;
 $5 = (($this) + 400|0);
 $6 = HEAP32[$5>>2]|0;
 __ZNK7b2World10GetGravityEv($0,$6);
 __ZmlfRK6b2Vec2($gravity,$4,$0);
 $7 = (($this) + 44|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)>(0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = (($this) + 104|0);
 $i$01 = 0;
 while(1) {
  $11 = HEAP32[$10>>2]|0;
  $12 = (($11) + ($i$01<<3)|0);
  __ZN6b2Vec2pLERKS_($12,$gravity);
  $13 = (($i$01) + 1)|0;
  $14 = HEAP32[$7>>2]|0;
  $15 = ($13|0)<($14|0);
  if ($15) {
   $i$01 = $13;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem19SolveStaticPressureERK10b2TimeStep($this,$step) {
 $this = $this|0;
 $step = $step|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0.0, $3 = 0.0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0.0, $34 = 0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0, $43 = 0, $44 = 0.0;
 var $45 = 0.0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0.0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0.0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0.0, $60 = 0, $61 = 0, $62 = 0.0;
 var $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0.0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0, $9 = 0.0, $i$02 = 0, $k$01 = 0;
 var $t$04 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 120|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN16b2ParticleSystem13RequestBufferIfEEPT_S2_($this,$1)|0);
 HEAP32[$0>>2] = $2;
 $3 = (+__ZNK16b2ParticleSystem19GetCriticalPressureERK10b2TimeStep($this,$step));
 $4 = (($this) + 376|0);
 $5 = +HEAPF32[$4>>2];
 $6 = $3 * $5;
 $7 = $3 * 0.25;
 $8 = (($this) + 380|0);
 $9 = +HEAPF32[$8>>2];
 $10 = (($this) + 384|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)>(0);
 if (!($12)) {
  STACKTOP = sp;return;
 }
 $13 = (($this) + 124|0);
 $14 = (($this) + 44|0);
 $15 = (($this) + 216|0);
 $16 = (($this) + 116|0);
 $17 = (($this) + 88|0);
 $t$04 = 0;
 while(1) {
  $18 = HEAP32[$13>>2]|0;
  $19 = HEAP32[$14>>2]|0;
  $20 = $19 << 2;
  _memset(($18|0),0,($20|0))|0;
  $21 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($15)|0);
  $22 = ($21|0)>(0);
  if ($22) {
   $k$01 = 0;
   while(1) {
    $23 = (__ZN16b2GrowableBufferI17b2ParticleContactEixEi($15,$k$01)|0);
    $24 = (__ZNK17b2ParticleContact8GetFlagsEv($23)|0);
    $25 = $24 & 2048;
    $26 = ($25|0)==(0);
    if (!($26)) {
     $27 = (__ZNK17b2ParticleContact9GetIndexAEv($23)|0);
     $28 = (__ZNK17b2ParticleContact9GetIndexBEv($23)|0);
     $29 = (+__ZNK17b2ParticleContact9GetWeightEv($23));
     $30 = HEAP32[$0>>2]|0;
     $31 = (($30) + ($28<<2)|0);
     $32 = +HEAPF32[$31>>2];
     $33 = $29 * $32;
     $34 = HEAP32[$13>>2]|0;
     $35 = (($34) + ($27<<2)|0);
     $36 = +HEAPF32[$35>>2];
     $37 = $33 + $36;
     HEAPF32[$35>>2] = $37;
     $38 = HEAP32[$0>>2]|0;
     $39 = (($38) + ($27<<2)|0);
     $40 = +HEAPF32[$39>>2];
     $41 = $29 * $40;
     $42 = HEAP32[$13>>2]|0;
     $43 = (($42) + ($28<<2)|0);
     $44 = +HEAPF32[$43>>2];
     $45 = $41 + $44;
     HEAPF32[$43>>2] = $45;
    }
    $46 = (($k$01) + 1)|0;
    $47 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($15)|0);
    $48 = ($46|0)<($47|0);
    if ($48) {
     $k$01 = $46;
    } else {
     break;
    }
   }
  }
  $49 = HEAP32[$14>>2]|0;
  $50 = ($49|0)>(0);
  if ($50) {
   $51 = HEAP32[$16>>2]|0;
   $52 = HEAP32[$17>>2]|0;
   $53 = HEAP32[$14>>2]|0;
   $i$02 = 0;
   while(1) {
    $54 = (($51) + ($i$02<<2)|0);
    $55 = +HEAPF32[$54>>2];
    $56 = (($52) + ($i$02<<2)|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = $57 & 2048;
    $59 = ($58|0)==(0);
    if ($59) {
     $71 = HEAP32[$0>>2]|0;
     $72 = (($71) + ($i$02<<2)|0);
     HEAPF32[$72>>2] = 0.0;
    } else {
     $60 = HEAP32[$13>>2]|0;
     $61 = (($60) + ($i$02<<2)|0);
     $62 = +HEAPF32[$61>>2];
     $63 = $55 + -1.0;
     $64 = $6 * $63;
     $65 = $64 + $62;
     $66 = $9 + $55;
     $67 = $65 / $66;
     $68 = (+__Z7b2ClampIfET_S0_S0_S0_($67,0.0,$7));
     $69 = HEAP32[$0>>2]|0;
     $70 = (($69) + ($i$02<<2)|0);
     HEAPF32[$70>>2] = $68;
    }
    $73 = (($i$02) + 1)|0;
    $74 = ($73|0)<($53|0);
    if ($74) {
     $i$02 = $73;
    } else {
     break;
    }
   }
  }
  $75 = (($t$04) + 1)|0;
  $76 = HEAP32[$10>>2]|0;
  $77 = ($75|0)<($76|0);
  if ($77) {
   $t$04 = $75;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem13SolvePressureERK10b2TimeStep($this,$step) {
 $this = $this|0;
 $step = $step|0;
 var $0 = 0, $1 = 0.0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0.0;
 var $116 = 0.0, $117 = 0.0, $118 = 0.0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0, $122 = 0, $123 = 0.0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0.0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0.0, $145 = 0, $146 = 0.0, $147 = 0.0, $148 = 0.0, $149 = 0.0, $15 = 0.0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0.0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0.0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0.0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0, $63 = 0, $64 = 0.0, $65 = 0;
 var $66 = 0.0, $67 = 0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0.0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $f = 0, $f12 = 0, $i$014 = 0;
 var $i1$012 = 0, $i2$08 = 0, $k$04 = 0, $k5$03 = 0, $n = 0, $n10 = 0, $p = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $n = sp + 16|0;
 $p = sp + 8|0;
 $f = sp + 40|0;
 $0 = sp + 32|0;
 $n10 = sp;
 $f12 = sp + 24|0;
 $1 = (+__ZNK16b2ParticleSystem19GetCriticalPressureERK10b2TimeStep($this,$step));
 $2 = (($this) + 336|0);
 $3 = +HEAPF32[$2>>2];
 $4 = $1 * $3;
 $5 = $1 * 0.25;
 $6 = (($this) + 44|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)>(0);
 if ($8) {
  $9 = (($this) + 116|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($this) + 124|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = HEAP32[$6>>2]|0;
  $i$014 = 0;
  while(1) {
   $14 = (($10) + ($i$014<<2)|0);
   $15 = +HEAPF32[$14>>2];
   $16 = $15 + -1.0;
   $17 = (+__Z5b2MaxIfET_S0_S0_(0.0,$16));
   $18 = $4 * $17;
   $19 = (+__Z5b2MinIfET_S0_S0_($18,$5));
   $20 = (($12) + ($i$014<<2)|0);
   HEAPF32[$20>>2] = $19;
   $21 = (($i$014) + 1)|0;
   $22 = ($21|0)<($13|0);
   if ($22) {
    $i$014 = $21;
   } else {
    break;
   }
  }
 }
 $23 = (($this) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = $24 & 192;
 $26 = ($25|0)==(0);
 if (!($26)) {
  $27 = HEAP32[$6>>2]|0;
  $28 = ($27|0)>(0);
  if ($28) {
   $29 = (($this) + 88|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = HEAP32[$6>>2]|0;
   $32 = (($this) + 124|0);
   $i1$012 = 0;
   while(1) {
    $33 = (($30) + ($i1$012<<2)|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = $34 & 192;
    $36 = ($35|0)==(0);
    if (!($36)) {
     $37 = HEAP32[$32>>2]|0;
     $38 = (($37) + ($i1$012<<2)|0);
     HEAPF32[$38>>2] = 0.0;
    }
    $39 = (($i1$012) + 1)|0;
    $40 = ($39|0)<($31|0);
    if ($40) {
     $i1$012 = $39;
    } else {
     break;
    }
   }
  }
 }
 $41 = HEAP32[$23>>2]|0;
 $42 = $41 & 2048;
 $43 = ($42|0)==(0);
 if (!($43)) {
  $44 = HEAP32[$6>>2]|0;
  $45 = ($44|0)>(0);
  if ($45) {
   $46 = (($this) + 88|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = HEAP32[$6>>2]|0;
   $49 = (($this) + 120|0);
   $50 = (($this) + 124|0);
   $i2$08 = 0;
   while(1) {
    $51 = (($47) + ($i2$08<<2)|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = $52 & 2048;
    $54 = ($53|0)==(0);
    if (!($54)) {
     $55 = HEAP32[$49>>2]|0;
     $56 = (($55) + ($i2$08<<2)|0);
     $57 = +HEAPF32[$56>>2];
     $58 = HEAP32[$50>>2]|0;
     $59 = (($58) + ($i2$08<<2)|0);
     $60 = +HEAPF32[$59>>2];
     $61 = $57 + $60;
     HEAPF32[$59>>2] = $61;
    }
    $62 = (($i2$08) + 1)|0;
    $63 = ($62|0)<($48|0);
    if ($63) {
     $i2$08 = $62;
    } else {
     break;
    }
   }
  }
 }
 $64 = +HEAPF32[$step>>2];
 $65 = (($this) + 320|0);
 $66 = +HEAPF32[$65>>2];
 $67 = (($this) + 32|0);
 $68 = +HEAPF32[$67>>2];
 $69 = $66 * $68;
 $70 = $64 / $69;
 $71 = (($this) + 232|0);
 $72 = (__ZNK16b2GrowableBufferI21b2ParticleBodyContactE8GetCountEv($71)|0);
 $73 = ($72|0)>(0);
 if ($73) {
  $74 = (($this) + 96|0);
  $75 = (($this) + 124|0);
  $76 = (($this) + 104|0);
  $k$04 = 0;
  while(1) {
   $82 = (__ZN16b2GrowableBufferI21b2ParticleBodyContactEixEi($71,$k$04)|0);
   $83 = HEAP32[$82>>2]|0;
   $84 = (($82) + 4|0);
   $85 = HEAP32[$84>>2]|0;
   $86 = (($82) + 12|0);
   $87 = +HEAPF32[$86>>2];
   $88 = (($82) + 24|0);
   $89 = +HEAPF32[$88>>2];
   $90 = (($82) + 16|0);
   $91 = $90;
   $92 = $91;
   $93 = HEAP32[$92>>2]|0;
   $94 = (($91) + 4)|0;
   $95 = $94;
   $96 = HEAP32[$95>>2]|0;
   $97 = $n;
   $98 = $97;
   HEAP32[$98>>2] = $93;
   $99 = (($97) + 4)|0;
   $100 = $99;
   HEAP32[$100>>2] = $96;
   $101 = HEAP32[$74>>2]|0;
   $102 = (($101) + ($83<<3)|0);
   $103 = $102;
   $104 = $103;
   $105 = HEAP32[$104>>2]|0;
   $106 = (($103) + 4)|0;
   $107 = $106;
   $108 = HEAP32[$107>>2]|0;
   $109 = $p;
   $110 = $109;
   HEAP32[$110>>2] = $105;
   $111 = (($109) + 4)|0;
   $112 = $111;
   HEAP32[$112>>2] = $108;
   $113 = HEAP32[$75>>2]|0;
   $114 = (($113) + ($83<<2)|0);
   $115 = +HEAPF32[$114>>2];
   $116 = $4 * $87;
   $117 = $116 + $115;
   $118 = $70 * $87;
   $119 = $118 * $89;
   $120 = $119 * $117;
   __ZmlfRK6b2Vec2($f,$120,$n);
   $121 = HEAP32[$76>>2]|0;
   $122 = (($121) + ($83<<3)|0);
   $123 = (+__ZNK16b2ParticleSystem18GetParticleInvMassEv($this));
   __ZmlfRK6b2Vec2($0,$123,$f);
   __ZN6b2Vec2mIERKS_($122,$0);
   __ZN6b2Body18ApplyLinearImpulseERK6b2Vec2S2_b($85,$f,$p,1);
   $124 = (($k$04) + 1)|0;
   $125 = (__ZNK16b2GrowableBufferI21b2ParticleBodyContactE8GetCountEv($71)|0);
   $126 = ($124|0)<($125|0);
   if ($126) {
    $k$04 = $124;
   } else {
    break;
   }
  }
 }
 $77 = (($this) + 216|0);
 $78 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($77)|0);
 $79 = ($78|0)>(0);
 if (!($79)) {
  STACKTOP = sp;return;
 }
 $80 = (($this) + 124|0);
 $81 = (($this) + 104|0);
 $k5$03 = 0;
 while(1) {
  $127 = (__ZN16b2GrowableBufferI17b2ParticleContactEixEi($77,$k5$03)|0);
  $128 = (__ZNK17b2ParticleContact9GetIndexAEv($127)|0);
  $129 = (__ZNK17b2ParticleContact9GetIndexBEv($127)|0);
  $130 = (+__ZNK17b2ParticleContact9GetWeightEv($127));
  $131 = (__ZNK17b2ParticleContact9GetNormalEv($127)|0);
  $132 = $131;
  $133 = $132;
  $134 = HEAP32[$133>>2]|0;
  $135 = (($132) + 4)|0;
  $136 = $135;
  $137 = HEAP32[$136>>2]|0;
  $138 = $n10;
  $139 = $138;
  HEAP32[$139>>2] = $134;
  $140 = (($138) + 4)|0;
  $141 = $140;
  HEAP32[$141>>2] = $137;
  $142 = HEAP32[$80>>2]|0;
  $143 = (($142) + ($128<<2)|0);
  $144 = +HEAPF32[$143>>2];
  $145 = (($142) + ($129<<2)|0);
  $146 = +HEAPF32[$145>>2];
  $147 = $144 + $146;
  $148 = $70 * $130;
  $149 = $148 * $147;
  __ZmlfRK6b2Vec2($f12,$149,$n10);
  $150 = HEAP32[$81>>2]|0;
  $151 = (($150) + ($128<<3)|0);
  __ZN6b2Vec2mIERKS_($151,$f12);
  $152 = HEAP32[$81>>2]|0;
  $153 = (($152) + ($129<<3)|0);
  __ZN6b2Vec2pLERKS_($153,$f12);
  $154 = (($k5$03) + 1)|0;
  $155 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($77)|0);
  $156 = ($154|0)<($155|0);
  if ($156) {
   $k5$03 = $154;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem12SolveDampingERK10b2TimeStep($this,$step) {
 $this = $this|0;
 $step = $step|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0.0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0.0, $50 = 0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0.0, $60 = 0.0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0.0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0.0, $83 = 0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $f = 0, $f10 = 0, $k$04 = 0;
 var $k1$03 = 0, $n = 0, $n6 = 0, $p = 0, $v = 0, $v7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $n = sp + 16|0;
 $p = sp + 8|0;
 $v = sp + 72|0;
 $0 = sp + 64|0;
 $f = sp + 56|0;
 $1 = sp + 48|0;
 $2 = sp + 40|0;
 $n6 = sp;
 $v7 = sp + 32|0;
 $f10 = sp + 24|0;
 $3 = (($this) + 340|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (+__ZNK16b2ParticleSystem19GetCriticalVelocityERK10b2TimeStep($this,$step));
 $6 = 1.0 / $5;
 $7 = (($this) + 232|0);
 $8 = (__ZNK16b2GrowableBufferI21b2ParticleBodyContactE8GetCountEv($7)|0);
 $9 = ($8|0)>(0);
 if ($9) {
  $10 = (($this) + 96|0);
  $11 = (($this) + 104|0);
  $k$04 = 0;
  while(1) {
   $16 = (__ZN16b2GrowableBufferI21b2ParticleBodyContactEixEi($7,$k$04)|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($16) + 4|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($16) + 12|0);
   $21 = +HEAPF32[$20>>2];
   $22 = (($16) + 24|0);
   $23 = +HEAPF32[$22>>2];
   $24 = (($16) + 16|0);
   $25 = $24;
   $26 = $25;
   $27 = HEAP32[$26>>2]|0;
   $28 = (($25) + 4)|0;
   $29 = $28;
   $30 = HEAP32[$29>>2]|0;
   $31 = $n;
   $32 = $31;
   HEAP32[$32>>2] = $27;
   $33 = (($31) + 4)|0;
   $34 = $33;
   HEAP32[$34>>2] = $30;
   $35 = HEAP32[$10>>2]|0;
   $36 = (($35) + ($17<<3)|0);
   $37 = $36;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = (($37) + 4)|0;
   $41 = $40;
   $42 = HEAP32[$41>>2]|0;
   $43 = $p;
   $44 = $43;
   HEAP32[$44>>2] = $39;
   $45 = (($43) + 4)|0;
   $46 = $45;
   HEAP32[$46>>2] = $42;
   __ZNK6b2Body31GetLinearVelocityFromWorldPointERK6b2Vec2($0,$19,$p);
   $47 = HEAP32[$11>>2]|0;
   $48 = (($47) + ($17<<3)|0);
   __ZmiRK6b2Vec2S1_($v,$0,$48);
   $49 = (+__Z5b2DotRK6b2Vec2S1_($v,$n));
   $50 = $49 < 0.0;
   if ($50) {
    $51 = $4 * $21;
    $52 = $6 * $49;
    $53 = -$52;
    $54 = (+__Z5b2MinIfET_S0_S0_($53,0.5));
    $55 = (+__Z5b2MaxIfET_S0_S0_($51,$54));
    $56 = $23 * $55;
    $57 = $49 * $56;
    __ZmlfRK6b2Vec2($f,$57,$n);
    $58 = HEAP32[$11>>2]|0;
    $59 = (($58) + ($17<<3)|0);
    $60 = (+__ZNK16b2ParticleSystem18GetParticleInvMassEv($this));
    __ZmlfRK6b2Vec2($1,$60,$f);
    __ZN6b2Vec2pLERKS_($59,$1);
    __ZNK6b2Vec2ngEv($2,$f);
    __ZN6b2Body18ApplyLinearImpulseERK6b2Vec2S2_b($19,$2,$p,1);
   }
   $61 = (($k$04) + 1)|0;
   $62 = (__ZNK16b2GrowableBufferI21b2ParticleBodyContactE8GetCountEv($7)|0);
   $63 = ($61|0)<($62|0);
   if ($63) {
    $k$04 = $61;
   } else {
    break;
   }
  }
 }
 $12 = (($this) + 216|0);
 $13 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($12)|0);
 $14 = ($13|0)>(0);
 if (!($14)) {
  STACKTOP = sp;return;
 }
 $15 = (($this) + 104|0);
 $k1$03 = 0;
 while(1) {
  $64 = (__ZN16b2GrowableBufferI17b2ParticleContactEixEi($12,$k1$03)|0);
  $65 = (__ZNK17b2ParticleContact9GetIndexAEv($64)|0);
  $66 = (__ZNK17b2ParticleContact9GetIndexBEv($64)|0);
  $67 = (+__ZNK17b2ParticleContact9GetWeightEv($64));
  $68 = (__ZNK17b2ParticleContact9GetNormalEv($64)|0);
  $69 = $68;
  $70 = $69;
  $71 = HEAP32[$70>>2]|0;
  $72 = (($69) + 4)|0;
  $73 = $72;
  $74 = HEAP32[$73>>2]|0;
  $75 = $n6;
  $76 = $75;
  HEAP32[$76>>2] = $71;
  $77 = (($75) + 4)|0;
  $78 = $77;
  HEAP32[$78>>2] = $74;
  $79 = HEAP32[$15>>2]|0;
  $80 = (($79) + ($66<<3)|0);
  $81 = (($79) + ($65<<3)|0);
  __ZmiRK6b2Vec2S1_($v7,$80,$81);
  $82 = (+__Z5b2DotRK6b2Vec2S1_($v7,$n6));
  $83 = $82 < 0.0;
  if ($83) {
   $84 = $4 * $67;
   $85 = $6 * $82;
   $86 = -$85;
   $87 = (+__Z5b2MinIfET_S0_S0_($86,0.5));
   $88 = (+__Z5b2MaxIfET_S0_S0_($84,$87));
   $89 = $82 * $88;
   __ZmlfRK6b2Vec2($f10,$89,$n6);
   $90 = HEAP32[$15>>2]|0;
   $91 = (($90) + ($65<<3)|0);
   __ZN6b2Vec2pLERKS_($91,$f10);
   $92 = HEAP32[$15>>2]|0;
   $93 = (($92) + ($66<<3)|0);
   __ZN6b2Vec2mIERKS_($93,$f10);
  }
  $94 = (($k1$03) + 1)|0;
  $95 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($12)|0);
  $96 = ($94|0)<($95|0);
  if ($96) {
   $k1$03 = $94;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem17SolveExtraDampingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0.0, $46 = 0, $47 = 0.0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $f = 0, $k$02 = 0, $n = 0, $p = 0, $v = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $n = sp + 8|0;
 $p = sp;
 $v = sp + 48|0;
 $0 = sp + 40|0;
 $f = sp + 32|0;
 $1 = sp + 24|0;
 $2 = sp + 16|0;
 $3 = (($this) + 232|0);
 $4 = (__ZNK16b2GrowableBufferI21b2ParticleBodyContactE8GetCountEv($3)|0);
 $5 = ($4|0)>(0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 88|0);
 $7 = (($this) + 96|0);
 $8 = (($this) + 104|0);
 $k$02 = 0;
 while(1) {
  $9 = (__ZN16b2GrowableBufferI21b2ParticleBodyContactEixEi($3,$k$02)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = HEAP32[$6>>2]|0;
  $12 = (($11) + ($10<<2)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $13 & 2048;
  $15 = ($14|0)==(0);
  if (!($15)) {
   $16 = (($9) + 4|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (($9) + 24|0);
   $19 = +HEAPF32[$18>>2];
   $20 = (($9) + 16|0);
   $21 = $20;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = $n;
   $28 = $27;
   HEAP32[$28>>2] = $23;
   $29 = (($27) + 4)|0;
   $30 = $29;
   HEAP32[$30>>2] = $26;
   $31 = HEAP32[$7>>2]|0;
   $32 = (($31) + ($10<<3)|0);
   $33 = $32;
   $34 = $33;
   $35 = HEAP32[$34>>2]|0;
   $36 = (($33) + 4)|0;
   $37 = $36;
   $38 = HEAP32[$37>>2]|0;
   $39 = $p;
   $40 = $39;
   HEAP32[$40>>2] = $35;
   $41 = (($39) + 4)|0;
   $42 = $41;
   HEAP32[$42>>2] = $38;
   __ZNK6b2Body31GetLinearVelocityFromWorldPointERK6b2Vec2($0,$17,$p);
   $43 = HEAP32[$8>>2]|0;
   $44 = (($43) + ($10<<3)|0);
   __ZmiRK6b2Vec2S1_($v,$0,$44);
   $45 = (+__Z5b2DotRK6b2Vec2S1_($v,$n));
   $46 = $45 < 0.0;
   if ($46) {
    $47 = $19 * 0.5;
    $48 = $47 * $45;
    __ZmlfRK6b2Vec2($f,$48,$n);
    $49 = HEAP32[$8>>2]|0;
    $50 = (($49) + ($10<<3)|0);
    $51 = (+__ZNK16b2ParticleSystem18GetParticleInvMassEv($this));
    __ZmlfRK6b2Vec2($1,$51,$f);
    __ZN6b2Vec2pLERKS_($50,$1);
    __ZNK6b2Vec2ngEv($2,$f);
    __ZN6b2Body18ApplyLinearImpulseERK6b2Vec2S2_b($17,$2,$p,1);
   }
  }
  $52 = (($k$02) + 1)|0;
  $53 = (__ZNK16b2GrowableBufferI21b2ParticleBodyContactE8GetCountEv($3)|0);
  $54 = ($52|0)<($53|0);
  if ($54) {
   $k$02 = $52;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem12SolveElasticERK10b2TimeStep($this,$step) {
 $this = $this|0;
 $step = $step|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0.0, $101 = 0.0, $102 = 0, $103 = 0, $104 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0.0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0.0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0.0, $85 = 0.0, $86 = 0.0, $87 = 0.0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0;
 var $95 = 0.0, $96 = 0.0, $97 = 0.0, $98 = 0.0, $99 = 0, $k$03 = 0, $midPoint = 0, $pa = 0, $pb = 0, $pc = 0, $r = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0;
 $pa = sp + 16|0;
 $pb = sp + 8|0;
 $pc = sp;
 $0 = sp + 144|0;
 $1 = sp + 136|0;
 $2 = sp + 128|0;
 $midPoint = sp + 120|0;
 $3 = sp + 112|0;
 $4 = sp + 104|0;
 $r = sp + 96|0;
 $5 = sp + 88|0;
 $6 = sp + 80|0;
 $7 = sp + 72|0;
 $8 = sp + 64|0;
 $9 = sp + 56|0;
 $10 = sp + 48|0;
 $11 = sp + 40|0;
 $12 = sp + 32|0;
 $13 = sp + 24|0;
 $14 = (($step) + 4|0);
 $15 = +HEAPF32[$14>>2];
 $16 = (($this) + 344|0);
 $17 = +HEAPF32[$16>>2];
 $18 = $15 * $17;
 $19 = (($this) + 264|0);
 $20 = (__ZNK16b2GrowableBufferI15b2ParticleTriadE8GetCountEv($19)|0);
 $21 = ($20|0)>(0);
 if (!($21)) {
  STACKTOP = sp;return;
 }
 $22 = (($this) + 96|0);
 $23 = (($this) + 104|0);
 $24 = (($r) + 4|0);
 $k$03 = 0;
 while(1) {
  $25 = (__ZN16b2GrowableBufferI15b2ParticleTriadEixEi($19,$k$03)|0);
  $26 = (($25) + 12|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = $27 & 16;
  $29 = ($28|0)==(0);
  if (!($29)) {
   $30 = HEAP32[$25>>2]|0;
   $31 = (($25) + 4|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (($25) + 8|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (($25) + 20|0);
   $36 = (($25) + 28|0);
   $37 = (($25) + 36|0);
   $38 = HEAP32[$22>>2]|0;
   $39 = (($38) + ($30<<3)|0);
   $40 = $39;
   $41 = $40;
   $42 = HEAP32[$41>>2]|0;
   $43 = (($40) + 4)|0;
   $44 = $43;
   $45 = HEAP32[$44>>2]|0;
   $46 = $pa;
   $47 = $46;
   HEAP32[$47>>2] = $42;
   $48 = (($46) + 4)|0;
   $49 = $48;
   HEAP32[$49>>2] = $45;
   $50 = HEAP32[$22>>2]|0;
   $51 = (($50) + ($32<<3)|0);
   $52 = $51;
   $53 = $52;
   $54 = HEAP32[$53>>2]|0;
   $55 = (($52) + 4)|0;
   $56 = $55;
   $57 = HEAP32[$56>>2]|0;
   $58 = $pb;
   $59 = $58;
   HEAP32[$59>>2] = $54;
   $60 = (($58) + 4)|0;
   $61 = $60;
   HEAP32[$61>>2] = $57;
   $62 = HEAP32[$22>>2]|0;
   $63 = (($62) + ($34<<3)|0);
   $64 = $63;
   $65 = $64;
   $66 = HEAP32[$65>>2]|0;
   $67 = (($64) + 4)|0;
   $68 = $67;
   $69 = HEAP32[$68>>2]|0;
   $70 = $pc;
   $71 = $70;
   HEAP32[$71>>2] = $66;
   $72 = (($70) + 4)|0;
   $73 = $72;
   HEAP32[$73>>2] = $69;
   $74 = HEAP32[$23>>2]|0;
   $75 = (($74) + ($30<<3)|0);
   $76 = (($74) + ($32<<3)|0);
   $77 = (($74) + ($34<<3)|0);
   $78 = +HEAPF32[$step>>2];
   __ZmlfRK6b2Vec2($0,$78,$75);
   __ZN6b2Vec2pLERKS_($pa,$0);
   $79 = +HEAPF32[$step>>2];
   __ZmlfRK6b2Vec2($1,$79,$76);
   __ZN6b2Vec2pLERKS_($pb,$1);
   $80 = +HEAPF32[$step>>2];
   __ZmlfRK6b2Vec2($2,$80,$77);
   __ZN6b2Vec2pLERKS_($pc,$2);
   __ZplRK6b2Vec2S1_($4,$pa,$pb);
   __ZplRK6b2Vec2S1_($3,$4,$pc);
   __ZmlfRK6b2Vec2($midPoint,0.3333333432674408,$3);
   __ZN6b2Vec2mIERKS_($pa,$midPoint);
   __ZN6b2Vec2mIERKS_($pb,$midPoint);
   __ZN6b2Vec2mIERKS_($pc,$midPoint);
   $81 = (+__Z7b2CrossRK6b2Vec2S1_($35,$pa));
   $82 = (+__Z7b2CrossRK6b2Vec2S1_($36,$pb));
   $83 = $81 + $82;
   $84 = (+__Z7b2CrossRK6b2Vec2S1_($37,$pc));
   $85 = $83 + $84;
   HEAPF32[$r>>2] = $85;
   $86 = (+__Z5b2DotRK6b2Vec2S1_($35,$pa));
   $87 = (+__Z5b2DotRK6b2Vec2S1_($36,$pb));
   $88 = $86 + $87;
   $89 = (+__Z5b2DotRK6b2Vec2S1_($37,$pc));
   $90 = $88 + $89;
   HEAPF32[$24>>2] = $90;
   $91 = +HEAPF32[$r>>2];
   $92 = $91 * $91;
   $93 = $90 * $90;
   $94 = $92 + $93;
   $95 = (+__Z9b2InvSqrtf($94));
   $96 = $91 * $95;
   HEAPF32[$r>>2] = $96;
   $97 = +HEAPF32[$24>>2];
   $98 = $95 * $97;
   HEAPF32[$24>>2] = $98;
   $99 = (($25) + 16|0);
   $100 = +HEAPF32[$99>>2];
   $101 = $18 * $100;
   __Z5b2MulRK5b2RotRK6b2Vec2($7,$r,$35);
   __ZmiRK6b2Vec2S1_($6,$7,$pa);
   __ZmlfRK6b2Vec2($5,$101,$6);
   __ZN6b2Vec2pLERKS_($75,$5);
   __Z5b2MulRK5b2RotRK6b2Vec2($10,$r,$36);
   __ZmiRK6b2Vec2S1_($9,$10,$pb);
   __ZmlfRK6b2Vec2($8,$101,$9);
   __ZN6b2Vec2pLERKS_($76,$8);
   __Z5b2MulRK5b2RotRK6b2Vec2($13,$r,$37);
   __ZmiRK6b2Vec2S1_($12,$13,$pc);
   __ZmlfRK6b2Vec2($11,$101,$12);
   __ZN6b2Vec2pLERKS_($77,$11);
  }
  $102 = (($k$03) + 1)|0;
  $103 = (__ZNK16b2GrowableBufferI15b2ParticleTriadE8GetCountEv($19)|0);
  $104 = ($102|0)<($103|0);
  if ($104) {
   $k$03 = $102;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem11SolveSpringERK10b2TimeStep($this,$step) {
 $this = $this|0;
 $step = $step|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0.0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0.0, $48 = 0.0, $49 = 0, $5 = 0.0, $50 = 0.0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0, $59 = 0, $6 = 0.0, $60 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $d = 0, $f = 0, $k$02 = 0, $pa = 0, $pb = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $pa = sp + 8|0;
 $pb = sp;
 $0 = sp + 40|0;
 $1 = sp + 32|0;
 $d = sp + 24|0;
 $f = sp + 16|0;
 $2 = (($step) + 4|0);
 $3 = +HEAPF32[$2>>2];
 $4 = (($this) + 348|0);
 $5 = +HEAPF32[$4>>2];
 $6 = $3 * $5;
 $7 = (($this) + 248|0);
 $8 = (__ZNK16b2GrowableBufferI14b2ParticlePairE8GetCountEv($7)|0);
 $9 = ($8|0)>(0);
 if (!($9)) {
  STACKTOP = sp;return;
 }
 $10 = (($this) + 96|0);
 $11 = (($this) + 104|0);
 $k$02 = 0;
 while(1) {
  $12 = (__ZN16b2GrowableBufferI14b2ParticlePairEixEi($7,$k$02)|0);
  $13 = (($12) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $14 & 8;
  $16 = ($15|0)==(0);
  if (!($16)) {
   $17 = HEAP32[$12>>2]|0;
   $18 = (($12) + 4|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$10>>2]|0;
   $21 = (($20) + ($17<<3)|0);
   $22 = $21;
   $23 = $22;
   $24 = HEAP32[$23>>2]|0;
   $25 = (($22) + 4)|0;
   $26 = $25;
   $27 = HEAP32[$26>>2]|0;
   $28 = $pa;
   $29 = $28;
   HEAP32[$29>>2] = $24;
   $30 = (($28) + 4)|0;
   $31 = $30;
   HEAP32[$31>>2] = $27;
   $32 = HEAP32[$10>>2]|0;
   $33 = (($32) + ($19<<3)|0);
   $34 = $33;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $pb;
   $41 = $40;
   HEAP32[$41>>2] = $36;
   $42 = (($40) + 4)|0;
   $43 = $42;
   HEAP32[$43>>2] = $39;
   $44 = HEAP32[$11>>2]|0;
   $45 = (($44) + ($17<<3)|0);
   $46 = (($44) + ($19<<3)|0);
   $47 = +HEAPF32[$step>>2];
   __ZmlfRK6b2Vec2($0,$47,$45);
   __ZN6b2Vec2pLERKS_($pa,$0);
   $48 = +HEAPF32[$step>>2];
   __ZmlfRK6b2Vec2($1,$48,$46);
   __ZN6b2Vec2pLERKS_($pb,$1);
   __ZmiRK6b2Vec2S1_($d,$pb,$pa);
   $49 = (($12) + 16|0);
   $50 = +HEAPF32[$49>>2];
   $51 = (+__ZNK6b2Vec26LengthEv($d));
   $52 = (($12) + 12|0);
   $53 = +HEAPF32[$52>>2];
   $54 = $6 * $53;
   $55 = $50 - $51;
   $56 = $55 * $54;
   $57 = $56 / $51;
   __ZmlfRK6b2Vec2($f,$57,$d);
   __ZN6b2Vec2mIERKS_($45,$f);
   __ZN6b2Vec2pLERKS_($46,$f);
  }
  $58 = (($k$02) + 1)|0;
  $59 = (__ZNK16b2GrowableBufferI14b2ParticlePairE8GetCountEv($7)|0);
  $60 = ($58|0)<($59|0);
  if ($60) {
   $k$02 = $58;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem13LimitVelocityERK10b2TimeStep($this,$step) {
 $this = $this|0;
 $step = $step|0;
 var $0 = 0.0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0.0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+__ZNK16b2ParticleSystem26GetCriticalVelocitySquaredERK10b2TimeStep($this,$step));
 $1 = (($this) + 44|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)>(0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 104|0);
 $i$01 = 0;
 while(1) {
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + ($i$01<<3)|0);
  $7 = (+__Z5b2DotRK6b2Vec2S1_($6,$6));
  $8 = $7 > $0;
  if ($8) {
   $9 = $0 / $7;
   $10 = (+Math_sqrt((+$9)));
   __ZN6b2Vec2mLEf($6,$10);
  }
  $11 = (($i$01) + 1)|0;
  $12 = HEAP32[$1>>2]|0;
  $13 = ($11|0)<($12|0);
  if ($13) {
   $i$01 = $11;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem17SolveRigidDampingEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0.0, $101 = 0, $102 = 0.0, $103 = 0.0, $104 = 0.0, $105 = 0.0, $106 = 0.0, $107 = 0.0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0.0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0;
 var $116 = 0, $117 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0, $53 = 0.0, $54 = 0.0, $55 = 0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0;
 var $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0.0, $70 = 0.0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0.0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $invInertiaA = 0;
 var $invInertiaA12 = 0, $invInertiaB = 0, $invInertiaB15 = 0, $invMassA = 0, $invMassA11 = 0, $invMassB = 0, $invMassB14 = 0, $k$04 = 0, $k1$03 = 0, $n = 0, $n5 = 0, $or$cond = 0, $p = 0, $p8 = 0, $tangentDistanceA = 0, $tangentDistanceA13 = 0, $tangentDistanceB = 0, $tangentDistanceB16 = 0, $v = 0, $v9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0;
 $n = sp + 16|0;
 $p = sp + 8|0;
 $v = sp + 136|0;
 $0 = sp + 128|0;
 $1 = sp + 120|0;
 $invMassA = sp + 116|0;
 $invInertiaA = sp + 112|0;
 $tangentDistanceA = sp + 108|0;
 $invMassB = sp + 104|0;
 $invInertiaB = sp + 100|0;
 $tangentDistanceB = sp + 96|0;
 $2 = sp + 88|0;
 $n5 = sp;
 $p8 = sp + 80|0;
 $3 = sp + 72|0;
 $v9 = sp + 64|0;
 $4 = sp + 56|0;
 $5 = sp + 48|0;
 $invMassA11 = sp + 44|0;
 $invInertiaA12 = sp + 40|0;
 $tangentDistanceA13 = sp + 36|0;
 $invMassB14 = sp + 32|0;
 $invInertiaB15 = sp + 28|0;
 $tangentDistanceB16 = sp + 24|0;
 $6 = (($this) + 340|0);
 $7 = +HEAPF32[$6>>2];
 $8 = (($this) + 232|0);
 $9 = (__ZNK16b2GrowableBufferI21b2ParticleBodyContactE8GetCountEv($8)|0);
 $10 = ($9|0)>(0);
 if ($10) {
  $11 = (($this) + 144|0);
  $12 = (($this) + 96|0);
  $k$04 = 0;
  while(1) {
   $18 = (__ZN16b2GrowableBufferI21b2ParticleBodyContactEixEi($8,$k$04)|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = HEAP32[$11>>2]|0;
   $21 = (($20) + ($19<<2)|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (__ZNK16b2ParticleSystem12IsRigidGroupEP15b2ParticleGroup($this,$22)|0);
   if ($23) {
    $24 = (($18) + 4|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($18) + 16|0);
    $27 = $26;
    $28 = $27;
    $29 = HEAP32[$28>>2]|0;
    $30 = (($27) + 4)|0;
    $31 = $30;
    $32 = HEAP32[$31>>2]|0;
    $33 = $n;
    $34 = $33;
    HEAP32[$34>>2] = $29;
    $35 = (($33) + 4)|0;
    $36 = $35;
    HEAP32[$36>>2] = $32;
    $37 = (($18) + 12|0);
    $38 = +HEAPF32[$37>>2];
    $39 = HEAP32[$12>>2]|0;
    $40 = (($39) + ($19<<3)|0);
    $41 = $40;
    $42 = $41;
    $43 = HEAP32[$42>>2]|0;
    $44 = (($41) + 4)|0;
    $45 = $44;
    $46 = HEAP32[$45>>2]|0;
    $47 = $p;
    $48 = $47;
    HEAP32[$48>>2] = $43;
    $49 = (($47) + 4)|0;
    $50 = $49;
    HEAP32[$50>>2] = $46;
    __ZNK6b2Body31GetLinearVelocityFromWorldPointERK6b2Vec2($0,$25,$p);
    __ZNK15b2ParticleGroup31GetLinearVelocityFromWorldPointERK6b2Vec2($1,$22,$p);
    __ZmiRK6b2Vec2S1_($v,$0,$1);
    $51 = (+__Z5b2DotRK6b2Vec2S1_($v,$n));
    $52 = $51 < 0.0;
    if ($52) {
     __ZNK16b2ParticleSystem44InitDampingParameterWithRigidGroupOrParticleEPfS0_S0_bP15b2ParticleGroupiRK6b2Vec2S5_($this,$invMassA,$invInertiaA,$tangentDistanceA,1,$22,$19,$p,$n);
     $53 = (+__ZNK6b2Body7GetMassEv($25));
     $54 = (+__ZNK6b2Body10GetInertiaEv($25));
     $55 = (__ZNK6b2Body14GetLocalCenterEv($25)|0);
     $56 = (+__ZNK6b2Vec213LengthSquaredEv($55));
     $57 = $53 * $56;
     $58 = $54 - $57;
     $59 = (__ZNK6b2Body14GetWorldCenterEv($25)|0);
     __ZNK16b2ParticleSystem20InitDampingParameterEPfS0_S0_ffRK6b2Vec2S3_S3_($this,$invMassB,$invInertiaB,$tangentDistanceB,$53,$58,$59,$p,$n);
     $60 = (+__Z5b2MinIfET_S0_S0_($38,1.0));
     $61 = $7 * $60;
     $62 = +HEAPF32[$invMassA>>2];
     $63 = +HEAPF32[$invInertiaA>>2];
     $64 = +HEAPF32[$tangentDistanceA>>2];
     $65 = +HEAPF32[$invMassB>>2];
     $66 = +HEAPF32[$invInertiaB>>2];
     $67 = +HEAPF32[$tangentDistanceB>>2];
     $68 = (+__ZNK16b2ParticleSystem21ComputeDampingImpulseEfffffff($this,$62,$63,$64,$65,$66,$67,$51));
     $69 = $61 * $68;
     __ZN16b2ParticleSystem12ApplyDampingEfffbP15b2ParticleGroupifRK6b2Vec2($this,$62,$63,$64,1,$22,$19,$69,$n);
     $70 = -$69;
     __ZmlfRK6b2Vec2($2,$70,$n);
     __ZN6b2Body18ApplyLinearImpulseERK6b2Vec2S2_b($25,$2,$p,1);
    }
   }
   $71 = (($k$04) + 1)|0;
   $72 = (__ZNK16b2GrowableBufferI21b2ParticleBodyContactE8GetCountEv($8)|0);
   $73 = ($71|0)<($72|0);
   if ($73) {
    $k$04 = $71;
   } else {
    break;
   }
  }
 }
 $13 = (($this) + 216|0);
 $14 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($13)|0);
 $15 = ($14|0)>(0);
 if (!($15)) {
  STACKTOP = sp;return;
 }
 $16 = (($this) + 144|0);
 $17 = (($this) + 96|0);
 $k1$03 = 0;
 while(1) {
  $74 = (__ZN16b2GrowableBufferI17b2ParticleContactEixEi($13,$k1$03)|0);
  $75 = (__ZNK17b2ParticleContact9GetIndexAEv($74)|0);
  $76 = (__ZNK17b2ParticleContact9GetIndexBEv($74)|0);
  $77 = (__ZNK17b2ParticleContact9GetNormalEv($74)|0);
  $78 = $77;
  $79 = $78;
  $80 = HEAP32[$79>>2]|0;
  $81 = (($78) + 4)|0;
  $82 = $81;
  $83 = HEAP32[$82>>2]|0;
  $84 = $n5;
  $85 = $84;
  HEAP32[$85>>2] = $80;
  $86 = (($84) + 4)|0;
  $87 = $86;
  HEAP32[$87>>2] = $83;
  $88 = (+__ZNK17b2ParticleContact9GetWeightEv($74));
  $89 = HEAP32[$16>>2]|0;
  $90 = (($89) + ($75<<2)|0);
  $91 = HEAP32[$90>>2]|0;
  $92 = (($89) + ($76<<2)|0);
  $93 = HEAP32[$92>>2]|0;
  $94 = (__ZNK16b2ParticleSystem12IsRigidGroupEP15b2ParticleGroup($this,$91)|0);
  $95 = (__ZNK16b2ParticleSystem12IsRigidGroupEP15b2ParticleGroup($this,$93)|0);
  $96 = ($91|0)!=($93|0);
  $brmerge = $94 | $95;
  $or$cond = $96 & $brmerge;
  if ($or$cond) {
   $97 = HEAP32[$17>>2]|0;
   $98 = (($97) + ($75<<3)|0);
   $99 = (($97) + ($76<<3)|0);
   __ZplRK6b2Vec2S1_($3,$98,$99);
   __ZmlfRK6b2Vec2($p8,0.5,$3);
   __ZNK16b2ParticleSystem17GetLinearVelocityEP15b2ParticleGroupiRK6b2Vec2($4,$this,$93,$76,$p8);
   __ZNK16b2ParticleSystem17GetLinearVelocityEP15b2ParticleGroupiRK6b2Vec2($5,$this,$91,$75,$p8);
   __ZmiRK6b2Vec2S1_($v9,$4,$5);
   $100 = (+__Z5b2DotRK6b2Vec2S1_($v9,$n5));
   $101 = $100 < 0.0;
   if ($101) {
    __ZNK16b2ParticleSystem44InitDampingParameterWithRigidGroupOrParticleEPfS0_S0_bP15b2ParticleGroupiRK6b2Vec2S5_($this,$invMassA11,$invInertiaA12,$tangentDistanceA13,$94,$91,$75,$p8,$n5);
    __ZNK16b2ParticleSystem44InitDampingParameterWithRigidGroupOrParticleEPfS0_S0_bP15b2ParticleGroupiRK6b2Vec2S5_($this,$invMassB14,$invInertiaB15,$tangentDistanceB16,$95,$93,$76,$p8,$n5);
    $102 = $7 * $88;
    $103 = +HEAPF32[$invMassA11>>2];
    $104 = +HEAPF32[$invInertiaA12>>2];
    $105 = +HEAPF32[$tangentDistanceA13>>2];
    $106 = +HEAPF32[$invMassB14>>2];
    $107 = +HEAPF32[$invInertiaB15>>2];
    $108 = +HEAPF32[$tangentDistanceB16>>2];
    $109 = (+__ZNK16b2ParticleSystem21ComputeDampingImpulseEfffffff($this,$103,$104,$105,$106,$107,$108,$100));
    $110 = $102 * $109;
    __ZN16b2ParticleSystem12ApplyDampingEfffbP15b2ParticleGroupifRK6b2Vec2($this,$103,$104,$105,$94,$91,$75,$110,$n5);
    $111 = +HEAPF32[$invMassB14>>2];
    $112 = +HEAPF32[$invInertiaB15>>2];
    $113 = +HEAPF32[$tangentDistanceB16>>2];
    $114 = -$110;
    __ZN16b2ParticleSystem12ApplyDampingEfffbP15b2ParticleGroupifRK6b2Vec2($this,$111,$112,$113,$95,$93,$76,$114,$n5);
   }
  }
  $115 = (($k1$03) + 1)|0;
  $116 = (__ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($13)|0);
  $117 = ($115|0)<($116|0);
  if ($117) {
   $k1$03 = $115;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem10SolveRigidERK10b2TimeStep($this,$step) {
 $this = $this|0;
 $step = $step|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0;
 var $27 = 0.0, $28 = 0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $group$02 = 0, $i$01 = 0, $rotation = 0, $transform = 0, $velocityTransform = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $rotation = sp + 88|0;
 $transform = sp + 72|0;
 $0 = sp + 64|0;
 $1 = sp + 56|0;
 $2 = sp + 48|0;
 $3 = sp + 40|0;
 $4 = sp + 24|0;
 $velocityTransform = sp + 8|0;
 $5 = sp;
 $6 = (($this) + 312|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  STACKTOP = sp;return;
 }
 $9 = (($step) + 4|0);
 $10 = (($transform) + 4|0);
 $11 = (($velocityTransform) + 4|0);
 $12 = (($transform) + 8|0);
 $13 = (($velocityTransform) + 8|0);
 $14 = (($transform) + 12|0);
 $15 = (($velocityTransform) + 12|0);
 $16 = (($this) + 104|0);
 $17 = (($this) + 96|0);
 $group$02 = $7;
 while(1) {
  $18 = (($group$02) + 12|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = $19 & 2;
  $21 = ($20|0)==(0);
  if (!($21)) {
   __ZNK15b2ParticleGroup16UpdateStatisticsEv($group$02);
   $22 = +HEAPF32[$step>>2];
   $23 = (($group$02) + 56|0);
   $24 = +HEAPF32[$23>>2];
   $25 = $22 * $24;
   __ZN5b2RotC2Ef($rotation,$25);
   $26 = (($group$02) + 40|0);
   $27 = +HEAPF32[$step>>2];
   $28 = (($group$02) + 48|0);
   __ZmlfRK6b2Vec2($2,$27,$28);
   __ZplRK6b2Vec2S1_($1,$26,$2);
   __Z5b2MulRK5b2RotRK6b2Vec2($3,$rotation,$26);
   __ZmiRK6b2Vec2S1_($0,$1,$3);
   __ZN11b2TransformC2ERK6b2Vec2RK5b2Rot($transform,$0,$rotation);
   $29 = (($group$02) + 60|0);
   __Z5b2MulRK11b2TransformS1_($4,$transform,$29);
   ;HEAP32[$29+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$29+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$29+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$29+12>>2]=HEAP32[$4+12>>2]|0;
   $30 = +HEAPF32[$9>>2];
   $31 = +HEAPF32[$transform>>2];
   $32 = $30 * $31;
   HEAPF32[$velocityTransform>>2] = $32;
   $33 = +HEAPF32[$9>>2];
   $34 = +HEAPF32[$10>>2];
   $35 = $33 * $34;
   HEAPF32[$11>>2] = $35;
   $36 = +HEAPF32[$9>>2];
   $37 = +HEAPF32[$12>>2];
   $38 = $36 * $37;
   HEAPF32[$13>>2] = $38;
   $39 = +HEAPF32[$9>>2];
   $40 = +HEAPF32[$14>>2];
   $41 = $40 + -1.0;
   $42 = $39 * $41;
   HEAPF32[$15>>2] = $42;
   $43 = (($group$02) + 4|0);
   $44 = HEAP32[$43>>2]|0;
   $45 = (($group$02) + 8|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($44|0)<($46|0);
   if ($47) {
    $i$01 = $44;
    while(1) {
     $48 = HEAP32[$16>>2]|0;
     $49 = (($48) + ($i$01<<3)|0);
     $50 = HEAP32[$17>>2]|0;
     $51 = (($50) + ($i$01<<3)|0);
     __Z5b2MulRK11b2TransformRK6b2Vec2($5,$velocityTransform,$51);
     $52 = $5;
     $53 = $52;
     $54 = HEAP32[$53>>2]|0;
     $55 = (($52) + 4)|0;
     $56 = $55;
     $57 = HEAP32[$56>>2]|0;
     $58 = $49;
     $59 = $58;
     HEAP32[$59>>2] = $54;
     $60 = (($58) + 4)|0;
     $61 = $60;
     HEAP32[$61>>2] = $57;
     $62 = (($i$01) + 1)|0;
     $63 = HEAP32[$45>>2]|0;
     $64 = ($62|0)<($63|0);
     if ($64) {
      $i$01 = $62;
     } else {
      break;
     }
    }
   }
  }
  $65 = (__ZN15b2ParticleGroup7GetNextEv($group$02)|0);
  $66 = ($65|0)==(0|0);
  if ($66) {
   break;
  } else {
   $group$02 = $65;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem9SolveWallEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 88|0);
 $4 = (($this) + 104|0);
 $i$01 = 0;
 while(1) {
  $5 = HEAP32[$3>>2]|0;
  $6 = (($5) + ($i$01<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $7 & 4;
  $9 = ($8|0)==(0);
  if (!($9)) {
   $10 = HEAP32[$4>>2]|0;
   $11 = (($10) + ($i$01<<3)|0);
   __ZN6b2Vec27SetZeroEv($11);
  }
  $12 = (($i$01) + 1)|0;
  $13 = HEAP32[$0>>2]|0;
  $14 = ($12|0)<($13|0);
  if ($14) {
   $i$01 = $12;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK16b2ParticleSystem24LifetimeToExpirationTimeEf($this,$lifetime) {
 $this = $this|0;
 $lifetime = +$lifetime;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 296|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = (($this) + 396|0);
 $8 = +HEAPF32[$7>>2];
 $9 = $lifetime / $8;
 $10 = $9 * 4294967296.0;
 $11 = (~~$10)>>>0;
 $12 = +Math_abs($10) >= 1.0 ? $10 > 0.0 ? (Math_min(+Math_floor($10 / 4294967296.0), 4294967295.0) | 0) >>> 0 : ~~+Math_ceil(($10 - +(~~$10 >>> 0)) / 4294967296.0) >>> 0 : 0;
 $13 = (_i64Add(($11|0),($12|0),($3|0),($6|0))|0);
 $14 = tempRet0;
 tempRet0 = $14;
 STACKTOP = sp;return ($13|0);
}
function __ZN16b2ParticleSystem23GetExpirationTimeBufferEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 280|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (__ZN16b2ParticleSystem13RequestBufferIiEEPT_S2_($this,$1)|0);
 HEAP32[$0>>2] = $2;
 STACKTOP = sp;return ($2|0);
}
function __ZN16b2ParticleSystem10ApplyForceEiiRK6b2Vec2($this,$firstIndex,$lastIndex,$force) {
 $this = $this|0;
 $firstIndex = $firstIndex|0;
 $lastIndex = $lastIndex|0;
 $force = $force|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $distributedForce = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $distributedForce = sp;
 $0 = (($lastIndex) - ($firstIndex))|0;
 $1 = (+($0|0));
 __ZdvRK6b2Vec2f($distributedForce,$force,$1);
 $2 = (__ZL18IsSignificantForceRK6b2Vec2($distributedForce)|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZN16b2ParticleSystem18PrepareForceBufferEv($this);
 $3 = ($lastIndex|0)>($firstIndex|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($this) + 112|0);
 $i$01 = $firstIndex;
 while(1) {
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + ($i$01<<3)|0);
  __ZN6b2Vec2pLERKS_($6,$distributedForce);
  $7 = (($i$01) + 1)|0;
  $exitcond = ($7|0)==($lastIndex|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $7;
  }
 }
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem18ApplyLinearImpulseEiiRK6b2Vec2($this,$firstIndex,$lastIndex,$impulse) {
 $this = $this|0;
 $firstIndex = $firstIndex|0;
 $lastIndex = $lastIndex|0;
 $impulse = $impulse|0;
 var $0 = 0, $1 = 0.0, $2 = 0.0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $exitcond = 0, $i$01 = 0, $velocityDelta = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $velocityDelta = sp;
 $0 = (($lastIndex) - ($firstIndex))|0;
 $1 = (+($0|0));
 $2 = (+__ZNK16b2ParticleSystem15GetParticleMassEv($this));
 $3 = $1 * $2;
 __ZdvRK6b2Vec2f($velocityDelta,$impulse,$3);
 $4 = ($lastIndex|0)>($firstIndex|0);
 if (!($4)) {
  STACKTOP = sp;return;
 }
 $5 = (($this) + 104|0);
 $i$01 = $firstIndex;
 while(1) {
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + ($i$01<<3)|0);
  __ZN6b2Vec2pLERKS_($7,$velocityDelta);
  $8 = (($i$01) + 1)|0;
  $exitcond = ($8|0)==($lastIndex|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $8;
  }
 }
 STACKTOP = sp;return;
}
function __ZNK16b2ParticleSystem9QueryAABBEP15b2QueryCallbackRK6b2AABB($this,$callback,$aabb) {
 $this = $this|0;
 $callback = $callback|0;
 $aabb = $aabb|0;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0.0, $23 = 0.0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0, $38 = 0.0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, $proxy$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp + 4|0;
 $2 = sp;
 $3 = (($this) + 200|0);
 $4 = (__ZNK16b2GrowableBufferIN16b2ParticleSystem5ProxyEE8GetCountEv($3)|0);
 $5 = ($4|0)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = (__ZNK16b2GrowableBufferIN16b2ParticleSystem5ProxyEE5BeginEv($3)|0);
 $7 = (__ZNK16b2GrowableBufferIN16b2ParticleSystem5ProxyEE3EndEv($3)|0);
 $8 = (($this) + 36|0);
 $9 = +HEAPF32[$8>>2];
 $10 = +HEAPF32[$aabb>>2];
 $11 = $9 * $10;
 $12 = (($aabb) + 4|0);
 $13 = +HEAPF32[$12>>2];
 $14 = $9 * $13;
 $15 = (__ZL10computeTagff($11,$14)|0);
 HEAP32[$1>>2] = $15;
 $16 = (__ZNSt3__113__lower_boundIRNS_6__lessIN16b2ParticleSystem5ProxyEjEEPKS3_jEET0_S8_S8_RKT1_T_($6,$7,$1,$0)|0);
 $17 = +HEAPF32[$8>>2];
 $18 = (($aabb) + 8|0);
 $19 = +HEAPF32[$18>>2];
 $20 = $17 * $19;
 $21 = (($aabb) + 12|0);
 $22 = +HEAPF32[$21>>2];
 $23 = $17 * $22;
 $24 = (__ZL10computeTagff($20,$23)|0);
 HEAP32[$2>>2] = $24;
 $25 = (__ZNSt3__113__upper_boundIRNS_6__lessIjN16b2ParticleSystem5ProxyEEEPKS3_jEET0_S8_S8_RKT1_T_($16,$7,$2,$0)|0);
 $26 = ($16>>>0)<($25>>>0);
 if (!($26)) {
  STACKTOP = sp;return;
 }
 $27 = (($this) + 96|0);
 $proxy$01 = $16;
 while(1) {
  $28 = HEAP32[$proxy$01>>2]|0;
  $29 = HEAP32[$27>>2]|0;
  $30 = +HEAPF32[$aabb>>2];
  $31 = (($29) + ($28<<3)|0);
  $32 = +HEAPF32[$31>>2];
  $33 = $30 < $32;
  if ($33) {
   $34 = +HEAPF32[$18>>2];
   $35 = $32 < $34;
   if ($35) {
    $36 = +HEAPF32[$12>>2];
    $37 = ((($29) + ($28<<3)|0) + 4|0);
    $38 = +HEAPF32[$37>>2];
    $39 = $36 < $38;
    if ($39) {
     $40 = +HEAPF32[$21>>2];
     $41 = $38 < $40;
     if ($41) {
      $42 = HEAP32[$callback>>2]|0;
      $43 = (($42) + 12|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = (FUNCTION_TABLE_iiii[$44 & 15]($callback,$this,$28)|0);
      if (!($45)) {
       label = 10;
       break;
      }
     }
    }
   }
  }
  $46 = (($proxy$01) + 8|0);
  $47 = ($46>>>0)<($25>>>0);
  if ($47) {
   $proxy$01 = $46;
  } else {
   label = 10;
   break;
  }
 }
 if ((label|0) == 10) {
  STACKTOP = sp;return;
 }
}
function __ZNK16b2ParticleSystem7RayCastEP17b2RayCastCallbackRK6b2Vec2S4_($this,$callback,$point1,$point2) {
 $this = $this|0;
 $callback = $callback|0;
 $point1 = $point1|0;
 $point2 = $point2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0.0;
 var $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0.0, $43 = 0.0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $aabb = 0, $enumerator = 0, $fraction$0$ph = 0.0, $n = 0, $or$cond = 0, $p = 0, $t$0 = 0.0, $v = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0;
 $aabb = sp + 8|0;
 $0 = sp;
 $v = sp + 88|0;
 $enumerator = sp + 64|0;
 $p = sp + 56|0;
 $n = sp + 48|0;
 $1 = sp + 40|0;
 $2 = sp + 32|0;
 $3 = sp + 24|0;
 $4 = (($this) + 200|0);
 $5 = (__ZNK16b2GrowableBufferIN16b2ParticleSystem5ProxyEE8GetCountEv($4)|0);
 $6 = ($5|0)==(0);
 if ($6) {
  STACKTOP = sp;return;
 }
 __Z5b2MinRK6b2Vec2S1_($aabb,$point1,$point2);
 $7 = (($aabb) + 8|0);
 __Z5b2MaxRK6b2Vec2S1_($0,$point1,$point2);
 $8 = $0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = $7;
 $15 = $14;
 HEAP32[$15>>2] = $10;
 $16 = (($14) + 4)|0;
 $17 = $16;
 HEAP32[$17>>2] = $13;
 __ZmiRK6b2Vec2S1_($v,$point2,$point1);
 $18 = (+__Z5b2DotRK6b2Vec2S1_($v,$v));
 __ZNK16b2ParticleSystem25GetInsideBoundsEnumeratorERK6b2AABB($enumerator,$this,$aabb);
 $19 = (($this) + 96|0);
 $20 = (($this) + 40|0);
 $fraction$0$ph = 1.0;
 L4: while(1) {
  $21 = (__ZN16b2ParticleSystem22InsideBoundsEnumerator7GetNextEv($enumerator)|0);
  $22 = ($21|0)>(-1);
  if ($22) {
   $25 = $21;
  } else {
   label = 10;
   break;
  }
  while(1) {
   $23 = HEAP32[$19>>2]|0;
   $24 = (($23) + ($25<<3)|0);
   __ZmiRK6b2Vec2S1_($p,$point1,$24);
   $26 = (+__Z5b2DotRK6b2Vec2S1_($p,$v));
   $27 = (+__Z5b2DotRK6b2Vec2S1_($p,$p));
   $28 = $26 * $26;
   $29 = +HEAPF32[$20>>2];
   $30 = $27 - $29;
   $31 = $18 * $30;
   $32 = $28 - $31;
   $33 = !($32 >= 0.0);
   if (!($33)) {
    $34 = (+Math_sqrt((+$32)));
    $35 = -$26;
    $36 = $35 - $34;
    $37 = $36 / $18;
    $38 = $37 > $fraction$0$ph;
    if (!($38)) {
     $41 = $37 < 0.0;
     if (!($41)) {
      $t$0 = $37;
      break;
     }
     $42 = $34 - $26;
     $43 = $42 / $18;
     $44 = $43 < 0.0;
     $45 = $43 > $fraction$0$ph;
     $or$cond = $44 | $45;
     if (!($or$cond)) {
      $t$0 = $43;
      break;
     }
    }
   }
   $39 = (__ZN16b2ParticleSystem22InsideBoundsEnumerator7GetNextEv($enumerator)|0);
   $40 = ($39|0)>(-1);
   if ($40) {
    $25 = $39;
   } else {
    label = 10;
    break L4;
   }
  }
  __ZmlfRK6b2Vec2($1,$t$0,$v);
  __ZplRK6b2Vec2S1_($n,$p,$1);
  (+__ZN6b2Vec29NormalizeEv($n));
  $46 = HEAP32[$callback>>2]|0;
  $47 = (($46) + 12|0);
  $48 = HEAP32[$47>>2]|0;
  __ZmlfRK6b2Vec2($3,$t$0,$v);
  __ZplRK6b2Vec2S1_($2,$point1,$3);
  $49 = (+FUNCTION_TABLE_diiiiid[$48 & 1]($callback,$this,$25,$2,$n,$t$0));
  $50 = (+__Z5b2MinIfET_S0_S0_($fraction$0$ph,$49));
  $51 = !($50 <= 0.0);
  if ($51) {
   $fraction$0$ph = $50;
  } else {
   label = 10;
   break;
  }
 }
 if ((label|0) == 10) {
  STACKTOP = sp;return;
 }
}
function __ZZN16b2ParticleSystem14SolveCollisionERK10b2TimeStepEN22SolveCollisionCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN30b2FixtureParticleQueryCallback13ReportFixtureEP9b2Fixture($this,$fixture) {
 $this = $this|0;
 $fixture = $fixture|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $aabb = 0;
 var $childIndex$01 = 0, $enumerator = 0, $exitcond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $aabb = sp + 24|0;
 $enumerator = sp;
 $0 = (__ZNK9b2Fixture8IsSensorEv($fixture)|0);
 if ($0) {
  STACKTOP = sp;return 1;
 }
 $1 = (__ZN9b2Fixture8GetShapeEv($fixture)|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (FUNCTION_TABLE_ii[$4 & 15]($1)|0);
 $6 = ($5|0)>(0);
 if (!($6)) {
  STACKTOP = sp;return 1;
 }
 $7 = (($this) + 4|0);
 $childIndex$01 = 0;
 while(1) {
  $8 = (__ZNK9b2Fixture7GetAABBEi($fixture,$childIndex$01)|0);
  ;HEAP32[$aabb+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$aabb+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$aabb+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$aabb+12>>2]=HEAP32[$8+12>>2]|0;
  $9 = HEAP32[$7>>2]|0;
  __ZNK16b2ParticleSystem25GetInsideBoundsEnumeratorERK6b2AABB($enumerator,$9,$aabb);
  $10 = (__ZN16b2ParticleSystem22InsideBoundsEnumerator7GetNextEv($enumerator)|0);
  $11 = ($10|0)>(-1);
  if ($11) {
   $15 = $10;
   while(1) {
    $12 = HEAP32[$this>>2]|0;
    $13 = (($12) + 20|0);
    $14 = HEAP32[$13>>2]|0;
    FUNCTION_TABLE_viiii[$14 & 31]($this,$fixture,$childIndex$01,$15);
    $16 = (__ZN16b2ParticleSystem22InsideBoundsEnumerator7GetNextEv($enumerator)|0);
    $17 = ($16|0)>(-1);
    if ($17) {
     $15 = $16;
    } else {
     break;
    }
   }
  }
  $18 = (($childIndex$01) + 1)|0;
  $exitcond = ($18|0)==($5|0);
  if ($exitcond) {
   break;
  } else {
   $childIndex$01 = $18;
  }
 }
 STACKTOP = sp;return 1;
}
function __ZN30b2FixtureParticleQueryCallback25ShouldQueryParticleSystemEPK16b2ParticleSystem($this,$system) {
 $this = $this|0;
 $system = $system|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZZN16b2ParticleSystem14SolveCollisionERK10b2TimeStepEN22SolveCollisionCallback24ReportFixtureAndParticleEP9b2Fixtureii($this,$fixture,$childIndex,$a) {
 $this = $this|0;
 $fixture = $fixture|0;
 $childIndex = $childIndex|0;
 $a = $a|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0.0, $12 = 0, $120 = 0.0, $121 = 0.0, $122 = 0, $123 = 0.0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0.0, $139 = 0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0.0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $ap = 0, $av = 0, $f = 0, $input = 0, $n = 0, $output = 0, $p = 0, $p1 = 0, $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 192|0;
 $ap = sp + 104|0;
 $av = sp + 96|0;
 $output = sp + 80|0;
 $input = sp + 56|0;
 $p1 = sp + 48|0;
 $0 = sp + 40|0;
 $1 = sp + 32|0;
 $2 = sp + 24|0;
 $3 = sp + 16|0;
 $4 = sp + 176|0;
 $n = sp + 8|0;
 $p = sp + 168|0;
 $5 = sp + 160|0;
 $6 = sp + 152|0;
 $7 = sp + 144|0;
 $8 = sp + 136|0;
 $v = sp;
 $9 = sp + 128|0;
 $f = sp + 120|0;
 $10 = sp + 112|0;
 $11 = (__ZN9b2Fixture7GetBodyEv($fixture)|0);
 $12 = (($this) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) + 96|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = (($15) + ($a<<3)|0);
 $17 = $16;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = (($17) + 4)|0;
 $21 = $20;
 $22 = HEAP32[$21>>2]|0;
 $23 = $ap;
 $24 = $23;
 HEAP32[$24>>2] = $19;
 $25 = (($23) + 4)|0;
 $26 = $25;
 HEAP32[$26>>2] = $22;
 $27 = HEAP32[$12>>2]|0;
 $28 = (($27) + 104|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = (($29) + ($a<<3)|0);
 $31 = $30;
 $32 = $31;
 $33 = HEAP32[$32>>2]|0;
 $34 = (($31) + 4)|0;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = $av;
 $38 = $37;
 HEAP32[$38>>2] = $33;
 $39 = (($37) + 4)|0;
 $40 = $39;
 HEAP32[$40>>2] = $36;
 $41 = HEAP32[$12>>2]|0;
 $42 = (($41) + 24|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0);
 if ($44) {
  $45 = (($11) + 28|0);
  __Z6b2MulTRK11b2TransformRK6b2Vec2($p1,$45,$ap);
  $46 = (__ZN9b2Fixture8GetShapeEv($fixture)|0);
  $47 = (__ZNK7b2Shape7GetTypeEv($46)|0);
  $48 = ($47|0)==(0);
  if ($48) {
   $49 = (__ZNK6b2Body14GetLocalCenterEv($11)|0);
   __ZN6b2Vec2mIERKS_($p1,$49);
   $50 = (($11) + 36|0);
   __Z5b2MulRK5b2RotRK6b2Vec2($0,$50,$p1);
   $51 = $0;
   $52 = $51;
   $53 = HEAP32[$52>>2]|0;
   $54 = (($51) + 4)|0;
   $55 = $54;
   $56 = HEAP32[$55>>2]|0;
   $57 = $p1;
   $58 = $57;
   HEAP32[$58>>2] = $53;
   $59 = (($57) + 4)|0;
   $60 = $59;
   HEAP32[$60>>2] = $56;
   $61 = (($11) + 20|0);
   __Z6b2MulTRK5b2RotRK6b2Vec2($1,$61,$p1);
   $62 = $1;
   $63 = $62;
   $64 = HEAP32[$63>>2]|0;
   $65 = (($62) + 4)|0;
   $66 = $65;
   $67 = HEAP32[$66>>2]|0;
   $68 = $p1;
   $69 = $68;
   HEAP32[$69>>2] = $64;
   $70 = (($68) + 4)|0;
   $71 = $70;
   HEAP32[$71>>2] = $67;
   __ZN6b2Vec2pLERKS_($p1,$49);
  }
  $72 = (($11) + 12|0);
  __Z5b2MulRK11b2TransformRK6b2Vec2($2,$72,$p1);
  $73 = $2;
  $74 = $73;
  $75 = HEAP32[$74>>2]|0;
  $76 = (($73) + 4)|0;
  $77 = $76;
  $78 = HEAP32[$77>>2]|0;
  $79 = $input;
  $80 = $79;
  HEAP32[$80>>2] = $75;
  $81 = (($79) + 4)|0;
  $82 = $81;
  HEAP32[$82>>2] = $78;
 } else {
  $83 = $ap;
  $84 = $83;
  $85 = HEAP32[$84>>2]|0;
  $86 = (($83) + 4)|0;
  $87 = $86;
  $88 = HEAP32[$87>>2]|0;
  $89 = $input;
  $90 = $89;
  HEAP32[$90>>2] = $85;
  $91 = (($89) + 4)|0;
  $92 = $91;
  HEAP32[$92>>2] = $88;
 }
 $93 = (($input) + 8|0);
 $94 = (($this) + 8|0);
 $95 = +HEAPF32[$94>>2];
 __ZmlfRK6b2Vec2($4,$95,$av);
 __ZplRK6b2Vec2S1_($3,$ap,$4);
 $96 = $3;
 $97 = $96;
 $98 = HEAP32[$97>>2]|0;
 $99 = (($96) + 4)|0;
 $100 = $99;
 $101 = HEAP32[$100>>2]|0;
 $102 = $93;
 $103 = $102;
 HEAP32[$103>>2] = $98;
 $104 = (($102) + 4)|0;
 $105 = $104;
 HEAP32[$105>>2] = $101;
 $106 = (($input) + 16|0);
 HEAPF32[$106>>2] = 1.0;
 $107 = (__ZNK9b2Fixture7RayCastEP15b2RayCastOutputRK14b2RayCastInputi($fixture,$output,$input,$childIndex)|0);
 if (!($107)) {
  STACKTOP = sp;return;
 }
 $108 = $output;
 $109 = $108;
 $110 = HEAP32[$109>>2]|0;
 $111 = (($108) + 4)|0;
 $112 = $111;
 $113 = HEAP32[$112>>2]|0;
 $114 = $n;
 $115 = $114;
 HEAP32[$115>>2] = $110;
 $116 = (($114) + 4)|0;
 $117 = $116;
 HEAP32[$117>>2] = $113;
 $118 = (($output) + 8|0);
 $119 = +HEAPF32[$118>>2];
 $120 = 1.0 - $119;
 __ZmlfRK6b2Vec2($6,$120,$input);
 $121 = +HEAPF32[$118>>2];
 __ZmlfRK6b2Vec2($7,$121,$93);
 __ZplRK6b2Vec2S1_($5,$6,$7);
 __ZmlfRK6b2Vec2($8,0.004999999888241291,$n);
 __ZplRK6b2Vec2S1_($p,$5,$8);
 $122 = (($this) + 12|0);
 $123 = +HEAPF32[$122>>2];
 __ZmiRK6b2Vec2S1_($9,$p,$ap);
 __ZmlfRK6b2Vec2($v,$123,$9);
 $124 = HEAP32[$12>>2]|0;
 $125 = (($124) + 104|0);
 $126 = HEAP32[$125>>2]|0;
 $127 = (($126) + ($a<<3)|0);
 $128 = $v;
 $129 = $128;
 $130 = HEAP32[$129>>2]|0;
 $131 = (($128) + 4)|0;
 $132 = $131;
 $133 = HEAP32[$132>>2]|0;
 $134 = $127;
 $135 = $134;
 HEAP32[$135>>2] = $130;
 $136 = (($134) + 4)|0;
 $137 = $136;
 HEAP32[$137>>2] = $133;
 $138 = +HEAPF32[$122>>2];
 $139 = HEAP32[$12>>2]|0;
 $140 = (+__ZNK16b2ParticleSystem15GetParticleMassEv($139));
 $141 = $138 * $140;
 __ZmiRK6b2Vec2S1_($10,$av,$v);
 __ZmlfRK6b2Vec2($f,$141,$10);
 $142 = HEAP32[$12>>2]|0;
 __ZN16b2ParticleSystem18ParticleApplyForceEiRK6b2Vec2($142,$a,$f);
 STACKTOP = sp;return;
}
function __ZN30b2FixtureParticleQueryCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZZN16b2ParticleSystem18UpdateBodyContactsEvEN26UpdateBodyContactsCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZZN16b2ParticleSystem18UpdateBodyContactsEvEN26UpdateBodyContactsCallback24ReportFixtureAndParticleEP9b2Fixtureii($this,$fixture,$childIndex,$a) {
 $this = $this|0;
 $fixture = $fixture|0;
 $childIndex = $childIndex|0;
 $a = $a|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0.0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0.0, $66 = 0, $67 = 0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0.0, $85 = 0, $86 = 0.0, $87 = 0, $9 = 0, $ap = 0, $bp = 0, $d = 0, $n = 0, $rp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $ap = sp + 16|0;
 $d = sp + 40|0;
 $n = sp + 32|0;
 $bp = sp + 8|0;
 $rp = sp + 24|0;
 $0 = sp;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 96|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($a<<3)|0);
 $6 = $5;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $ap;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 __ZNK9b2Fixture15ComputeDistanceERK6b2Vec2PfPS0_i($fixture,$ap,$d,$n,$childIndex);
 $16 = +HEAPF32[$d>>2];
 $17 = HEAP32[$1>>2]|0;
 $18 = (($17) + 32|0);
 $19 = +HEAPF32[$18>>2];
 $20 = $16 < $19;
 if (!($20)) {
  STACKTOP = sp;return;
 }
 $21 = (__ZZN16b2ParticleSystem18UpdateBodyContactsEvEN26UpdateBodyContactsCallback13ShouldCollideEP9b2Fixturei($this,$fixture,$a)|0);
 if (!($21)) {
  STACKTOP = sp;return;
 }
 $22 = (__ZN9b2Fixture7GetBodyEv($fixture)|0);
 $23 = (__ZNK6b2Body14GetWorldCenterEv($22)|0);
 $24 = $23;
 $25 = $24;
 $26 = HEAP32[$25>>2]|0;
 $27 = (($24) + 4)|0;
 $28 = $27;
 $29 = HEAP32[$28>>2]|0;
 $30 = $bp;
 $31 = $30;
 HEAP32[$31>>2] = $26;
 $32 = (($30) + 4)|0;
 $33 = $32;
 HEAP32[$33>>2] = $29;
 $34 = (+__ZNK6b2Body7GetMassEv($22));
 $35 = (+__ZNK6b2Body10GetInertiaEv($22));
 $36 = (__ZNK6b2Body14GetLocalCenterEv($22)|0);
 $37 = (+__ZNK6b2Vec213LengthSquaredEv($36));
 $38 = $34 * $37;
 $39 = $35 - $38;
 $40 = $34 > 0.0;
 if ($40) {
  $41 = 1.0 / $34;
  $55 = $41;
 } else {
  $55 = 0.0;
 }
 $42 = $39 > 0.0;
 if ($42) {
  $43 = 1.0 / $39;
  $57 = $43;
 } else {
  $57 = 0.0;
 }
 $44 = HEAP32[$1>>2]|0;
 $45 = (($44) + 88|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($46) + ($a<<2)|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = $48 & 4;
 $50 = ($49|0)==(0);
 if ($50) {
  $51 = (+__ZNK16b2ParticleSystem18GetParticleInvMassEv($44));
  $54 = $51;
 } else {
  $54 = 0.0;
 }
 __ZmiRK6b2Vec2S1_($rp,$ap,$bp);
 $52 = (+__Z7b2CrossRK6b2Vec2S1_($rp,$n));
 $53 = $55 + $54;
 $56 = $57 * $52;
 $58 = $52 * $56;
 $59 = $53 + $58;
 $60 = HEAP32[$1>>2]|0;
 $61 = (($60) + 232|0);
 $62 = (__ZN16b2GrowableBufferI21b2ParticleBodyContactE6AppendEv($61)|0);
 HEAP32[$62>>2] = $a;
 $63 = (($62) + 4|0);
 HEAP32[$63>>2] = $22;
 $64 = (($62) + 8|0);
 HEAP32[$64>>2] = $fixture;
 $65 = +HEAPF32[$d>>2];
 $66 = HEAP32[$1>>2]|0;
 $67 = (($66) + 36|0);
 $68 = +HEAPF32[$67>>2];
 $69 = $65 * $68;
 $70 = 1.0 - $69;
 $71 = (($62) + 12|0);
 HEAPF32[$71>>2] = $70;
 $72 = (($62) + 16|0);
 __ZNK6b2Vec2ngEv($0,$n);
 $73 = $0;
 $74 = $73;
 $75 = HEAP32[$74>>2]|0;
 $76 = (($73) + 4)|0;
 $77 = $76;
 $78 = HEAP32[$77>>2]|0;
 $79 = $72;
 $80 = $79;
 HEAP32[$80>>2] = $75;
 $81 = (($79) + 4)|0;
 $82 = $81;
 HEAP32[$82>>2] = $78;
 $83 = $59 > 0.0;
 if ($83) {
  $84 = 1.0 / $59;
  $86 = $84;
 } else {
  $86 = 0.0;
 }
 $85 = (($62) + 24|0);
 HEAPF32[$85>>2] = $86;
 $87 = HEAP32[$1>>2]|0;
 __ZN16b2ParticleSystem19DetectStuckParticleEi($87,$a);
 STACKTOP = sp;return;
}
function __ZN16b2VoronoiDiagram12NodeCallbackD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZZN16b2ParticleSystem20UpdatePairsAndTriadsEiiRKNS_16ConnectionFilterEEN20UpdateTriadsCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZZN16b2ParticleSystem20UpdatePairsAndTriadsEiiRKNS_16ConnectionFilterEEN20UpdateTriadsCallbackclEiii($this,$a,$b,$c) {
 $this = $this|0;
 $a = $a|0;
 $b = $b|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0.0, $103 = 0.0, $104 = 0, $105 = 0.0, $106 = 0.0, $107 = 0, $108 = 0.0, $109 = 0.0, $11 = 0, $110 = 0, $111 = 0.0, $112 = 0.0, $113 = 0.0, $114 = 0.0, $115 = 0.0;
 var $116 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0, $37 = 0.0, $38 = 0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0.0, $57 = 0, $58 = 0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0, $64 = 0, $65 = 0.0;
 var $66 = 0.0, $67 = 0.0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $dab = 0, $dbc = 0, $dca = 0;
 var $midPoint = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0;
 $dab = sp + 64|0;
 $dbc = sp + 56|0;
 $dca = sp + 48|0;
 $midPoint = sp + 40|0;
 $0 = sp + 32|0;
 $1 = sp + 24|0;
 $2 = sp + 16|0;
 $3 = sp + 8|0;
 $4 = sp;
 $5 = (($this) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 88|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + ($a<<2)|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + ($b<<2)|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($8) + ($c<<2)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $12 | $10;
 $16 = $15 | $14;
 $17 = $16 & 16;
 $18 = ($17|0)==(0);
 if ($18) {
  STACKTOP = sp;return;
 }
 $19 = (($this) + 8|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + 16|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (FUNCTION_TABLE_iiiii[$23 & 7]($20,$a,$b,$c)|0);
 if (!($24)) {
  STACKTOP = sp;return;
 }
 $25 = HEAP32[$5>>2]|0;
 $26 = (($25) + 96|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (($27) + ($a<<3)|0);
 $29 = (($27) + ($b<<3)|0);
 $30 = (($27) + ($c<<3)|0);
 __ZmiRK6b2Vec2S1_($dab,$28,$29);
 __ZmiRK6b2Vec2S1_($dbc,$29,$30);
 __ZmiRK6b2Vec2S1_($dca,$30,$28);
 $31 = HEAP32[$5>>2]|0;
 $32 = (($31) + 40|0);
 $33 = +HEAPF32[$32>>2];
 $34 = $33 * 4.0;
 $35 = (+__Z5b2DotRK6b2Vec2S1_($dab,$dab));
 $36 = $35 > $34;
 if ($36) {
  STACKTOP = sp;return;
 }
 $37 = (+__Z5b2DotRK6b2Vec2S1_($dbc,$dbc));
 $38 = $37 > $34;
 if ($38) {
  STACKTOP = sp;return;
 }
 $39 = (+__Z5b2DotRK6b2Vec2S1_($dca,$dca));
 $40 = $39 > $34;
 if ($40) {
  STACKTOP = sp;return;
 }
 $41 = (($31) + 144|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($42) + ($a<<2)|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($42) + ($b<<2)|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = (($42) + ($c<<2)|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = (($31) + 264|0);
 $50 = (__ZN16b2GrowableBufferI15b2ParticleTriadE6AppendEv($49)|0);
 HEAP32[$50>>2] = $a;
 $51 = (($50) + 4|0);
 HEAP32[$51>>2] = $b;
 $52 = (($50) + 8|0);
 HEAP32[$52>>2] = $c;
 $53 = (($50) + 12|0);
 HEAP32[$53>>2] = $16;
 $54 = ($44|0)==(0|0);
 if ($54) {
  $60 = 1.0;
 } else {
  $55 = (($44) + 16|0);
  $56 = +HEAPF32[$55>>2];
  $60 = $56;
 }
 $57 = ($46|0)==(0|0);
 if ($57) {
  $61 = 1.0;
 } else {
  $58 = (($46) + 16|0);
  $59 = +HEAPF32[$58>>2];
  $61 = $59;
 }
 $62 = (+__Z5b2MinIfET_S0_S0_($60,$61));
 $63 = ($48|0)==(0|0);
 if ($63) {
  $66 = 1.0;
 } else {
  $64 = (($48) + 16|0);
  $65 = +HEAPF32[$64>>2];
  $66 = $65;
 }
 $67 = (+__Z5b2MinIfET_S0_S0_($62,$66));
 $68 = (($50) + 16|0);
 HEAPF32[$68>>2] = $67;
 __ZplRK6b2Vec2S1_($1,$28,$29);
 __ZplRK6b2Vec2S1_($0,$1,$30);
 __ZmlfRK6b2Vec2($midPoint,0.3333333432674408,$0);
 $69 = (($50) + 20|0);
 __ZmiRK6b2Vec2S1_($2,$28,$midPoint);
 $70 = $2;
 $71 = $70;
 $72 = HEAP32[$71>>2]|0;
 $73 = (($70) + 4)|0;
 $74 = $73;
 $75 = HEAP32[$74>>2]|0;
 $76 = $69;
 $77 = $76;
 HEAP32[$77>>2] = $72;
 $78 = (($76) + 4)|0;
 $79 = $78;
 HEAP32[$79>>2] = $75;
 $80 = (($50) + 28|0);
 __ZmiRK6b2Vec2S1_($3,$29,$midPoint);
 $81 = $3;
 $82 = $81;
 $83 = HEAP32[$82>>2]|0;
 $84 = (($81) + 4)|0;
 $85 = $84;
 $86 = HEAP32[$85>>2]|0;
 $87 = $80;
 $88 = $87;
 HEAP32[$88>>2] = $83;
 $89 = (($87) + 4)|0;
 $90 = $89;
 HEAP32[$90>>2] = $86;
 $91 = (($50) + 36|0);
 __ZmiRK6b2Vec2S1_($4,$30,$midPoint);
 $92 = $4;
 $93 = $92;
 $94 = HEAP32[$93>>2]|0;
 $95 = (($92) + 4)|0;
 $96 = $95;
 $97 = HEAP32[$96>>2]|0;
 $98 = $91;
 $99 = $98;
 HEAP32[$99>>2] = $94;
 $100 = (($98) + 4)|0;
 $101 = $100;
 HEAP32[$101>>2] = $97;
 $102 = (+__Z5b2DotRK6b2Vec2S1_($dca,$dab));
 $103 = -$102;
 $104 = (($50) + 44|0);
 HEAPF32[$104>>2] = $103;
 $105 = (+__Z5b2DotRK6b2Vec2S1_($dab,$dbc));
 $106 = -$105;
 $107 = (($50) + 48|0);
 HEAPF32[$107>>2] = $106;
 $108 = (+__Z5b2DotRK6b2Vec2S1_($dbc,$dca));
 $109 = -$108;
 $110 = (($50) + 52|0);
 HEAPF32[$110>>2] = $109;
 $111 = (+__Z7b2CrossRK6b2Vec2S1_($28,$29));
 $112 = (+__Z7b2CrossRK6b2Vec2S1_($29,$30));
 $113 = $111 + $112;
 $114 = (+__Z7b2CrossRK6b2Vec2S1_($30,$28));
 $115 = $113 + $114;
 $116 = (($50) + 56|0);
 HEAPF32[$116>>2] = $115;
 STACKTOP = sp;return;
}
function __ZN16b2VoronoiDiagram12NodeCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem16ConnectionFilterD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZZN16b2ParticleSystem41UpdatePairsAndTriadsWithReactiveParticlesEvEN14ReactiveFilterD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZZN16b2ParticleSystem41UpdatePairsAndTriadsWithReactiveParticlesEvENK14ReactiveFilter11IsNecessaryEi($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($index<<2)|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 & 4096;
 $5 = ($4|0)!=(0);
 STACKTOP = sp;return ($5|0);
}
function __ZNK16b2ParticleSystem16ConnectionFilter16ShouldCreatePairEii($this,$a,$b) {
 $this = $this|0;
 $a = $a|0;
 $b = $b|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZNK16b2ParticleSystem16ConnectionFilter17ShouldCreateTriadEiii($this,$a,$b,$c) {
 $this = $this|0;
 $a = $a|0;
 $b = $b|0;
 $c = $c|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZN16b2ParticleSystem16ConnectionFilterD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK16b2ParticleSystem16ConnectionFilter11IsNecessaryEi($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZZN16b2ParticleSystem18JoinParticleGroupsEP15b2ParticleGroupS1_EN24JoinParticleGroupsFilterD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZZN16b2ParticleSystem18JoinParticleGroupsEP15b2ParticleGroupS1_ENK24JoinParticleGroupsFilter16ShouldCreatePairEii($this,$a,$b) {
 $this = $this|0;
 $a = $a|0;
 $b = $b|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)<=($a|0);
 $3 = ($1|0)>($b|0);
 $or$cond = $2 | $3;
 if ($or$cond) {
  $$ = $3 & $2;
  STACKTOP = sp;return ($$|0);
 } else {
  STACKTOP = sp;return 1;
 }
 return (0)|0;
}
function __ZZN16b2ParticleSystem18JoinParticleGroupsEP15b2ParticleGroupS1_ENK24JoinParticleGroupsFilter17ShouldCreateTriadEiii($this,$a,$b,$c) {
 $this = $this|0;
 $a = $a|0;
 $b = $b|0;
 $c = $c|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $not$or$cond2 = 0, $or$cond = 0, $or$cond1 = 0, $or$cond2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>($a|0);
 $3 = ($1|0)>($b|0);
 $or$cond = $2 | $3;
 $4 = ($1|0)>($c|0);
 $or$cond1 = $or$cond | $4;
 if ($or$cond1) {
  $or$cond2 = $2 & $3;
  $5 = ($1|0)<=($c|0);
  $not$or$cond2 = $or$cond2 ^ 1;
  $$ = $5 | $not$or$cond2;
  STACKTOP = sp;return ($$|0);
 } else {
  STACKTOP = sp;return 0;
 }
 return (0)|0;
}
function __ZZN16b2ParticleSystem33CreateParticlesWithShapesForGroupEPKPK7b2ShapeiRK18b2ParticleGroupDefRK11b2TransformEN14CompositeShapeD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZZN16b2ParticleSystem33CreateParticlesWithShapesForGroupEPKPK7b2ShapeiRK18b2ParticleGroupDefRK11b2TransformENK14CompositeShape5CloneEP16b2BlockAllocator($this,$allocator) {
 $this = $this|0;
 $allocator = $allocator|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (0|0);
}
function __ZZN16b2ParticleSystem33CreateParticlesWithShapesForGroupEPKPK7b2ShapeiRK18b2ParticleGroupDefRK11b2TransformENK14CompositeShape13GetChildCountEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 1;
}
function __ZZN16b2ParticleSystem33CreateParticlesWithShapesForGroupEPKPK7b2ShapeiRK18b2ParticleGroupDefRK11b2TransformENK14CompositeShape9TestPointESA_RK6b2Vec2($this,$xf,$p) {
 $this = $this|0;
 $xf = $xf|0;
 $p = $p|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 12|0);
 $i$01 = 0;
 while(1) {
  $7 = HEAP32[$3>>2]|0;
  $8 = (($7) + ($i$01<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 16|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (FUNCTION_TABLE_iiii[$12 & 15]($9,$xf,$p)|0);
  $5 = (($i$01) + 1)|0;
  if ($13) {
   $$0 = 1;
   label = 5;
   break;
  }
  $4 = HEAP32[$0>>2]|0;
  $6 = ($5|0)<($4|0);
  if ($6) {
   $i$01 = $5;
  } else {
   $$0 = 0;
   label = 5;
   break;
  }
 }
 if ((label|0) == 5) {
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function __ZZN16b2ParticleSystem33CreateParticlesWithShapesForGroupEPKPK7b2ShapeiRK18b2ParticleGroupDefRK11b2TransformENK14CompositeShape15ComputeDistanceESA_RK6b2Vec2PfPSC_i($this,$xf,$p,$distance,$normal,$childIndex) {
 $this = $this|0;
 $xf = $xf|0;
 $p = $p|0;
 $distance = $distance|0;
 $normal = $normal|0;
 $childIndex = $childIndex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZZN16b2ParticleSystem33CreateParticlesWithShapesForGroupEPKPK7b2ShapeiRK18b2ParticleGroupDefRK11b2TransformENK14CompositeShape7RayCastEP15b2RayCastOutputRK14b2RayCastInputSA_i($this,$output,$input,$transform,$childIndex) {
 $this = $this|0;
 $output = $output|0;
 $input = $input|0;
 $transform = $transform|0;
 $childIndex = $childIndex|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZZN16b2ParticleSystem33CreateParticlesWithShapesForGroupEPKPK7b2ShapeiRK18b2ParticleGroupDefRK11b2TransformENK14CompositeShape11ComputeAABBEP6b2AABBSA_i($this,$aabb,$xf,$childIndex) {
 $this = $this|0;
 $aabb = $aabb|0;
 $xf = $xf|0;
 $childIndex = $childIndex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$02 = 0, $j$01 = 0, $subaabb = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $subaabb = sp;
 HEAPF32[$aabb>>2] = 3.4028234663852886E+38;
 $0 = (($aabb) + 4|0);
 HEAPF32[$0>>2] = 3.4028234663852886E+38;
 $1 = (($aabb) + 8|0);
 HEAPF32[$1>>2] = -3.4028234663852886E+38;
 $2 = (($aabb) + 12|0);
 HEAPF32[$2>>2] = -3.4028234663852886E+38;
 $3 = (($this) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)>(0);
 if (!($5)) {
  STACKTOP = sp;return;
 }
 $6 = (($this) + 12|0);
 $i$02 = 0;
 while(1) {
  $7 = HEAP32[$6>>2]|0;
  $8 = (($7) + ($i$02<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (FUNCTION_TABLE_ii[$12 & 15]($9)|0);
  $14 = ($13|0)>(0);
  if ($14) {
   $j$01 = 0;
   while(1) {
    $15 = HEAP32[$6>>2]|0;
    $16 = (($15) + ($i$02<<2)|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = HEAP32[$17>>2]|0;
    $19 = (($18) + 28|0);
    $20 = HEAP32[$19>>2]|0;
    FUNCTION_TABLE_viiii[$20 & 31]($17,$subaabb,$xf,$j$01);
    __ZN6b2AABB7CombineERKS_($aabb,$subaabb);
    $21 = (($j$01) + 1)|0;
    $exitcond = ($21|0)==($13|0);
    if ($exitcond) {
     break;
    } else {
     $j$01 = $21;
    }
   }
  }
  $22 = (($i$02) + 1)|0;
  $23 = HEAP32[$3>>2]|0;
  $24 = ($22|0)<($23|0);
  if ($24) {
   $i$02 = $22;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZZN16b2ParticleSystem33CreateParticlesWithShapesForGroupEPKPK7b2ShapeiRK18b2ParticleGroupDefRK11b2TransformENK14CompositeShape11ComputeMassEP10b2MassDataf($this,$massData,$density) {
 $this = $this|0;
 $massData = $massData|0;
 $density = +$density;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZZN16b2ParticleSystem23DestroyParticlesInShapeERK7b2ShapeRK11b2TransformbEN31DestroyParticlesInShapeCallbackD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZZN16b2ParticleSystem23DestroyParticlesInShapeERK7b2ShapeRK11b2TransformbEN31DestroyParticlesInShapeCallback13ReportFixtureEP9b2Fixture($this,$fixture) {
 $this = $this|0;
 $fixture = $fixture|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return 0;
}
function __ZZN16b2ParticleSystem23DestroyParticlesInShapeERK7b2ShapeRK11b2TransformbEN31DestroyParticlesInShapeCallback14ReportParticleEPKS_i($this,$particleSystem,$index) {
 $this = $this|0;
 $particleSystem = $particleSystem|0;
 $index = $index|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($particleSystem|0);
 if (!($2)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($this) + 12|0);
 $9 = (($1) + 96|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (($10) + ($index<<3)|0);
 $12 = (FUNCTION_TABLE_iiii[$7 & 15]($4,$8,$11)|0);
 if (!($12)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = HEAP32[$0>>2]|0;
 $14 = (($this) + 28|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = ($15<<24>>24)!=(0);
 __ZN16b2ParticleSystem15DestroyParticleEib($13,$index,$16);
 $17 = (($this) + 32|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = (($18) + 1)|0;
 HEAP32[$17>>2] = $19;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN15b2SlabAllocatorI16b2ParticleHandleEC2Ej($this,$itemsPerSlab) {
 $this = $this|0;
 $itemsPerSlab = $itemsPerSlab|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN23b2TrackedBlockAllocatorC2Ev($this);
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = $itemsPerSlab;
 $1 = (($this) + 12|0);
 __ZN15b2TypedFreeListI16b2ParticleHandleEC2Ev($1);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem21UserOverridableBufferIP16b2ParticleHandleEC2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem21UserOverridableBufferIjEC2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem21UserOverridableBufferI6b2Vec2EC2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem21UserOverridableBufferI15b2ParticleColorEC2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem21UserOverridableBufferIPvEC2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem21UserOverridableBufferIiEC2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferIiEC2ER16b2BlockAllocator($this,$allocator) {
 $this = $this|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = $allocator;
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEEC2ER16b2BlockAllocator($this,$allocator) {
 $this = $this|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = $allocator;
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferI17b2ParticleContactEC2ER16b2BlockAllocator($this,$allocator) {
 $this = $this|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = $allocator;
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferI21b2ParticleBodyContactEC2ER16b2BlockAllocator($this,$allocator) {
 $this = $this|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = $allocator;
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferI14b2ParticlePairEC2ER16b2BlockAllocator($this,$allocator) {
 $this = $this|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = $allocator;
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferI15b2ParticleTriadEC2ER16b2BlockAllocator($this,$allocator) {
 $this = $this|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = $allocator;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem21SetStrictContactCheckEb($this,$enabled) {
 $this = $this|0;
 $enabled = $enabled|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 316|0);
 $1 = $enabled&1;
 HEAP8[$0>>0] = $1;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem15SetGravityScaleEf($this,$gravityScale) {
 $this = $this|0;
 $gravityScale = +$gravityScale;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 324|0);
 HEAPF32[$0>>2] = $gravityScale;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem19SetMaxParticleCountEi($this,$count) {
 $this = $this|0;
 $count = $count|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 332|0);
 HEAP32[$0>>2] = $count;
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferI15b2ParticleTriadED2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16b2GrowableBufferI15b2ParticleTriadE4FreeEv($this);
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferI14b2ParticlePairED2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16b2GrowableBufferI14b2ParticlePairE4FreeEv($this);
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferI21b2ParticleBodyContactED2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16b2GrowableBufferI21b2ParticleBodyContactE4FreeEv($this);
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferI17b2ParticleContactED2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16b2GrowableBufferI17b2ParticleContactE4FreeEv($this);
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEED2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEE4FreeEv($this);
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferIiED2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16b2GrowableBufferIiE4FreeEv($this);
 STACKTOP = sp;return;
}
function __ZN15b2SlabAllocatorI16b2ParticleHandleED2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN15b2SlabAllocatorI16b2ParticleHandleE12FreeAllSlabsEv($this);
 $0 = (($this) + 12|0);
 __ZN15b2TypedFreeListI16b2ParticleHandleED2Ev($0);
 __ZN23b2TrackedBlockAllocatorD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem25FreeUserOverridableBufferIP16b2ParticleHandleEEvPNS_21UserOverridableBufferIT_EE($this,$b) {
 $this = $this|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($b) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN16b2ParticleSystem10FreeBufferIP16b2ParticleHandleEEvPPT_i($this,$b,$4);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem25FreeUserOverridableBufferIjEEvPNS_21UserOverridableBufferIT_EE($this,$b) {
 $this = $this|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($b) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN16b2ParticleSystem10FreeBufferIjEEvPPT_i($this,$b,$4);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem25FreeUserOverridableBufferIiEEvPNS_21UserOverridableBufferIT_EE($this,$b) {
 $this = $this|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($b) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN16b2ParticleSystem10FreeBufferIiEEvPPT_i($this,$b,$4);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem25FreeUserOverridableBufferI6b2Vec2EEvPNS_21UserOverridableBufferIT_EE($this,$b) {
 $this = $this|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($b) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN16b2ParticleSystem10FreeBufferI6b2Vec2EEvPPT_i($this,$b,$4);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem25FreeUserOverridableBufferI15b2ParticleColorEEvPNS_21UserOverridableBufferIT_EE($this,$b) {
 $this = $this|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($b) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN16b2ParticleSystem10FreeBufferI15b2ParticleColorEEvPPT_i($this,$b,$4);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem25FreeUserOverridableBufferIPvEEvPNS_21UserOverridableBufferIT_EE($this,$b) {
 $this = $this|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($b) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 48|0);
 $4 = HEAP32[$3>>2]|0;
 __ZN16b2ParticleSystem10FreeBufferIPvEEvPPT_i($this,$b,$4);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem10FreeBufferI6b2Vec2EEvPPT_i($this,$b,$capacity) {
 $this = $this|0;
 $b = $b|0;
 $capacity = $capacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$b>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 400|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $capacity << 3;
 __ZN16b2BlockAllocator4FreeEPvi($3,$0,$4);
 HEAP32[$b>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem10FreeBufferIfEEvPPT_i($this,$b,$capacity) {
 $this = $this|0;
 $b = $b|0;
 $capacity = $capacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$b>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 400|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $capacity << 2;
 __ZN16b2BlockAllocator4FreeEPvi($3,$0,$4);
 HEAP32[$b>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem10FreeBufferIP15b2ParticleGroupEEvPPT_i($this,$b,$capacity) {
 $this = $this|0;
 $b = $b|0;
 $capacity = $capacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$b>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 400|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $capacity << 2;
 __ZN16b2BlockAllocator4FreeEPvi($3,$0,$4);
 HEAP32[$b>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem16ReallocateBufferIP16b2ParticleHandleEEPT_PNS_21UserOverridableBufferIS3_EEiib($this,$buffer,$oldCapacity,$newCapacity,$deferred) {
 $this = $this|0;
 $buffer = $buffer|0;
 $oldCapacity = $oldCapacity|0;
 $newCapacity = $newCapacity|0;
 $deferred = $deferred|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$buffer>>2]|0;
 $1 = (($buffer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN16b2ParticleSystem16ReallocateBufferIP16b2ParticleHandleEEPT_S4_iiib($this,$0,$2,$oldCapacity,$newCapacity,$deferred)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN15b2SlabAllocatorI16b2ParticleHandleE15SetItemsPerSlabEj($this,$itemsPerSlab) {
 $this = $this|0;
 $itemsPerSlab = $itemsPerSlab|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = $itemsPerSlab;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem13RequestBufferI15b2ParticleColorEEPT_S3_($this,$buffer) {
 $this = $this|0;
 $buffer = $buffer|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($buffer|0)==(0|0);
 if (!($0)) {
  $$0 = $buffer;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 48|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  __ZN16b2ParticleSystem34ReallocateInternalAllocatedBuffersEi($this,256);
 }
 $4 = (($this) + 400|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = $6 << 2;
 $8 = (__ZN16b2BlockAllocator8AllocateEi($5,$7)|0);
 $9 = HEAP32[$1>>2]|0;
 $10 = $9 << 2;
 _memset(($8|0),0,($10|0))|0;
 $$0 = $8;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16b2ParticleSystem13RequestBufferIPvEEPT_S3_($this,$buffer) {
 $this = $this|0;
 $buffer = $buffer|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($buffer|0)==(0|0);
 if (!($0)) {
  $$0 = $buffer;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 48|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  __ZN16b2ParticleSystem34ReallocateInternalAllocatedBuffersEi($this,256);
 }
 $4 = (($this) + 400|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = $6 << 2;
 $8 = (__ZN16b2BlockAllocator8AllocateEi($5,$7)|0);
 $9 = HEAP32[$1>>2]|0;
 $10 = $9 << 2;
 _memset(($8|0),0,($10|0))|0;
 $$0 = $8;
 STACKTOP = sp;return ($$0|0);
}
function __ZL13LimitCapacityii($capacity,$maxCount) {
 $capacity = $capacity|0;
 $maxCount = $maxCount|0;
 var $0 = 0, $1 = 0, $2 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($maxCount|0)!=(0);
 $1 = ($capacity|0)>($maxCount|0);
 $or$cond = $0 & $1;
 $2 = $or$cond ? $maxCount : $capacity;
 STACKTOP = sp;return ($2|0);
}
function __ZN16b2ParticleSystem16ReallocateBufferIjEEPT_PNS_21UserOverridableBufferIS1_EEiib($this,$buffer,$oldCapacity,$newCapacity,$deferred) {
 $this = $this|0;
 $buffer = $buffer|0;
 $oldCapacity = $oldCapacity|0;
 $newCapacity = $newCapacity|0;
 $deferred = $deferred|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$buffer>>2]|0;
 $1 = (($buffer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN16b2ParticleSystem16ReallocateBufferIjEEPT_S2_iiib($this,$0,$2,$oldCapacity,$newCapacity,$deferred)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN16b2ParticleSystem16ReallocateBufferIiEEPT_PNS_21UserOverridableBufferIS1_EEiib($this,$buffer,$oldCapacity,$newCapacity,$deferred) {
 $this = $this|0;
 $buffer = $buffer|0;
 $oldCapacity = $oldCapacity|0;
 $newCapacity = $newCapacity|0;
 $deferred = $deferred|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$buffer>>2]|0;
 $1 = (($buffer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN16b2ParticleSystem16ReallocateBufferIiEEPT_S2_iiib($this,$0,$2,$oldCapacity,$newCapacity,$deferred)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN16b2ParticleSystem16ReallocateBufferI6b2Vec2EEPT_PNS_21UserOverridableBufferIS2_EEiib($this,$buffer,$oldCapacity,$newCapacity,$deferred) {
 $this = $this|0;
 $buffer = $buffer|0;
 $oldCapacity = $oldCapacity|0;
 $newCapacity = $newCapacity|0;
 $deferred = $deferred|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$buffer>>2]|0;
 $1 = (($buffer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN16b2ParticleSystem16ReallocateBufferI6b2Vec2EEPT_S3_iiib($this,$0,$2,$oldCapacity,$newCapacity,$deferred)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN16b2ParticleSystem16ReallocateBufferI6b2Vec2EEPT_S3_iiib($this,$buffer,$userSuppliedCapacity,$oldCapacity,$newCapacity,$deferred) {
 $this = $this|0;
 $buffer = $buffer|0;
 $userSuppliedCapacity = $userSuppliedCapacity|0;
 $oldCapacity = $oldCapacity|0;
 $newCapacity = $newCapacity|0;
 $deferred = $deferred|0;
 var $$0 = 0, $$not4 = 0, $0 = 0, $1 = 0, $or$cond$not = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$not4 = ($buffer|0)==(0|0);
 $or$cond$not = $$not4 & $deferred;
 $0 = ($userSuppliedCapacity|0)!=(0);
 $or$cond3 = $or$cond$not | $0;
 if ($or$cond3) {
  $$0 = $buffer;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (__ZN16b2ParticleSystem16ReallocateBufferI6b2Vec2EEPT_S3_ii($this,$buffer,$oldCapacity,$newCapacity)|0);
 $$0 = $1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16b2ParticleSystem16ReallocateBufferIfEEPT_S2_iiib($this,$buffer,$userSuppliedCapacity,$oldCapacity,$newCapacity,$deferred) {
 $this = $this|0;
 $buffer = $buffer|0;
 $userSuppliedCapacity = $userSuppliedCapacity|0;
 $oldCapacity = $oldCapacity|0;
 $newCapacity = $newCapacity|0;
 $deferred = $deferred|0;
 var $$0 = 0, $$not4 = 0, $0 = 0, $1 = 0, $or$cond$not = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$not4 = ($buffer|0)==(0|0);
 $or$cond$not = $$not4 & $deferred;
 $0 = ($userSuppliedCapacity|0)!=(0);
 $or$cond3 = $or$cond$not | $0;
 if ($or$cond3) {
  $$0 = $buffer;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (__ZN16b2ParticleSystem16ReallocateBufferIfEEPT_S2_ii($this,$buffer,$oldCapacity,$newCapacity)|0);
 $$0 = $1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16b2ParticleSystem16ReallocateBufferI15b2ParticleColorEEPT_PNS_21UserOverridableBufferIS2_EEiib($this,$buffer,$oldCapacity,$newCapacity,$deferred) {
 $this = $this|0;
 $buffer = $buffer|0;
 $oldCapacity = $oldCapacity|0;
 $newCapacity = $newCapacity|0;
 $deferred = $deferred|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$buffer>>2]|0;
 $1 = (($buffer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN16b2ParticleSystem16ReallocateBufferI15b2ParticleColorEEPT_S3_iiib($this,$0,$2,$oldCapacity,$newCapacity,$deferred)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN16b2ParticleSystem16ReallocateBufferIP15b2ParticleGroupEEPT_S4_iiib($this,$buffer,$userSuppliedCapacity,$oldCapacity,$newCapacity,$deferred) {
 $this = $this|0;
 $buffer = $buffer|0;
 $userSuppliedCapacity = $userSuppliedCapacity|0;
 $oldCapacity = $oldCapacity|0;
 $newCapacity = $newCapacity|0;
 $deferred = $deferred|0;
 var $$0 = 0, $$not4 = 0, $0 = 0, $1 = 0, $or$cond$not = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$not4 = ($buffer|0)==(0|0);
 $or$cond$not = $$not4 & $deferred;
 $0 = ($userSuppliedCapacity|0)!=(0);
 $or$cond3 = $or$cond$not | $0;
 if ($or$cond3) {
  $$0 = $buffer;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (__ZN16b2ParticleSystem16ReallocateBufferIP15b2ParticleGroupEEPT_S4_ii($this,$buffer,$oldCapacity,$newCapacity)|0);
 $$0 = $1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16b2ParticleSystem16ReallocateBufferIPvEEPT_PNS_21UserOverridableBufferIS2_EEiib($this,$buffer,$oldCapacity,$newCapacity,$deferred) {
 $this = $this|0;
 $buffer = $buffer|0;
 $oldCapacity = $oldCapacity|0;
 $newCapacity = $newCapacity|0;
 $deferred = $deferred|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$buffer>>2]|0;
 $1 = (($buffer) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (__ZN16b2ParticleSystem16ReallocateBufferIPvEEPT_S3_iiib($this,$0,$2,$oldCapacity,$newCapacity,$deferred)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZNK15b2ParticleColor6IsZeroEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$this>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $2 = (($this) + 1|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  if ($4) {
   $5 = (($this) + 2|0);
   $6 = HEAP8[$5>>0]|0;
   $7 = ($6<<24>>24)==(0);
   if ($7) {
    $8 = (($this) + 3|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = ($9<<24>>24)==(0);
    $11 = $10;
   } else {
    $11 = 0;
   }
  } else {
   $11 = 0;
  }
 } else {
  $11 = 0;
 }
 STACKTOP = sp;return ($11|0);
}
function __ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEE6AppendEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)<($3|0);
 if (!($4)) {
  __ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEE4GrowEv($this);
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = (($5) + 1)|0;
 HEAP32[$0>>2] = $6;
 $7 = HEAP32[$this>>2]|0;
 $8 = (($7) + ($5<<3)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZNK16b2GrowableBufferIN16b2ParticleSystem5ProxyEE8GetCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN16b2ParticleHandle8SetIndexEi($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = $index;
 STACKTOP = sp;return;
}
function __ZN15b2SlabAllocatorI16b2ParticleHandleE4FreeEPS0_($this,$object) {
 $this = $this|0;
 $object = $object|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 __ZN15b2TypedFreeListI16b2ParticleHandleE4FreeEPS0_($0,$object);
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEE5BeginEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZZN16b2ParticleSystem11SolveZombieEvEN4Test14IsProxyInvalidERKNS_5ProxyE($proxy) {
 $proxy = $proxy|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$proxy>>2]|0;
 $1 = ($0|0)<(0);
 STACKTOP = sp;return ($1|0);
}
function __ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEE8RemoveIfIPFbRKS1_EEEPS1_T_($this,$pred) {
 $this = $this|0;
 $pred = $pred|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + ($2<<3)|0);
 $4 = (__ZNSt3__19remove_ifIPN16b2ParticleSystem5ProxyEPFbRKS2_EEET_S8_S8_T0_($0,$3,$pred)|0);
 __ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEE7ShortenEPKS1_($this,$4);
 STACKTOP = sp;return ($4|0);
}
function __ZNK16b2GrowableBufferI17b2ParticleContactE8GetCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN16b2GrowableBufferI17b2ParticleContactEixEi($this,$i) {
 $this = $this|0;
 $i = $i|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + (($i*24)|0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK17b2ParticleContact9GetIndexAEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZNK17b2ParticleContact9GetIndexBEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN17b2ParticleContact10SetIndicesEii($this,$a,$b) {
 $this = $this|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $a;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $b;
 STACKTOP = sp;return;
}
function __ZZN16b2ParticleSystem11SolveZombieEvEN4Test16IsContactInvalidERK17b2ParticleContact($contact) {
 $contact = $contact|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK17b2ParticleContact9GetIndexAEv($contact)|0);
 $1 = ($0|0)<(0);
 if ($1) {
  $4 = 1;
  STACKTOP = sp;return ($4|0);
 }
 $2 = (__ZNK17b2ParticleContact9GetIndexBEv($contact)|0);
 $3 = ($2|0)<(0);
 $4 = $3;
 STACKTOP = sp;return ($4|0);
}
function __ZN16b2GrowableBufferI17b2ParticleContactE8RemoveIfIPFbRKS0_EEEPS0_T_($this,$pred) {
 $this = $this|0;
 $pred = $pred|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + (($2*24)|0)|0);
 $4 = (__ZNSt3__19remove_ifIP17b2ParticleContactPFbRKS1_EEET_S7_S7_T0_($0,$3,$pred)|0);
 __ZN16b2GrowableBufferI17b2ParticleContactE7ShortenEPKS0_($this,$4);
 STACKTOP = sp;return ($4|0);
}
function __ZNK16b2GrowableBufferI21b2ParticleBodyContactE8GetCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN16b2GrowableBufferI21b2ParticleBodyContactEixEi($this,$i) {
 $this = $this|0;
 $i = $i|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + (($i*28)|0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZZN16b2ParticleSystem11SolveZombieEvEN4Test20IsBodyContactInvalidERK21b2ParticleBodyContact($contact) {
 $contact = $contact|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$contact>>2]|0;
 $1 = ($0|0)<(0);
 STACKTOP = sp;return ($1|0);
}
function __ZN16b2GrowableBufferI21b2ParticleBodyContactE8RemoveIfIPFbRKS0_EEEPS0_T_($this,$pred) {
 $this = $this|0;
 $pred = $pred|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + (($2*28)|0)|0);
 $4 = (__ZNSt3__19remove_ifIP21b2ParticleBodyContactPFbRKS1_EEET_S7_S7_T0_($0,$3,$pred)|0);
 __ZN16b2GrowableBufferI21b2ParticleBodyContactE7ShortenEPKS0_($this,$4);
 STACKTOP = sp;return ($4|0);
}
function __ZNK16b2GrowableBufferI14b2ParticlePairE8GetCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN16b2GrowableBufferI14b2ParticlePairEixEi($this,$i) {
 $this = $this|0;
 $i = $i|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + (($i*20)|0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZZN16b2ParticleSystem11SolveZombieEvEN4Test13IsPairInvalidERK14b2ParticlePair($pair) {
 $pair = $pair|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$pair>>2]|0;
 $1 = ($0|0)<(0);
 if ($1) {
  $5 = 1;
 } else {
  $2 = (($pair) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)<(0);
  $5 = $4;
 }
 STACKTOP = sp;return ($5|0);
}
function __ZN16b2GrowableBufferI14b2ParticlePairE8RemoveIfIPFbRKS0_EEEPS0_T_($this,$pred) {
 $this = $this|0;
 $pred = $pred|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + (($2*20)|0)|0);
 $4 = (__ZNSt3__19remove_ifIP14b2ParticlePairPFbRKS1_EEET_S7_S7_T0_($0,$3,$pred)|0);
 __ZN16b2GrowableBufferI14b2ParticlePairE7ShortenEPKS0_($this,$4);
 STACKTOP = sp;return ($4|0);
}
function __ZNK16b2GrowableBufferI15b2ParticleTriadE8GetCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN16b2GrowableBufferI15b2ParticleTriadEixEi($this,$i) {
 $this = $this|0;
 $i = $i|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + (($i*60)|0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZZN16b2ParticleSystem11SolveZombieEvEN4Test14IsTriadInvalidERK15b2ParticleTriad($triad) {
 $triad = $triad|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$triad>>2]|0;
 $1 = ($0|0)<(0);
 if ($1) {
  $8 = 1;
 } else {
  $2 = (($triad) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)<(0);
  if ($4) {
   $8 = 1;
  } else {
   $5 = (($triad) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)<(0);
   $8 = $7;
  }
 }
 STACKTOP = sp;return ($8|0);
}
function __ZN16b2GrowableBufferI15b2ParticleTriadE8RemoveIfIPFbRKS0_EEEPS0_T_($this,$pred) {
 $this = $this|0;
 $pred = $pred|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + (($2*60)|0)|0);
 $4 = (__ZNSt3__19remove_ifIP15b2ParticleTriadPFbRKS1_EEET_S7_S7_T0_($0,$3,$pred)|0);
 __ZN16b2GrowableBufferI15b2ParticleTriadE7ShortenEPKS0_($this,$4);
 STACKTOP = sp;return ($4|0);
}
function __ZN15b2ParticleGroup7GetNextEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN16b2ParticleSystem13RequestBufferIiEEPT_S2_($this,$buffer) {
 $this = $this|0;
 $buffer = $buffer|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($buffer|0)==(0|0);
 if (!($0)) {
  $$0 = $buffer;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 48|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  __ZN16b2ParticleSystem34ReallocateInternalAllocatedBuffersEi($this,256);
 }
 $4 = (($this) + 400|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = $6 << 2;
 $8 = (__ZN16b2BlockAllocator8AllocateEi($5,$7)|0);
 $9 = HEAP32[$1>>2]|0;
 $10 = $9 << 2;
 _memset(($8|0),0,($10|0))|0;
 $$0 = $8;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__113__rotate_leftIPjEET_S2_S2_($__first,$__last) {
 $__first = $__first|0;
 $__last = $__last|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__first>>2]|0;
 $1 = (($__first) + 4|0);
 $2 = $__last;
 $3 = $1;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 _memmove(($__first|0),($1|0),($4|0))|0;
 $6 = (($__first) + ($5<<2)|0);
 HEAP32[$6>>2] = $0;
 STACKTOP = sp;return ($6|0);
}
function __ZNSt3__114__rotate_rightIPjEET_S2_S2_($__first,$__last) {
 $__first = $__first|0;
 $__last = $__last|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__last) + -4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $0;
 $3 = $__first;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 $6 = (0 - ($5))|0;
 $7 = (($__last) + ($6<<2)|0);
 _memmove(($7|0),($__first|0),($4|0))|0;
 HEAP32[$__first>>2] = $1;
 STACKTOP = sp;return ($7|0);
}
function __ZNSt3__112__rotate_gcdIPjEET_S2_S2_S2_($__first,$__middle,$__last) {
 $__first = $__first|0;
 $__middle = $__middle|0;
 $__last = $__last|0;
 var $$0 = 0, $$0$i = 0, $$0$i$phi = 0, $$01$i = 0, $$012$i = 0, $$03$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$01 = 0;
 var $__p1$0 = 0, $__p1$0$phi = 0, $__p2$0 = 0, $__p2$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__middle;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 $4 = $__last;
 $5 = (($4) - ($0))|0;
 $6 = $5 >> 2;
 $7 = ($3|0)==($6|0);
 if ($7) {
  $8 = ($__first|0)==($__middle|0);
  if ($8) {
   $$0 = $__middle;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$012$i = $__first;$$03$i = $__middle;
  }
  while(1) {
   $9 = HEAP32[$$012$i>>2]|0;
   $10 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $10;
   HEAP32[$$03$i>>2] = $9;
   $11 = (($$012$i) + 4|0);
   $12 = (($$03$i) + 4|0);
   $13 = ($11|0)==($__middle|0);
   if ($13) {
    $$0 = $__middle;
    break;
   } else {
    $$012$i = $11;$$03$i = $12;
   }
  }
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0$i = $3;$$01$i = $6;
 }
 while(1) {
  $14 = (($$0$i|0) % ($$01$i|0))&-1;
  $15 = ($14|0)==(0);
  if ($15) {
   break;
  } else {
   $$0$i$phi = $$01$i;$$01$i = $14;$$0$i = $$0$i$phi;
  }
 }
 $16 = ($$01$i|0)==(0);
 if (!($16)) {
  $17 = (($__first) + ($$01$i<<2)|0);
  $$sum = (($3) + -1)|0;
  $__p$01 = $17;
  while(1) {
   $18 = (($__p$01) + -4|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($__p$01) + ($$sum<<2)|0);
   $__p1$0 = $18;$__p2$0 = $20;
   while(1) {
    $21 = HEAP32[$__p2$0>>2]|0;
    HEAP32[$__p1$0>>2] = $21;
    $22 = $__p2$0;
    $23 = (($4) - ($22))|0;
    $24 = $23 >> 2;
    $25 = ($3|0)<($24|0);
    if ($25) {
     $26 = (($__p2$0) + ($3<<2)|0);
     $__p2$1 = $26;
    } else {
     $27 = (($3) - ($24))|0;
     $28 = (($__first) + ($27<<2)|0);
     $__p2$1 = $28;
    }
    $29 = ($__p2$1|0)==($18|0);
    if ($29) {
     break;
    } else {
     $__p1$0$phi = $__p2$0;$__p2$0 = $__p2$1;$__p1$0 = $__p1$0$phi;
    }
   }
   HEAP32[$__p2$0>>2] = $19;
   $30 = ($18|0)==($__first|0);
   if ($30) {
    break;
   } else {
    $__p$01 = $18;
   }
  }
 }
 $31 = (($__first) + ($6<<2)|0);
 $$0 = $31;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__113__rotate_leftIPiEET_S2_S2_($__first,$__last) {
 $__first = $__first|0;
 $__last = $__last|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__first>>2]|0;
 $1 = (($__first) + 4|0);
 $2 = $__last;
 $3 = $1;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 _memmove(($__first|0),($1|0),($4|0))|0;
 $6 = (($__first) + ($5<<2)|0);
 HEAP32[$6>>2] = $0;
 STACKTOP = sp;return ($6|0);
}
function __ZNSt3__114__rotate_rightIPiEET_S2_S2_($__first,$__last) {
 $__first = $__first|0;
 $__last = $__last|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__last) + -4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $0;
 $3 = $__first;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 $6 = (0 - ($5))|0;
 $7 = (($__last) + ($6<<2)|0);
 _memmove(($7|0),($__first|0),($4|0))|0;
 HEAP32[$__first>>2] = $1;
 STACKTOP = sp;return ($7|0);
}
function __ZNSt3__112__rotate_gcdIPiEET_S2_S2_S2_($__first,$__middle,$__last) {
 $__first = $__first|0;
 $__middle = $__middle|0;
 $__last = $__last|0;
 var $$0 = 0, $$0$i = 0, $$0$i$phi = 0, $$01$i = 0, $$012$i = 0, $$03$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$01 = 0;
 var $__p1$0 = 0, $__p1$0$phi = 0, $__p2$0 = 0, $__p2$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__middle;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 $4 = $__last;
 $5 = (($4) - ($0))|0;
 $6 = $5 >> 2;
 $7 = ($3|0)==($6|0);
 if ($7) {
  $8 = ($__first|0)==($__middle|0);
  if ($8) {
   $$0 = $__middle;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$012$i = $__first;$$03$i = $__middle;
  }
  while(1) {
   $9 = HEAP32[$$012$i>>2]|0;
   $10 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $10;
   HEAP32[$$03$i>>2] = $9;
   $11 = (($$012$i) + 4|0);
   $12 = (($$03$i) + 4|0);
   $13 = ($11|0)==($__middle|0);
   if ($13) {
    $$0 = $__middle;
    break;
   } else {
    $$012$i = $11;$$03$i = $12;
   }
  }
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0$i = $3;$$01$i = $6;
 }
 while(1) {
  $14 = (($$0$i|0) % ($$01$i|0))&-1;
  $15 = ($14|0)==(0);
  if ($15) {
   break;
  } else {
   $$0$i$phi = $$01$i;$$01$i = $14;$$0$i = $$0$i$phi;
  }
 }
 $16 = ($$01$i|0)==(0);
 if (!($16)) {
  $17 = (($__first) + ($$01$i<<2)|0);
  $$sum = (($3) + -1)|0;
  $__p$01 = $17;
  while(1) {
   $18 = (($__p$01) + -4|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($__p$01) + ($$sum<<2)|0);
   $__p1$0 = $18;$__p2$0 = $20;
   while(1) {
    $21 = HEAP32[$__p2$0>>2]|0;
    HEAP32[$__p1$0>>2] = $21;
    $22 = $__p2$0;
    $23 = (($4) - ($22))|0;
    $24 = $23 >> 2;
    $25 = ($3|0)<($24|0);
    if ($25) {
     $26 = (($__p2$0) + ($3<<2)|0);
     $__p2$1 = $26;
    } else {
     $27 = (($3) - ($24))|0;
     $28 = (($__first) + ($27<<2)|0);
     $__p2$1 = $28;
    }
    $29 = ($__p2$1|0)==($18|0);
    if ($29) {
     break;
    } else {
     $__p1$0$phi = $__p2$0;$__p2$0 = $__p2$1;$__p1$0 = $__p1$0$phi;
    }
   }
   HEAP32[$__p2$0>>2] = $19;
   $30 = ($18|0)==($__first|0);
   if ($30) {
    break;
   } else {
    $__p$01 = $18;
   }
  }
 }
 $31 = (($__first) + ($6<<2)|0);
 $$0 = $31;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__113__rotate_leftIP6b2Vec2EET_S3_S3_($__first,$__last) {
 $__first = $__first|0;
 $__last = $__last|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__first;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($__first) + 8|0);
 $7 = $__last;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 3;
 _memmove(($__first|0),($6|0),($9|0))|0;
 $11 = (($__first) + ($10<<3)|0);
 $12 = $11;
 $13 = $12;
 HEAP32[$13>>2] = $2;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $5;
 STACKTOP = sp;return ($11|0);
}
function __ZNSt3__114__rotate_rightIP6b2Vec2EET_S3_S3_($__first,$__last) {
 $__first = $__first|0;
 $__last = $__last|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__last) + -8|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $__first;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 3;
 $11 = (0 - ($10))|0;
 $12 = (($__last) + ($11<<3)|0);
 _memmove(($12|0),($__first|0),($9|0))|0;
 $13 = $__first;
 $14 = $13;
 HEAP32[$14>>2] = $3;
 $15 = (($13) + 4)|0;
 $16 = $15;
 HEAP32[$16>>2] = $6;
 STACKTOP = sp;return ($12|0);
}
function __ZNSt3__112__rotate_gcdIP6b2Vec2EET_S3_S3_S3_($__first,$__middle,$__last) {
 $__first = $__first|0;
 $__middle = $__middle|0;
 $__last = $__last|0;
 var $$0 = 0, $$0$i = 0, $$0$i$phi = 0, $$01$i = 0, $$012$i = 0, $$03$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$01 = 0, $__p1$0 = 0, $__p1$0$phi = 0, $__p2$0 = 0, $__p2$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__middle;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 3;
 $4 = $__last;
 $5 = (($4) - ($0))|0;
 $6 = $5 >> 3;
 $7 = ($3|0)==($6|0);
 if ($7) {
  $8 = ($__first|0)==($__middle|0);
  if ($8) {
   $$0 = $__middle;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$012$i = $__first;$$03$i = $__middle;
  }
  while(1) {
   $9 = $$012$i;
   $10 = $9;
   $11 = HEAP32[$10>>2]|0;
   $12 = (($9) + 4)|0;
   $13 = $12;
   $14 = HEAP32[$13>>2]|0;
   $15 = $$03$i;
   $16 = $15;
   $17 = HEAP32[$16>>2]|0;
   $18 = (($15) + 4)|0;
   $19 = $18;
   $20 = HEAP32[$19>>2]|0;
   $21 = $$012$i;
   $22 = $21;
   HEAP32[$22>>2] = $17;
   $23 = (($21) + 4)|0;
   $24 = $23;
   HEAP32[$24>>2] = $20;
   $25 = $$03$i;
   $26 = $25;
   HEAP32[$26>>2] = $11;
   $27 = (($25) + 4)|0;
   $28 = $27;
   HEAP32[$28>>2] = $14;
   $29 = (($$012$i) + 8|0);
   $30 = (($$03$i) + 8|0);
   $31 = ($29|0)==($__middle|0);
   if ($31) {
    $$0 = $__middle;
    break;
   } else {
    $$012$i = $29;$$03$i = $30;
   }
  }
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0$i = $3;$$01$i = $6;
 }
 while(1) {
  $32 = (($$0$i|0) % ($$01$i|0))&-1;
  $33 = ($32|0)==(0);
  if ($33) {
   break;
  } else {
   $$0$i$phi = $$01$i;$$01$i = $32;$$0$i = $$0$i$phi;
  }
 }
 $34 = ($$01$i|0)==(0);
 if (!($34)) {
  $35 = (($__first) + ($$01$i<<3)|0);
  $$sum = (($3) + -1)|0;
  $__p$01 = $35;
  while(1) {
   $36 = (($__p$01) + -8|0);
   $37 = $36;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = (($37) + 4)|0;
   $41 = $40;
   $42 = HEAP32[$41>>2]|0;
   $43 = (($__p$01) + ($$sum<<3)|0);
   $__p1$0 = $36;$__p2$0 = $43;
   while(1) {
    $44 = $__p2$0;
    $45 = $44;
    $46 = HEAP32[$45>>2]|0;
    $47 = (($44) + 4)|0;
    $48 = $47;
    $49 = HEAP32[$48>>2]|0;
    $50 = $__p1$0;
    $51 = $50;
    HEAP32[$51>>2] = $46;
    $52 = (($50) + 4)|0;
    $53 = $52;
    HEAP32[$53>>2] = $49;
    $54 = $__p2$0;
    $55 = (($4) - ($54))|0;
    $56 = $55 >> 3;
    $57 = ($3|0)<($56|0);
    if ($57) {
     $58 = (($__p2$0) + ($3<<3)|0);
     $__p2$1 = $58;
    } else {
     $59 = (($3) - ($56))|0;
     $60 = (($__first) + ($59<<3)|0);
     $__p2$1 = $60;
    }
    $61 = ($__p2$1|0)==($36|0);
    if ($61) {
     break;
    } else {
     $__p1$0$phi = $__p2$0;$__p2$0 = $__p2$1;$__p1$0 = $__p1$0$phi;
    }
   }
   $62 = $__p2$0;
   $63 = $62;
   HEAP32[$63>>2] = $39;
   $64 = (($62) + 4)|0;
   $65 = $64;
   HEAP32[$65>>2] = $42;
   $66 = ($36|0)==($__first|0);
   if ($66) {
    break;
   } else {
    $__p$01 = $36;
   }
  }
 }
 $67 = (($__first) + ($6<<3)|0);
 $$0 = $67;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__113__rotate_leftIPP15b2ParticleGroupEET_S4_S4_($__first,$__last) {
 $__first = $__first|0;
 $__last = $__last|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__first>>2]|0;
 $1 = (($__first) + 4|0);
 $2 = $__last;
 $3 = $1;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 _memmove(($__first|0),($1|0),($4|0))|0;
 $6 = (($__first) + ($5<<2)|0);
 HEAP32[$6>>2] = $0;
 STACKTOP = sp;return ($6|0);
}
function __ZNSt3__114__rotate_rightIPP15b2ParticleGroupEET_S4_S4_($__first,$__last) {
 $__first = $__first|0;
 $__last = $__last|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__last) + -4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $0;
 $3 = $__first;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 $6 = (0 - ($5))|0;
 $7 = (($__last) + ($6<<2)|0);
 _memmove(($7|0),($__first|0),($4|0))|0;
 HEAP32[$__first>>2] = $1;
 STACKTOP = sp;return ($7|0);
}
function __ZNSt3__112__rotate_gcdIPP15b2ParticleGroupEET_S4_S4_S4_($__first,$__middle,$__last) {
 $__first = $__first|0;
 $__middle = $__middle|0;
 $__last = $__last|0;
 var $$0 = 0, $$0$i = 0, $$0$i$phi = 0, $$01$i = 0, $$012$i = 0, $$03$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$01 = 0;
 var $__p1$0 = 0, $__p1$0$phi = 0, $__p2$0 = 0, $__p2$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__middle;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 $4 = $__last;
 $5 = (($4) - ($0))|0;
 $6 = $5 >> 2;
 $7 = ($3|0)==($6|0);
 if ($7) {
  $8 = ($__first|0)==($__middle|0);
  if ($8) {
   $$0 = $__middle;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$012$i = $__first;$$03$i = $__middle;
  }
  while(1) {
   $9 = HEAP32[$$012$i>>2]|0;
   $10 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $10;
   HEAP32[$$03$i>>2] = $9;
   $11 = (($$012$i) + 4|0);
   $12 = (($$03$i) + 4|0);
   $13 = ($11|0)==($__middle|0);
   if ($13) {
    $$0 = $__middle;
    break;
   } else {
    $$012$i = $11;$$03$i = $12;
   }
  }
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0$i = $3;$$01$i = $6;
 }
 while(1) {
  $14 = (($$0$i|0) % ($$01$i|0))&-1;
  $15 = ($14|0)==(0);
  if ($15) {
   break;
  } else {
   $$0$i$phi = $$01$i;$$01$i = $14;$$0$i = $$0$i$phi;
  }
 }
 $16 = ($$01$i|0)==(0);
 if (!($16)) {
  $17 = (($__first) + ($$01$i<<2)|0);
  $$sum = (($3) + -1)|0;
  $__p$01 = $17;
  while(1) {
   $18 = (($__p$01) + -4|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($__p$01) + ($$sum<<2)|0);
   $__p1$0 = $18;$__p2$0 = $20;
   while(1) {
    $21 = HEAP32[$__p2$0>>2]|0;
    HEAP32[$__p1$0>>2] = $21;
    $22 = $__p2$0;
    $23 = (($4) - ($22))|0;
    $24 = $23 >> 2;
    $25 = ($3|0)<($24|0);
    if ($25) {
     $26 = (($__p2$0) + ($3<<2)|0);
     $__p2$1 = $26;
    } else {
     $27 = (($3) - ($24))|0;
     $28 = (($__first) + ($27<<2)|0);
     $__p2$1 = $28;
    }
    $29 = ($__p2$1|0)==($18|0);
    if ($29) {
     break;
    } else {
     $__p1$0$phi = $__p2$0;$__p2$0 = $__p2$1;$__p1$0 = $__p1$0$phi;
    }
   }
   HEAP32[$__p2$0>>2] = $19;
   $30 = ($18|0)==($__first|0);
   if ($30) {
    break;
   } else {
    $__p$01 = $18;
   }
  }
 }
 $31 = (($__first) + ($6<<2)|0);
 $$0 = $31;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__113__rotate_leftIPfEET_S2_S2_($__first,$__last) {
 $__first = $__first|0;
 $__last = $__last|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$__first>>2];
 $1 = (($__first) + 4|0);
 $2 = $__last;
 $3 = $1;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 _memmove(($__first|0),($1|0),($4|0))|0;
 $6 = (($__first) + ($5<<2)|0);
 HEAPF32[$6>>2] = $0;
 STACKTOP = sp;return ($6|0);
}
function __ZNSt3__114__rotate_rightIPfEET_S2_S2_($__first,$__last) {
 $__first = $__first|0;
 $__last = $__last|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__last) + -4|0);
 $1 = +HEAPF32[$0>>2];
 $2 = $0;
 $3 = $__first;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 $6 = (0 - ($5))|0;
 $7 = (($__last) + ($6<<2)|0);
 _memmove(($7|0),($__first|0),($4|0))|0;
 HEAPF32[$__first>>2] = $1;
 STACKTOP = sp;return ($7|0);
}
function __ZNSt3__112__rotate_gcdIPfEET_S2_S2_S2_($__first,$__middle,$__last) {
 $__first = $__first|0;
 $__middle = $__middle|0;
 $__last = $__last|0;
 var $$0 = 0, $$0$i = 0, $$0$i$phi = 0, $$01$i = 0, $$012$i = 0, $$03$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0.0, $2 = 0;
 var $20 = 0, $21 = 0.0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, $__p$01 = 0;
 var $__p1$0 = 0, $__p1$0$phi = 0, $__p2$0 = 0, $__p2$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__middle;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 $4 = $__last;
 $5 = (($4) - ($0))|0;
 $6 = $5 >> 2;
 $7 = ($3|0)==($6|0);
 if ($7) {
  $8 = ($__first|0)==($__middle|0);
  if ($8) {
   $$0 = $__middle;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$012$i = $__first;$$03$i = $__middle;
  }
  while(1) {
   $9 = +HEAPF32[$$012$i>>2];
   $10 = +HEAPF32[$$03$i>>2];
   HEAPF32[$$012$i>>2] = $10;
   HEAPF32[$$03$i>>2] = $9;
   $11 = (($$012$i) + 4|0);
   $12 = (($$03$i) + 4|0);
   $13 = ($11|0)==($__middle|0);
   if ($13) {
    $$0 = $__middle;
    break;
   } else {
    $$012$i = $11;$$03$i = $12;
   }
  }
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0$i = $3;$$01$i = $6;
 }
 while(1) {
  $14 = (($$0$i|0) % ($$01$i|0))&-1;
  $15 = ($14|0)==(0);
  if ($15) {
   break;
  } else {
   $$0$i$phi = $$01$i;$$01$i = $14;$$0$i = $$0$i$phi;
  }
 }
 $16 = ($$01$i|0)==(0);
 if (!($16)) {
  $17 = (($__first) + ($$01$i<<2)|0);
  $$sum = (($3) + -1)|0;
  $__p$01 = $17;
  while(1) {
   $18 = (($__p$01) + -4|0);
   $19 = +HEAPF32[$18>>2];
   $20 = (($__p$01) + ($$sum<<2)|0);
   $__p1$0 = $18;$__p2$0 = $20;
   while(1) {
    $21 = +HEAPF32[$__p2$0>>2];
    HEAPF32[$__p1$0>>2] = $21;
    $22 = $__p2$0;
    $23 = (($4) - ($22))|0;
    $24 = $23 >> 2;
    $25 = ($3|0)<($24|0);
    if ($25) {
     $26 = (($__p2$0) + ($3<<2)|0);
     $__p2$1 = $26;
    } else {
     $27 = (($3) - ($24))|0;
     $28 = (($__first) + ($27<<2)|0);
     $__p2$1 = $28;
    }
    $29 = ($__p2$1|0)==($18|0);
    if ($29) {
     break;
    } else {
     $__p1$0$phi = $__p2$0;$__p2$0 = $__p2$1;$__p1$0 = $__p1$0$phi;
    }
   }
   HEAPF32[$__p2$0>>2] = $19;
   $30 = ($18|0)==($__first|0);
   if ($30) {
    break;
   } else {
    $__p$01 = $18;
   }
  }
 }
 $31 = (($__first) + ($6<<2)|0);
 $$0 = $31;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__116__rotate_forwardIP15b2ParticleColorEET_S3_S3_S3_($__first,$__middle,$__last) {
 $__first = $__first|0;
 $__middle = $__middle|0;
 $__last = $__last|0;
 var $$$01 = 0, $$$12 = 0, $$01$lcssa28 = 0, $$0112 = 0, $$1 = 0, $$1$ph = 0, $$12$ph = 0, $$lcssa1026 = 0, $$lcssa1027 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$1 = 0, $__i$1$ph = 0, $__middle22 = 0, $__t$i3 = 0, $scevgep = 0, $scevgep25 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t$i3 = sp;
 $0 = HEAPU8[$__first>>0]|(HEAPU8[$__first+1>>0]<<8)|(HEAPU8[$__first+2>>0]<<16)|(HEAPU8[$__first+3>>0]<<24);
 HEAP32[$__t$i3>>2] = $0;
 (__ZN15b2ParticleColoraSERKS_($__first,$__middle)|0);
 (__ZN15b2ParticleColoraSERKS_($__middle,$__t$i3)|0);
 $1 = (($__first) + 4|0);
 $2 = (($__middle) + 4|0);
 $3 = ($2|0)==($__last|0);
 $4 = ($1|0)==($__middle|0);
 if ($3) {
  if ($4) {
   $$lcssa1027 = $1;
   STACKTOP = sp;return ($$lcssa1027|0);
  } else {
   $$01$lcssa28 = $__middle;$$lcssa1026 = $1;
  }
 } else {
  $__middle22 = $__middle;
  $scevgep = (($__last) + -8|0);
  $5 = $scevgep;
  $6 = (($5) - ($__middle22))|0;
  $7 = $6 >>> 2;
  $8 = (($7) + 2)|0;
  $$0112 = $__middle;$10 = $4;$12 = $1;$9 = $2;
  while(1) {
   $$$01 = $10 ? $9 : $$0112;
   $11 = HEAPU8[$12>>0]|(HEAPU8[$12+1>>0]<<8)|(HEAPU8[$12+2>>0]<<16)|(HEAPU8[$12+3>>0]<<24);
   HEAP32[$__t$i3>>2] = $11;
   (__ZN15b2ParticleColoraSERKS_($12,$9)|0);
   (__ZN15b2ParticleColoraSERKS_($9,$__t$i3)|0);
   $13 = (($12) + 4|0);
   $14 = (($9) + 4|0);
   $15 = ($14|0)==($__last|0);
   $16 = ($13|0)==($$$01|0);
   if ($15) {
    break;
   } else {
    $$0112 = $$$01;$10 = $16;$12 = $13;$9 = $14;
   }
  }
  $scevgep25 = (($__first) + ($8<<2)|0);
  if ($16) {
   $$lcssa1027 = $scevgep25;
   STACKTOP = sp;return ($$lcssa1027|0);
  } else {
   $$01$lcssa28 = $$$01;$$lcssa1026 = $scevgep25;
  }
 }
 $$1$ph = $$lcssa1026;$$12$ph = $$01$lcssa28;$__i$1$ph = $$01$lcssa28;
 L10: while(1) {
  $$1 = $$1$ph;$__i$1 = $__i$1$ph;
  while(1) {
   $17 = HEAPU8[$$1>>0]|(HEAPU8[$$1+1>>0]<<8)|(HEAPU8[$$1+2>>0]<<16)|(HEAPU8[$$1+3>>0]<<24);
   HEAP32[$__t$i3>>2] = $17;
   (__ZN15b2ParticleColoraSERKS_($$1,$__i$1)|0);
   (__ZN15b2ParticleColoraSERKS_($__i$1,$__t$i3)|0);
   $18 = (($$1) + 4|0);
   $19 = (($__i$1) + 4|0);
   $20 = ($19|0)==($__last|0);
   $21 = ($18|0)==($$12$ph|0);
   if (!($20)) {
    break;
   }
   if ($21) {
    $$lcssa1027 = $$lcssa1026;
    break L10;
   } else {
    $$1 = $18;$__i$1 = $$12$ph;
   }
  }
  $$$12 = $21 ? $19 : $$12$ph;
  $$1$ph = $18;$$12$ph = $$$12;$__i$1$ph = $19;
 }
 STACKTOP = sp;return ($$lcssa1027|0);
}
function __ZNSt3__113__rotate_leftIPPvEET_S3_S3_($__first,$__last) {
 $__first = $__first|0;
 $__last = $__last|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__first>>2]|0;
 $1 = (($__first) + 4|0);
 $2 = $__last;
 $3 = $1;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 _memmove(($__first|0),($1|0),($4|0))|0;
 $6 = (($__first) + ($5<<2)|0);
 HEAP32[$6>>2] = $0;
 STACKTOP = sp;return ($6|0);
}
function __ZNSt3__114__rotate_rightIPPvEET_S3_S3_($__first,$__last) {
 $__first = $__first|0;
 $__last = $__last|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__last) + -4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $0;
 $3 = $__first;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 $6 = (0 - ($5))|0;
 $7 = (($__last) + ($6<<2)|0);
 _memmove(($7|0),($__first|0),($4|0))|0;
 HEAP32[$__first>>2] = $1;
 STACKTOP = sp;return ($7|0);
}
function __ZNSt3__112__rotate_gcdIPPvEET_S3_S3_S3_($__first,$__middle,$__last) {
 $__first = $__first|0;
 $__middle = $__middle|0;
 $__last = $__last|0;
 var $$0 = 0, $$0$i = 0, $$0$i$phi = 0, $$01$i = 0, $$012$i = 0, $$03$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$01 = 0;
 var $__p1$0 = 0, $__p1$0$phi = 0, $__p2$0 = 0, $__p2$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__middle;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 $4 = $__last;
 $5 = (($4) - ($0))|0;
 $6 = $5 >> 2;
 $7 = ($3|0)==($6|0);
 if ($7) {
  $8 = ($__first|0)==($__middle|0);
  if ($8) {
   $$0 = $__middle;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$012$i = $__first;$$03$i = $__middle;
  }
  while(1) {
   $9 = HEAP32[$$012$i>>2]|0;
   $10 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $10;
   HEAP32[$$03$i>>2] = $9;
   $11 = (($$012$i) + 4|0);
   $12 = (($$03$i) + 4|0);
   $13 = ($11|0)==($__middle|0);
   if ($13) {
    $$0 = $__middle;
    break;
   } else {
    $$012$i = $11;$$03$i = $12;
   }
  }
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0$i = $3;$$01$i = $6;
 }
 while(1) {
  $14 = (($$0$i|0) % ($$01$i|0))&-1;
  $15 = ($14|0)==(0);
  if ($15) {
   break;
  } else {
   $$0$i$phi = $$01$i;$$01$i = $14;$$0$i = $$0$i$phi;
  }
 }
 $16 = ($$01$i|0)==(0);
 if (!($16)) {
  $17 = (($__first) + ($$01$i<<2)|0);
  $$sum = (($3) + -1)|0;
  $__p$01 = $17;
  while(1) {
   $18 = (($__p$01) + -4|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($__p$01) + ($$sum<<2)|0);
   $__p1$0 = $18;$__p2$0 = $20;
   while(1) {
    $21 = HEAP32[$__p2$0>>2]|0;
    HEAP32[$__p1$0>>2] = $21;
    $22 = $__p2$0;
    $23 = (($4) - ($22))|0;
    $24 = $23 >> 2;
    $25 = ($3|0)<($24|0);
    if ($25) {
     $26 = (($__p2$0) + ($3<<2)|0);
     $__p2$1 = $26;
    } else {
     $27 = (($3) - ($24))|0;
     $28 = (($__first) + ($27<<2)|0);
     $__p2$1 = $28;
    }
    $29 = ($__p2$1|0)==($18|0);
    if ($29) {
     break;
    } else {
     $__p1$0$phi = $__p2$0;$__p2$0 = $__p2$1;$__p1$0 = $__p1$0$phi;
    }
   }
   HEAP32[$__p2$0>>2] = $19;
   $30 = ($18|0)==($__first|0);
   if ($30) {
    break;
   } else {
    $__p$01 = $18;
   }
  }
 }
 $31 = (($__first) + ($6<<2)|0);
 $$0 = $31;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__113__rotate_leftIPP16b2ParticleHandleEET_S4_S4_($__first,$__last) {
 $__first = $__first|0;
 $__last = $__last|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__first>>2]|0;
 $1 = (($__first) + 4|0);
 $2 = $__last;
 $3 = $1;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 _memmove(($__first|0),($1|0),($4|0))|0;
 $6 = (($__first) + ($5<<2)|0);
 HEAP32[$6>>2] = $0;
 STACKTOP = sp;return ($6|0);
}
function __ZNSt3__114__rotate_rightIPP16b2ParticleHandleEET_S4_S4_($__first,$__last) {
 $__first = $__first|0;
 $__last = $__last|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__last) + -4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $0;
 $3 = $__first;
 $4 = (($2) - ($3))|0;
 $5 = $4 >> 2;
 $6 = (0 - ($5))|0;
 $7 = (($__last) + ($6<<2)|0);
 _memmove(($7|0),($__first|0),($4|0))|0;
 HEAP32[$__first>>2] = $1;
 STACKTOP = sp;return ($7|0);
}
function __ZNSt3__112__rotate_gcdIPP16b2ParticleHandleEET_S4_S4_S4_($__first,$__middle,$__last) {
 $__first = $__first|0;
 $__middle = $__middle|0;
 $__last = $__last|0;
 var $$0 = 0, $$0$i = 0, $$0$i$phi = 0, $$01$i = 0, $$012$i = 0, $$03$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$01 = 0;
 var $__p1$0 = 0, $__p1$0$phi = 0, $__p2$0 = 0, $__p2$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__middle;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 $4 = $__last;
 $5 = (($4) - ($0))|0;
 $6 = $5 >> 2;
 $7 = ($3|0)==($6|0);
 if ($7) {
  $8 = ($__first|0)==($__middle|0);
  if ($8) {
   $$0 = $__middle;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$012$i = $__first;$$03$i = $__middle;
  }
  while(1) {
   $9 = HEAP32[$$012$i>>2]|0;
   $10 = HEAP32[$$03$i>>2]|0;
   HEAP32[$$012$i>>2] = $10;
   HEAP32[$$03$i>>2] = $9;
   $11 = (($$012$i) + 4|0);
   $12 = (($$03$i) + 4|0);
   $13 = ($11|0)==($__middle|0);
   if ($13) {
    $$0 = $__middle;
    break;
   } else {
    $$012$i = $11;$$03$i = $12;
   }
  }
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0$i = $3;$$01$i = $6;
 }
 while(1) {
  $14 = (($$0$i|0) % ($$01$i|0))&-1;
  $15 = ($14|0)==(0);
  if ($15) {
   break;
  } else {
   $$0$i$phi = $$01$i;$$01$i = $14;$$0$i = $$0$i$phi;
  }
 }
 $16 = ($$01$i|0)==(0);
 if (!($16)) {
  $17 = (($__first) + ($$01$i<<2)|0);
  $$sum = (($3) + -1)|0;
  $__p$01 = $17;
  while(1) {
   $18 = (($__p$01) + -4|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (($__p$01) + ($$sum<<2)|0);
   $__p1$0 = $18;$__p2$0 = $20;
   while(1) {
    $21 = HEAP32[$__p2$0>>2]|0;
    HEAP32[$__p1$0>>2] = $21;
    $22 = $__p2$0;
    $23 = (($4) - ($22))|0;
    $24 = $23 >> 2;
    $25 = ($3|0)<($24|0);
    if ($25) {
     $26 = (($__p2$0) + ($3<<2)|0);
     $__p2$1 = $26;
    } else {
     $27 = (($3) - ($24))|0;
     $28 = (($__first) + ($27<<2)|0);
     $__p2$1 = $28;
    }
    $29 = ($__p2$1|0)==($18|0);
    if ($29) {
     break;
    } else {
     $__p1$0$phi = $__p2$0;$__p2$0 = $__p2$1;$__p1$0 = $__p1$0$phi;
    }
   }
   HEAP32[$__p2$0>>2] = $19;
   $30 = ($18|0)==($__first|0);
   if ($30) {
    break;
   } else {
    $__p$01 = $18;
   }
  }
 }
 $31 = (($__first) + ($6<<2)|0);
 $$0 = $31;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK16b2ParticleHandle8GetIndexEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZZN16b2ParticleSystem12RotateBufferEiiiENK10NewIndicesixEi($this,$i) {
 $this = $this|0;
 $i = $i|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)>($i|0);
 do {
  if ($1) {
   $$0 = $i;
  } else {
   $2 = (($this) + 4|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)>($i|0);
   $5 = (($this) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   if ($4) {
    $7 = (($i) - ($3))|0;
    $8 = (($7) + ($6))|0;
    $$0 = $8;
    break;
   }
   $9 = ($6|0)>($i|0);
   if ($9) {
    $10 = (($0) + ($i))|0;
    $11 = (($10) - ($3))|0;
    $$0 = $11;
   } else {
    $$0 = $i;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZN16b2ParticleSystem13RequestBufferI6b2Vec2EEPT_S3_($this,$buffer) {
 $this = $this|0;
 $buffer = $buffer|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($buffer|0)==(0|0);
 if (!($0)) {
  $$0 = $buffer;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 48|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  __ZN16b2ParticleSystem34ReallocateInternalAllocatedBuffersEi($this,256);
 }
 $4 = (($this) + 400|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = $6 << 3;
 $8 = (__ZN16b2BlockAllocator8AllocateEi($5,$7)|0);
 $9 = HEAP32[$1>>2]|0;
 $10 = $9 << 3;
 _memset(($8|0),0,($10|0))|0;
 $$0 = $8;
 STACKTOP = sp;return ($$0|0);
}
function __ZZN16b2ParticleSystem23DestroyParticlesInShapeERK7b2ShapeRK11b2TransformbEN31DestroyParticlesInShapeCallbackC2EPS_S2_S5_b($this,$system,$shape,$xf,$callDestructionListener) {
 $this = $this|0;
 $system = $system|0;
 $shape = $shape|0;
 $xf = $xf|0;
 $callDestructionListener = $callDestructionListener|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN15b2QueryCallbackC2Ev($this);
 HEAP32[$this>>2] = ((9336 + 8|0));
 $0 = (($this) + 12|0);
 $1 = (($this) + 4|0);
 HEAP32[$1>>2] = $system;
 $2 = (($this) + 8|0);
 HEAP32[$2>>2] = $shape;
 ;HEAP32[$0+0>>2]=HEAP32[$xf+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$xf+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$xf+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$xf+12>>2]|0;
 $3 = (($this) + 28|0);
 $4 = $callDestructionListener&1;
 HEAP8[$3>>0] = $4;
 $5 = (($this) + 32|0);
 HEAP32[$5>>2] = 0;
 STACKTOP = sp;return;
}
function __ZZN16b2ParticleSystem23DestroyParticlesInShapeERK7b2ShapeRK11b2TransformbEN31DestroyParticlesInShapeCallback9DestroyedEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZZN16b2ParticleSystem33CreateParticlesWithShapesForGroupEPKPK7b2ShapeiRK18b2ParticleGroupDefRK11b2TransformEN14CompositeShapeC2ES4_i($this,$shapes,$shapeCount) {
 $this = $this|0;
 $shapes = $shapes|0;
 $shapeCount = $shapeCount|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN7b2ShapeC2Ev($this);
 HEAP32[$this>>2] = ((9144 + 8|0));
 $0 = (($this) + 12|0);
 HEAP32[$0>>2] = $shapes;
 $1 = (($this) + 16|0);
 HEAP32[$1>>2] = $shapeCount;
 STACKTOP = sp;return;
}
function __ZN11b2Transform3SetERK6b2Vec2f($this,$position,$angle) {
 $this = $this|0;
 $position = $position|0;
 $angle = +$angle;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $position;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $this;
 $7 = $6;
 HEAP32[$7>>2] = $2;
 $8 = (($6) + 4)|0;
 $9 = $8;
 HEAP32[$9>>2] = $5;
 $10 = (($this) + 8|0);
 __ZN5b2Rot3SetEf($10,$angle);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem16ConnectionFilterC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((8968 + 8|0));
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem13RequestBufferIfEEPT_S2_($this,$buffer) {
 $this = $this|0;
 $buffer = $buffer|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($buffer|0)==(0|0);
 if (!($0)) {
  $$0 = $buffer;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (($this) + 48|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  __ZN16b2ParticleSystem34ReallocateInternalAllocatedBuffersEi($this,256);
 }
 $4 = (($this) + 400|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = HEAP32[$1>>2]|0;
 $7 = $6 << 2;
 $8 = (__ZN16b2BlockAllocator8AllocateEi($5,$7)|0);
 $9 = HEAP32[$1>>2]|0;
 $10 = $9 << 2;
 _memset(($8|0),0,($10|0))|0;
 $$0 = $8;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK16b2ParticleSystem13UpdateProxiesER16b2GrowableBufferINS_5ProxyEE($this,$proxies) {
 $this = $this|0;
 $proxies = $proxies|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNK16b2ParticleSystem23UpdateProxies_ReferenceER16b2GrowableBufferINS_5ProxyEE($this,$proxies);
 STACKTOP = sp;return;
}
function __ZN17b2ParticlePairSetC2EP16b2StackAllocator($this,$allocator) {
 $this = $this|0;
 $allocator = $allocator|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIiiEEEC2EP16b2StackAllocator($this,$allocator);
 STACKTOP = sp;return;
}
function __ZNK16b2ParticleSystem12FindContactsER16b2GrowableBufferI17b2ParticleContactE($this,$contacts) {
 $this = $this|0;
 $contacts = $contacts|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZNK16b2ParticleSystem22FindContacts_ReferenceER16b2GrowableBufferI17b2ParticleContactE($this,$contacts);
 STACKTOP = sp;return;
}
function __ZL25b2ParticleContactIsZombieRK17b2ParticleContact($contact) {
 $contact = $contact|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK17b2ParticleContact8GetFlagsEv($contact)|0);
 $1 = $0 & 2;
 $2 = ($1|0)!=(0);
 STACKTOP = sp;return ($2|0);
}
function __ZN12_GLOBAL__N_117FixedSetAllocatorD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12_GLOBAL__N_117FixedSetAllocator5ClearEv($this);
 STACKTOP = sp;return;
}
function __ZL22ParticleCanBeConnectedjP15b2ParticleGroup($flags,$group) {
 $flags = $flags|0;
 $group = $group|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $flags & 28;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = ($group|0)==(0|0);
  if ($2) {
   $6 = 0;
  } else {
   $3 = (__ZNK15b2ParticleGroup13GetGroupFlagsEv($group)|0);
   $4 = $3 & 2;
   $5 = ($4|0)!=(0);
   $6 = $5;
  }
 } else {
  $6 = 1;
 }
 STACKTOP = sp;return ($6|0);
}
function __ZN16b2GrowableBufferI14b2ParticlePairE6AppendEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)<($3|0);
 if (!($4)) {
  __ZN16b2GrowableBufferI14b2ParticlePairE4GrowEv($this);
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = (($5) + 1)|0;
 HEAP32[$0>>2] = $6;
 $7 = HEAP32[$this>>2]|0;
 $8 = (($7) + (($5*20)|0)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZNK17b2ParticleContact8GetFlagsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN16b2GrowableBufferI14b2ParticlePairE5BeginEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN16b2GrowableBufferI14b2ParticlePairE3EndEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + (($1*20)|0)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZNSt3__120get_temporary_bufferI14b2ParticlePairEENS_4pairIPT_iEEi($agg$result,$__n) {
 $agg$result = $agg$result|0;
 $__n = $__n|0;
 var $$02 = 0, $$__n = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$agg$result>>2] = 0;
 $0 = (($agg$result) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = ($__n|0)>(107374182);
 $$__n = $1 ? 107374182 : $__n;
 $2 = ($$__n|0)>(0);
 if ($2) {
  $$02 = $$__n;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $3 = ($$02*20)|0;
  $4 = (__ZnwjRKSt9nothrow_t($3,11256)|0);
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   label = 3;
   break;
  }
  $6 = (($$02|0) / 2)&-1;
  $7 = ($$02|0)>(1);
  if ($7) {
   $$02 = $6;
  } else {
   label = 5;
   break;
  }
 }
 if ((label|0) == 3) {
  HEAP32[$agg$result>>2] = $4;
  HEAP32[$0>>2] = $$02;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 5) {
  HEAP32[$agg$result>>2] = $4;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__113__stable_sortIRPFbRK14b2ParticlePairS3_EPS1_EEvT0_S8_T_NS_15iterator_traitsIS8_E15difference_typeEPNSB_10value_typeEi($__first,$__last,$__comp,$__len,$__buff,$__buff_size) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 $__len = $__len|0;
 $__buff = $__buff|0;
 $__buff_size = $__buff_size|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__t$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i = sp;
 if ((($__len|0) == 2)) {
  $0 = HEAP32[$__comp>>2]|0;
  $1 = (($__last) + -20|0);
  $2 = (FUNCTION_TABLE_iii[$0 & 63]($1,$__first)|0);
  if (!($2)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i+16>>2]=HEAP32[$__first+16>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$__first+16>>2]=HEAP32[$1+16>>2]|0;
  ;HEAP32[$1+0>>2]=HEAP32[$__t$i+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$__t$i+16>>2]|0;
  STACKTOP = sp;return;
 } else if ((($__len|0) == 1) | (($__len|0) == 0)) {
  STACKTOP = sp;return;
 } else {
  $3 = ($__len|0)<(129);
  if ($3) {
   __ZNSt3__116__insertion_sortIRPFbRK14b2ParticlePairS3_EPS1_EEvT0_S8_T_($__first,$__last,$__comp);
   STACKTOP = sp;return;
  }
  $4 = (($__len|0) / 2)&-1;
  $5 = (($__first) + (($4*20)|0)|0);
  $6 = ($__len|0)>($__buff_size|0);
  if ($6) {
   __ZNSt3__113__stable_sortIRPFbRK14b2ParticlePairS3_EPS1_EEvT0_S8_T_NS_15iterator_traitsIS8_E15difference_typeEPNSB_10value_typeEi($__first,$5,$__comp,$4,$__buff,$__buff_size);
   $10 = (($__len) - ($4))|0;
   __ZNSt3__113__stable_sortIRPFbRK14b2ParticlePairS3_EPS1_EEvT0_S8_T_NS_15iterator_traitsIS8_E15difference_typeEPNSB_10value_typeEi($5,$__last,$__comp,$10,$__buff,$__buff_size);
   __ZNSt3__115__inplace_mergeIRPFbRK14b2ParticlePairS3_EPS1_EEvT0_S8_S8_T_NS_15iterator_traitsIS8_E15difference_typeESC_PNSB_10value_typeEi($__first,$5,$__last,$__comp,$4,$10,$__buff,$__buff_size);
   STACKTOP = sp;return;
  } else {
   __ZNSt3__118__stable_sort_moveIRPFbRK14b2ParticlePairS3_EPS1_EEvT0_S8_T_NS_15iterator_traitsIS8_E15difference_typeEPNSB_10value_typeE($__first,$5,$__comp,$4,$__buff);
   $7 = (($__len) - ($4))|0;
   $8 = (($__buff) + (($4*20)|0)|0);
   __ZNSt3__118__stable_sort_moveIRPFbRK14b2ParticlePairS3_EPS1_EEvT0_S8_T_NS_15iterator_traitsIS8_E15difference_typeEPNSB_10value_typeE($5,$__last,$__comp,$7,$8);
   $9 = (($__buff) + (($__len*20)|0)|0);
   __ZNSt3__119__merge_move_assignIRPFbRK14b2ParticlePairS3_EPS1_S7_S7_EEvT0_S8_T1_S9_T2_T_($__buff,$8,$8,$9,$__first,$__comp);
   STACKTOP = sp;return;
  }
 }
}
function __ZN16b2GrowableBufferI14b2ParticlePairE6UniqueIPFbRKS0_S4_EEEPS0_T_($this,$pred) {
 $this = $this|0;
 $pred = $pred|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + (($2*20)|0)|0);
 $4 = (__ZNSt3__16uniqueIP14b2ParticlePairPFbRKS1_S4_EEET_S7_S7_T0_($0,$3,$pred)|0);
 __ZN16b2GrowableBufferI14b2ParticlePairE7ShortenEPKS0_($this,$4);
 STACKTOP = sp;return ($4|0);
}
function __ZZN16b2ParticleSystem20UpdatePairsAndTriadsEiiRKNS_16ConnectionFilterEEN20UpdateTriadsCallbackC2EPS_PS1_($this,$system,$filter) {
 $this = $this|0;
 $system = $system|0;
 $filter = $filter|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16b2VoronoiDiagram12NodeCallbackC2Ev($this);
 HEAP32[$this>>2] = ((8576 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $system;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = $filter;
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferI15b2ParticleTriadE5BeginEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN16b2GrowableBufferI15b2ParticleTriadE3EndEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + (($1*60)|0)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZNSt3__120get_temporary_bufferI15b2ParticleTriadEENS_4pairIPT_iEEi($agg$result,$__n) {
 $agg$result = $agg$result|0;
 $__n = $__n|0;
 var $$02 = 0, $$__n = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$agg$result>>2] = 0;
 $0 = (($agg$result) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = ($__n|0)>(35791394);
 $$__n = $1 ? 35791394 : $__n;
 $2 = ($$__n|0)>(0);
 if ($2) {
  $$02 = $$__n;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $3 = ($$02*60)|0;
  $4 = (__ZnwjRKSt9nothrow_t($3,11256)|0);
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   label = 3;
   break;
  }
  $6 = (($$02|0) / 2)&-1;
  $7 = ($$02|0)>(1);
  if ($7) {
   $$02 = $6;
  } else {
   label = 5;
   break;
  }
 }
 if ((label|0) == 3) {
  HEAP32[$agg$result>>2] = $4;
  HEAP32[$0>>2] = $$02;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 5) {
  HEAP32[$agg$result>>2] = $4;
  STACKTOP = sp;return;
 }
}
function __ZNSt3__113__stable_sortIRPFbRK15b2ParticleTriadS3_EPS1_EEvT0_S8_T_NS_15iterator_traitsIS8_E15difference_typeEPNSB_10value_typeEi($__first,$__last,$__comp,$__len,$__buff,$__buff_size) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 $__len = $__len|0;
 $__buff = $__buff|0;
 $__buff_size = $__buff_size|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__t$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $__t$i = sp;
 if ((($__len|0) == 1) | (($__len|0) == 0)) {
  STACKTOP = sp;return;
 } else if ((($__len|0) == 2)) {
  $0 = HEAP32[$__comp>>2]|0;
  $1 = (($__last) + -60|0);
  $2 = (FUNCTION_TABLE_iii[$0 & 63]($1,$__first)|0);
  if (!($2)) {
   STACKTOP = sp;return;
  }
  dest=$__t$i+0|0; src=$__first+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$__first+0|0; src=$1+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$1+0|0; src=$__t$i+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 } else {
  $3 = ($__len|0)<(129);
  if ($3) {
   __ZNSt3__116__insertion_sortIRPFbRK15b2ParticleTriadS3_EPS1_EEvT0_S8_T_($__first,$__last,$__comp);
   STACKTOP = sp;return;
  }
  $4 = (($__len|0) / 2)&-1;
  $5 = (($__first) + (($4*60)|0)|0);
  $6 = ($__len|0)>($__buff_size|0);
  if ($6) {
   __ZNSt3__113__stable_sortIRPFbRK15b2ParticleTriadS3_EPS1_EEvT0_S8_T_NS_15iterator_traitsIS8_E15difference_typeEPNSB_10value_typeEi($__first,$5,$__comp,$4,$__buff,$__buff_size);
   $10 = (($__len) - ($4))|0;
   __ZNSt3__113__stable_sortIRPFbRK15b2ParticleTriadS3_EPS1_EEvT0_S8_T_NS_15iterator_traitsIS8_E15difference_typeEPNSB_10value_typeEi($5,$__last,$__comp,$10,$__buff,$__buff_size);
   __ZNSt3__115__inplace_mergeIRPFbRK15b2ParticleTriadS3_EPS1_EEvT0_S8_S8_T_NS_15iterator_traitsIS8_E15difference_typeESC_PNSB_10value_typeEi($__first,$5,$__last,$__comp,$4,$10,$__buff,$__buff_size);
   STACKTOP = sp;return;
  } else {
   __ZNSt3__118__stable_sort_moveIRPFbRK15b2ParticleTriadS3_EPS1_EEvT0_S8_T_NS_15iterator_traitsIS8_E15difference_typeEPNSB_10value_typeE($__first,$5,$__comp,$4,$__buff);
   $7 = (($__len) - ($4))|0;
   $8 = (($__buff) + (($4*60)|0)|0);
   __ZNSt3__118__stable_sort_moveIRPFbRK15b2ParticleTriadS3_EPS1_EEvT0_S8_T_NS_15iterator_traitsIS8_E15difference_typeEPNSB_10value_typeE($5,$__last,$__comp,$7,$8);
   $9 = (($__buff) + (($__len*60)|0)|0);
   __ZNSt3__119__merge_move_assignIRPFbRK15b2ParticleTriadS3_EPS1_S7_S7_EEvT0_S8_T1_S9_T2_T_($__buff,$8,$8,$9,$__first,$__comp);
   STACKTOP = sp;return;
  }
 }
}
function __ZN16b2GrowableBufferI15b2ParticleTriadE6UniqueIPFbRKS0_S4_EEEPS0_T_($this,$pred) {
 $this = $this|0;
 $pred = $pred|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + (($2*60)|0)|0);
 $4 = (__ZNSt3__16uniqueIP15b2ParticleTriadPFbRKS1_S4_EEET_S7_S7_T0_($0,$3,$pred)|0);
 __ZN16b2GrowableBufferI15b2ParticleTriadE7ShortenEPKS0_($this,$4);
 STACKTOP = sp;return ($4|0);
}
function __ZZN16b2ParticleSystem18JoinParticleGroupsEP15b2ParticleGroupS1_EN24JoinParticleGroupsFilterC2Ei($this,$threshold) {
 $this = $this|0;
 $threshold = $threshold|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16b2ParticleSystem16ConnectionFilterC2Ev($this);
 HEAP32[$this>>2] = ((9000 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $threshold;
 STACKTOP = sp;return;
}
function __ZNK15b2ParticleGroup13GetGroupFlagsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & -25;
 STACKTOP = sp;return ($2|0);
}
function __ZZN16b2ParticleSystem41UpdatePairsAndTriadsWithReactiveParticlesEvEN14ReactiveFilterC2EPj($this,$flagsBuffer) {
 $this = $this|0;
 $flagsBuffer = $flagsBuffer|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16b2ParticleSystem16ConnectionFilterC2Ev($this);
 HEAP32[$this>>2] = ((8784 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $flagsBuffer;
 STACKTOP = sp;return;
}
function __ZNK17b2ParticleContact9GetWeightEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = +HEAPF32[$0>>2];
 STACKTOP = sp;return (+$1);
}
function __ZL10computeTagff($x,$y) {
 $x = +$x;
 $y = +$y;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0.0, $4 = 0.0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $y + 2048.0;
 $1 = (~~(($0))>>>0);
 $2 = $1 << 20;
 $3 = $x * 256.0;
 $4 = $3 + 524288.0;
 $5 = (~~(($4))>>>0);
 $6 = (($2) + ($5))|0;
 STACKTOP = sp;return ($6|0);
}
function __ZNK16b2GrowableBufferIN16b2ParticleSystem5ProxyEE5BeginEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZNK16b2GrowableBufferIN16b2ParticleSystem5ProxyEE3EndEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + ($1<<3)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZNSt3__113__lower_boundIRNS_6__lessIN16b2ParticleSystem5ProxyEjEEPKS3_jEET0_S8_S8_RKT1_T_($__first,$__last,$__value_,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__value_ = $__value_|0;
 $__comp = $__comp|0;
 var $$0$ph = 0, $$neg1 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0 = 0, $__len$0$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 3;
 $$0$ph = $__first;$__len$0$ph = $3;
 L1: while(1) {
  $__len$0 = $__len$0$ph;
  while(1) {
   $4 = ($__len$0|0)==(0);
   if ($4) {
    break L1;
   }
   $5 = (($__len$0|0) / 2)&-1;
   $6 = (($$0$ph) + ($5<<3)|0);
   $7 = HEAP32[$__value_>>2]|0;
   $8 = (__ZltRKN16b2ParticleSystem5ProxyEj($6,$7)|0);
   if ($8) {
    break;
   } else {
    $__len$0 = $5;
   }
  }
  $$sum = (($5) + 1)|0;
  $9 = (($$0$ph) + ($$sum<<3)|0);
  $$neg1 = (($__len$0) + -1)|0;
  $10 = (($$neg1) - ($5))|0;
  $$0$ph = $9;$__len$0$ph = $10;
 }
 STACKTOP = sp;return ($$0$ph|0);
}
function __ZNSt3__113__upper_boundIRNS_6__lessIjN16b2ParticleSystem5ProxyEEEPKS3_jEET0_S8_S8_RKT1_T_($__first,$__last,$__value_,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__value_ = $__value_|0;
 $__comp = $__comp|0;
 var $$0$ph = 0, $$neg1 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0 = 0, $__len$0$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 3;
 $$0$ph = $__first;$__len$0$ph = $3;
 L1: while(1) {
  $__len$0 = $__len$0$ph;
  while(1) {
   $4 = ($__len$0|0)==(0);
   if ($4) {
    break L1;
   }
   $5 = (($__len$0|0) / 2)&-1;
   $6 = (($$0$ph) + ($5<<3)|0);
   $7 = HEAP32[$__value_>>2]|0;
   $8 = (__ZltjRKN16b2ParticleSystem5ProxyE($7,$6)|0);
   if ($8) {
    $__len$0 = $5;
   } else {
    break;
   }
  }
  $$sum = (($5) + 1)|0;
  $9 = (($$0$ph) + ($$sum<<3)|0);
  $$neg1 = (($__len$0) + -1)|0;
  $10 = (($$neg1) - ($5))|0;
  $$0$ph = $9;$__len$0$ph = $10;
 }
 STACKTOP = sp;return ($$0$ph|0);
}
function __ZN16b2GrowableBufferI17b2ParticleContactE8SetCountEi($this,$newCount) {
 $this = $this|0;
 $newCount = $newCount|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $newCount;
 STACKTOP = sp;return;
}
function __ZL18computeRelativeTagjii($tag,$x,$y) {
 $tag = $tag|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $y << 20;
 $1 = $x << 8;
 $2 = (($1) + ($tag))|0;
 $3 = (($2) + ($0))|0;
 STACKTOP = sp;return ($3|0);
}
function __ZNK16b2ParticleSystem10AddContactEiiR16b2GrowableBufferI17b2ParticleContactE($this,$a,$b,$contacts) {
 $this = $this|0;
 $a = $a|0;
 $b = $b|0;
 $contacts = $contacts|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0;
 var $7 = 0.0, $8 = 0, $9 = 0.0, $d = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $d = sp + 8|0;
 $0 = sp;
 $1 = (($this) + 96|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($b<<3)|0);
 $4 = (($2) + ($a<<3)|0);
 __ZmiRK6b2Vec2S1_($d,$3,$4);
 $5 = (+__Z5b2DotRK6b2Vec2S1_($d,$d));
 $6 = (($this) + 40|0);
 $7 = +HEAPF32[$6>>2];
 $8 = $5 < $7;
 if (!($8)) {
  STACKTOP = sp;return;
 }
 $9 = (+__Z9b2InvSqrtf($5));
 $10 = (__ZN16b2GrowableBufferI17b2ParticleContactE6AppendEv($contacts)|0);
 __ZN17b2ParticleContact10SetIndicesEii($10,$a,$b);
 $11 = (($this) + 88|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($12) + ($a<<2)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($12) + ($b<<2)|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16 | $14;
 __ZN17b2ParticleContact8SetFlagsEj($10,$17);
 $18 = $5 * $9;
 $19 = (($this) + 36|0);
 $20 = +HEAPF32[$19>>2];
 $21 = $18 * $20;
 $22 = 1.0 - $21;
 __ZN17b2ParticleContact9SetWeightEf($10,$22);
 __ZmlfRK6b2Vec2($0,$9,$d);
 __ZN17b2ParticleContact9SetNormalERK6b2Vec2($10,$0);
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEE3EndEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + ($1<<3)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZNSt3__16__sortIRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEvT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $__i$05 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0;
 var $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -8|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 3;
   switch ($4|0) {
   case 4:  {
    label = 7;
    break L1;
    break;
   }
   case 5:  {
    label = 8;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 45;
    break L1;
    break;
   }
   default: {
   }
   }
   $36 = ($3|0)<(248);
   if ($36) {
    label = 10;
    break L1;
   }
   $37 = ($3|0)>(7992);
   $38 = (($4|0) / 2)&-1;
   $39 = (($$0) + ($38<<3)|0);
   if ($37) {
    $40 = (($4|0) / 4)&-1;
    $41 = (($$0) + ($40<<3)|0);
    $$sum = (($40) + ($38))|0;
    $42 = (($$0) + ($$sum<<3)|0);
    $43 = (__ZNSt3__17__sort5IRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEjT0_S7_S7_S7_S7_T_($$0,$41,$39,$42,$1,$__comp)|0);
    $__n_swaps$0 = $43;
   } else {
    $44 = (__ZNSt3__17__sort3IRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEjT0_S7_S7_T_($$0,$39,$1,$__comp)|0);
    $__n_swaps$0 = $44;
   }
   $45 = (__ZltRKN16b2ParticleSystem5ProxyES2_($$0,$39)|0);
   do {
    if ($45) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $46 = (($__j$0) + -8|0);
      $47 = ($$0|0)==($46|0);
      if ($47) {
       break;
      }
      $102 = (__ZltRKN16b2ParticleSystem5ProxyES2_($46,$39)|0);
      if ($102) {
       label = 28;
       break;
      } else {
       $__j$0 = $46;
      }
     }
     if ((label|0) == 28) {
      label = 0;
      $103 = $$0;
      $104 = $103;
      $105 = HEAP32[$104>>2]|0;
      $106 = (($103) + 4)|0;
      $107 = $106;
      $108 = HEAP32[$107>>2]|0;
      $109 = $46;
      $110 = $109;
      $111 = HEAP32[$110>>2]|0;
      $112 = (($109) + 4)|0;
      $113 = $112;
      $114 = HEAP32[$113>>2]|0;
      $115 = $$0;
      $116 = $115;
      HEAP32[$116>>2] = $111;
      $117 = (($115) + 4)|0;
      $118 = $117;
      HEAP32[$118>>2] = $114;
      $119 = $46;
      $120 = $119;
      HEAP32[$120>>2] = $105;
      $121 = (($119) + 4)|0;
      $122 = $121;
      HEAP32[$122>>2] = $108;
      $123 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $46;$__n_swaps$3 = $123;
      break;
     }
     $48 = (($$0) + 8|0);
     $49 = (__ZltRKN16b2ParticleSystem5ProxyES2_($$0,$1)|0);
     if ($49) {
      $__i$1 = $48;
     } else {
      $50 = ($48|0)==($1|0);
      if ($50) {
       label = 45;
       break L1;
      } else {
       $__i$05 = $48;
      }
      while(1) {
       $53 = (__ZltRKN16b2ParticleSystem5ProxyES2_($$0,$__i$05)|0);
       $51 = (($__i$05) + 8|0);
       if ($53) {
        break;
       }
       $52 = ($51|0)==($1|0);
       if ($52) {
        label = 45;
        break L1;
       } else {
        $__i$05 = $51;
       }
      }
      $54 = $__i$05;
      $55 = $54;
      $56 = HEAP32[$55>>2]|0;
      $57 = (($54) + 4)|0;
      $58 = $57;
      $59 = HEAP32[$58>>2]|0;
      $60 = $1;
      $61 = $60;
      $62 = HEAP32[$61>>2]|0;
      $63 = (($60) + 4)|0;
      $64 = $63;
      $65 = HEAP32[$64>>2]|0;
      $66 = $__i$05;
      $67 = $66;
      HEAP32[$67>>2] = $62;
      $68 = (($66) + 4)|0;
      $69 = $68;
      HEAP32[$69>>2] = $65;
      $70 = $1;
      $71 = $70;
      HEAP32[$71>>2] = $56;
      $72 = (($70) + 4)|0;
      $73 = $72;
      HEAP32[$73>>2] = $59;
      $74 = (($__i$05) + 8|0);
      $__i$1 = $74;
     }
     $75 = ($__i$1|0)==($1|0);
     if ($75) {
      label = 45;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $__i$2 = $__i$2$ph;
      while(1) {
       $76 = (__ZltRKN16b2ParticleSystem5ProxyES2_($$0,$__i$2)|0);
       $77 = (($__i$2) + 8|0);
       if ($76) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $77;
       }
      }
      while(1) {
       $78 = (($__j$2) + -8|0);
       $79 = (__ZltRKN16b2ParticleSystem5ProxyES2_($$0,$78)|0);
       if ($79) {
        $__j$2 = $78;
       } else {
        break;
       }
      }
      $80 = ($__i$2>>>0)<($78>>>0);
      if (!($80)) {
       $$0 = $__i$2;
       continue L3;
      }
      $81 = $__i$2;
      $82 = $81;
      $83 = HEAP32[$82>>2]|0;
      $84 = (($81) + 4)|0;
      $85 = $84;
      $86 = HEAP32[$85>>2]|0;
      $87 = $78;
      $88 = $87;
      $89 = HEAP32[$88>>2]|0;
      $90 = (($87) + 4)|0;
      $91 = $90;
      $92 = HEAP32[$91>>2]|0;
      $93 = $__i$2;
      $94 = $93;
      HEAP32[$94>>2] = $89;
      $95 = (($93) + 4)|0;
      $96 = $95;
      HEAP32[$96>>2] = $92;
      $97 = $78;
      $98 = $97;
      HEAP32[$98>>2] = $83;
      $99 = (($97) + 4)|0;
      $100 = $99;
      HEAP32[$100>>2] = $86;
      $101 = (($__i$2) + 8|0);
      $__i$2$ph = $101;$__j$1$ph = $78;
     }
    }
   } while(0);
   $124 = (($$0) + 8|0);
   $125 = ($124>>>0)<($__j$3>>>0);
   L34: do {
    if ($125) {
     $__i$3$ph = $124;$__j$4$ph = $__j$3;$__m$0$ph = $39;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $__i$3 = $__i$3$ph;
      while(1) {
       $126 = (__ZltRKN16b2ParticleSystem5ProxyES2_($__i$3,$__m$0$ph)|0);
       $127 = (($__i$3) + 8|0);
       if ($126) {
        $__i$3 = $127;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $128 = (($__j$5) + -8|0);
       $129 = (__ZltRKN16b2ParticleSystem5ProxyES2_($128,$__m$0$ph)|0);
       if ($129) {
        break;
       } else {
        $__j$5 = $128;
       }
      }
      $130 = ($__i$3>>>0)>($128>>>0);
      if ($130) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L34;
      }
      $131 = $__i$3;
      $132 = $131;
      $133 = HEAP32[$132>>2]|0;
      $134 = (($131) + 4)|0;
      $135 = $134;
      $136 = HEAP32[$135>>2]|0;
      $137 = $128;
      $138 = $137;
      $139 = HEAP32[$138>>2]|0;
      $140 = (($137) + 4)|0;
      $141 = $140;
      $142 = HEAP32[$141>>2]|0;
      $143 = $__i$3;
      $144 = $143;
      HEAP32[$144>>2] = $139;
      $145 = (($143) + 4)|0;
      $146 = $145;
      HEAP32[$146>>2] = $142;
      $147 = $128;
      $148 = $147;
      HEAP32[$148>>2] = $133;
      $149 = (($147) + 4)|0;
      $150 = $149;
      HEAP32[$150>>2] = $136;
      $151 = (($__n_swaps$4$ph) + 1)|0;
      $152 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $152 ? $128 : $__m$0$ph;
      $153 = (($__i$3) + 8|0);
      $__i$3$ph = $153;$__j$4$ph = $128;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $151;
     }
    } else {
     $__i$4 = $124;$__m$2 = $39;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $154 = ($__i$4|0)==($__m$2|0);
   if ($154) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $155 = (__ZltRKN16b2ParticleSystem5ProxyES2_($__m$2,$__i$4)|0);
    if ($155) {
     $156 = $__i$4;
     $157 = $156;
     $158 = HEAP32[$157>>2]|0;
     $159 = (($156) + 4)|0;
     $160 = $159;
     $161 = HEAP32[$160>>2]|0;
     $162 = $__m$2;
     $163 = $162;
     $164 = HEAP32[$163>>2]|0;
     $165 = (($162) + 4)|0;
     $166 = $165;
     $167 = HEAP32[$166>>2]|0;
     $168 = $__i$4;
     $169 = $168;
     HEAP32[$169>>2] = $164;
     $170 = (($168) + 4)|0;
     $171 = $170;
     HEAP32[$171>>2] = $167;
     $172 = $__m$2;
     $173 = $172;
     HEAP32[$173>>2] = $158;
     $174 = (($172) + 4)|0;
     $175 = $174;
     HEAP32[$175>>2] = $161;
     $176 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $176;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $177 = ($__n_swaps$6|0)==(0);
   if ($177) {
    $178 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEbT0_S7_T_($$0,$__i$4,$__comp)|0);
    $179 = (($__i$4) + 8|0);
    $180 = (__ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEbT0_S7_T_($179,$$01$ph,$__comp)|0);
    if ($180) {
     label = 40;
     break;
    }
    if ($178) {
     $$0 = $179;
     continue;
    }
   }
   $181 = $__i$4;
   $182 = (($181) - ($2))|0;
   $183 = (($0) - ($181))|0;
   $184 = ($182|0)<($183|0);
   if (!($184)) {
    label = 44;
    break;
   }
   __ZNSt3__16__sortIRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEvT0_S7_T_($$0,$__i$4,$__comp);
   $185 = (($__i$4) + 8|0);
   $$0 = $185;
  }
  if ((label|0) == 40) {
   label = 0;
   if ($178) {
    label = 45;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 44) {
   label = 0;
   $186 = (($__i$4) + 8|0);
   __ZNSt3__16__sortIRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEvT0_S7_T_($186,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = (($$01$ph) + -8|0);
  $6 = (__ZltRKN16b2ParticleSystem5ProxyES2_($5,$$0)|0);
  if (!($6)) {
   STACKTOP = sp;return;
  }
  $7 = $$0;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) + 4)|0;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $13 = $5;
  $14 = $13;
  $15 = HEAP32[$14>>2]|0;
  $16 = (($13) + 4)|0;
  $17 = $16;
  $18 = HEAP32[$17>>2]|0;
  $19 = $$0;
  $20 = $19;
  HEAP32[$20>>2] = $15;
  $21 = (($19) + 4)|0;
  $22 = $21;
  HEAP32[$22>>2] = $18;
  $23 = $5;
  $24 = $23;
  HEAP32[$24>>2] = $9;
  $25 = (($23) + 4)|0;
  $26 = $25;
  HEAP32[$26>>2] = $12;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $27 = (($$0) + 8|0);
  $28 = (($$01$ph) + -8|0);
  (__ZNSt3__17__sort3IRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEjT0_S7_S7_T_($$0,$27,$28,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 7) {
  $29 = (($$0) + 8|0);
  $30 = (($$0) + 16|0);
  $31 = (($$01$ph) + -8|0);
  (__ZNSt3__17__sort4IRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEjT0_S7_S7_S7_T_($$0,$29,$30,$31,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 8) {
  $32 = (($$0) + 8|0);
  $33 = (($$0) + 16|0);
  $34 = (($$0) + 24|0);
  $35 = (($$01$ph) + -8|0);
  (__ZNSt3__17__sort5IRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEjT0_S7_S7_S7_S7_T_($$0,$32,$33,$34,$35,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 10) {
  __ZNSt3__118__insertion_sort_3IRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEvT0_S7_T_($$0,$$01$ph,$__comp);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 45) {
  STACKTOP = sp;return;
 }
}
function __ZNK16b2ParticleSystem24GetParticleContactFilterEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 131072;
 $3 = ($2|0)==(0);
 if ($3) {
  $8 = 0;
  STACKTOP = sp;return ($8|0);
 }
 $4 = (($this) + 400|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 102948|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7;
 STACKTOP = sp;return ($8|0);
}
function __ZN32b2ParticleContactRemovePredicateC2EP16b2ParticleSystemP15b2ContactFilter($this,$system,$contactFilter) {
 $this = $this|0;
 $system = $system|0;
 $contactFilter = $contactFilter|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $system;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $contactFilter;
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferI17b2ParticleContactE8RemoveIfI32b2ParticleContactRemovePredicateEEPS0_T_($this,$pred) {
 $this = $this|0;
 $pred = $pred|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tmpcast$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $tmpcast$byval_copy = sp + 8|0;
 $0 = sp;
 $1 = HEAP32[$this>>2]|0;
 $2 = (($this) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + (($3*24)|0)|0);
 $5 = $pred;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = (($5) + 4)|0;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = $0;
 $12 = $11;
 HEAP32[$12>>2] = $7;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = $10;
 ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$0+4>>2]|0;
 $15 = (__ZNSt3__19remove_ifIP17b2ParticleContact32b2ParticleContactRemovePredicateEET_S4_S4_T0_($1,$4,$tmpcast$byval_copy)|0);
 __ZN16b2GrowableBufferI17b2ParticleContactE7ShortenEPKS0_($this,$15);
 STACKTOP = sp;return ($15|0);
}
function __ZNK16b2ParticleSystem26GetParticleContactListenerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 32768;
 $3 = ($2|0)==(0);
 if ($3) {
  $8 = 0;
  STACKTOP = sp;return ($8|0);
 }
 $4 = (($this) + 400|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 102952|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7;
 STACKTOP = sp;return ($8|0);
}
function __ZNK16b2GrowableBufferI17b2ParticleContactE5BeginEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZNK16b2ParticleSystem14GetFlagsBufferEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN12_GLOBAL__N_117FixedSetAllocator5ClearEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 __ZN16b2StackAllocator4FreeEPv($3,$0);
 HEAP32[$this>>2] = 0;
 $4 = (($this) + 8|0);
 HEAP32[$4>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIiiEEE8AllocateEi($this,$numberOfObjects) {
 $this = $this|0;
 $numberOfObjects = $numberOfObjects|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12_GLOBAL__N_117FixedSetAllocator5ClearEv($this);
 $0 = (__ZN12_GLOBAL__N_117FixedSetAllocator8AllocateEii($this,$numberOfObjects)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIiiEEE9GetBufferEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN12_GLOBAL__N_117FixedSetAllocator9GetBufferEv($this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12_GLOBAL__N_117FixedSetAllocator8SetCountEi($this,$count) {
 $this = $this|0;
 $count = $count|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = $count;
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_115LightweightPairIiiE7CompareERKS1_S3_($left,$right) {
 $left = $left|0;
 $right = $right|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$left>>2]|0;
 $1 = HEAP32[$right>>2]|0;
 $2 = ($0|0)<($1|0);
 if (!($2)) {
  $8 = 0;
  STACKTOP = sp;return ($8|0);
 }
 $3 = (($left) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($right) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)<($6|0);
 $8 = $7;
 STACKTOP = sp;return ($8|0);
}
function __ZNSt3__16__sortIRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEvT0_SA_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__i$05 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0;
 var $__n_swaps$5 = 0, $__n_swaps$6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -8|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 3;
   switch ($4|0) {
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 5:  {
    label = 8;
    break L1;
    break;
   }
   case 4:  {
    label = 7;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 45;
    break L1;
    break;
   }
   default: {
   }
   }
   $37 = ($3|0)<(248);
   if ($37) {
    label = 10;
    break L1;
   }
   $38 = ($3|0)>(7992);
   $39 = (($4|0) / 2)&-1;
   $40 = (($$0) + ($39<<3)|0);
   if ($38) {
    $41 = (($4|0) / 4)&-1;
    $42 = (($$0) + ($41<<3)|0);
    $$sum = (($41) + ($39))|0;
    $43 = (($$0) + ($$sum<<3)|0);
    $44 = (__ZNSt3__17__sort5IRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEjT0_SA_SA_SA_SA_T_($$0,$42,$40,$43,$1,$__comp)|0);
    $__n_swaps$0 = $44;
   } else {
    $45 = (__ZNSt3__17__sort3IRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEjT0_SA_SA_T_($$0,$40,$1,$__comp)|0);
    $__n_swaps$0 = $45;
   }
   $46 = HEAP32[$__comp>>2]|0;
   $47 = (FUNCTION_TABLE_iii[$46 & 63]($$0,$40)|0);
   do {
    if ($47) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $48 = (($__j$0) + -8|0);
      $49 = ($$0|0)==($48|0);
      if ($49) {
       break;
      }
      $108 = HEAP32[$__comp>>2]|0;
      $109 = (FUNCTION_TABLE_iii[$108 & 63]($48,$40)|0);
      if ($109) {
       label = 28;
       break;
      } else {
       $__j$0 = $48;
      }
     }
     if ((label|0) == 28) {
      label = 0;
      $110 = $$0;
      $111 = $110;
      $112 = HEAP32[$111>>2]|0;
      $113 = (($110) + 4)|0;
      $114 = $113;
      $115 = HEAP32[$114>>2]|0;
      $116 = $48;
      $117 = $116;
      $118 = HEAP32[$117>>2]|0;
      $119 = (($116) + 4)|0;
      $120 = $119;
      $121 = HEAP32[$120>>2]|0;
      $122 = $$0;
      $123 = $122;
      HEAP32[$123>>2] = $118;
      $124 = (($122) + 4)|0;
      $125 = $124;
      HEAP32[$125>>2] = $121;
      $126 = $48;
      $127 = $126;
      HEAP32[$127>>2] = $112;
      $128 = (($126) + 4)|0;
      $129 = $128;
      HEAP32[$129>>2] = $115;
      $130 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $48;$__n_swaps$3 = $130;
      break;
     }
     $50 = (($$0) + 8|0);
     $51 = HEAP32[$__comp>>2]|0;
     $52 = (FUNCTION_TABLE_iii[$51 & 63]($$0,$1)|0);
     if ($52) {
      $__i$1 = $50;
     } else {
      $53 = ($50|0)==($1|0);
      if ($53) {
       label = 45;
       break L1;
      } else {
       $__i$05 = $50;
      }
      while(1) {
       $56 = HEAP32[$__comp>>2]|0;
       $57 = (FUNCTION_TABLE_iii[$56 & 63]($$0,$__i$05)|0);
       $54 = (($__i$05) + 8|0);
       if ($57) {
        break;
       }
       $55 = ($54|0)==($1|0);
       if ($55) {
        label = 45;
        break L1;
       } else {
        $__i$05 = $54;
       }
      }
      $58 = $__i$05;
      $59 = $58;
      $60 = HEAP32[$59>>2]|0;
      $61 = (($58) + 4)|0;
      $62 = $61;
      $63 = HEAP32[$62>>2]|0;
      $64 = $1;
      $65 = $64;
      $66 = HEAP32[$65>>2]|0;
      $67 = (($64) + 4)|0;
      $68 = $67;
      $69 = HEAP32[$68>>2]|0;
      $70 = $__i$05;
      $71 = $70;
      HEAP32[$71>>2] = $66;
      $72 = (($70) + 4)|0;
      $73 = $72;
      HEAP32[$73>>2] = $69;
      $74 = $1;
      $75 = $74;
      HEAP32[$75>>2] = $60;
      $76 = (($74) + 4)|0;
      $77 = $76;
      HEAP32[$77>>2] = $63;
      $78 = (($__i$05) + 8|0);
      $__i$1 = $78;
     }
     $79 = ($__i$1|0)==($1|0);
     if ($79) {
      label = 45;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $__i$2 = $__i$2$ph;
      while(1) {
       $80 = HEAP32[$__comp>>2]|0;
       $81 = (FUNCTION_TABLE_iii[$80 & 63]($$0,$__i$2)|0);
       $82 = (($__i$2) + 8|0);
       if ($81) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $82;
       }
      }
      while(1) {
       $83 = HEAP32[$__comp>>2]|0;
       $84 = (($__j$2) + -8|0);
       $85 = (FUNCTION_TABLE_iii[$83 & 63]($$0,$84)|0);
       if ($85) {
        $__j$2 = $84;
       } else {
        break;
       }
      }
      $86 = ($__i$2>>>0)<($84>>>0);
      if (!($86)) {
       $$0 = $__i$2;
       continue L3;
      }
      $87 = $__i$2;
      $88 = $87;
      $89 = HEAP32[$88>>2]|0;
      $90 = (($87) + 4)|0;
      $91 = $90;
      $92 = HEAP32[$91>>2]|0;
      $93 = $84;
      $94 = $93;
      $95 = HEAP32[$94>>2]|0;
      $96 = (($93) + 4)|0;
      $97 = $96;
      $98 = HEAP32[$97>>2]|0;
      $99 = $__i$2;
      $100 = $99;
      HEAP32[$100>>2] = $95;
      $101 = (($99) + 4)|0;
      $102 = $101;
      HEAP32[$102>>2] = $98;
      $103 = $84;
      $104 = $103;
      HEAP32[$104>>2] = $89;
      $105 = (($103) + 4)|0;
      $106 = $105;
      HEAP32[$106>>2] = $92;
      $107 = (($__i$2) + 8|0);
      $__i$2$ph = $107;$__j$1$ph = $84;
     }
    }
   } while(0);
   $131 = (($$0) + 8|0);
   $132 = ($131>>>0)<($__j$3>>>0);
   L34: do {
    if ($132) {
     $__i$3$ph = $131;$__j$4$ph = $__j$3;$__m$0$ph = $40;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $__i$3 = $__i$3$ph;
      while(1) {
       $133 = HEAP32[$__comp>>2]|0;
       $134 = (FUNCTION_TABLE_iii[$133 & 63]($__i$3,$__m$0$ph)|0);
       $135 = (($__i$3) + 8|0);
       if ($134) {
        $__i$3 = $135;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $136 = HEAP32[$__comp>>2]|0;
       $137 = (($__j$5) + -8|0);
       $138 = (FUNCTION_TABLE_iii[$136 & 63]($137,$__m$0$ph)|0);
       if ($138) {
        break;
       } else {
        $__j$5 = $137;
       }
      }
      $139 = ($__i$3>>>0)>($137>>>0);
      if ($139) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L34;
      }
      $140 = $__i$3;
      $141 = $140;
      $142 = HEAP32[$141>>2]|0;
      $143 = (($140) + 4)|0;
      $144 = $143;
      $145 = HEAP32[$144>>2]|0;
      $146 = $137;
      $147 = $146;
      $148 = HEAP32[$147>>2]|0;
      $149 = (($146) + 4)|0;
      $150 = $149;
      $151 = HEAP32[$150>>2]|0;
      $152 = $__i$3;
      $153 = $152;
      HEAP32[$153>>2] = $148;
      $154 = (($152) + 4)|0;
      $155 = $154;
      HEAP32[$155>>2] = $151;
      $156 = $137;
      $157 = $156;
      HEAP32[$157>>2] = $142;
      $158 = (($156) + 4)|0;
      $159 = $158;
      HEAP32[$159>>2] = $145;
      $160 = (($__n_swaps$4$ph) + 1)|0;
      $161 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $161 ? $137 : $__m$0$ph;
      $162 = (($__i$3) + 8|0);
      $__i$3$ph = $162;$__j$4$ph = $137;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $160;
     }
    } else {
     $__i$4 = $131;$__m$2 = $40;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $163 = ($__i$4|0)==($__m$2|0);
   if ($163) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $164 = HEAP32[$__comp>>2]|0;
    $165 = (FUNCTION_TABLE_iii[$164 & 63]($__m$2,$__i$4)|0);
    if ($165) {
     $166 = $__i$4;
     $167 = $166;
     $168 = HEAP32[$167>>2]|0;
     $169 = (($166) + 4)|0;
     $170 = $169;
     $171 = HEAP32[$170>>2]|0;
     $172 = $__m$2;
     $173 = $172;
     $174 = HEAP32[$173>>2]|0;
     $175 = (($172) + 4)|0;
     $176 = $175;
     $177 = HEAP32[$176>>2]|0;
     $178 = $__i$4;
     $179 = $178;
     HEAP32[$179>>2] = $174;
     $180 = (($178) + 4)|0;
     $181 = $180;
     HEAP32[$181>>2] = $177;
     $182 = $__m$2;
     $183 = $182;
     HEAP32[$183>>2] = $168;
     $184 = (($182) + 4)|0;
     $185 = $184;
     HEAP32[$185>>2] = $171;
     $186 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $186;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $187 = ($__n_swaps$6|0)==(0);
   if ($187) {
    $188 = (__ZNSt3__127__insertion_sort_incompleteIRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEbT0_SA_T_($$0,$__i$4,$__comp)|0);
    $189 = (($__i$4) + 8|0);
    $190 = (__ZNSt3__127__insertion_sort_incompleteIRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEbT0_SA_T_($189,$$01$ph,$__comp)|0);
    if ($190) {
     label = 40;
     break;
    }
    if ($188) {
     $$0 = $189;
     continue;
    }
   }
   $191 = $__i$4;
   $192 = (($191) - ($2))|0;
   $193 = (($0) - ($191))|0;
   $194 = ($192|0)<($193|0);
   if (!($194)) {
    label = 44;
    break;
   }
   __ZNSt3__16__sortIRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEvT0_SA_T_($$0,$__i$4,$__comp);
   $195 = (($__i$4) + 8|0);
   $$0 = $195;
  }
  if ((label|0) == 40) {
   label = 0;
   if ($188) {
    label = 45;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 44) {
   label = 0;
   $196 = (($__i$4) + 8|0);
   __ZNSt3__16__sortIRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEvT0_SA_T_($196,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = HEAP32[$__comp>>2]|0;
  $6 = (($$01$ph) + -8|0);
  $7 = (FUNCTION_TABLE_iii[$5 & 63]($6,$$0)|0);
  if (!($7)) {
   STACKTOP = sp;return;
  }
  $8 = $$0;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($8) + 4)|0;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = $6;
  $15 = $14;
  $16 = HEAP32[$15>>2]|0;
  $17 = (($14) + 4)|0;
  $18 = $17;
  $19 = HEAP32[$18>>2]|0;
  $20 = $$0;
  $21 = $20;
  HEAP32[$21>>2] = $16;
  $22 = (($20) + 4)|0;
  $23 = $22;
  HEAP32[$23>>2] = $19;
  $24 = $6;
  $25 = $24;
  HEAP32[$25>>2] = $10;
  $26 = (($24) + 4)|0;
  $27 = $26;
  HEAP32[$27>>2] = $13;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $28 = (($$0) + 8|0);
  $29 = (($$01$ph) + -8|0);
  (__ZNSt3__17__sort3IRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEjT0_SA_SA_T_($$0,$28,$29,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 7) {
  $30 = (($$0) + 8|0);
  $31 = (($$0) + 16|0);
  $32 = (($$01$ph) + -8|0);
  (__ZNSt3__17__sort4IRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEjT0_SA_SA_SA_T_($$0,$30,$31,$32,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 8) {
  $33 = (($$0) + 8|0);
  $34 = (($$0) + 16|0);
  $35 = (($$0) + 24|0);
  $36 = (($$01$ph) + -8|0);
  (__ZNSt3__17__sort5IRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEjT0_SA_SA_SA_SA_T_($$0,$33,$34,$35,$36,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 10) {
  __ZNSt3__118__insertion_sort_3IRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEvT0_SA_T_($$0,$$01$ph,$__comp);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 45) {
  STACKTOP = sp;return;
 }
}
function __ZN16b2GrowableBufferI17b2ParticleContactE3EndEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + (($1*24)|0)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZN16b2GrowableBufferI17b2ParticleContactE5BeginEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZNK17b2ParticlePairSet4FindERKN12_GLOBAL__N_115LightweightPairIiiEE($this,$pair) {
 $this = $this|0;
 $pair = $pair|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $index$0 = 0, $swapped = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $swapped = sp;
 $0 = (__ZL23FindItemIndexInFixedSetIN12_GLOBAL__N_115LightweightPairIiiEEEiRKNS0_22TypedFixedSetAllocatorIT_EERKS4_($this,$pair)|0);
 $1 = ($0|0)<(0);
 if (!($1)) {
  $index$0 = $0;
  STACKTOP = sp;return ($index$0|0);
 }
 $2 = (($pair) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$swapped>>2] = $3;
 $4 = HEAP32[$pair>>2]|0;
 $5 = (($swapped) + 4|0);
 HEAP32[$5>>2] = $4;
 $6 = (__ZL23FindItemIndexInFixedSetIN12_GLOBAL__N_115LightweightPairIiiEEEiRKNS0_22TypedFixedSetAllocatorIT_EERKS4_($this,$swapped)|0);
 $index$0 = $6;
 STACKTOP = sp;return ($index$0|0);
}
function __ZN12_GLOBAL__N_117FixedSetAllocator10InvalidateEi($this,$itemIndex) {
 $this = $this|0;
 $itemIndex = $itemIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($itemIndex)|0);
 HEAP8[$2>>0] = 0;
 STACKTOP = sp;return;
}
function __ZNK12_GLOBAL__N_117FixedSetAllocator8GetCountEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK12_GLOBAL__N_117FixedSetAllocator14GetValidBufferEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN16b2GrowableBufferIiE6AppendEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)<($3|0);
 if (!($4)) {
  __ZN16b2GrowableBufferIiE4GrowEv($this);
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = (($5) + 1)|0;
 HEAP32[$0>>2] = $6;
 $7 = HEAP32[$this>>2]|0;
 $8 = (($7) + ($5<<2)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIP9b2FixtureiEEE8AllocateEi($this,$numberOfObjects) {
 $this = $this|0;
 $numberOfObjects = $numberOfObjects|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12_GLOBAL__N_117FixedSetAllocator5ClearEv($this);
 $0 = (__ZN12_GLOBAL__N_117FixedSetAllocator8AllocateEii($this,$numberOfObjects)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIP9b2FixtureiEEE9GetBufferEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN12_GLOBAL__N_117FixedSetAllocator9GetBufferEv($this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12_GLOBAL__N_115LightweightPairIP9b2FixtureiE7CompareERKS3_S5_($left,$right) {
 $left = $left|0;
 $right = $right|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$left>>2]|0;
 $1 = HEAP32[$right>>2]|0;
 $2 = ($0>>>0)<($1>>>0);
 if (!($2)) {
  $8 = 0;
  STACKTOP = sp;return ($8|0);
 }
 $3 = (($left) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($right) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($4|0)<($6|0);
 $8 = $7;
 STACKTOP = sp;return ($8|0);
}
function __ZNSt3__16__sortIRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEvT0_SC_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $__i$05 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0;
 var $__n_swaps$5 = 0, $__n_swaps$6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -8|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 3;
   switch ($4|0) {
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 5:  {
    label = 8;
    break L1;
    break;
   }
   case 4:  {
    label = 7;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 45;
    break L1;
    break;
   }
   default: {
   }
   }
   $37 = ($3|0)<(248);
   if ($37) {
    label = 10;
    break L1;
   }
   $38 = ($3|0)>(7992);
   $39 = (($4|0) / 2)&-1;
   $40 = (($$0) + ($39<<3)|0);
   if ($38) {
    $41 = (($4|0) / 4)&-1;
    $42 = (($$0) + ($41<<3)|0);
    $$sum = (($41) + ($39))|0;
    $43 = (($$0) + ($$sum<<3)|0);
    $44 = (__ZNSt3__17__sort5IRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEjT0_SC_SC_SC_SC_T_($$0,$42,$40,$43,$1,$__comp)|0);
    $__n_swaps$0 = $44;
   } else {
    $45 = (__ZNSt3__17__sort3IRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEjT0_SC_SC_T_($$0,$40,$1,$__comp)|0);
    $__n_swaps$0 = $45;
   }
   $46 = HEAP32[$__comp>>2]|0;
   $47 = (FUNCTION_TABLE_iii[$46 & 63]($$0,$40)|0);
   do {
    if ($47) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $48 = (($__j$0) + -8|0);
      $49 = ($$0|0)==($48|0);
      if ($49) {
       break;
      }
      $108 = HEAP32[$__comp>>2]|0;
      $109 = (FUNCTION_TABLE_iii[$108 & 63]($48,$40)|0);
      if ($109) {
       label = 28;
       break;
      } else {
       $__j$0 = $48;
      }
     }
     if ((label|0) == 28) {
      label = 0;
      $110 = $$0;
      $111 = $110;
      $112 = HEAP32[$111>>2]|0;
      $113 = (($110) + 4)|0;
      $114 = $113;
      $115 = HEAP32[$114>>2]|0;
      $116 = $48;
      $117 = $116;
      $118 = HEAP32[$117>>2]|0;
      $119 = (($116) + 4)|0;
      $120 = $119;
      $121 = HEAP32[$120>>2]|0;
      $122 = $$0;
      $123 = $122;
      HEAP32[$123>>2] = $118;
      $124 = (($122) + 4)|0;
      $125 = $124;
      HEAP32[$125>>2] = $121;
      $126 = $48;
      $127 = $126;
      HEAP32[$127>>2] = $112;
      $128 = (($126) + 4)|0;
      $129 = $128;
      HEAP32[$129>>2] = $115;
      $130 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $48;$__n_swaps$3 = $130;
      break;
     }
     $50 = (($$0) + 8|0);
     $51 = HEAP32[$__comp>>2]|0;
     $52 = (FUNCTION_TABLE_iii[$51 & 63]($$0,$1)|0);
     if ($52) {
      $__i$1 = $50;
     } else {
      $53 = ($50|0)==($1|0);
      if ($53) {
       label = 45;
       break L1;
      } else {
       $__i$05 = $50;
      }
      while(1) {
       $56 = HEAP32[$__comp>>2]|0;
       $57 = (FUNCTION_TABLE_iii[$56 & 63]($$0,$__i$05)|0);
       $54 = (($__i$05) + 8|0);
       if ($57) {
        break;
       }
       $55 = ($54|0)==($1|0);
       if ($55) {
        label = 45;
        break L1;
       } else {
        $__i$05 = $54;
       }
      }
      $58 = $__i$05;
      $59 = $58;
      $60 = HEAP32[$59>>2]|0;
      $61 = (($58) + 4)|0;
      $62 = $61;
      $63 = HEAP32[$62>>2]|0;
      $64 = $1;
      $65 = $64;
      $66 = HEAP32[$65>>2]|0;
      $67 = (($64) + 4)|0;
      $68 = $67;
      $69 = HEAP32[$68>>2]|0;
      $70 = $__i$05;
      $71 = $70;
      HEAP32[$71>>2] = $66;
      $72 = (($70) + 4)|0;
      $73 = $72;
      HEAP32[$73>>2] = $69;
      $74 = $1;
      $75 = $74;
      HEAP32[$75>>2] = $60;
      $76 = (($74) + 4)|0;
      $77 = $76;
      HEAP32[$77>>2] = $63;
      $78 = (($__i$05) + 8|0);
      $__i$1 = $78;
     }
     $79 = ($__i$1|0)==($1|0);
     if ($79) {
      label = 45;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $__i$2 = $__i$2$ph;
      while(1) {
       $80 = HEAP32[$__comp>>2]|0;
       $81 = (FUNCTION_TABLE_iii[$80 & 63]($$0,$__i$2)|0);
       $82 = (($__i$2) + 8|0);
       if ($81) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $82;
       }
      }
      while(1) {
       $83 = HEAP32[$__comp>>2]|0;
       $84 = (($__j$2) + -8|0);
       $85 = (FUNCTION_TABLE_iii[$83 & 63]($$0,$84)|0);
       if ($85) {
        $__j$2 = $84;
       } else {
        break;
       }
      }
      $86 = ($__i$2>>>0)<($84>>>0);
      if (!($86)) {
       $$0 = $__i$2;
       continue L3;
      }
      $87 = $__i$2;
      $88 = $87;
      $89 = HEAP32[$88>>2]|0;
      $90 = (($87) + 4)|0;
      $91 = $90;
      $92 = HEAP32[$91>>2]|0;
      $93 = $84;
      $94 = $93;
      $95 = HEAP32[$94>>2]|0;
      $96 = (($93) + 4)|0;
      $97 = $96;
      $98 = HEAP32[$97>>2]|0;
      $99 = $__i$2;
      $100 = $99;
      HEAP32[$100>>2] = $95;
      $101 = (($99) + 4)|0;
      $102 = $101;
      HEAP32[$102>>2] = $98;
      $103 = $84;
      $104 = $103;
      HEAP32[$104>>2] = $89;
      $105 = (($103) + 4)|0;
      $106 = $105;
      HEAP32[$106>>2] = $92;
      $107 = (($__i$2) + 8|0);
      $__i$2$ph = $107;$__j$1$ph = $84;
     }
    }
   } while(0);
   $131 = (($$0) + 8|0);
   $132 = ($131>>>0)<($__j$3>>>0);
   L34: do {
    if ($132) {
     $__i$3$ph = $131;$__j$4$ph = $__j$3;$__m$0$ph = $40;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $__i$3 = $__i$3$ph;
      while(1) {
       $133 = HEAP32[$__comp>>2]|0;
       $134 = (FUNCTION_TABLE_iii[$133 & 63]($__i$3,$__m$0$ph)|0);
       $135 = (($__i$3) + 8|0);
       if ($134) {
        $__i$3 = $135;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $136 = HEAP32[$__comp>>2]|0;
       $137 = (($__j$5) + -8|0);
       $138 = (FUNCTION_TABLE_iii[$136 & 63]($137,$__m$0$ph)|0);
       if ($138) {
        break;
       } else {
        $__j$5 = $137;
       }
      }
      $139 = ($__i$3>>>0)>($137>>>0);
      if ($139) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L34;
      }
      $140 = $__i$3;
      $141 = $140;
      $142 = HEAP32[$141>>2]|0;
      $143 = (($140) + 4)|0;
      $144 = $143;
      $145 = HEAP32[$144>>2]|0;
      $146 = $137;
      $147 = $146;
      $148 = HEAP32[$147>>2]|0;
      $149 = (($146) + 4)|0;
      $150 = $149;
      $151 = HEAP32[$150>>2]|0;
      $152 = $__i$3;
      $153 = $152;
      HEAP32[$153>>2] = $148;
      $154 = (($152) + 4)|0;
      $155 = $154;
      HEAP32[$155>>2] = $151;
      $156 = $137;
      $157 = $156;
      HEAP32[$157>>2] = $142;
      $158 = (($156) + 4)|0;
      $159 = $158;
      HEAP32[$159>>2] = $145;
      $160 = (($__n_swaps$4$ph) + 1)|0;
      $161 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $161 ? $137 : $__m$0$ph;
      $162 = (($__i$3) + 8|0);
      $__i$3$ph = $162;$__j$4$ph = $137;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $160;
     }
    } else {
     $__i$4 = $131;$__m$2 = $40;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $163 = ($__i$4|0)==($__m$2|0);
   if ($163) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $164 = HEAP32[$__comp>>2]|0;
    $165 = (FUNCTION_TABLE_iii[$164 & 63]($__m$2,$__i$4)|0);
    if ($165) {
     $166 = $__i$4;
     $167 = $166;
     $168 = HEAP32[$167>>2]|0;
     $169 = (($166) + 4)|0;
     $170 = $169;
     $171 = HEAP32[$170>>2]|0;
     $172 = $__m$2;
     $173 = $172;
     $174 = HEAP32[$173>>2]|0;
     $175 = (($172) + 4)|0;
     $176 = $175;
     $177 = HEAP32[$176>>2]|0;
     $178 = $__i$4;
     $179 = $178;
     HEAP32[$179>>2] = $174;
     $180 = (($178) + 4)|0;
     $181 = $180;
     HEAP32[$181>>2] = $177;
     $182 = $__m$2;
     $183 = $182;
     HEAP32[$183>>2] = $168;
     $184 = (($182) + 4)|0;
     $185 = $184;
     HEAP32[$185>>2] = $171;
     $186 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $186;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $187 = ($__n_swaps$6|0)==(0);
   if ($187) {
    $188 = (__ZNSt3__127__insertion_sort_incompleteIRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEbT0_SC_T_($$0,$__i$4,$__comp)|0);
    $189 = (($__i$4) + 8|0);
    $190 = (__ZNSt3__127__insertion_sort_incompleteIRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEbT0_SC_T_($189,$$01$ph,$__comp)|0);
    if ($190) {
     label = 40;
     break;
    }
    if ($188) {
     $$0 = $189;
     continue;
    }
   }
   $191 = $__i$4;
   $192 = (($191) - ($2))|0;
   $193 = (($0) - ($191))|0;
   $194 = ($192|0)<($193|0);
   if (!($194)) {
    label = 44;
    break;
   }
   __ZNSt3__16__sortIRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEvT0_SC_T_($$0,$__i$4,$__comp);
   $195 = (($__i$4) + 8|0);
   $$0 = $195;
  }
  if ((label|0) == 40) {
   label = 0;
   if ($188) {
    label = 45;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 44) {
   label = 0;
   $196 = (($__i$4) + 8|0);
   __ZNSt3__16__sortIRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEvT0_SC_T_($196,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = HEAP32[$__comp>>2]|0;
  $6 = (($$01$ph) + -8|0);
  $7 = (FUNCTION_TABLE_iii[$5 & 63]($6,$$0)|0);
  if (!($7)) {
   STACKTOP = sp;return;
  }
  $8 = $$0;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($8) + 4)|0;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = $6;
  $15 = $14;
  $16 = HEAP32[$15>>2]|0;
  $17 = (($14) + 4)|0;
  $18 = $17;
  $19 = HEAP32[$18>>2]|0;
  $20 = $$0;
  $21 = $20;
  HEAP32[$21>>2] = $16;
  $22 = (($20) + 4)|0;
  $23 = $22;
  HEAP32[$23>>2] = $19;
  $24 = $6;
  $25 = $24;
  HEAP32[$25>>2] = $10;
  $26 = (($24) + 4)|0;
  $27 = $26;
  HEAP32[$27>>2] = $13;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $28 = (($$0) + 8|0);
  $29 = (($$01$ph) + -8|0);
  (__ZNSt3__17__sort3IRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEjT0_SC_SC_T_($$0,$28,$29,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 7) {
  $30 = (($$0) + 8|0);
  $31 = (($$0) + 16|0);
  $32 = (($$01$ph) + -8|0);
  (__ZNSt3__17__sort4IRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEjT0_SC_SC_SC_T_($$0,$30,$31,$32,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 8) {
  $33 = (($$0) + 8|0);
  $34 = (($$0) + 16|0);
  $35 = (($$0) + 24|0);
  $36 = (($$01$ph) + -8|0);
  (__ZNSt3__17__sort5IRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEjT0_SC_SC_SC_SC_T_($$0,$33,$34,$35,$36,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 10) {
  __ZNSt3__118__insertion_sort_3IRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEvT0_SC_T_($$0,$$01$ph,$__comp);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 45) {
  STACKTOP = sp;return;
 }
}
function __ZNK16b2ParticleSystem25GetFixtureContactListenerEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 16384;
 $3 = ($2|0)==(0);
 if ($3) {
  $8 = 0;
  STACKTOP = sp;return ($8|0);
 }
 $4 = (($this) + 400|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 102952|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7;
 STACKTOP = sp;return ($8|0);
}
function __ZNK16b2GrowableBufferI21b2ParticleBodyContactE5BeginEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN16b2GrowableBufferI21b2ParticleBodyContactE5BeginEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN16b2GrowableBufferI21b2ParticleBodyContactE3EndEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + (($1*28)|0)|0);
 STACKTOP = sp;return ($3|0);
}
function __ZNK18FixtureParticleSet4FindERKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEE($this,$fixtureParticle) {
 $this = $this|0;
 $fixtureParticle = $fixtureParticle|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZL23FindItemIndexInFixedSetIN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEEEiRKNS0_22TypedFixedSetAllocatorIT_EERKS6_($this,$fixtureParticle)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN18FixtureParticleSetC2EP16b2StackAllocator($this,$allocator) {
 $this = $this|0;
 $allocator = $allocator|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIP9b2FixtureiEEEC2EP16b2StackAllocator($this,$allocator);
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferI21b2ParticleBodyContactE8SetCountEi($this,$newCount) {
 $this = $this|0;
 $newCount = $newCount|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $newCount;
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferIiE8SetCountEi($this,$newCount) {
 $this = $this|0;
 $newCount = $newCount|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $newCount;
 STACKTOP = sp;return;
}
function __ZNK16b2ParticleSystem23GetFixtureContactFilterEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 65536;
 $3 = ($2|0)==(0);
 if ($3) {
  $8 = 0;
  STACKTOP = sp;return ($8|0);
 }
 $4 = (($this) + 400|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 102948|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7;
 STACKTOP = sp;return ($8|0);
}
function __ZZN16b2ParticleSystem18UpdateBodyContactsEvEN26UpdateBodyContactsCallbackC2EPS_P15b2ContactFilter($this,$system,$contactFilter) {
 $this = $this|0;
 $system = $system|0;
 $contactFilter = $contactFilter|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN30b2FixtureParticleQueryCallbackC2EP16b2ParticleSystem($this,$system);
 HEAP32[$this>>2] = ((8456 + 8|0));
 $0 = (($this) + 8|0);
 HEAP32[$0>>2] = $contactFilter;
 STACKTOP = sp;return;
}
function __ZNSt3__16__sortIRPFbRK21b2ParticleBodyContactS3_EPS1_EEvT0_S8_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $8 = 0, $9 = 0, $__i$010 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0, $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0;
 var $__n_swaps$5 = 0, $__n_swaps$6 = 0, $__t$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i6 = sp;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -28|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = (($3|0) / 28)&-1;
   switch ($4|0) {
   case 4:  {
    label = 7;
    break L1;
    break;
   }
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 5:  {
    label = 8;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 45;
    break L1;
    break;
   }
   default: {
   }
   }
   $17 = ($3|0)<(868);
   if ($17) {
    label = 10;
    break L1;
   }
   $18 = ($3|0)>(27972);
   $19 = (($3|0) / 56)&-1;
   $20 = (($$0) + (($19*28)|0)|0);
   if ($18) {
    $21 = (($3|0) / 112)&-1;
    $22 = (($$0) + (($21*28)|0)|0);
    $$sum = (($21) + ($19))|0;
    $23 = (($$0) + (($$sum*28)|0)|0);
    $24 = (__ZNSt3__17__sort5IRPFbRK21b2ParticleBodyContactS3_EPS1_EEjT0_S8_S8_S8_S8_T_($$0,$22,$20,$23,$1,$__comp)|0);
    $__n_swaps$0 = $24;
   } else {
    $25 = (__ZNSt3__17__sort3IRPFbRK21b2ParticleBodyContactS3_EPS1_EEjT0_S8_S8_T_($$0,$20,$1,$__comp)|0);
    $__n_swaps$0 = $25;
   }
   $26 = HEAP32[$__comp>>2]|0;
   $27 = (FUNCTION_TABLE_iii[$26 & 63]($$0,$20)|0);
   do {
    if ($27) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $28 = (($__j$0) + -28|0);
      $29 = ($$0|0)==($28|0);
      if ($29) {
       break;
      }
      $48 = HEAP32[$__comp>>2]|0;
      $49 = (FUNCTION_TABLE_iii[$48 & 63]($28,$20)|0);
      if ($49) {
       label = 28;
       break;
      } else {
       $__j$0 = $28;
      }
     }
     if ((label|0) == 28) {
      label = 0;
      ;HEAP32[$__t$i6+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i6+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i6+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i6+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i6+16>>2]=HEAP32[$$0+16>>2]|0;HEAP32[$__t$i6+20>>2]=HEAP32[$$0+20>>2]|0;HEAP32[$__t$i6+24>>2]=HEAP32[$$0+24>>2]|0;
      ;HEAP32[$$0+0>>2]=HEAP32[$28+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$28+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$28+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$28+12>>2]|0;HEAP32[$$0+16>>2]=HEAP32[$28+16>>2]|0;HEAP32[$$0+20>>2]=HEAP32[$28+20>>2]|0;HEAP32[$$0+24>>2]=HEAP32[$28+24>>2]|0;
      ;HEAP32[$28+0>>2]=HEAP32[$__t$i6+0>>2]|0;HEAP32[$28+4>>2]=HEAP32[$__t$i6+4>>2]|0;HEAP32[$28+8>>2]=HEAP32[$__t$i6+8>>2]|0;HEAP32[$28+12>>2]=HEAP32[$__t$i6+12>>2]|0;HEAP32[$28+16>>2]=HEAP32[$__t$i6+16>>2]|0;HEAP32[$28+20>>2]=HEAP32[$__t$i6+20>>2]|0;HEAP32[$28+24>>2]=HEAP32[$__t$i6+24>>2]|0;
      $50 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $28;$__n_swaps$3 = $50;
      break;
     }
     $30 = (($$0) + 28|0);
     $31 = HEAP32[$__comp>>2]|0;
     $32 = (FUNCTION_TABLE_iii[$31 & 63]($$0,$1)|0);
     if ($32) {
      $__i$1 = $30;
     } else {
      $33 = ($30|0)==($1|0);
      if ($33) {
       label = 45;
       break L1;
      } else {
       $__i$010 = $30;
      }
      while(1) {
       $36 = HEAP32[$__comp>>2]|0;
       $37 = (FUNCTION_TABLE_iii[$36 & 63]($$0,$__i$010)|0);
       $34 = (($__i$010) + 28|0);
       if ($37) {
        break;
       }
       $35 = ($34|0)==($1|0);
       if ($35) {
        label = 45;
        break L1;
       } else {
        $__i$010 = $34;
       }
      }
      ;HEAP32[$__t$i6+0>>2]=HEAP32[$__i$010+0>>2]|0;HEAP32[$__t$i6+4>>2]=HEAP32[$__i$010+4>>2]|0;HEAP32[$__t$i6+8>>2]=HEAP32[$__i$010+8>>2]|0;HEAP32[$__t$i6+12>>2]=HEAP32[$__i$010+12>>2]|0;HEAP32[$__t$i6+16>>2]=HEAP32[$__i$010+16>>2]|0;HEAP32[$__t$i6+20>>2]=HEAP32[$__i$010+20>>2]|0;HEAP32[$__t$i6+24>>2]=HEAP32[$__i$010+24>>2]|0;
      ;HEAP32[$__i$010+0>>2]=HEAP32[$1+0>>2]|0;HEAP32[$__i$010+4>>2]=HEAP32[$1+4>>2]|0;HEAP32[$__i$010+8>>2]=HEAP32[$1+8>>2]|0;HEAP32[$__i$010+12>>2]=HEAP32[$1+12>>2]|0;HEAP32[$__i$010+16>>2]=HEAP32[$1+16>>2]|0;HEAP32[$__i$010+20>>2]=HEAP32[$1+20>>2]|0;HEAP32[$__i$010+24>>2]=HEAP32[$1+24>>2]|0;
      ;HEAP32[$1+0>>2]=HEAP32[$__t$i6+0>>2]|0;HEAP32[$1+4>>2]=HEAP32[$__t$i6+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$__t$i6+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$__t$i6+12>>2]|0;HEAP32[$1+16>>2]=HEAP32[$__t$i6+16>>2]|0;HEAP32[$1+20>>2]=HEAP32[$__t$i6+20>>2]|0;HEAP32[$1+24>>2]=HEAP32[$__t$i6+24>>2]|0;
      $38 = (($__i$010) + 28|0);
      $__i$1 = $38;
     }
     $39 = ($__i$1|0)==($1|0);
     if ($39) {
      label = 45;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $__i$2 = $__i$2$ph;
      while(1) {
       $40 = HEAP32[$__comp>>2]|0;
       $41 = (FUNCTION_TABLE_iii[$40 & 63]($$0,$__i$2)|0);
       $42 = (($__i$2) + 28|0);
       if ($41) {
        $__j$2 = $__j$1$ph;
        break;
       } else {
        $__i$2 = $42;
       }
      }
      while(1) {
       $43 = HEAP32[$__comp>>2]|0;
       $44 = (($__j$2) + -28|0);
       $45 = (FUNCTION_TABLE_iii[$43 & 63]($$0,$44)|0);
       if ($45) {
        $__j$2 = $44;
       } else {
        break;
       }
      }
      $46 = ($__i$2>>>0)<($44>>>0);
      if (!($46)) {
       $$0 = $__i$2;
       continue L3;
      }
      ;HEAP32[$__t$i6+0>>2]=HEAP32[$__i$2+0>>2]|0;HEAP32[$__t$i6+4>>2]=HEAP32[$__i$2+4>>2]|0;HEAP32[$__t$i6+8>>2]=HEAP32[$__i$2+8>>2]|0;HEAP32[$__t$i6+12>>2]=HEAP32[$__i$2+12>>2]|0;HEAP32[$__t$i6+16>>2]=HEAP32[$__i$2+16>>2]|0;HEAP32[$__t$i6+20>>2]=HEAP32[$__i$2+20>>2]|0;HEAP32[$__t$i6+24>>2]=HEAP32[$__i$2+24>>2]|0;
      ;HEAP32[$__i$2+0>>2]=HEAP32[$44+0>>2]|0;HEAP32[$__i$2+4>>2]=HEAP32[$44+4>>2]|0;HEAP32[$__i$2+8>>2]=HEAP32[$44+8>>2]|0;HEAP32[$__i$2+12>>2]=HEAP32[$44+12>>2]|0;HEAP32[$__i$2+16>>2]=HEAP32[$44+16>>2]|0;HEAP32[$__i$2+20>>2]=HEAP32[$44+20>>2]|0;HEAP32[$__i$2+24>>2]=HEAP32[$44+24>>2]|0;
      ;HEAP32[$44+0>>2]=HEAP32[$__t$i6+0>>2]|0;HEAP32[$44+4>>2]=HEAP32[$__t$i6+4>>2]|0;HEAP32[$44+8>>2]=HEAP32[$__t$i6+8>>2]|0;HEAP32[$44+12>>2]=HEAP32[$__t$i6+12>>2]|0;HEAP32[$44+16>>2]=HEAP32[$__t$i6+16>>2]|0;HEAP32[$44+20>>2]=HEAP32[$__t$i6+20>>2]|0;HEAP32[$44+24>>2]=HEAP32[$__t$i6+24>>2]|0;
      $47 = (($__i$2) + 28|0);
      $__i$2$ph = $47;$__j$1$ph = $44;
     }
    }
   } while(0);
   $51 = (($$0) + 28|0);
   $52 = ($51>>>0)<($__j$3>>>0);
   L34: do {
    if ($52) {
     $__i$3$ph = $51;$__j$4$ph = $__j$3;$__m$0$ph = $20;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $__i$3 = $__i$3$ph;
      while(1) {
       $53 = HEAP32[$__comp>>2]|0;
       $54 = (FUNCTION_TABLE_iii[$53 & 63]($__i$3,$__m$0$ph)|0);
       $55 = (($__i$3) + 28|0);
       if ($54) {
        $__i$3 = $55;
       } else {
        $__j$5 = $__j$4$ph;
        break;
       }
      }
      while(1) {
       $56 = HEAP32[$__comp>>2]|0;
       $57 = (($__j$5) + -28|0);
       $58 = (FUNCTION_TABLE_iii[$56 & 63]($57,$__m$0$ph)|0);
       if ($58) {
        break;
       } else {
        $__j$5 = $57;
       }
      }
      $59 = ($__i$3>>>0)>($57>>>0);
      if ($59) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L34;
      }
      ;HEAP32[$__t$i6+0>>2]=HEAP32[$__i$3+0>>2]|0;HEAP32[$__t$i6+4>>2]=HEAP32[$__i$3+4>>2]|0;HEAP32[$__t$i6+8>>2]=HEAP32[$__i$3+8>>2]|0;HEAP32[$__t$i6+12>>2]=HEAP32[$__i$3+12>>2]|0;HEAP32[$__t$i6+16>>2]=HEAP32[$__i$3+16>>2]|0;HEAP32[$__t$i6+20>>2]=HEAP32[$__i$3+20>>2]|0;HEAP32[$__t$i6+24>>2]=HEAP32[$__i$3+24>>2]|0;
      ;HEAP32[$__i$3+0>>2]=HEAP32[$57+0>>2]|0;HEAP32[$__i$3+4>>2]=HEAP32[$57+4>>2]|0;HEAP32[$__i$3+8>>2]=HEAP32[$57+8>>2]|0;HEAP32[$__i$3+12>>2]=HEAP32[$57+12>>2]|0;HEAP32[$__i$3+16>>2]=HEAP32[$57+16>>2]|0;HEAP32[$__i$3+20>>2]=HEAP32[$57+20>>2]|0;HEAP32[$__i$3+24>>2]=HEAP32[$57+24>>2]|0;
      ;HEAP32[$57+0>>2]=HEAP32[$__t$i6+0>>2]|0;HEAP32[$57+4>>2]=HEAP32[$__t$i6+4>>2]|0;HEAP32[$57+8>>2]=HEAP32[$__t$i6+8>>2]|0;HEAP32[$57+12>>2]=HEAP32[$__t$i6+12>>2]|0;HEAP32[$57+16>>2]=HEAP32[$__t$i6+16>>2]|0;HEAP32[$57+20>>2]=HEAP32[$__t$i6+20>>2]|0;HEAP32[$57+24>>2]=HEAP32[$__t$i6+24>>2]|0;
      $60 = (($__n_swaps$4$ph) + 1)|0;
      $61 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $61 ? $57 : $__m$0$ph;
      $62 = (($__i$3) + 28|0);
      $__i$3$ph = $62;$__j$4$ph = $57;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $60;
     }
    } else {
     $__i$4 = $51;$__m$2 = $20;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $63 = ($__i$4|0)==($__m$2|0);
   if ($63) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $64 = HEAP32[$__comp>>2]|0;
    $65 = (FUNCTION_TABLE_iii[$64 & 63]($__m$2,$__i$4)|0);
    if ($65) {
     ;HEAP32[$__t$i6+0>>2]=HEAP32[$__i$4+0>>2]|0;HEAP32[$__t$i6+4>>2]=HEAP32[$__i$4+4>>2]|0;HEAP32[$__t$i6+8>>2]=HEAP32[$__i$4+8>>2]|0;HEAP32[$__t$i6+12>>2]=HEAP32[$__i$4+12>>2]|0;HEAP32[$__t$i6+16>>2]=HEAP32[$__i$4+16>>2]|0;HEAP32[$__t$i6+20>>2]=HEAP32[$__i$4+20>>2]|0;HEAP32[$__t$i6+24>>2]=HEAP32[$__i$4+24>>2]|0;
     ;HEAP32[$__i$4+0>>2]=HEAP32[$__m$2+0>>2]|0;HEAP32[$__i$4+4>>2]=HEAP32[$__m$2+4>>2]|0;HEAP32[$__i$4+8>>2]=HEAP32[$__m$2+8>>2]|0;HEAP32[$__i$4+12>>2]=HEAP32[$__m$2+12>>2]|0;HEAP32[$__i$4+16>>2]=HEAP32[$__m$2+16>>2]|0;HEAP32[$__i$4+20>>2]=HEAP32[$__m$2+20>>2]|0;HEAP32[$__i$4+24>>2]=HEAP32[$__m$2+24>>2]|0;
     ;HEAP32[$__m$2+0>>2]=HEAP32[$__t$i6+0>>2]|0;HEAP32[$__m$2+4>>2]=HEAP32[$__t$i6+4>>2]|0;HEAP32[$__m$2+8>>2]=HEAP32[$__t$i6+8>>2]|0;HEAP32[$__m$2+12>>2]=HEAP32[$__t$i6+12>>2]|0;HEAP32[$__m$2+16>>2]=HEAP32[$__t$i6+16>>2]|0;HEAP32[$__m$2+20>>2]=HEAP32[$__t$i6+20>>2]|0;HEAP32[$__m$2+24>>2]=HEAP32[$__t$i6+24>>2]|0;
     $66 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $66;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $67 = ($__n_swaps$6|0)==(0);
   if ($67) {
    $68 = (__ZNSt3__127__insertion_sort_incompleteIRPFbRK21b2ParticleBodyContactS3_EPS1_EEbT0_S8_T_($$0,$__i$4,$__comp)|0);
    $69 = (($__i$4) + 28|0);
    $70 = (__ZNSt3__127__insertion_sort_incompleteIRPFbRK21b2ParticleBodyContactS3_EPS1_EEbT0_S8_T_($69,$$01$ph,$__comp)|0);
    if ($70) {
     label = 40;
     break;
    }
    if ($68) {
     $$0 = $69;
     continue;
    }
   }
   $71 = $__i$4;
   $72 = (($71) - ($2))|0;
   $73 = (($0) - ($71))|0;
   $74 = ($72|0)<($73|0);
   if (!($74)) {
    label = 44;
    break;
   }
   __ZNSt3__16__sortIRPFbRK21b2ParticleBodyContactS3_EPS1_EEvT0_S8_T_($$0,$__i$4,$__comp);
   $75 = (($__i$4) + 28|0);
   $$0 = $75;
  }
  if ((label|0) == 40) {
   label = 0;
   if ($68) {
    label = 45;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 44) {
   label = 0;
   $76 = (($__i$4) + 28|0);
   __ZNSt3__16__sortIRPFbRK21b2ParticleBodyContactS3_EPS1_EEvT0_S8_T_($76,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = HEAP32[$__comp>>2]|0;
  $6 = (($$01$ph) + -28|0);
  $7 = (FUNCTION_TABLE_iii[$5 & 63]($6,$$0)|0);
  if (!($7)) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__t$i6+0>>2]=HEAP32[$$0+0>>2]|0;HEAP32[$__t$i6+4>>2]=HEAP32[$$0+4>>2]|0;HEAP32[$__t$i6+8>>2]=HEAP32[$$0+8>>2]|0;HEAP32[$__t$i6+12>>2]=HEAP32[$$0+12>>2]|0;HEAP32[$__t$i6+16>>2]=HEAP32[$$0+16>>2]|0;HEAP32[$__t$i6+20>>2]=HEAP32[$$0+20>>2]|0;HEAP32[$__t$i6+24>>2]=HEAP32[$$0+24>>2]|0;
  ;HEAP32[$$0+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$$0+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$$0+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$$0+12>>2]=HEAP32[$6+12>>2]|0;HEAP32[$$0+16>>2]=HEAP32[$6+16>>2]|0;HEAP32[$$0+20>>2]=HEAP32[$6+20>>2]|0;HEAP32[$$0+24>>2]=HEAP32[$6+24>>2]|0;
  ;HEAP32[$6+0>>2]=HEAP32[$__t$i6+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$__t$i6+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$__t$i6+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$__t$i6+12>>2]|0;HEAP32[$6+16>>2]=HEAP32[$__t$i6+16>>2]|0;HEAP32[$6+20>>2]=HEAP32[$__t$i6+20>>2]|0;HEAP32[$6+24>>2]=HEAP32[$__t$i6+24>>2]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $8 = (($$0) + 28|0);
  $9 = (($$01$ph) + -28|0);
  (__ZNSt3__17__sort3IRPFbRK21b2ParticleBodyContactS3_EPS1_EEjT0_S8_S8_T_($$0,$8,$9,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 7) {
  $10 = (($$0) + 28|0);
  $11 = (($$0) + 56|0);
  $12 = (($$01$ph) + -28|0);
  (__ZNSt3__17__sort4IRPFbRK21b2ParticleBodyContactS3_EPS1_EEjT0_S8_S8_S8_T_($$0,$10,$11,$12,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 8) {
  $13 = (($$0) + 28|0);
  $14 = (($$0) + 56|0);
  $15 = (($$0) + 84|0);
  $16 = (($$01$ph) + -28|0);
  (__ZNSt3__17__sort5IRPFbRK21b2ParticleBodyContactS3_EPS1_EEjT0_S8_S8_S8_S8_T_($$0,$13,$14,$15,$16,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 10) {
  __ZNSt3__118__insertion_sort_3IRPFbRK21b2ParticleBodyContactS3_EPS1_EEvT0_S8_T_($$0,$$01$ph,$__comp);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 45) {
  STACKTOP = sp;return;
 }
}
function __ZN36b2ParticleBodyContactRemovePredicateC2EP16b2ParticleSystemPi($this,$system,$discarded) {
 $this = $this|0;
 $system = $system|0;
 $discarded = $discarded|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $system;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = -1;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = $discarded;
 STACKTOP = sp;return;
}
function __ZNSt3__19remove_ifIP21b2ParticleBodyContact36b2ParticleBodyContactRemovePredicateEET_S4_S4_T0_($__first,$__last,$__pred) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__pred = $__pred|0;
 var $$0$lcssa$i = 0, $$0$ph = 0, $$01$i = 0, $$1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $__i$0 = 0, $__i$0$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__first|0)==($__last|0);
 L1: do {
  if ($0) {
   $$0$lcssa$i = $__first;
  } else {
   $$01$i = $__first;
   while(1) {
    $3 = (__ZN36b2ParticleBodyContactRemovePredicateclERK21b2ParticleBodyContact($__pred,$$01$i)|0);
    $1 = (($$01$i) + 28|0);
    if ($3) {
     $$0$lcssa$i = $$01$i;
     break L1;
    }
    $2 = ($1|0)==($__last|0);
    if ($2) {
     $$0$lcssa$i = $1;
     break;
    } else {
     $$01$i = $1;
    }
   }
  }
 } while(0);
 $4 = ($$0$lcssa$i|0)==($__last|0);
 if ($4) {
  $$1 = $$0$lcssa$i;
  STACKTOP = sp;return ($$1|0);
 } else {
  $$0$ph = $$0$lcssa$i;$__i$0$ph = $$0$lcssa$i;
 }
 L8: while(1) {
  $__i$0 = $__i$0$ph;
  while(1) {
   $5 = (($__i$0) + 28|0);
   $6 = ($5|0)==($__last|0);
   if ($6) {
    $$1 = $$0$ph;
    break L8;
   }
   $7 = (__ZN36b2ParticleBodyContactRemovePredicateclERK21b2ParticleBodyContact($__pred,$5)|0);
   if ($7) {
    $__i$0 = $5;
   } else {
    break;
   }
  }
  ;HEAP32[$$0$ph+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$$0$ph+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$$0$ph+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$$0$ph+12>>2]=HEAP32[$5+12>>2]|0;HEAP32[$$0$ph+16>>2]=HEAP32[$5+16>>2]|0;HEAP32[$$0$ph+20>>2]=HEAP32[$5+20>>2]|0;HEAP32[$$0$ph+24>>2]=HEAP32[$5+24>>2]|0;
  $8 = (($$0$ph) + 28|0);
  $$0$ph = $8;$__i$0$ph = $5;
 }
 STACKTOP = sp;return ($$1|0);
}
function __ZZN16b2ParticleSystem14SolveCollisionERK10b2TimeStepEN22SolveCollisionCallbackC2EPS_S2_($this,$system,$step) {
 $this = $this|0;
 $system = $system|0;
 $step = $step|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN30b2FixtureParticleQueryCallbackC2EP16b2ParticleSystem($this,$system);
 HEAP32[$this>>2] = ((8240 + 8|0));
 $0 = (($this) + 8|0);
 ;HEAP32[$0+0>>2]=HEAP32[$step+0>>2]|0;HEAP32[$0+4>>2]=HEAP32[$step+4>>2]|0;HEAP32[$0+8>>2]=HEAP32[$step+8>>2]|0;HEAP32[$0+12>>2]=HEAP32[$step+12>>2]|0;HEAP32[$0+16>>2]=HEAP32[$step+16>>2]|0;HEAP32[$0+20>>2]=HEAP32[$step+20>>2]|0;HEAP32[$0+24>>2]=HEAP32[$step+24>>2]|0;
 STACKTOP = sp;return;
}
function __ZNK16b2ParticleSystem17GetLinearVelocityEP15b2ParticleGroupiRK6b2Vec2($agg$result,$this,$group,$particleIndex,$point) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $group = $group|0;
 $particleIndex = $particleIndex|0;
 $point = $point|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK16b2ParticleSystem12IsRigidGroupEP15b2ParticleGroup($this,$group)|0);
 if ($0) {
  __ZNK15b2ParticleGroup31GetLinearVelocityFromWorldPointERK6b2Vec2($agg$result,$group,$point);
  STACKTOP = sp;return;
 } else {
  $1 = (($this) + 104|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (($2) + ($particleIndex<<3)|0);
  $4 = $3;
  $5 = $4;
  $6 = HEAP32[$5>>2]|0;
  $7 = (($4) + 4)|0;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = $agg$result;
  $11 = $10;
  HEAP32[$11>>2] = $6;
  $12 = (($10) + 4)|0;
  $13 = $12;
  HEAP32[$13>>2] = $9;
  STACKTOP = sp;return;
 }
}
function __ZNK16b2ParticleSystem12IsRigidGroupEP15b2ParticleGroup($this,$group) {
 $this = $this|0;
 $group = $group|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($group|0)==(0|0);
 if ($0) {
  $5 = 0;
 } else {
  $1 = (($group) + 12|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = $2 & 2;
  $4 = ($3|0)!=(0);
  $5 = $4;
 }
 STACKTOP = sp;return ($5|0);
}
function __ZNK15b2ParticleGroup7GetMassEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZNK15b2ParticleGroup16UpdateStatisticsEv($this);
 $0 = (($this) + 32|0);
 $1 = +HEAPF32[$0>>2];
 STACKTOP = sp;return (+$1);
}
function __ZNK15b2ParticleGroup10GetInertiaEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZNK15b2ParticleGroup16UpdateStatisticsEv($this);
 $0 = (($this) + 36|0);
 $1 = +HEAPF32[$0>>2];
 STACKTOP = sp;return (+$1);
}
function __ZNK15b2ParticleGroup9GetCenterEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZNK15b2ParticleGroup16UpdateStatisticsEv($this);
 $0 = (($this) + 40|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $agg$result;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 STACKTOP = sp;return;
}
function __ZL18IsSignificantForceRK6b2Vec2($force) {
 $force = $force|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0.0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$force>>2];
 $1 = $0 != 0.0;
 if ($1) {
  $5 = 1;
 } else {
  $2 = (($force) + 4|0);
  $3 = +HEAPF32[$2>>2];
  $4 = $3 != 0.0;
  $5 = $4;
 }
 STACKTOP = sp;return ($5|0);
}
function __ZNK16b2ParticleSystem17ForceCanBeAppliedEj($this,$flags) {
 $this = $this|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $flags & 4;
 $1 = ($0|0)==(0);
 STACKTOP = sp;return ($1|0);
}
function __ZN16b2ParticleSystem18PrepareForceBufferEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 21|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 112|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 44|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 << 3;
 _memset(($4|0),0,($7|0))|0;
 HEAP8[$0>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN12_GLOBAL__N_124ExpirationTimeComparatorC2EPKi($this,$expirationTimes) {
 $this = $this|0;
 $expirationTimes = $expirationTimes|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = $expirationTimes;
 STACKTOP = sp;return;
}
function __ZNSt3__16__sortIRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEvT0_S5_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $$0$ph = 0, $$01$ph = 0, $$__m$0 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $__i$06 = 0, $__i$1 = 0, $__i$2 = 0, $__i$2$ph = 0;
 var $__i$3 = 0, $__i$3$ph = 0, $__i$4 = 0, $__j$0 = 0, $__j$1$ph = 0, $__j$2 = 0, $__j$3 = 0, $__j$4$ph = 0, $__j$5 = 0, $__m$0$ph = 0, $__m$2 = 0, $__n_swaps$0 = 0, $__n_swaps$3 = 0, $__n_swaps$4$ph = 0, $__n_swaps$5 = 0, $__n_swaps$6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0$ph = $__first;$$01$ph = $__last;
 L1: while(1) {
  $0 = $$01$ph;
  $1 = (($$01$ph) + -4|0);
  $$0 = $$0$ph;
  L3: while(1) {
   $2 = $$0;
   $3 = (($0) - ($2))|0;
   $4 = $3 >> 2;
   switch ($4|0) {
   case 4:  {
    label = 7;
    break L1;
    break;
   }
   case 3:  {
    label = 6;
    break L1;
    break;
   }
   case 2:  {
    label = 4;
    break L1;
    break;
   }
   case 5:  {
    label = 8;
    break L1;
    break;
   }
   case 1: case 0:  {
    label = 48;
    break L1;
    break;
   }
   default: {
   }
   }
   $18 = ($3|0)<(124);
   if ($18) {
    label = 10;
    break L1;
   }
   $19 = ($3|0)>(3996);
   $20 = (($4|0) / 2)&-1;
   $21 = (($$0) + ($20<<2)|0);
   if ($19) {
    $22 = (($4|0) / 4)&-1;
    $23 = (($$0) + ($22<<2)|0);
    $$sum = (($22) + ($20))|0;
    $24 = (($$0) + ($$sum<<2)|0);
    $25 = (__ZNSt3__17__sort5IRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEjT0_S5_S5_S5_S5_T_($$0,$23,$21,$24,$1,$__comp)|0);
    $__n_swaps$0 = $25;
   } else {
    $26 = (__ZNSt3__17__sort3IRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEjT0_S5_S5_T_($$0,$21,$1,$__comp)|0);
    $__n_swaps$0 = $26;
   }
   $27 = HEAP32[$$0>>2]|0;
   $28 = HEAP32[$21>>2]|0;
   $29 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__comp,$27,$28)|0);
   do {
    if ($29) {
     $__j$3 = $1;$__n_swaps$3 = $__n_swaps$0;
    } else {
     $__j$0 = $1;
     while(1) {
      $30 = (($__j$0) + -4|0);
      $31 = ($$0|0)==($30|0);
      if ($31) {
       break;
      }
      $56 = HEAP32[$30>>2]|0;
      $57 = HEAP32[$21>>2]|0;
      $58 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__comp,$56,$57)|0);
      if ($58) {
       label = 30;
       break;
      } else {
       $__j$0 = $30;
      }
     }
     if ((label|0) == 30) {
      label = 0;
      $59 = HEAP32[$$0>>2]|0;
      HEAP32[$$0>>2] = $56;
      HEAP32[$30>>2] = $59;
      $60 = (($__n_swaps$0) + 1)|0;
      $__j$3 = $30;$__n_swaps$3 = $60;
      break;
     }
     $32 = (($$0) + 4|0);
     $33 = HEAP32[$$0>>2]|0;
     $34 = HEAP32[$1>>2]|0;
     $35 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__comp,$33,$34)|0);
     if ($35) {
      $__i$1 = $32;
     } else {
      $36 = ($32|0)==($1|0);
      if ($36) {
       label = 48;
       break L1;
      }
      $37 = HEAP32[$$0>>2]|0;
      $__i$06 = $32;
      while(1) {
       $40 = HEAP32[$__i$06>>2]|0;
       $41 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__comp,$37,$40)|0);
       $38 = (($__i$06) + 4|0);
       if ($41) {
        break;
       }
       $39 = ($38|0)==($1|0);
       if ($39) {
        label = 48;
        break L1;
       } else {
        $__i$06 = $38;
       }
      }
      $42 = HEAP32[$1>>2]|0;
      HEAP32[$__i$06>>2] = $42;
      HEAP32[$1>>2] = $40;
      $43 = (($__i$06) + 4|0);
      $__i$1 = $43;
     }
     $44 = ($__i$1|0)==($1|0);
     if ($44) {
      label = 48;
      break L1;
     } else {
      $__i$2$ph = $__i$1;$__j$1$ph = $1;
     }
     while(1) {
      $45 = HEAP32[$$0>>2]|0;
      $__i$2 = $__i$2$ph;
      while(1) {
       $46 = HEAP32[$__i$2>>2]|0;
       $47 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__comp,$45,$46)|0);
       $48 = (($__i$2) + 4|0);
       if ($47) {
        break;
       } else {
        $__i$2 = $48;
       }
      }
      $49 = HEAP32[$$0>>2]|0;
      $__j$2 = $__j$1$ph;
      while(1) {
       $50 = (($__j$2) + -4|0);
       $51 = HEAP32[$50>>2]|0;
       $52 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__comp,$49,$51)|0);
       if ($52) {
        $__j$2 = $50;
       } else {
        break;
       }
      }
      $53 = ($__i$2>>>0)<($50>>>0);
      if (!($53)) {
       $$0 = $__i$2;
       continue L3;
      }
      $54 = HEAP32[$__i$2>>2]|0;
      HEAP32[$__i$2>>2] = $51;
      HEAP32[$50>>2] = $54;
      $55 = (($__i$2) + 4|0);
      $__i$2$ph = $55;$__j$1$ph = $50;
     }
    }
   } while(0);
   $61 = (($$0) + 4|0);
   $62 = ($61>>>0)<($__j$3>>>0);
   L36: do {
    if ($62) {
     $__i$3$ph = $61;$__j$4$ph = $__j$3;$__m$0$ph = $21;$__n_swaps$4$ph = $__n_swaps$3;
     while(1) {
      $63 = HEAP32[$__m$0$ph>>2]|0;
      $__i$3 = $__i$3$ph;
      while(1) {
       $64 = HEAP32[$__i$3>>2]|0;
       $65 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__comp,$64,$63)|0);
       $66 = (($__i$3) + 4|0);
       if ($65) {
        $__i$3 = $66;
       } else {
        break;
       }
      }
      $67 = HEAP32[$__m$0$ph>>2]|0;
      $__j$5 = $__j$4$ph;
      while(1) {
       $68 = (($__j$5) + -4|0);
       $69 = HEAP32[$68>>2]|0;
       $70 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__comp,$69,$67)|0);
       if ($70) {
        break;
       } else {
        $__j$5 = $68;
       }
      }
      $71 = ($__i$3>>>0)>($68>>>0);
      if ($71) {
       $__i$4 = $__i$3;$__m$2 = $__m$0$ph;$__n_swaps$5 = $__n_swaps$4$ph;
       break L36;
      }
      $72 = HEAP32[$__i$3>>2]|0;
      HEAP32[$__i$3>>2] = $69;
      HEAP32[$68>>2] = $72;
      $73 = (($__n_swaps$4$ph) + 1)|0;
      $74 = ($__m$0$ph|0)==($__i$3|0);
      $$__m$0 = $74 ? $68 : $__m$0$ph;
      $75 = (($__i$3) + 4|0);
      $__i$3$ph = $75;$__j$4$ph = $68;$__m$0$ph = $$__m$0;$__n_swaps$4$ph = $73;
     }
    } else {
     $__i$4 = $61;$__m$2 = $21;$__n_swaps$5 = $__n_swaps$3;
    }
   } while(0);
   $76 = ($__i$4|0)==($__m$2|0);
   if ($76) {
    $__n_swaps$6 = $__n_swaps$5;
   } else {
    $77 = HEAP32[$__m$2>>2]|0;
    $78 = HEAP32[$__i$4>>2]|0;
    $79 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__comp,$77,$78)|0);
    if ($79) {
     HEAP32[$__i$4>>2] = $77;
     HEAP32[$__m$2>>2] = $78;
     $80 = (($__n_swaps$5) + 1)|0;
     $__n_swaps$6 = $80;
    } else {
     $__n_swaps$6 = $__n_swaps$5;
    }
   }
   $81 = ($__n_swaps$6|0)==(0);
   if ($81) {
    $82 = (__ZNSt3__127__insertion_sort_incompleteIRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEbT0_S5_T_($$0,$__i$4,$__comp)|0);
    $83 = (($__i$4) + 4|0);
    $84 = (__ZNSt3__127__insertion_sort_incompleteIRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEbT0_S5_T_($83,$$01$ph,$__comp)|0);
    if ($84) {
     label = 43;
     break;
    }
    if ($82) {
     $$0 = $83;
     continue;
    }
   }
   $85 = $__i$4;
   $86 = (($85) - ($2))|0;
   $87 = (($0) - ($85))|0;
   $88 = ($86|0)<($87|0);
   if (!($88)) {
    label = 47;
    break;
   }
   __ZNSt3__16__sortIRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEvT0_S5_T_($$0,$__i$4,$__comp);
   $89 = (($__i$4) + 4|0);
   $$0 = $89;
  }
  if ((label|0) == 43) {
   label = 0;
   if ($82) {
    label = 48;
    break;
   } else {
    $$0$ph = $$0;$$01$ph = $__i$4;
    continue;
   }
  }
  else if ((label|0) == 47) {
   label = 0;
   $90 = (($__i$4) + 4|0);
   __ZNSt3__16__sortIRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEvT0_S5_T_($90,$$01$ph,$__comp);
   $$0$ph = $$0;$$01$ph = $__i$4;
   continue;
  }
 }
 if ((label|0) == 4) {
  $5 = (($$01$ph) + -4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[$$0>>2]|0;
  $8 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__comp,$6,$7)|0);
  if (!($8)) {
   STACKTOP = sp;return;
  }
  HEAP32[$$0>>2] = $6;
  HEAP32[$5>>2] = $7;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 6) {
  $9 = (($$0) + 4|0);
  $10 = (($$01$ph) + -4|0);
  (__ZNSt3__17__sort3IRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEjT0_S5_S5_T_($$0,$9,$10,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 7) {
  $11 = (($$0) + 4|0);
  $12 = (($$0) + 8|0);
  $13 = (($$01$ph) + -4|0);
  (__ZNSt3__17__sort4IRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEjT0_S5_S5_S5_T_($$0,$11,$12,$13,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 8) {
  $14 = (($$0) + 4|0);
  $15 = (($$0) + 8|0);
  $16 = (($$0) + 12|0);
  $17 = (($$01$ph) + -4|0);
  (__ZNSt3__17__sort5IRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEjT0_S5_S5_S5_S5_T_($$0,$14,$15,$16,$17,$__comp)|0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 10) {
  __ZNSt3__118__insertion_sort_3IRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEvT0_S5_T_($$0,$$01$ph,$__comp);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 48) {
  STACKTOP = sp;return;
 }
}
function __ZN16b2ParticleSystem15DestroyParticleEi($this,$index) {
 $this = $this|0;
 $index = $index|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN16b2ParticleSystem15DestroyParticleEib($this,$index,0);
 STACKTOP = sp;return;
}
function __ZNK15b2ParticleGroup7GetNextEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK16b2ParticleSystem18GetParticleInvMassEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0.0, $2 = 0.0, $3 = 0, $4 = 0.0, $5 = 0.0, $6 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 36|0);
 $1 = +HEAPF32[$0>>2];
 $2 = $1 * 1.3333333730697632;
 $3 = (($this) + 28|0);
 $4 = +HEAPF32[$3>>2];
 $5 = $4 * $2;
 $6 = $2 * $5;
 STACKTOP = sp;return (+$6);
}
function __ZNK6b2Body31GetLinearVelocityFromWorldPointERK6b2Vec2($agg$result,$this,$worldPoint) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $worldPoint = $worldPoint|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = (($this) + 80|0);
 $3 = (($this) + 88|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($this) + 60|0);
 __ZmiRK6b2Vec2S1_($1,$worldPoint,$5);
 __Z7b2CrossfRK6b2Vec2($0,$4,$1);
 __ZplRK6b2Vec2S1_($agg$result,$2,$0);
 STACKTOP = sp;return;
}
function __ZN6b2Body18ApplyLinearImpulseERK6b2Vec2S2_b($this,$impulse,$point,$wake) {
 $this = $this|0;
 $impulse = $impulse|0;
 $point = $point|0;
 $wake = $wake|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0.0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0, $21 = 0.0, $22 = 0.0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = HEAP32[$this>>2]|0;
 $3 = ($2|0)==(2);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 if ($wake) {
  $4 = (($this) + 4|0);
  $5 = HEAP16[$4>>1]|0;
  $6 = $5 & 2;
  $7 = ($6<<16>>16)==(0);
  if ($7) {
   __ZN6b2Body8SetAwakeEb($this,1);
  }
 }
 $8 = (($this) + 4|0);
 $9 = HEAP16[$8>>1]|0;
 $10 = $9 & 2;
 $11 = ($10<<16>>16)==(0);
 if ($11) {
  STACKTOP = sp;return;
 }
 $12 = (($this) + 80|0);
 $13 = (($this) + 136|0);
 $14 = +HEAPF32[$13>>2];
 __ZmlfRK6b2Vec2($0,$14,$impulse);
 __ZN6b2Vec2pLERKS_($12,$0);
 $15 = (($this) + 144|0);
 $16 = +HEAPF32[$15>>2];
 $17 = (($this) + 60|0);
 __ZmiRK6b2Vec2S1_($1,$point,$17);
 $18 = (+__Z7b2CrossRK6b2Vec2S1_($1,$impulse));
 $19 = $16 * $18;
 $20 = (($this) + 88|0);
 $21 = +HEAPF32[$20>>2];
 $22 = $21 + $19;
 HEAPF32[$20>>2] = $22;
 STACKTOP = sp;return;
}
function __ZNK16b2ParticleSystem19GetCriticalVelocityERK10b2TimeStep($this,$step) {
 $this = $this|0;
 $step = $step|0;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0.0, $4 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 $1 = +HEAPF32[$0>>2];
 $2 = (($step) + 4|0);
 $3 = +HEAPF32[$2>>2];
 $4 = $1 * $3;
 STACKTOP = sp;return (+$4);
}
function __ZNK7b2World10GetGravityEv($agg$result,$this) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 102980|0);
 $1 = $0;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $agg$result;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 STACKTOP = sp;return;
}
function __ZNK16b2ParticleSystem19GetCriticalPressureERK10b2TimeStep($this,$step) {
 $this = $this|0;
 $step = $step|0;
 var $0 = 0, $1 = 0.0, $2 = 0.0, $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 320|0);
 $1 = +HEAPF32[$0>>2];
 $2 = (+__ZNK16b2ParticleSystem26GetCriticalVelocitySquaredERK10b2TimeStep($this,$step));
 $3 = $1 * $2;
 STACKTOP = sp;return (+$3);
}
function __Z9b2InvSqrtf($x) {
 $x = +$x;
 var $0 = 0, $1 = 0.0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (HEAPF32[tempDoublePtr>>2]=$x,HEAP32[tempDoublePtr>>2]|0);
 $1 = $x * 0.5;
 $2 = $0 >> 1;
 $3 = (1597463007 - ($2))|0;
 $4 = (HEAP32[tempDoublePtr>>2]=$3,+HEAPF32[tempDoublePtr>>2]);
 $5 = $1 * $4;
 $6 = $4 * $5;
 $7 = 1.5 - $6;
 $8 = $4 * $7;
 STACKTOP = sp;return (+$8);
}
function __ZNK16b2ParticleSystem26GetCriticalVelocitySquaredERK10b2TimeStep($this,$step) {
 $this = $this|0;
 $step = $step|0;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+__ZNK16b2ParticleSystem19GetCriticalVelocityERK10b2TimeStep($this,$step));
 $1 = $0 * $0;
 STACKTOP = sp;return (+$1);
}
function __ZNK15b2ParticleGroup31GetLinearVelocityFromWorldPointERK6b2Vec2($agg$result,$this,$worldPoint) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $worldPoint = $worldPoint|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 __ZNK15b2ParticleGroup16UpdateStatisticsEv($this);
 $2 = (($this) + 48|0);
 $3 = (($this) + 56|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($this) + 40|0);
 __ZmiRK6b2Vec2S1_($1,$worldPoint,$5);
 __Z7b2CrossfRK6b2Vec2($0,$4,$1);
 __ZplRK6b2Vec2S1_($agg$result,$2,$0);
 STACKTOP = sp;return;
}
function __ZNK16b2ParticleSystem44InitDampingParameterWithRigidGroupOrParticleEPfS0_S0_bP15b2ParticleGroupiRK6b2Vec2S5_($this,$invMass,$invInertia,$tangentDistance,$isRigidGroup,$group,$particleIndex,$point,$normal) {
 $this = $this|0;
 $invMass = $invMass|0;
 $invInertia = $invInertia|0;
 $tangentDistance = $tangentDistance|0;
 $isRigidGroup = $isRigidGroup|0;
 $group = $group|0;
 $particleIndex = $particleIndex|0;
 $point = $point|0;
 $normal = $normal|0;
 var $0 = 0, $1 = 0.0, $10 = 0.0, $2 = 0.0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 if ($isRigidGroup) {
  $1 = (+__ZNK15b2ParticleGroup7GetMassEv($group));
  $2 = (+__ZNK15b2ParticleGroup10GetInertiaEv($group));
  __ZNK15b2ParticleGroup9GetCenterEv($0,$group);
  __ZNK16b2ParticleSystem20InitDampingParameterEPfS0_S0_ffRK6b2Vec2S3_S3_($this,$invMass,$invInertia,$tangentDistance,$1,$2,$0,$point,$normal);
  STACKTOP = sp;return;
 }
 $3 = (($this) + 88|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($particleIndex<<2)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6 & 4;
 $8 = ($7|0)==(0);
 if ($8) {
  $9 = (+__ZNK16b2ParticleSystem15GetParticleMassEv($this));
  $10 = $9;
 } else {
  $10 = 0.0;
 }
 __ZNK16b2ParticleSystem20InitDampingParameterEPfS0_S0_ffRK6b2Vec2S3_S3_($this,$invMass,$invInertia,$tangentDistance,$10,0.0,$point,$point,$normal);
 STACKTOP = sp;return;
}
function __ZNK6b2Body14GetLocalCenterEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 44|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNK16b2ParticleSystem20InitDampingParameterEPfS0_S0_ffRK6b2Vec2S3_S3_($this,$invMass,$invInertia,$tangentDistance,$mass,$inertia,$center,$point,$normal) {
 $this = $this|0;
 $invMass = $invMass|0;
 $invInertia = $invInertia|0;
 $tangentDistance = $tangentDistance|0;
 $mass = +$mass;
 $inertia = +$inertia;
 $center = $center|0;
 $point = $point|0;
 $normal = $normal|0;
 var $0 = 0, $1 = 0, $2 = 0.0, $3 = 0.0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = $mass > 0.0;
 if ($1) {
  $2 = 1.0 / $mass;
  $3 = $2;
 } else {
  $3 = 0.0;
 }
 HEAPF32[$invMass>>2] = $3;
 $4 = $inertia > 0.0;
 if ($4) {
  $5 = 1.0 / $inertia;
  $6 = $5;
 } else {
  $6 = 0.0;
 }
 HEAPF32[$invInertia>>2] = $6;
 __ZmiRK6b2Vec2S1_($0,$point,$center);
 $7 = (+__Z7b2CrossRK6b2Vec2S1_($0,$normal));
 HEAPF32[$tangentDistance>>2] = $7;
 STACKTOP = sp;return;
}
function __ZNK16b2ParticleSystem21ComputeDampingImpulseEfffffff($this,$invMassA,$invInertiaA,$tangentDistanceA,$invMassB,$invInertiaB,$tangentDistanceB,$normalVelocity) {
 $this = $this|0;
 $invMassA = +$invMassA;
 $invInertiaA = +$invInertiaA;
 $tangentDistanceA = +$tangentDistanceA;
 $invMassB = +$invMassB;
 $invInertiaB = +$invInertiaB;
 $tangentDistanceB = +$tangentDistanceB;
 $normalVelocity = +$normalVelocity;
 var $0 = 0.0, $1 = 0.0, $2 = 0.0, $3 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $invInertiaA * $tangentDistanceA;
 $1 = $0 * $tangentDistanceA;
 $2 = $1 + $invMassA;
 $3 = $2 + $invMassB;
 $4 = $invInertiaB * $tangentDistanceB;
 $5 = $4 * $tangentDistanceB;
 $6 = $3 + $5;
 $7 = $6 > 0.0;
 if (!($7)) {
  $9 = 0.0;
  STACKTOP = sp;return (+$9);
 }
 $8 = $normalVelocity / $6;
 $9 = $8;
 STACKTOP = sp;return (+$9);
}
function __ZN16b2ParticleSystem12ApplyDampingEfffbP15b2ParticleGroupifRK6b2Vec2($this,$invMass,$invInertia,$tangentDistance,$isRigidGroup,$group,$particleIndex,$impulse,$normal) {
 $this = $this|0;
 $invMass = +$invMass;
 $invInertia = +$invInertia;
 $tangentDistance = +$tangentDistance;
 $isRigidGroup = $isRigidGroup|0;
 $group = $group|0;
 $particleIndex = $particleIndex|0;
 $impulse = +$impulse;
 $normal = $normal|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $2 = 0, $3 = 0.0, $4 = 0.0, $5 = 0.0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 if ($isRigidGroup) {
  $2 = (($group) + 48|0);
  $3 = $invMass * $impulse;
  __ZmlfRK6b2Vec2($0,$3,$normal);
  __ZN6b2Vec2pLERKS_($2,$0);
  $4 = $tangentDistance * $impulse;
  $5 = $4 * $invInertia;
  $6 = (($group) + 56|0);
  $7 = +HEAPF32[$6>>2];
  $8 = $5 + $7;
  HEAPF32[$6>>2] = $8;
  STACKTOP = sp;return;
 } else {
  $9 = (($this) + 104|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + ($particleIndex<<3)|0);
  $12 = $invMass * $impulse;
  __ZmlfRK6b2Vec2($1,$12,$normal);
  __ZN6b2Vec2pLERKS_($11,$1);
  STACKTOP = sp;return;
 }
}
function __ZN11b2TransformC2ERK6b2Vec2RK5b2Rot($this,$position,$rotation) {
 $this = $this|0;
 $position = $position|0;
 $rotation = $rotation|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $position;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $this;
 $7 = $6;
 HEAP32[$7>>2] = $2;
 $8 = (($6) + 4)|0;
 $9 = $8;
 HEAP32[$9>>2] = $5;
 $10 = (($this) + 8|0);
 $11 = $rotation;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = (($11) + 4)|0;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = $10;
 $18 = $17;
 HEAP32[$18>>2] = $13;
 $19 = (($17) + 4)|0;
 $20 = $19;
 HEAP32[$20>>2] = $16;
 STACKTOP = sp;return;
}
function __Z5b2MulRK11b2TransformS1_($agg$result,$A,$B) {
 $agg$result = $agg$result|0;
 $A = $A|0;
 $B = $B|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $0 = sp + 8|0;
 $1 = sp;
 $2 = sp + 16|0;
 $3 = (($agg$result) + 8|0);
 $4 = (($A) + 8|0);
 $5 = (($B) + 8|0);
 __Z5b2MulRK5b2RotS1_($0,$4,$5);
 $6 = $0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $3;
 $13 = $12;
 HEAP32[$13>>2] = $8;
 $14 = (($12) + 4)|0;
 $15 = $14;
 HEAP32[$15>>2] = $11;
 __Z5b2MulRK5b2RotRK6b2Vec2($2,$4,$B);
 __ZplRK6b2Vec2S1_($1,$2,$A);
 $16 = $1;
 $17 = $16;
 $18 = HEAP32[$17>>2]|0;
 $19 = (($16) + 4)|0;
 $20 = $19;
 $21 = HEAP32[$20>>2]|0;
 $22 = $agg$result;
 $23 = $22;
 HEAP32[$23>>2] = $18;
 $24 = (($22) + 4)|0;
 $25 = $24;
 HEAP32[$25>>2] = $21;
 STACKTOP = sp;return;
}
function __ZdvRK6b2Vec2f($agg$result,$v,$f) {
 $agg$result = $agg$result|0;
 $v = $v|0;
 $f = +$f;
 var $0 = 0.0, $1 = 0.0, $2 = 0, $3 = 0.0, $4 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$v>>2];
 $1 = $0 / $f;
 $2 = (($v) + 4|0);
 $3 = +HEAPF32[$2>>2];
 $4 = $3 / $f;
 __ZN6b2Vec2C2Eff($agg$result,$1,$4);
 STACKTOP = sp;return;
}
function __ZNK9b2Fixture7GetAABBEi($this,$childIndex) {
 $this = $this|0;
 $childIndex = $childIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + (($childIndex*28)|0)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZNK9b2Fixture15ComputeDistanceERK6b2Vec2PfPS0_i($this,$p,$d,$n,$childIndex) {
 $this = $this|0;
 $p = $p|0;
 $d = $d|0;
 $n = $n|0;
 $childIndex = $childIndex|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + 20|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($this) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__ZNK6b2Body12GetTransformEv($6)|0);
 FUNCTION_TABLE_viiiiii[$4 & 7]($1,$7,$p,$d,$n,$childIndex);
 STACKTOP = sp;return;
}
function __ZZN16b2ParticleSystem18UpdateBodyContactsEvEN26UpdateBodyContactsCallback13ShouldCollideEP9b2Fixturei($this,$fixture,$particleIndex) {
 $this = $this|0;
 $fixture = $fixture|0;
 $particleIndex = $particleIndex|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__ZNK16b2ParticleSystem14GetFlagsBufferEv($4)|0);
 $6 = (($5) + ($particleIndex<<2)|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 65536;
 $9 = ($8|0)==(0);
 if ($9) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = HEAP32[$1>>2]|0;
 $11 = (($10) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (FUNCTION_TABLE_iiiii[$12 & 7]($1,$fixture,$4,$particleIndex)|0);
 $$0 = $13;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16b2GrowableBufferI21b2ParticleBodyContactE6AppendEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)<($3|0);
 if (!($4)) {
  __ZN16b2GrowableBufferI21b2ParticleBodyContactE4GrowEv($this);
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = (($5) + 1)|0;
 HEAP32[$0>>2] = $6;
 $7 = HEAP32[$this>>2]|0;
 $8 = (($7) + (($5*28)|0)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN16b2GrowableBufferI15b2ParticleTriadE6AppendEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)<($3|0);
 if (!($4)) {
  __ZN16b2GrowableBufferI15b2ParticleTriadE4GrowEv($this);
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = (($5) + 1)|0;
 HEAP32[$0>>2] = $6;
 $7 = HEAP32[$this>>2]|0;
 $8 = (($7) + (($5*60)|0)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN6b2AABB7CombineERKS_($this,$aabb) {
 $this = $this|0;
 $aabb = $aabb|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp + 8|0;
 $1 = sp;
 __Z5b2MinRK6b2Vec2S1_($0,$this,$aabb);
 $2 = $0;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $this;
 $9 = $8;
 HEAP32[$9>>2] = $4;
 $10 = (($8) + 4)|0;
 $11 = $10;
 HEAP32[$11>>2] = $7;
 $12 = (($this) + 8|0);
 $13 = (($aabb) + 8|0);
 __Z5b2MaxRK6b2Vec2S1_($1,$12,$13);
 $14 = $1;
 $15 = $14;
 $16 = HEAP32[$15>>2]|0;
 $17 = (($14) + 4)|0;
 $18 = $17;
 $19 = HEAP32[$18>>2]|0;
 $20 = $12;
 $21 = $20;
 HEAP32[$21>>2] = $16;
 $22 = (($20) + 4)|0;
 $23 = $22;
 HEAP32[$23>>2] = $19;
 STACKTOP = sp;return;
}
function __ZN23b2TrackedBlockAllocatorC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN24b2TypedIntrusiveListNodeI14b2TrackedBlockEC2Ev($this);
 STACKTOP = sp;return;
}
function __ZN15b2TypedFreeListI16b2ParticleHandleEC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10b2FreeListC2Ev($this);
 STACKTOP = sp;return;
}
function __ZN23b2TrackedBlockAllocatorD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN23b2TrackedBlockAllocator7FreeAllEv($this);
 __ZN24b2TypedIntrusiveListNodeI14b2TrackedBlockED2Ev($this);
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferI15b2ParticleTriadE4FreeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5*60)|0;
 __ZN16b2BlockAllocator4FreeEPvi($3,$0,$6);
 HEAP32[$this>>2] = 0;
 HEAP32[$4>>2] = 0;
 $7 = (($this) + 4|0);
 HEAP32[$7>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferI14b2ParticlePairE4FreeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5*20)|0;
 __ZN16b2BlockAllocator4FreeEPvi($3,$0,$6);
 HEAP32[$this>>2] = 0;
 HEAP32[$4>>2] = 0;
 $7 = (($this) + 4|0);
 HEAP32[$7>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferI21b2ParticleBodyContactE4FreeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5*28)|0;
 __ZN16b2BlockAllocator4FreeEPvi($3,$0,$6);
 HEAP32[$this>>2] = 0;
 HEAP32[$4>>2] = 0;
 $7 = (($this) + 4|0);
 HEAP32[$7>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferI17b2ParticleContactE4FreeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5*24)|0;
 __ZN16b2BlockAllocator4FreeEPvi($3,$0,$6);
 HEAP32[$this>>2] = 0;
 HEAP32[$4>>2] = 0;
 $7 = (($this) + 4|0);
 HEAP32[$7>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEE4FreeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 << 3;
 __ZN16b2BlockAllocator4FreeEPvi($3,$0,$6);
 HEAP32[$this>>2] = 0;
 HEAP32[$4>>2] = 0;
 $7 = (($this) + 4|0);
 HEAP32[$7>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferIiE4FreeEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($this) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 << 2;
 __ZN16b2BlockAllocator4FreeEPvi($3,$0,$6);
 HEAP32[$this>>2] = 0;
 HEAP32[$4>>2] = 0;
 $7 = (($this) + 4|0);
 HEAP32[$7>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN15b2SlabAllocatorI16b2ParticleHandleE12FreeAllSlabsEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK23b2TrackedBlockAllocator7GetListEv($this)|0);
 $1 = (__ZNK24b2TypedIntrusiveListNodeI14b2TrackedBlockE7IsEmptyEv($0)|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 while(1) {
  $2 = (__ZNK24b2TypedIntrusiveListNodeI14b2TrackedBlockE7GetNextEv($0)|0);
  $3 = (__ZNK14b2TrackedBlock9GetMemoryEv($2)|0);
  $4 = (__ZN15b2SlabAllocatorI16b2ParticleHandleE12BlockGetSlabEPv($this,$3)|0);
  __ZN15b2SlabAllocatorI16b2ParticleHandleE8FreeSlabEPNS1_4SlabE($this,$4);
  $5 = (__ZNK24b2TypedIntrusiveListNodeI14b2TrackedBlockE7IsEmptyEv($0)|0);
  if ($5) {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN15b2TypedFreeListI16b2ParticleHandleED2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN10b2FreeListD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem10FreeBufferIP16b2ParticleHandleEEvPPT_i($this,$b,$capacity) {
 $this = $this|0;
 $b = $b|0;
 $capacity = $capacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$b>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 400|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $capacity << 2;
 __ZN16b2BlockAllocator4FreeEPvi($3,$0,$4);
 HEAP32[$b>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem10FreeBufferIjEEvPPT_i($this,$b,$capacity) {
 $this = $this|0;
 $b = $b|0;
 $capacity = $capacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$b>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 400|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $capacity << 2;
 __ZN16b2BlockAllocator4FreeEPvi($3,$0,$4);
 HEAP32[$b>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem10FreeBufferIiEEvPPT_i($this,$b,$capacity) {
 $this = $this|0;
 $b = $b|0;
 $capacity = $capacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$b>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 400|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $capacity << 2;
 __ZN16b2BlockAllocator4FreeEPvi($3,$0,$4);
 HEAP32[$b>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem10FreeBufferI15b2ParticleColorEEvPPT_i($this,$b,$capacity) {
 $this = $this|0;
 $b = $b|0;
 $capacity = $capacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$b>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 400|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $capacity << 2;
 __ZN16b2BlockAllocator4FreeEPvi($3,$0,$4);
 HEAP32[$b>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem10FreeBufferIPvEEvPPT_i($this,$b,$capacity) {
 $this = $this|0;
 $b = $b|0;
 $capacity = $capacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$b>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $2 = (($this) + 400|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $capacity << 2;
 __ZN16b2BlockAllocator4FreeEPvi($3,$0,$4);
 HEAP32[$b>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem16ReallocateBufferIP16b2ParticleHandleEEPT_S4_iiib($this,$buffer,$userSuppliedCapacity,$oldCapacity,$newCapacity,$deferred) {
 $this = $this|0;
 $buffer = $buffer|0;
 $userSuppliedCapacity = $userSuppliedCapacity|0;
 $oldCapacity = $oldCapacity|0;
 $newCapacity = $newCapacity|0;
 $deferred = $deferred|0;
 var $$0 = 0, $$not4 = 0, $0 = 0, $1 = 0, $or$cond$not = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$not4 = ($buffer|0)==(0|0);
 $or$cond$not = $$not4 & $deferred;
 $0 = ($userSuppliedCapacity|0)!=(0);
 $or$cond3 = $or$cond$not | $0;
 if ($or$cond3) {
  $$0 = $buffer;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (__ZN16b2ParticleSystem16ReallocateBufferIP16b2ParticleHandleEEPT_S4_ii($this,$buffer,$oldCapacity,$newCapacity)|0);
 $$0 = $1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16b2ParticleSystem16ReallocateBufferIjEEPT_S2_iiib($this,$buffer,$userSuppliedCapacity,$oldCapacity,$newCapacity,$deferred) {
 $this = $this|0;
 $buffer = $buffer|0;
 $userSuppliedCapacity = $userSuppliedCapacity|0;
 $oldCapacity = $oldCapacity|0;
 $newCapacity = $newCapacity|0;
 $deferred = $deferred|0;
 var $$0 = 0, $$not4 = 0, $0 = 0, $1 = 0, $or$cond$not = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$not4 = ($buffer|0)==(0|0);
 $or$cond$not = $$not4 & $deferred;
 $0 = ($userSuppliedCapacity|0)!=(0);
 $or$cond3 = $or$cond$not | $0;
 if ($or$cond3) {
  $$0 = $buffer;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (__ZN16b2ParticleSystem16ReallocateBufferIjEEPT_S2_ii($this,$buffer,$oldCapacity,$newCapacity)|0);
 $$0 = $1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16b2ParticleSystem16ReallocateBufferIiEEPT_S2_iiib($this,$buffer,$userSuppliedCapacity,$oldCapacity,$newCapacity,$deferred) {
 $this = $this|0;
 $buffer = $buffer|0;
 $userSuppliedCapacity = $userSuppliedCapacity|0;
 $oldCapacity = $oldCapacity|0;
 $newCapacity = $newCapacity|0;
 $deferred = $deferred|0;
 var $$0 = 0, $$not4 = 0, $0 = 0, $1 = 0, $or$cond$not = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$not4 = ($buffer|0)==(0|0);
 $or$cond$not = $$not4 & $deferred;
 $0 = ($userSuppliedCapacity|0)!=(0);
 $or$cond3 = $or$cond$not | $0;
 if ($or$cond3) {
  $$0 = $buffer;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (__ZN16b2ParticleSystem16ReallocateBufferIiEEPT_S2_ii($this,$buffer,$oldCapacity,$newCapacity)|0);
 $$0 = $1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16b2ParticleSystem16ReallocateBufferI6b2Vec2EEPT_S3_ii($this,$oldBuffer,$oldCapacity,$newCapacity) {
 $this = $this|0;
 $oldBuffer = $oldBuffer|0;
 $oldCapacity = $oldCapacity|0;
 $newCapacity = $newCapacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 400|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $newCapacity << 3;
 $3 = (__ZN16b2BlockAllocator8AllocateEi($1,$2)|0);
 $4 = ($oldBuffer|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return ($3|0);
 }
 $5 = $oldCapacity << 3;
 _memcpy(($3|0),($oldBuffer|0),($5|0))|0;
 $6 = HEAP32[$0>>2]|0;
 __ZN16b2BlockAllocator4FreeEPvi($6,$oldBuffer,$5);
 STACKTOP = sp;return ($3|0);
}
function __ZN16b2ParticleSystem16ReallocateBufferIfEEPT_S2_ii($this,$oldBuffer,$oldCapacity,$newCapacity) {
 $this = $this|0;
 $oldBuffer = $oldBuffer|0;
 $oldCapacity = $oldCapacity|0;
 $newCapacity = $newCapacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 400|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $newCapacity << 2;
 $3 = (__ZN16b2BlockAllocator8AllocateEi($1,$2)|0);
 $4 = ($oldBuffer|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return ($3|0);
 }
 $5 = $oldCapacity << 2;
 _memcpy(($3|0),($oldBuffer|0),($5|0))|0;
 $6 = HEAP32[$0>>2]|0;
 __ZN16b2BlockAllocator4FreeEPvi($6,$oldBuffer,$5);
 STACKTOP = sp;return ($3|0);
}
function __ZN16b2ParticleSystem16ReallocateBufferI15b2ParticleColorEEPT_S3_iiib($this,$buffer,$userSuppliedCapacity,$oldCapacity,$newCapacity,$deferred) {
 $this = $this|0;
 $buffer = $buffer|0;
 $userSuppliedCapacity = $userSuppliedCapacity|0;
 $oldCapacity = $oldCapacity|0;
 $newCapacity = $newCapacity|0;
 $deferred = $deferred|0;
 var $$0 = 0, $$not4 = 0, $0 = 0, $1 = 0, $or$cond$not = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$not4 = ($buffer|0)==(0|0);
 $or$cond$not = $$not4 & $deferred;
 $0 = ($userSuppliedCapacity|0)!=(0);
 $or$cond3 = $or$cond$not | $0;
 if ($or$cond3) {
  $$0 = $buffer;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (__ZN16b2ParticleSystem16ReallocateBufferI15b2ParticleColorEEPT_S3_ii($this,$buffer,$oldCapacity,$newCapacity)|0);
 $$0 = $1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16b2ParticleSystem16ReallocateBufferIP15b2ParticleGroupEEPT_S4_ii($this,$oldBuffer,$oldCapacity,$newCapacity) {
 $this = $this|0;
 $oldBuffer = $oldBuffer|0;
 $oldCapacity = $oldCapacity|0;
 $newCapacity = $newCapacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 400|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $newCapacity << 2;
 $3 = (__ZN16b2BlockAllocator8AllocateEi($1,$2)|0);
 $4 = ($oldBuffer|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return ($3|0);
 }
 $5 = $oldCapacity << 2;
 _memcpy(($3|0),($oldBuffer|0),($5|0))|0;
 $6 = HEAP32[$0>>2]|0;
 __ZN16b2BlockAllocator4FreeEPvi($6,$oldBuffer,$5);
 STACKTOP = sp;return ($3|0);
}
function __ZN16b2ParticleSystem16ReallocateBufferIPvEEPT_S3_iiib($this,$buffer,$userSuppliedCapacity,$oldCapacity,$newCapacity,$deferred) {
 $this = $this|0;
 $buffer = $buffer|0;
 $userSuppliedCapacity = $userSuppliedCapacity|0;
 $oldCapacity = $oldCapacity|0;
 $newCapacity = $newCapacity|0;
 $deferred = $deferred|0;
 var $$0 = 0, $$not4 = 0, $0 = 0, $1 = 0, $or$cond$not = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$not4 = ($buffer|0)==(0|0);
 $or$cond$not = $$not4 & $deferred;
 $0 = ($userSuppliedCapacity|0)!=(0);
 $or$cond3 = $or$cond$not | $0;
 if ($or$cond3) {
  $$0 = $buffer;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (__ZN16b2ParticleSystem16ReallocateBufferIPvEEPT_S3_ii($this,$buffer,$oldCapacity,$newCapacity)|0);
 $$0 = $1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEE4GrowEv($this) {
 $this = $this|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 $3 = $1 << 1;
 $$ = $2 ? 256 : $3;
 __ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEE7ReserveEi($this,$$);
 STACKTOP = sp;return;
}
function __ZN15b2TypedFreeListI16b2ParticleHandleE4FreeEPS0_($this,$instance) {
 $this = $this|0;
 $instance = $instance|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN24b2TypedIntrusiveListNodeI16b2ParticleHandleE11GetListNodeEv($instance)|0);
 __ZN10b2FreeList4FreeEP19b2IntrusiveListNode($this,$0);
 STACKTOP = sp;return;
}
function __ZNSt3__19remove_ifIPN16b2ParticleSystem5ProxyEPFbRKS2_EEET_S8_S8_T0_($__first,$__last,$__pred) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__pred = $__pred|0;
 var $$0$lcssa$i = 0, $$0$ph = 0, $$01$i = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $__i$0 = 0, $__i$0$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__first|0)==($__last|0);
 L1: do {
  if ($0) {
   $$0$lcssa$i = $__first;
  } else {
   $$01$i = $__first;
   while(1) {
    $3 = (FUNCTION_TABLE_ii[$__pred & 15]($$01$i)|0);
    $1 = (($$01$i) + 8|0);
    if ($3) {
     $$0$lcssa$i = $$01$i;
     break L1;
    }
    $2 = ($1|0)==($__last|0);
    if ($2) {
     $$0$lcssa$i = $1;
     break;
    } else {
     $$01$i = $1;
    }
   }
  }
 } while(0);
 $4 = ($$0$lcssa$i|0)==($__last|0);
 if ($4) {
  $$1 = $$0$lcssa$i;
  STACKTOP = sp;return ($$1|0);
 } else {
  $$0$ph = $$0$lcssa$i;$__i$0$ph = $$0$lcssa$i;
 }
 L8: while(1) {
  $__i$0 = $__i$0$ph;
  while(1) {
   $5 = (($__i$0) + 8|0);
   $6 = ($5|0)==($__last|0);
   if ($6) {
    $$1 = $$0$ph;
    break L8;
   }
   $7 = (FUNCTION_TABLE_ii[$__pred & 15]($5)|0);
   if ($7) {
    $__i$0 = $5;
   } else {
    break;
   }
  }
  $8 = $5;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($8) + 4)|0;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = $$0$ph;
  $15 = $14;
  HEAP32[$15>>2] = $10;
  $16 = (($14) + 4)|0;
  $17 = $16;
  HEAP32[$17>>2] = $13;
  $18 = (($$0$ph) + 8|0);
  $$0$ph = $18;$__i$0$ph = $5;
 }
 STACKTOP = sp;return ($$1|0);
}
function __ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEE7ShortenEPKS1_($this,$newEnd) {
 $this = $this|0;
 $newEnd = $newEnd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = $newEnd;
 $2 = $0;
 $3 = (($1) - ($2))|0;
 $4 = $3 >> 3;
 $5 = (($this) + 4|0);
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __ZNSt3__19remove_ifIP17b2ParticleContactPFbRKS1_EEET_S7_S7_T0_($__first,$__last,$__pred) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__pred = $__pred|0;
 var $$0$lcssa$i = 0, $$0$ph = 0, $$01$i = 0, $$1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $__i$0 = 0, $__i$0$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__first|0)==($__last|0);
 L1: do {
  if ($0) {
   $$0$lcssa$i = $__first;
  } else {
   $$01$i = $__first;
   while(1) {
    $3 = (FUNCTION_TABLE_ii[$__pred & 15]($$01$i)|0);
    $1 = (($$01$i) + 24|0);
    if ($3) {
     $$0$lcssa$i = $$01$i;
     break L1;
    }
    $2 = ($1|0)==($__last|0);
    if ($2) {
     $$0$lcssa$i = $1;
     break;
    } else {
     $$01$i = $1;
    }
   }
  }
 } while(0);
 $4 = ($$0$lcssa$i|0)==($__last|0);
 if ($4) {
  $$1 = $$0$lcssa$i;
  STACKTOP = sp;return ($$1|0);
 } else {
  $$0$ph = $$0$lcssa$i;$__i$0$ph = $$0$lcssa$i;
 }
 L8: while(1) {
  $__i$0 = $__i$0$ph;
  while(1) {
   $5 = (($__i$0) + 24|0);
   $6 = ($5|0)==($__last|0);
   if ($6) {
    $$1 = $$0$ph;
    break L8;
   }
   $7 = (FUNCTION_TABLE_ii[$__pred & 15]($5)|0);
   if ($7) {
    $__i$0 = $5;
   } else {
    break;
   }
  }
  ;HEAP32[$$0$ph+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$$0$ph+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$$0$ph+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$$0$ph+12>>2]=HEAP32[$5+12>>2]|0;HEAP32[$$0$ph+16>>2]=HEAP32[$5+16>>2]|0;HEAP32[$$0$ph+20>>2]=HEAP32[$5+20>>2]|0;
  $8 = (($$0$ph) + 24|0);
  $$0$ph = $8;$__i$0$ph = $5;
 }
 STACKTOP = sp;return ($$1|0);
}
function __ZN16b2GrowableBufferI17b2ParticleContactE7ShortenEPKS0_($this,$newEnd) {
 $this = $this|0;
 $newEnd = $newEnd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = $newEnd;
 $2 = $0;
 $3 = (($1) - ($2))|0;
 $4 = (($3|0) / 24)&-1;
 $5 = (($this) + 4|0);
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __ZNSt3__19remove_ifIP21b2ParticleBodyContactPFbRKS1_EEET_S7_S7_T0_($__first,$__last,$__pred) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__pred = $__pred|0;
 var $$0$lcssa$i = 0, $$0$ph = 0, $$01$i = 0, $$1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $__i$0 = 0, $__i$0$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__first|0)==($__last|0);
 L1: do {
  if ($0) {
   $$0$lcssa$i = $__first;
  } else {
   $$01$i = $__first;
   while(1) {
    $3 = (FUNCTION_TABLE_ii[$__pred & 15]($$01$i)|0);
    $1 = (($$01$i) + 28|0);
    if ($3) {
     $$0$lcssa$i = $$01$i;
     break L1;
    }
    $2 = ($1|0)==($__last|0);
    if ($2) {
     $$0$lcssa$i = $1;
     break;
    } else {
     $$01$i = $1;
    }
   }
  }
 } while(0);
 $4 = ($$0$lcssa$i|0)==($__last|0);
 if ($4) {
  $$1 = $$0$lcssa$i;
  STACKTOP = sp;return ($$1|0);
 } else {
  $$0$ph = $$0$lcssa$i;$__i$0$ph = $$0$lcssa$i;
 }
 L8: while(1) {
  $__i$0 = $__i$0$ph;
  while(1) {
   $5 = (($__i$0) + 28|0);
   $6 = ($5|0)==($__last|0);
   if ($6) {
    $$1 = $$0$ph;
    break L8;
   }
   $7 = (FUNCTION_TABLE_ii[$__pred & 15]($5)|0);
   if ($7) {
    $__i$0 = $5;
   } else {
    break;
   }
  }
  ;HEAP32[$$0$ph+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$$0$ph+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$$0$ph+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$$0$ph+12>>2]=HEAP32[$5+12>>2]|0;HEAP32[$$0$ph+16>>2]=HEAP32[$5+16>>2]|0;HEAP32[$$0$ph+20>>2]=HEAP32[$5+20>>2]|0;HEAP32[$$0$ph+24>>2]=HEAP32[$5+24>>2]|0;
  $8 = (($$0$ph) + 28|0);
  $$0$ph = $8;$__i$0$ph = $5;
 }
 STACKTOP = sp;return ($$1|0);
}
function __ZN16b2GrowableBufferI21b2ParticleBodyContactE7ShortenEPKS0_($this,$newEnd) {
 $this = $this|0;
 $newEnd = $newEnd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = $newEnd;
 $2 = $0;
 $3 = (($1) - ($2))|0;
 $4 = (($3|0) / 28)&-1;
 $5 = (($this) + 4|0);
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __ZNSt3__19remove_ifIP14b2ParticlePairPFbRKS1_EEET_S7_S7_T0_($__first,$__last,$__pred) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__pred = $__pred|0;
 var $$0$lcssa$i = 0, $$0$ph = 0, $$01$i = 0, $$1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $__i$0 = 0, $__i$0$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__first|0)==($__last|0);
 L1: do {
  if ($0) {
   $$0$lcssa$i = $__first;
  } else {
   $$01$i = $__first;
   while(1) {
    $3 = (FUNCTION_TABLE_ii[$__pred & 15]($$01$i)|0);
    $1 = (($$01$i) + 20|0);
    if ($3) {
     $$0$lcssa$i = $$01$i;
     break L1;
    }
    $2 = ($1|0)==($__last|0);
    if ($2) {
     $$0$lcssa$i = $1;
     break;
    } else {
     $$01$i = $1;
    }
   }
  }
 } while(0);
 $4 = ($$0$lcssa$i|0)==($__last|0);
 if ($4) {
  $$1 = $$0$lcssa$i;
  STACKTOP = sp;return ($$1|0);
 } else {
  $$0$ph = $$0$lcssa$i;$__i$0$ph = $$0$lcssa$i;
 }
 L8: while(1) {
  $__i$0 = $__i$0$ph;
  while(1) {
   $5 = (($__i$0) + 20|0);
   $6 = ($5|0)==($__last|0);
   if ($6) {
    $$1 = $$0$ph;
    break L8;
   }
   $7 = (FUNCTION_TABLE_ii[$__pred & 15]($5)|0);
   if ($7) {
    $__i$0 = $5;
   } else {
    break;
   }
  }
  ;HEAP32[$$0$ph+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$$0$ph+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$$0$ph+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$$0$ph+12>>2]=HEAP32[$5+12>>2]|0;HEAP32[$$0$ph+16>>2]=HEAP32[$5+16>>2]|0;
  $8 = (($$0$ph) + 20|0);
  $$0$ph = $8;$__i$0$ph = $5;
 }
 STACKTOP = sp;return ($$1|0);
}
function __ZN16b2GrowableBufferI14b2ParticlePairE7ShortenEPKS0_($this,$newEnd) {
 $this = $this|0;
 $newEnd = $newEnd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = $newEnd;
 $2 = $0;
 $3 = (($1) - ($2))|0;
 $4 = (($3|0) / 20)&-1;
 $5 = (($this) + 4|0);
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __ZNSt3__19remove_ifIP15b2ParticleTriadPFbRKS1_EEET_S7_S7_T0_($__first,$__last,$__pred) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__pred = $__pred|0;
 var $$0$lcssa$i = 0, $$0$ph = 0, $$01$i = 0, $$1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $__i$0 = 0, $__i$0$ph = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = ($__first|0)==($__last|0);
 L1: do {
  if ($0) {
   $$0$lcssa$i = $__first;
  } else {
   $$01$i = $__first;
   while(1) {
    $3 = (FUNCTION_TABLE_ii[$__pred & 15]($$01$i)|0);
    $1 = (($$01$i) + 60|0);
    if ($3) {
     $$0$lcssa$i = $$01$i;
     break L1;
    }
    $2 = ($1|0)==($__last|0);
    if ($2) {
     $$0$lcssa$i = $1;
     break;
    } else {
     $$01$i = $1;
    }
   }
  }
 } while(0);
 $4 = ($$0$lcssa$i|0)==($__last|0);
 if ($4) {
  $$1 = $$0$lcssa$i;
  STACKTOP = sp;return ($$1|0);
 } else {
  $$0$ph = $$0$lcssa$i;$__i$0$ph = $$0$lcssa$i;
 }
 L8: while(1) {
  $__i$0 = $__i$0$ph;
  while(1) {
   $5 = (($__i$0) + 60|0);
   $6 = ($5|0)==($__last|0);
   if ($6) {
    $$1 = $$0$ph;
    break L8;
   }
   $7 = (FUNCTION_TABLE_ii[$__pred & 15]($5)|0);
   if ($7) {
    $__i$0 = $5;
   } else {
    break;
   }
  }
  dest=$$0$ph+0|0; src=$5+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $8 = (($$0$ph) + 60|0);
  $$0$ph = $8;$__i$0$ph = $5;
 }
 STACKTOP = sp;return ($$1|0);
}
function __ZN16b2GrowableBufferI15b2ParticleTriadE7ShortenEPKS0_($this,$newEnd) {
 $this = $this|0;
 $newEnd = $newEnd|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = $newEnd;
 $2 = $0;
 $3 = (($1) - ($2))|0;
 $4 = (($3|0) / 60)&-1;
 $5 = (($this) + 4|0);
 HEAP32[$5>>2] = $4;
 STACKTOP = sp;return;
}
function __ZNK19b2IntrusiveListNode7IsEmptyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK19b2IntrusiveListNode7GetNextEv($this)|0);
 $1 = ($0|0)==($this|0);
 STACKTOP = sp;return ($1|0);
}
function __ZN12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIiiEEEC2EP16b2StackAllocator($this,$allocator) {
 $this = $this|0;
 $allocator = $allocator|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12_GLOBAL__N_117FixedSetAllocatorC2EP16b2StackAllocator($this,$allocator);
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferI14b2ParticlePairE4GrowEv($this) {
 $this = $this|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 $3 = $1 << 1;
 $$ = $2 ? 256 : $3;
 __ZN16b2GrowableBufferI14b2ParticlePairE7ReserveEi($this,$$);
 STACKTOP = sp;return;
}
function __ZNSt3__116__insertion_sortIRPFbRK14b2ParticlePairS3_EPS1_EEvT0_S8_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $__i$0 = 0, $__i$04 = 0, $__i$05 = 0, $__j$0$lcssa = 0, $__k$02 = 0, $__t = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t = sp;
 $0 = ($__first|0)==($__last|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $__i$04 = (($__first) + 20|0);
 $1 = ($__i$04|0)==($__last|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $__i$05 = $__i$04;
 while(1) {
  ;HEAP32[$__t+0>>2]=HEAP32[$__i$05+0>>2]|0;HEAP32[$__t+4>>2]=HEAP32[$__i$05+4>>2]|0;HEAP32[$__t+8>>2]=HEAP32[$__i$05+8>>2]|0;HEAP32[$__t+12>>2]=HEAP32[$__i$05+12>>2]|0;HEAP32[$__t+16>>2]=HEAP32[$__i$05+16>>2]|0;
  $2 = ($__i$05|0)==($__first|0);
  L9: do {
   if ($2) {
    $__j$0$lcssa = $__i$05;
   } else {
    $__k$02 = $__i$05;
    while(1) {
     $3 = HEAP32[$__comp>>2]|0;
     $4 = (($__k$02) + -20|0);
     $5 = (FUNCTION_TABLE_iii[$3 & 63]($__t,$4)|0);
     if (!($5)) {
      $__j$0$lcssa = $__k$02;
      break L9;
     }
     ;HEAP32[$__k$02+0>>2]=HEAP32[$4+0>>2]|0;HEAP32[$__k$02+4>>2]=HEAP32[$4+4>>2]|0;HEAP32[$__k$02+8>>2]=HEAP32[$4+8>>2]|0;HEAP32[$__k$02+12>>2]=HEAP32[$4+12>>2]|0;HEAP32[$__k$02+16>>2]=HEAP32[$4+16>>2]|0;
     $6 = ($4|0)==($__first|0);
     if ($6) {
      $__j$0$lcssa = $4;
      break;
     } else {
      $__k$02 = $4;
     }
    }
   }
  } while(0);
  ;HEAP32[$__j$0$lcssa+0>>2]=HEAP32[$__t+0>>2]|0;HEAP32[$__j$0$lcssa+4>>2]=HEAP32[$__t+4>>2]|0;HEAP32[$__j$0$lcssa+8>>2]=HEAP32[$__t+8>>2]|0;HEAP32[$__j$0$lcssa+12>>2]=HEAP32[$__t+12>>2]|0;HEAP32[$__j$0$lcssa+16>>2]=HEAP32[$__t+16>>2]|0;
  $__i$0 = (($__i$05) + 20|0);
  $7 = ($__i$0|0)==($__last|0);
  if ($7) {
   break;
  } else {
   $__i$05 = $__i$0;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__118__stable_sort_moveIRPFbRK14b2ParticlePairS3_EPS1_EEvT0_S8_T_NS_15iterator_traitsIS8_E15difference_typeEPNSB_10value_typeE($__first1,$__last1,$__comp,$__len,$__first2) {
 $__first1 = $__first1|0;
 $__last1 = $__last1|0;
 $__comp = $__comp|0;
 $__len = $__len|0;
 $__first2 = $__first2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ((($__len|0) == 2)) {
  $1 = HEAP32[$__comp>>2]|0;
  $2 = (($__last1) + -20|0);
  $3 = (FUNCTION_TABLE_iii[$1 & 63]($2,$__first1)|0);
  $4 = ($__first2|0)==(0|0);
  if ($3) {
   if (!($4)) {
    ;HEAP32[$__first2+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$__first2+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$__first2+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$__first2+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$__first2+16>>2]=HEAP32[$2+16>>2]|0;
   }
   $5 = (($__first2) + 20|0);
   ;HEAP32[$5+0>>2]=HEAP32[$__first1+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$__first1+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$__first1+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$__first1+12>>2]|0;HEAP32[$5+16>>2]=HEAP32[$__first1+16>>2]|0;
   STACKTOP = sp;return;
  } else {
   if (!($4)) {
    ;HEAP32[$__first2+0>>2]=HEAP32[$__first1+0>>2]|0;HEAP32[$__first2+4>>2]=HEAP32[$__first1+4>>2]|0;HEAP32[$__first2+8>>2]=HEAP32[$__first1+8>>2]|0;HEAP32[$__first2+12>>2]=HEAP32[$__first1+12>>2]|0;HEAP32[$__first2+16>>2]=HEAP32[$__first1+16>>2]|0;
   }
   $6 = (($__first2) + 20|0);
   ;HEAP32[$6+0>>2]=HEAP32[$2+0>>2]|0;HEAP32[$6+4>>2]=HEAP32[$2+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$2+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$2+12>>2]|0;HEAP32[$6+16>>2]=HEAP32[$2+16>>2]|0;
   STACKTOP = sp;return;
  }
 } else if ((($__len|0) == 1)) {
  $0 = ($__first2|0)==(0|0);
  if ($0) {
   STACKTOP = sp;return;
  }
  ;HEAP32[$__first2+0>>2]=HEAP32[$__first1+0>>2]|0;HEAP32[$__first2+4>>2]=HEAP32[$__first1+4>>2]|0;HEAP32[$__first2+8>>2]=HEAP32[$__first1+8>>2]|0;HEAP32[$__first2+12>>2]=HEAP32[$__first1+12>>2]|0;HEAP32[$__first2+16>>2]=HEAP32[$__first1+16>>2]|0;
  STACKTOP = sp;return;
 } else if ((($__len|0) == 0)) {
  STACKTOP = sp;return;
 } else {
  $7 = ($__len|0)<(9);
  if ($7) {
   __ZNSt3__121__insertion_sort_moveIRPFbRK14b2ParticlePairS3_EPS1_EEvT0_S8_PNS_15iterator_traitsIS8_E10value_typeET_($__first1,$__last1,$__first2,$__comp);
   STACKTOP = sp;return;
  } else {
   $8 = (($__len|0) / 2)&-1;
   $9 = (($__first1) + (($8*20)|0)|0);
   __ZNSt3__113__stable_sortIRPFbRK14b2ParticlePairS3_EPS1_EEvT0_S8_T_NS_15iterator_traitsIS8_E15difference_typeEPNSB_10value_typeEi($__first1,$9,$__comp,$8,$__first2,$8);
   $10 = (($__len) - ($8))|0;
   $11 = (($__first2) + (($8*20)|0)|0);
   __ZNSt3__113__stable_sortIRPFbRK14b2ParticlePairS3_EPS1_EEvT0_S8_T_NS_15iterator_traitsIS8_E15difference_typeEPNSB_10value_typeEi($9,$__last1,$__comp,$10,$11,$10);
   __ZNSt3__122__merge_move_constructIRPFbRK14b2ParticlePairS3_EPS1_S7_EEvT0_S8_T1_S9_PNS_15iterator_traitsIS8_E10value_typeET_($__first1,$9,$9,$__last1,$__first2,$__comp);
   STACKTOP = sp;return;
  }
 }
}
function __ZNSt3__119__merge_move_assignIRPFbRK14b2ParticlePairS3_EPS1_S7_S7_EEvT0_S8_T1_S9_T2_T_($__first1,$__last1,$__first2,$__last2,$__result,$__comp) {
 $__first1 = $__first1|0;
 $__last1 = $__last1|0;
 $__first2 = $__first2|0;
 $__last2 = $__last2|0;
 $__result = $__result|0;
 $__comp = $__comp|0;
 var $$01$lcssa = 0, $$0118 = 0, $$019 = 0, $$04$lcssa = 0, $$0417 = 0, $$112 = 0, $$1211 = 0, $$15 = 0, $$2 = 0, $$238 = 0, $$267 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__first1|0)==($__last1|0);
 L1: do {
  if ($0) {
   $$01$lcssa = $__result;$$04$lcssa = $__first2;
  } else {
   $$0118 = $__result;$$019 = $__first1;$$0417 = $__first2;
   while(1) {
    $2 = ($$0417|0)==($__last2|0);
    if ($2) {
     break;
    }
    $7 = HEAP32[$__comp>>2]|0;
    $8 = (FUNCTION_TABLE_iii[$7 & 63]($$0417,$$019)|0);
    if ($8) {
     ;HEAP32[$$0118+0>>2]=HEAP32[$$0417+0>>2]|0;HEAP32[$$0118+4>>2]=HEAP32[$$0417+4>>2]|0;HEAP32[$$0118+8>>2]=HEAP32[$$0417+8>>2]|0;HEAP32[$$0118+12>>2]=HEAP32[$$0417+12>>2]|0;HEAP32[$$0118+16>>2]=HEAP32[$$0417+16>>2]|0;
     $9 = (($$0417) + 20|0);
     $$15 = $9;$$2 = $$019;
    } else {
     ;HEAP32[$$0118+0>>2]=HEAP32[$$019+0>>2]|0;HEAP32[$$0118+4>>2]=HEAP32[$$019+4>>2]|0;HEAP32[$$0118+8>>2]=HEAP32[$$019+8>>2]|0;HEAP32[$$0118+12>>2]=HEAP32[$$019+12>>2]|0;HEAP32[$$0118+16>>2]=HEAP32[$$019+16>>2]|0;
     $10 = (($$019) + 20|0);
     $$15 = $$0417;$$2 = $10;
    }
    $11 = (($$0118) + 20|0);
    $12 = ($$2|0)==($__last1|0);
    if ($12) {
     $$01$lcssa = $11;$$04$lcssa = $$15;
     break L1;
    } else {
     $$0118 = $11;$$019 = $$2;$$0417 = $$15;
    }
   }
   $3 = ($$019|0)==($__last1|0);
   if ($3) {
    STACKTOP = sp;return;
   } else {
    $$112 = $$019;$$1211 = $$0118;
   }
   while(1) {
    ;HEAP32[$$1211+0>>2]=HEAP32[$$112+0>>2]|0;HEAP32[$$1211+4>>2]=HEAP32[$$112+4>>2]|0;HEAP32[$$1211+8>>2]=HEAP32[$$112+8>>2]|0;HEAP32[$$1211+12>>2]=HEAP32[$$112+12>>2]|0;HEAP32[$$1211+16>>2]=HEAP32[$$112+16>>2]|0;
    $4 = (($$112) + 20|0);
    $5 = (($$1211) + 20|0);
    $6 = ($4|0)==($__last1|0);
    if ($6) {
     break;
    } else {
     $$112 = $4;$$1211 = $5;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $1 = ($$04$lcssa|0)==($__last2|0);
 if ($1) {
  STACKTOP = sp;return;
 } else {
  $$238 = $$01$lcssa;$$267 = $$04$lcssa;
 }
 while(1) {
  ;HEAP32[$$238+0>>2]=HEAP32[$$267+0>>2]|0;HEAP32[$$238+4>>2]=HEAP32[$$267+4>>2]|0;HEAP32[$$238+8>>2]=HEAP32[$$267+8>>2]|0;HEAP32[$$238+12>>2]=HEAP32[$$267+12>>2]|0;HEAP32[$$238+16>>2]=HEAP32[$$267+16>>2]|0;
  $13 = (($$267) + 20|0);
  $14 = (($$238) + 20|0);
  $15 = ($13|0)==($__last2|0);
  if ($15) {
   break;
  } else {
   $$238 = $14;$$267 = $13;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__115__inplace_mergeIRPFbRK14b2ParticlePairS3_EPS1_EEvT0_S8_S8_T_NS_15iterator_traitsIS8_E15difference_typeESC_PNSB_10value_typeEi($__first,$__middle,$__last,$__comp,$__len1,$__len2,$__buff,$__buff_size) {
 $__first = $__first|0;
 $__middle = $__middle|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 $__len1 = $__len1|0;
 $__len2 = $__len2|0;
 $__buff = $__buff|0;
 $__buff_size = $__buff_size|0;
 var $$0$i = 0, $$0$ph40 = 0, $$02$ph39 = 0, $$0229 = 0, $$028 = 0, $$03$ph38 = 0, $$030 = 0, $$04$ph37 = 0, $$0428 = 0, $$06$ph36 = 0, $$0627 = 0, $$1 = 0, $$15 = 0, $$old1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len11$0 = 0, $__len21$0 = 0, $__t$i = 0;
 var $or$cond = 0, $or$cond26 = 0, $or$cond2635 = 0, $or$cond7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i = sp;
 $0 = ($__len2|0)==(0);
 $1 = ($__len1|0)==(0);
 $or$cond2635 = $0 | $1;
 if ($or$cond2635) {
  STACKTOP = sp;return;
 } else {
  $$0$ph40 = $__first;$$02$ph39 = $__middle;$$03$ph38 = $__last;$$04$ph37 = $__len1;$$06$ph36 = $__len2;
 }
 L3: while(1) {
  $$0229 = $$02$ph39;$$030 = $$0$ph40;$$0428 = $$04$ph37;$$0627 = $$06$ph36;
  while(1) {
   $$1 = $$030;$$15 = $$0428;
   while(1) {
    $2 = HEAP32[$__comp>>2]|0;
    $3 = (FUNCTION_TABLE_iii[$2 & 63]($$0229,$$1)|0);
    if ($3) {
     break;
    }
    $4 = (($$1) + 20|0);
    $5 = (($$15) + -1)|0;
    $$old1 = ($5|0)==(0);
    if ($$old1) {
     label = 23;
     break L3;
    } else {
     $$1 = $4;$$15 = $5;
    }
   }
   $6 = ($$15|0)>($__buff_size|0);
   $7 = ($$0627|0)>($__buff_size|0);
   $or$cond7 = $6 & $7;
   if (!($or$cond7)) {
    label = 7;
    break L3;
   }
   $8 = ($$15|0)<($$0627|0);
   if ($8) {
    $9 = (($$0627|0) / 2)&-1;
    $10 = (($$0229) + (($9*20)|0)|0);
    $11 = (__ZNSt3__113__upper_boundIRPFbRK14b2ParticlePairS3_EPS1_S1_EET0_S8_S8_RKT1_T_($$1,$$0229,$10,$__comp)|0);
    $12 = $11;
    $13 = $$1;
    $14 = (($12) - ($13))|0;
    $15 = (($14|0) / 20)&-1;
    $$028 = $10;$26 = $11;$__len11$0 = $15;$__len21$0 = $9;
   } else {
    $16 = ($$15|0)==(1);
    if ($16) {
     label = 11;
     break L3;
    }
    $17 = (($$15|0) / 2)&-1;
    $18 = (($$1) + (($17*20)|0)|0);
    $19 = (__ZNSt3__113__lower_boundIRPFbRK14b2ParticlePairS3_EPS1_S1_EET0_S8_S8_RKT1_T_($$0229,$$03$ph38,$18,$__comp)|0);
    $20 = $19;
    $21 = $$0229;
    $22 = (($20) - ($21))|0;
    $23 = (($22|0) / 20)&-1;
    $$028 = $19;$26 = $18;$__len11$0 = $17;$__len21$0 = $23;
   }
   $24 = (($$15) - ($__len11$0))|0;
   $25 = (($$0627) - ($__len21$0))|0;
   $27 = ($26|0)==($$0229|0);
   do {
    if ($27) {
     $$0$i = $$028;
    } else {
     $28 = ($$0229|0)==($$028|0);
     if ($28) {
      $$0$i = $26;
     } else {
      $29 = (($26) + 20|0);
      $30 = ($29|0)==($$0229|0);
      if ($30) {
       $31 = (__ZNSt3__113__rotate_leftIP14b2ParticlePairEET_S3_S3_($26,$$028)|0);
       $$0$i = $31;
       break;
      }
      $32 = (($$0229) + 20|0);
      $33 = ($32|0)==($$028|0);
      if ($33) {
       $34 = (__ZNSt3__114__rotate_rightIP14b2ParticlePairEET_S3_S3_($26,$$028)|0);
       $$0$i = $34;
       break;
      } else {
       $35 = (__ZNSt3__112__rotate_gcdIP14b2ParticlePairEET_S3_S3_S3_($26,$$0229,$$028)|0);
       $$0$i = $35;
       break;
      }
     }
    }
   } while(0);
   $36 = (($__len21$0) + ($__len11$0))|0;
   $37 = (($25) + ($24))|0;
   $38 = ($36|0)<($37|0);
   if (!($38)) {
    break;
   }
   __ZNSt3__115__inplace_mergeIRPFbRK14b2ParticlePairS3_EPS1_EEvT0_S8_S8_T_NS_15iterator_traitsIS8_E15difference_typeESC_PNSB_10value_typeEi($$1,$26,$$0$i,$__comp,$__len11$0,$__len21$0,$__buff,$__buff_size);
   $39 = ($$0627|0)==($__len21$0|0);
   $40 = ($$15|0)==($__len11$0|0);
   $or$cond = $39 | $40;
   if ($or$cond) {
    label = 23;
    break L3;
   } else {
    $$0229 = $$028;$$030 = $$0$i;$$0428 = $24;$$0627 = $25;
   }
  }
  __ZNSt3__115__inplace_mergeIRPFbRK14b2ParticlePairS3_EPS1_EEvT0_S8_S8_T_NS_15iterator_traitsIS8_E15difference_typeESC_PNSB_10value_typeEi($$0$i,$$028,$$03$ph38,$__comp,$24,$25,$__buff,$__buff_size);
  $41 = ($__len21$0|0)==(0);
  $42 = ($__len11$0|0)==(0);
  $or$cond26 = $41 | $42;
  if ($or$cond26) {
   label = 23;
   break;
  } else {
   $$0$ph40 = $$1;$$02$ph39 = $26;$$03$ph38 = $$0$i;$$04$ph37 = $__len11$0;$$06$ph36 = $__len21$0;
  }
 }
 if ((label|0) == 7) {
  __ZNSt3__124__buffered_inplace_mergeIRPFbRK14b2ParticlePairS3_EPS1_EEvT0_S8_S8_T_NS_15iterator_traitsIS8_E15difference_typeESC_PNSB_10value_typeE($$1,$$0229,$$03$ph38,$__comp,$$15,$$0627,$__buff);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 11) {
  ;HEAP32[$__t$i+0>>2]=HEAP32[$$1+0>>2]|0;HEAP32[$__t$i+4>>2]=HEAP32[$$1+4>>2]|0;HEAP32[$__t$i+8>>2]=HEAP32[$$1+8>>2]|0;HEAP32[$__t$i+12>>2]=HEAP32[$$1+12>>2]|0;HEAP32[$__t$i+16>>2]=HEAP32[$$1+16>>2]|0;
  ;HEAP32[$$1+0>>2]=HEAP32[$$0229+0>>2]|0;HEAP32[$$1+4>>2]=HEAP32[$$0229+4>>2]|0;HEAP32[$$1+8>>2]=HEAP32[$$0229+8>>2]|0;HEAP32[$$1+12>>2]=HEAP32[$$0229+12>>2]|0;HEAP32[$$1+16>>2]=HEAP32[$$0229+16>>2]|0;
  ;HEAP32[$$0229+0>>2]=HEAP32[$__t$i+0>>2]|0;HEAP32[$$0229+4>>2]=HEAP32[$__t$i+4>>2]|0;HEAP32[$$0229+8>>2]=HEAP32[$__t$i+8>>2]|0;HEAP32[$$0229+12>>2]=HEAP32[$__t$i+12>>2]|0;HEAP32[$$0229+16>>2]=HEAP32[$__t$i+16>>2]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 23) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16uniqueIP14b2ParticlePairPFbRKS1_S4_EEET_S7_S7_T0_($__first,$__last,$__pred) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__pred = $__pred|0;
 var $$0$ph = 0, $$01$i = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$0 = 0, $__i$0$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__first|0)==($__last|0);
 if ($0) {
  $$1 = $__last;
  STACKTOP = sp;return ($$1|0);
 } else {
  $$01$i = $__first;
 }
 while(1) {
  $1 = (($$01$i) + 20|0);
  $2 = ($1|0)==($__last|0);
  if ($2) {
   $$1 = $__last;
   label = 11;
   break;
  }
  $3 = (FUNCTION_TABLE_iii[$__pred & 63]($$01$i,$1)|0);
  if ($3) {
   break;
  } else {
   $$01$i = $1;
  }
 }
 if ((label|0) == 11) {
  STACKTOP = sp;return ($$1|0);
 }
 $4 = ($$01$i|0)==($__last|0);
 if ($4) {
  $$1 = $$01$i;
  STACKTOP = sp;return ($$1|0);
 }
 $5 = (($$01$i) + 20|0);
 $$0$ph = $$01$i;$__i$0$ph = $5;
 L12: while(1) {
  $__i$0 = $__i$0$ph;
  while(1) {
   $6 = (($__i$0) + 20|0);
   $7 = ($6|0)==($__last|0);
   if ($7) {
    break L12;
   }
   $8 = (FUNCTION_TABLE_iii[$__pred & 63]($$0$ph,$6)|0);
   if ($8) {
    $__i$0 = $6;
   } else {
    break;
   }
  }
  $9 = (($$0$ph) + 20|0);
  ;HEAP32[$9+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$9+4>>2]=HEAP32[$6+4>>2]|0;HEAP32[$9+8>>2]=HEAP32[$6+8>>2]|0;HEAP32[$9+12>>2]=HEAP32[$6+12>>2]|0;HEAP32[$9+16>>2]=HEAP32[$6+16>>2]|0;
  $$0$ph = $9;$__i$0$ph = $6;
 }
 $10 = (($$0$ph) + 20|0);
 $$1 = $10;
 STACKTOP = sp;return ($$1|0);
}
function __ZN16b2VoronoiDiagram12NodeCallbackC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = ((8760 + 8|0));
 STACKTOP = sp;return;
}
function __ZNSt3__116__insertion_sortIRPFbRK15b2ParticleTriadS3_EPS1_EEvT0_S8_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $__i$0 = 0, $__i$04 = 0, $__i$05 = 0, $__j$0$lcssa = 0, $__k$02 = 0, $__t = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $__t = sp;
 $0 = ($__first|0)==($__last|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $__i$04 = (($__first) + 60|0);
 $1 = ($__i$04|0)==($__last|0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $__i$05 = $__i$04;
 while(1) {
  dest=$__t+0|0; src=$__i$05+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $2 = ($__i$05|0)==($__first|0);
  L9: do {
   if ($2) {
    $__j$0$lcssa = $__i$05;
   } else {
    $__k$02 = $__i$05;
    while(1) {
     $3 = HEAP32[$__comp>>2]|0;
     $4 = (($__k$02) + -60|0);
     $5 = (FUNCTION_TABLE_iii[$3 & 63]($__t,$4)|0);
     if (!($5)) {
      $__j$0$lcssa = $__k$02;
      break L9;
     }
     dest=$__k$02+0|0; src=$4+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     $6 = ($4|0)==($__first|0);
     if ($6) {
      $__j$0$lcssa = $4;
      break;
     } else {
      $__k$02 = $4;
     }
    }
   }
  } while(0);
  dest=$__j$0$lcssa+0|0; src=$__t+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $__i$0 = (($__i$05) + 60|0);
  $7 = ($__i$0|0)==($__last|0);
  if ($7) {
   break;
  } else {
   $__i$05 = $__i$0;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__118__stable_sort_moveIRPFbRK15b2ParticleTriadS3_EPS1_EEvT0_S8_T_NS_15iterator_traitsIS8_E15difference_typeEPNSB_10value_typeE($__first1,$__last1,$__comp,$__len,$__first2) {
 $__first1 = $__first1|0;
 $__last1 = $__last1|0;
 $__comp = $__comp|0;
 $__len = $__len|0;
 $__first2 = $__first2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 if ((($__len|0) == 2)) {
  $1 = HEAP32[$__comp>>2]|0;
  $2 = (($__last1) + -60|0);
  $3 = (FUNCTION_TABLE_iii[$1 & 63]($2,$__first1)|0);
  $4 = ($__first2|0)==(0|0);
  if ($3) {
   if (!($4)) {
    dest=$__first2+0|0; src=$2+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   }
   $5 = (($__first2) + 60|0);
   dest=$5+0|0; src=$__first1+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   STACKTOP = sp;return;
  } else {
   if (!($4)) {
    dest=$__first2+0|0; src=$__first1+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   }
   $6 = (($__first2) + 60|0);
   dest=$6+0|0; src=$2+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   STACKTOP = sp;return;
  }
 } else if ((($__len|0) == 1)) {
  $0 = ($__first2|0)==(0|0);
  if ($0) {
   STACKTOP = sp;return;
  }
  dest=$__first2+0|0; src=$__first1+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 } else if ((($__len|0) == 0)) {
  STACKTOP = sp;return;
 } else {
  $7 = ($__len|0)<(9);
  if ($7) {
   __ZNSt3__121__insertion_sort_moveIRPFbRK15b2ParticleTriadS3_EPS1_EEvT0_S8_PNS_15iterator_traitsIS8_E10value_typeET_($__first1,$__last1,$__first2,$__comp);
   STACKTOP = sp;return;
  } else {
   $8 = (($__len|0) / 2)&-1;
   $9 = (($__first1) + (($8*60)|0)|0);
   __ZNSt3__113__stable_sortIRPFbRK15b2ParticleTriadS3_EPS1_EEvT0_S8_T_NS_15iterator_traitsIS8_E15difference_typeEPNSB_10value_typeEi($__first1,$9,$__comp,$8,$__first2,$8);
   $10 = (($__len) - ($8))|0;
   $11 = (($__first2) + (($8*60)|0)|0);
   __ZNSt3__113__stable_sortIRPFbRK15b2ParticleTriadS3_EPS1_EEvT0_S8_T_NS_15iterator_traitsIS8_E15difference_typeEPNSB_10value_typeEi($9,$__last1,$__comp,$10,$11,$10);
   __ZNSt3__122__merge_move_constructIRPFbRK15b2ParticleTriadS3_EPS1_S7_EEvT0_S8_T1_S9_PNS_15iterator_traitsIS8_E10value_typeET_($__first1,$9,$9,$__last1,$__first2,$__comp);
   STACKTOP = sp;return;
  }
 }
}
function __ZNSt3__119__merge_move_assignIRPFbRK15b2ParticleTriadS3_EPS1_S7_S7_EEvT0_S8_T1_S9_T2_T_($__first1,$__last1,$__first2,$__last2,$__result,$__comp) {
 $__first1 = $__first1|0;
 $__last1 = $__last1|0;
 $__first2 = $__first2|0;
 $__last2 = $__last2|0;
 $__result = $__result|0;
 $__comp = $__comp|0;
 var $$01$lcssa = 0, $$0118 = 0, $$019 = 0, $$04$lcssa = 0, $$0417 = 0, $$112 = 0, $$1211 = 0, $$15 = 0, $$2 = 0, $$238 = 0, $$267 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = ($__first1|0)==($__last1|0);
 L1: do {
  if ($0) {
   $$01$lcssa = $__result;$$04$lcssa = $__first2;
  } else {
   $$0118 = $__result;$$019 = $__first1;$$0417 = $__first2;
   while(1) {
    $2 = ($$0417|0)==($__last2|0);
    if ($2) {
     break;
    }
    $7 = HEAP32[$__comp>>2]|0;
    $8 = (FUNCTION_TABLE_iii[$7 & 63]($$0417,$$019)|0);
    if ($8) {
     dest=$$0118+0|0; src=$$0417+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     $9 = (($$0417) + 60|0);
     $$15 = $9;$$2 = $$019;
    } else {
     dest=$$0118+0|0; src=$$019+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     $10 = (($$019) + 60|0);
     $$15 = $$0417;$$2 = $10;
    }
    $11 = (($$0118) + 60|0);
    $12 = ($$2|0)==($__last1|0);
    if ($12) {
     $$01$lcssa = $11;$$04$lcssa = $$15;
     break L1;
    } else {
     $$0118 = $11;$$019 = $$2;$$0417 = $$15;
    }
   }
   $3 = ($$019|0)==($__last1|0);
   if ($3) {
    STACKTOP = sp;return;
   } else {
    $$112 = $$019;$$1211 = $$0118;
   }
   while(1) {
    dest=$$1211+0|0; src=$$112+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $4 = (($$112) + 60|0);
    $5 = (($$1211) + 60|0);
    $6 = ($4|0)==($__last1|0);
    if ($6) {
     break;
    } else {
     $$112 = $4;$$1211 = $5;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $1 = ($$04$lcssa|0)==($__last2|0);
 if ($1) {
  STACKTOP = sp;return;
 } else {
  $$238 = $$01$lcssa;$$267 = $$04$lcssa;
 }
 while(1) {
  dest=$$238+0|0; src=$$267+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $13 = (($$267) + 60|0);
  $14 = (($$238) + 60|0);
  $15 = ($13|0)==($__last2|0);
  if ($15) {
   break;
  } else {
   $$238 = $14;$$267 = $13;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__115__inplace_mergeIRPFbRK15b2ParticleTriadS3_EPS1_EEvT0_S8_S8_T_NS_15iterator_traitsIS8_E15difference_typeESC_PNSB_10value_typeEi($__first,$__middle,$__last,$__comp,$__len1,$__len2,$__buff,$__buff_size) {
 $__first = $__first|0;
 $__middle = $__middle|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 $__len1 = $__len1|0;
 $__len2 = $__len2|0;
 $__buff = $__buff|0;
 $__buff_size = $__buff_size|0;
 var $$0$i = 0, $$0$ph40 = 0, $$02$ph39 = 0, $$0229 = 0, $$028 = 0, $$03$ph38 = 0, $$030 = 0, $$04$ph37 = 0, $$0428 = 0, $$06$ph36 = 0, $$0627 = 0, $$1 = 0, $$15 = 0, $$old1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len11$0 = 0, $__len21$0 = 0, $__t$i = 0;
 var $or$cond = 0, $or$cond26 = 0, $or$cond2635 = 0, $or$cond7 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $__t$i = sp;
 $0 = ($__len2|0)==(0);
 $1 = ($__len1|0)==(0);
 $or$cond2635 = $0 | $1;
 if ($or$cond2635) {
  STACKTOP = sp;return;
 } else {
  $$0$ph40 = $__first;$$02$ph39 = $__middle;$$03$ph38 = $__last;$$04$ph37 = $__len1;$$06$ph36 = $__len2;
 }
 L3: while(1) {
  $$0229 = $$02$ph39;$$030 = $$0$ph40;$$0428 = $$04$ph37;$$0627 = $$06$ph36;
  while(1) {
   $$1 = $$030;$$15 = $$0428;
   while(1) {
    $2 = HEAP32[$__comp>>2]|0;
    $3 = (FUNCTION_TABLE_iii[$2 & 63]($$0229,$$1)|0);
    if ($3) {
     break;
    }
    $4 = (($$1) + 60|0);
    $5 = (($$15) + -1)|0;
    $$old1 = ($5|0)==(0);
    if ($$old1) {
     label = 23;
     break L3;
    } else {
     $$1 = $4;$$15 = $5;
    }
   }
   $6 = ($$15|0)>($__buff_size|0);
   $7 = ($$0627|0)>($__buff_size|0);
   $or$cond7 = $6 & $7;
   if (!($or$cond7)) {
    label = 7;
    break L3;
   }
   $8 = ($$15|0)<($$0627|0);
   if ($8) {
    $9 = (($$0627|0) / 2)&-1;
    $10 = (($$0229) + (($9*60)|0)|0);
    $11 = (__ZNSt3__113__upper_boundIRPFbRK15b2ParticleTriadS3_EPS1_S1_EET0_S8_S8_RKT1_T_($$1,$$0229,$10,$__comp)|0);
    $12 = $11;
    $13 = $$1;
    $14 = (($12) - ($13))|0;
    $15 = (($14|0) / 60)&-1;
    $$028 = $10;$26 = $11;$__len11$0 = $15;$__len21$0 = $9;
   } else {
    $16 = ($$15|0)==(1);
    if ($16) {
     label = 11;
     break L3;
    }
    $17 = (($$15|0) / 2)&-1;
    $18 = (($$1) + (($17*60)|0)|0);
    $19 = (__ZNSt3__113__lower_boundIRPFbRK15b2ParticleTriadS3_EPS1_S1_EET0_S8_S8_RKT1_T_($$0229,$$03$ph38,$18,$__comp)|0);
    $20 = $19;
    $21 = $$0229;
    $22 = (($20) - ($21))|0;
    $23 = (($22|0) / 60)&-1;
    $$028 = $19;$26 = $18;$__len11$0 = $17;$__len21$0 = $23;
   }
   $24 = (($$15) - ($__len11$0))|0;
   $25 = (($$0627) - ($__len21$0))|0;
   $27 = ($26|0)==($$0229|0);
   do {
    if ($27) {
     $$0$i = $$028;
    } else {
     $28 = ($$0229|0)==($$028|0);
     if ($28) {
      $$0$i = $26;
     } else {
      $29 = (($26) + 60|0);
      $30 = ($29|0)==($$0229|0);
      if ($30) {
       $31 = (__ZNSt3__113__rotate_leftIP15b2ParticleTriadEET_S3_S3_($26,$$028)|0);
       $$0$i = $31;
       break;
      }
      $32 = (($$0229) + 60|0);
      $33 = ($32|0)==($$028|0);
      if ($33) {
       $34 = (__ZNSt3__114__rotate_rightIP15b2ParticleTriadEET_S3_S3_($26,$$028)|0);
       $$0$i = $34;
       break;
      } else {
       $35 = (__ZNSt3__112__rotate_gcdIP15b2ParticleTriadEET_S3_S3_S3_($26,$$0229,$$028)|0);
       $$0$i = $35;
       break;
      }
     }
    }
   } while(0);
   $36 = (($__len21$0) + ($__len11$0))|0;
   $37 = (($25) + ($24))|0;
   $38 = ($36|0)<($37|0);
   if (!($38)) {
    break;
   }
   __ZNSt3__115__inplace_mergeIRPFbRK15b2ParticleTriadS3_EPS1_EEvT0_S8_S8_T_NS_15iterator_traitsIS8_E15difference_typeESC_PNSB_10value_typeEi($$1,$26,$$0$i,$__comp,$__len11$0,$__len21$0,$__buff,$__buff_size);
   $39 = ($$0627|0)==($__len21$0|0);
   $40 = ($$15|0)==($__len11$0|0);
   $or$cond = $39 | $40;
   if ($or$cond) {
    label = 23;
    break L3;
   } else {
    $$0229 = $$028;$$030 = $$0$i;$$0428 = $24;$$0627 = $25;
   }
  }
  __ZNSt3__115__inplace_mergeIRPFbRK15b2ParticleTriadS3_EPS1_EEvT0_S8_S8_T_NS_15iterator_traitsIS8_E15difference_typeESC_PNSB_10value_typeEi($$0$i,$$028,$$03$ph38,$__comp,$24,$25,$__buff,$__buff_size);
  $41 = ($__len21$0|0)==(0);
  $42 = ($__len11$0|0)==(0);
  $or$cond26 = $41 | $42;
  if ($or$cond26) {
   label = 23;
   break;
  } else {
   $$0$ph40 = $$1;$$02$ph39 = $26;$$03$ph38 = $$0$i;$$04$ph37 = $__len11$0;$$06$ph36 = $__len21$0;
  }
 }
 if ((label|0) == 7) {
  __ZNSt3__124__buffered_inplace_mergeIRPFbRK15b2ParticleTriadS3_EPS1_EEvT0_S8_S8_T_NS_15iterator_traitsIS8_E15difference_typeESC_PNSB_10value_typeE($$1,$$0229,$$03$ph38,$__comp,$$15,$$0627,$__buff);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 11) {
  dest=$__t$i+0|0; src=$$1+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$$1+0|0; src=$$0229+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  dest=$$0229+0|0; src=$__t$i+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  STACKTOP = sp;return;
 }
 else if ((label|0) == 23) {
  STACKTOP = sp;return;
 }
}
function __ZNSt3__16uniqueIP15b2ParticleTriadPFbRKS1_S4_EEET_S7_S7_T0_($__first,$__last,$__pred) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__pred = $__pred|0;
 var $$0$ph = 0, $$01$i = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$0 = 0, $__i$0$ph = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 $0 = ($__first|0)==($__last|0);
 if ($0) {
  $$1 = $__last;
  STACKTOP = sp;return ($$1|0);
 } else {
  $$01$i = $__first;
 }
 while(1) {
  $1 = (($$01$i) + 60|0);
  $2 = ($1|0)==($__last|0);
  if ($2) {
   $$1 = $__last;
   label = 11;
   break;
  }
  $3 = (FUNCTION_TABLE_iii[$__pred & 63]($$01$i,$1)|0);
  if ($3) {
   break;
  } else {
   $$01$i = $1;
  }
 }
 if ((label|0) == 11) {
  STACKTOP = sp;return ($$1|0);
 }
 $4 = ($$01$i|0)==($__last|0);
 if ($4) {
  $$1 = $$01$i;
  STACKTOP = sp;return ($$1|0);
 }
 $5 = (($$01$i) + 60|0);
 $$0$ph = $$01$i;$__i$0$ph = $5;
 L12: while(1) {
  $__i$0 = $__i$0$ph;
  while(1) {
   $6 = (($__i$0) + 60|0);
   $7 = ($6|0)==($__last|0);
   if ($7) {
    break L12;
   }
   $8 = (FUNCTION_TABLE_iii[$__pred & 63]($$0$ph,$6)|0);
   if ($8) {
    $__i$0 = $6;
   } else {
    break;
   }
  }
  $9 = (($$0$ph) + 60|0);
  dest=$9+0|0; src=$6+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $$0$ph = $9;$__i$0$ph = $6;
 }
 $10 = (($$0$ph) + 60|0);
 $$1 = $10;
 STACKTOP = sp;return ($$1|0);
}
function __ZltRKN16b2ParticleSystem5ProxyEj($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($a) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)<($b>>>0);
 STACKTOP = sp;return ($2|0);
}
function __ZltjRKN16b2ParticleSystem5ProxyE($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($b) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)>($a>>>0);
 STACKTOP = sp;return ($2|0);
}
function __ZN16b2GrowableBufferI17b2ParticleContactE6AppendEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($this) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)<($3|0);
 if (!($4)) {
  __ZN16b2GrowableBufferI17b2ParticleContactE4GrowEv($this);
 }
 $5 = HEAP32[$0>>2]|0;
 $6 = (($5) + 1)|0;
 HEAP32[$0>>2] = $6;
 $7 = HEAP32[$this>>2]|0;
 $8 = (($7) + (($5*24)|0)|0);
 STACKTOP = sp;return ($8|0);
}
function __ZN17b2ParticleContact8SetFlagsEj($this,$f) {
 $this = $this|0;
 $f = $f|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 20|0);
 HEAP32[$0>>2] = $f;
 STACKTOP = sp;return;
}
function __ZN17b2ParticleContact9SetWeightEf($this,$w) {
 $this = $this|0;
 $w = +$w;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 HEAPF32[$0>>2] = $w;
 STACKTOP = sp;return;
}
function __ZN17b2ParticleContact9SetNormalERK6b2Vec2($this,$n) {
 $this = $this|0;
 $n = $n|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 12|0);
 $1 = $n;
 $2 = $1;
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) + 4)|0;
 $5 = $4;
 $6 = HEAP32[$5>>2]|0;
 $7 = $0;
 $8 = $7;
 HEAP32[$8>>2] = $3;
 $9 = (($7) + 4)|0;
 $10 = $9;
 HEAP32[$10>>2] = $6;
 STACKTOP = sp;return;
}
function __ZltRKN16b2ParticleSystem5ProxyES2_($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($a) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($b) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1>>>0)<($3>>>0);
 STACKTOP = sp;return ($4|0);
}
function __ZNSt3__17__sort3IRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEjT0_S7_S7_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZltRKN16b2ParticleSystem5ProxyES2_($__y,$__x)|0);
 $1 = (__ZltRKN16b2ParticleSystem5ProxyES2_($__z,$__y)|0);
 if (!($0)) {
  if (!($1)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $2 = $__y;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = $__z;
  $9 = $8;
  $10 = HEAP32[$9>>2]|0;
  $11 = (($8) + 4)|0;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = $__y;
  $15 = $14;
  HEAP32[$15>>2] = $10;
  $16 = (($14) + 4)|0;
  $17 = $16;
  HEAP32[$17>>2] = $13;
  $18 = $__z;
  $19 = $18;
  HEAP32[$19>>2] = $4;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $7;
  $22 = (__ZltRKN16b2ParticleSystem5ProxyES2_($__y,$__x)|0);
  if (!($22)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $23 = $__x;
  $24 = $23;
  $25 = HEAP32[$24>>2]|0;
  $26 = (($23) + 4)|0;
  $27 = $26;
  $28 = HEAP32[$27>>2]|0;
  $29 = $__y;
  $30 = $29;
  $31 = HEAP32[$30>>2]|0;
  $32 = (($29) + 4)|0;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = $__x;
  $36 = $35;
  HEAP32[$36>>2] = $31;
  $37 = (($35) + 4)|0;
  $38 = $37;
  HEAP32[$38>>2] = $34;
  $39 = $__y;
  $40 = $39;
  HEAP32[$40>>2] = $25;
  $41 = (($39) + 4)|0;
  $42 = $41;
  HEAP32[$42>>2] = $28;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $43 = $__x;
 $44 = $43;
 $45 = HEAP32[$44>>2]|0;
 $46 = (($43) + 4)|0;
 $47 = $46;
 $48 = HEAP32[$47>>2]|0;
 if ($1) {
  $49 = $__z;
  $50 = $49;
  $51 = HEAP32[$50>>2]|0;
  $52 = (($49) + 4)|0;
  $53 = $52;
  $54 = HEAP32[$53>>2]|0;
  $55 = $__x;
  $56 = $55;
  HEAP32[$56>>2] = $51;
  $57 = (($55) + 4)|0;
  $58 = $57;
  HEAP32[$58>>2] = $54;
  $59 = $__z;
  $60 = $59;
  HEAP32[$60>>2] = $45;
  $61 = (($59) + 4)|0;
  $62 = $61;
  HEAP32[$62>>2] = $48;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $63 = $__y;
 $64 = $63;
 $65 = HEAP32[$64>>2]|0;
 $66 = (($63) + 4)|0;
 $67 = $66;
 $68 = HEAP32[$67>>2]|0;
 $69 = $__x;
 $70 = $69;
 HEAP32[$70>>2] = $65;
 $71 = (($69) + 4)|0;
 $72 = $71;
 HEAP32[$72>>2] = $68;
 $73 = $__y;
 $74 = $73;
 HEAP32[$74>>2] = $45;
 $75 = (($73) + 4)|0;
 $76 = $75;
 HEAP32[$76>>2] = $48;
 $77 = (__ZltRKN16b2ParticleSystem5ProxyES2_($__z,$__y)|0);
 if (!($77)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $78 = $__z;
 $79 = $78;
 $80 = HEAP32[$79>>2]|0;
 $81 = (($78) + 4)|0;
 $82 = $81;
 $83 = HEAP32[$82>>2]|0;
 $84 = $__y;
 $85 = $84;
 HEAP32[$85>>2] = $80;
 $86 = (($84) + 4)|0;
 $87 = $86;
 HEAP32[$87>>2] = $83;
 $88 = $__z;
 $89 = $88;
 HEAP32[$89>>2] = $45;
 $90 = (($88) + 4)|0;
 $91 = $90;
 HEAP32[$91>>2] = $48;
 $$0 = 2;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17__sort4IRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEjT0_S7_S7_S7_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__17__sort3IRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEjT0_S7_S7_T_($__x1,$__x2,$__x3,$__c)|0);
 $1 = (__ZltRKN16b2ParticleSystem5ProxyES2_($__x4,$__x3)|0);
 if (!($1)) {
  $__r$0 = $0;
  STACKTOP = sp;return ($__r$0|0);
 }
 $2 = $__x3;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $__x4;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = $__x3;
 $15 = $14;
 HEAP32[$15>>2] = $10;
 $16 = (($14) + 4)|0;
 $17 = $16;
 HEAP32[$17>>2] = $13;
 $18 = $__x4;
 $19 = $18;
 HEAP32[$19>>2] = $4;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = $7;
 $22 = (($0) + 1)|0;
 $23 = (__ZltRKN16b2ParticleSystem5ProxyES2_($__x3,$__x2)|0);
 if (!($23)) {
  $__r$0 = $22;
  STACKTOP = sp;return ($__r$0|0);
 }
 $24 = $__x2;
 $25 = $24;
 $26 = HEAP32[$25>>2]|0;
 $27 = (($24) + 4)|0;
 $28 = $27;
 $29 = HEAP32[$28>>2]|0;
 $30 = $__x3;
 $31 = $30;
 $32 = HEAP32[$31>>2]|0;
 $33 = (($30) + 4)|0;
 $34 = $33;
 $35 = HEAP32[$34>>2]|0;
 $36 = $__x2;
 $37 = $36;
 HEAP32[$37>>2] = $32;
 $38 = (($36) + 4)|0;
 $39 = $38;
 HEAP32[$39>>2] = $35;
 $40 = $__x3;
 $41 = $40;
 HEAP32[$41>>2] = $26;
 $42 = (($40) + 4)|0;
 $43 = $42;
 HEAP32[$43>>2] = $29;
 $44 = (($0) + 2)|0;
 $45 = (__ZltRKN16b2ParticleSystem5ProxyES2_($__x2,$__x1)|0);
 if (!($45)) {
  $__r$0 = $44;
  STACKTOP = sp;return ($__r$0|0);
 }
 $46 = $__x1;
 $47 = $46;
 $48 = HEAP32[$47>>2]|0;
 $49 = (($46) + 4)|0;
 $50 = $49;
 $51 = HEAP32[$50>>2]|0;
 $52 = $__x2;
 $53 = $52;
 $54 = HEAP32[$53>>2]|0;
 $55 = (($52) + 4)|0;
 $56 = $55;
 $57 = HEAP32[$56>>2]|0;
 $58 = $__x1;
 $59 = $58;
 HEAP32[$59>>2] = $54;
 $60 = (($58) + 4)|0;
 $61 = $60;
 HEAP32[$61>>2] = $57;
 $62 = $__x2;
 $63 = $62;
 HEAP32[$63>>2] = $48;
 $64 = (($62) + 4)|0;
 $65 = $64;
 HEAP32[$65>>2] = $51;
 $66 = (($0) + 3)|0;
 $__r$0 = $66;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__17__sort5IRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEjT0_S7_S7_S7_S7_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__17__sort4IRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEjT0_S7_S7_S7_T_($__x1,$__x2,$__x3,$__x4,$__c)|0);
 $1 = (__ZltRKN16b2ParticleSystem5ProxyES2_($__x5,$__x4)|0);
 if (!($1)) {
  $__r$0 = $0;
  STACKTOP = sp;return ($__r$0|0);
 }
 $2 = $__x4;
 $3 = $2;
 $4 = HEAP32[$3>>2]|0;
 $5 = (($2) + 4)|0;
 $6 = $5;
 $7 = HEAP32[$6>>2]|0;
 $8 = $__x5;
 $9 = $8;
 $10 = HEAP32[$9>>2]|0;
 $11 = (($8) + 4)|0;
 $12 = $11;
 $13 = HEAP32[$12>>2]|0;
 $14 = $__x4;
 $15 = $14;
 HEAP32[$15>>2] = $10;
 $16 = (($14) + 4)|0;
 $17 = $16;
 HEAP32[$17>>2] = $13;
 $18 = $__x5;
 $19 = $18;
 HEAP32[$19>>2] = $4;
 $20 = (($18) + 4)|0;
 $21 = $20;
 HEAP32[$21>>2] = $7;
 $22 = (($0) + 1)|0;
 $23 = (__ZltRKN16b2ParticleSystem5ProxyES2_($__x4,$__x3)|0);
 if (!($23)) {
  $__r$0 = $22;
  STACKTOP = sp;return ($__r$0|0);
 }
 $24 = $__x3;
 $25 = $24;
 $26 = HEAP32[$25>>2]|0;
 $27 = (($24) + 4)|0;
 $28 = $27;
 $29 = HEAP32[$28>>2]|0;
 $30 = $__x4;
 $31 = $30;
 $32 = HEAP32[$31>>2]|0;
 $33 = (($30) + 4)|0;
 $34 = $33;
 $35 = HEAP32[$34>>2]|0;
 $36 = $__x3;
 $37 = $36;
 HEAP32[$37>>2] = $32;
 $38 = (($36) + 4)|0;
 $39 = $38;
 HEAP32[$39>>2] = $35;
 $40 = $__x4;
 $41 = $40;
 HEAP32[$41>>2] = $26;
 $42 = (($40) + 4)|0;
 $43 = $42;
 HEAP32[$43>>2] = $29;
 $44 = (($0) + 2)|0;
 $45 = (__ZltRKN16b2ParticleSystem5ProxyES2_($__x3,$__x2)|0);
 if (!($45)) {
  $__r$0 = $44;
  STACKTOP = sp;return ($__r$0|0);
 }
 $46 = $__x2;
 $47 = $46;
 $48 = HEAP32[$47>>2]|0;
 $49 = (($46) + 4)|0;
 $50 = $49;
 $51 = HEAP32[$50>>2]|0;
 $52 = $__x3;
 $53 = $52;
 $54 = HEAP32[$53>>2]|0;
 $55 = (($52) + 4)|0;
 $56 = $55;
 $57 = HEAP32[$56>>2]|0;
 $58 = $__x2;
 $59 = $58;
 HEAP32[$59>>2] = $54;
 $60 = (($58) + 4)|0;
 $61 = $60;
 HEAP32[$61>>2] = $57;
 $62 = $__x3;
 $63 = $62;
 HEAP32[$63>>2] = $48;
 $64 = (($62) + 4)|0;
 $65 = $64;
 HEAP32[$65>>2] = $51;
 $66 = (($0) + 3)|0;
 $67 = (__ZltRKN16b2ParticleSystem5ProxyES2_($__x2,$__x1)|0);
 if (!($67)) {
  $__r$0 = $66;
  STACKTOP = sp;return ($__r$0|0);
 }
 $68 = $__x1;
 $69 = $68;
 $70 = HEAP32[$69>>2]|0;
 $71 = (($68) + 4)|0;
 $72 = $71;
 $73 = HEAP32[$72>>2]|0;
 $74 = $__x2;
 $75 = $74;
 $76 = HEAP32[$75>>2]|0;
 $77 = (($74) + 4)|0;
 $78 = $77;
 $79 = HEAP32[$78>>2]|0;
 $80 = $__x1;
 $81 = $80;
 HEAP32[$81>>2] = $76;
 $82 = (($80) + 4)|0;
 $83 = $82;
 HEAP32[$83>>2] = $79;
 $84 = $__x2;
 $85 = $84;
 HEAP32[$85>>2] = $70;
 $86 = (($84) + 4)|0;
 $87 = $86;
 HEAP32[$87>>2] = $73;
 $88 = (($0) + 4)|0;
 $__r$0 = $88;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEvT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $__i$02 = 0, $__j$01 = 0, $__j$01$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__t = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t = sp;
 $0 = (($__first) + 16|0);
 $1 = (($__first) + 8|0);
 (__ZNSt3__17__sort3IRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEjT0_S7_S7_T_($__first,$1,$0,$__comp)|0);
 $2 = (($__first) + 24|0);
 $3 = ($2|0)==($__last|0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $__i$02 = $2;$__j$01 = $0;
 }
 while(1) {
  $4 = (__ZltRKN16b2ParticleSystem5ProxyES2_($__i$02,$__j$01)|0);
  if ($4) {
   $5 = $__i$02;
   $6 = $5;
   $7 = HEAP32[$6>>2]|0;
   $8 = (($5) + 4)|0;
   $9 = $8;
   $10 = HEAP32[$9>>2]|0;
   $11 = $__t;
   $12 = $11;
   HEAP32[$12>>2] = $7;
   $13 = (($11) + 4)|0;
   $14 = $13;
   HEAP32[$14>>2] = $10;
   $__j$1 = $__i$02;$__k$0 = $__j$01;
   while(1) {
    $15 = $__k$0;
    $16 = $15;
    $17 = HEAP32[$16>>2]|0;
    $18 = (($15) + 4)|0;
    $19 = $18;
    $20 = HEAP32[$19>>2]|0;
    $21 = $__j$1;
    $22 = $21;
    HEAP32[$22>>2] = $17;
    $23 = (($21) + 4)|0;
    $24 = $23;
    HEAP32[$24>>2] = $20;
    $25 = ($__k$0|0)==($__first|0);
    if ($25) {
     break;
    }
    $26 = (($__k$0) + -8|0);
    $27 = (__ZltRKN16b2ParticleSystem5ProxyES2_($__t,$26)|0);
    if ($27) {
     $__j$1$phi = $__k$0;$__k$0 = $26;$__j$1 = $__j$1$phi;
    } else {
     break;
    }
   }
   $28 = $__t;
   $29 = $28;
   $30 = HEAP32[$29>>2]|0;
   $31 = (($28) + 4)|0;
   $32 = $31;
   $33 = HEAP32[$32>>2]|0;
   $34 = $__k$0;
   $35 = $34;
   HEAP32[$35>>2] = $30;
   $36 = (($34) + 4)|0;
   $37 = $36;
   HEAP32[$37>>2] = $33;
  }
  $38 = (($__i$02) + 8|0);
  $39 = ($38|0)==($__last|0);
  if ($39) {
   break;
  } else {
   $__j$01$phi = $__i$02;$__i$02 = $38;$__j$01 = $__j$01$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEbT0_S7_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $8 = 0, $9 = 0;
 var $__count$03 = 0, $__count$1 = 0, $__i$04 = 0, $__j$02 = 0, $__j$02$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__t = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t = sp;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 3;
 switch ($3|0) {
 case 3:  {
  $26 = (($__first) + 8|0);
  $27 = (($__last) + -8|0);
  (__ZNSt3__17__sort3IRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEjT0_S7_S7_T_($__first,$26,$27,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $28 = (($__first) + 8|0);
  $29 = (($__first) + 16|0);
  $30 = (($__last) + -8|0);
  (__ZNSt3__17__sort4IRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEjT0_S7_S7_S7_T_($__first,$28,$29,$30,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = (($__last) + -8|0);
  $5 = (__ZltRKN16b2ParticleSystem5ProxyES2_($4,$__first)|0);
  if (!($5)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $6 = $__first;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $4;
  $13 = $12;
  $14 = HEAP32[$13>>2]|0;
  $15 = (($12) + 4)|0;
  $16 = $15;
  $17 = HEAP32[$16>>2]|0;
  $18 = $__first;
  $19 = $18;
  HEAP32[$19>>2] = $14;
  $20 = (($18) + 4)|0;
  $21 = $20;
  HEAP32[$21>>2] = $17;
  $22 = $4;
  $23 = $22;
  HEAP32[$23>>2] = $8;
  $24 = (($22) + 4)|0;
  $25 = $24;
  HEAP32[$25>>2] = $11;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $31 = (($__first) + 8|0);
  $32 = (($__first) + 16|0);
  $33 = (($__first) + 24|0);
  $34 = (($__last) + -8|0);
  (__ZNSt3__17__sort5IRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEjT0_S7_S7_S7_S7_T_($__first,$31,$32,$33,$34,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $35 = (($__first) + 16|0);
  $36 = (($__first) + 8|0);
  (__ZNSt3__17__sort3IRNS_6__lessIN16b2ParticleSystem5ProxyES3_EEPS3_EEjT0_S7_S7_T_($__first,$36,$35,$__comp)|0);
  $37 = (($__first) + 24|0);
  $38 = ($37|0)==($__last|0);
  if ($38) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $__count$03 = 0;$__i$04 = $37;$__j$02 = $35;
  }
  while(1) {
   $39 = (__ZltRKN16b2ParticleSystem5ProxyES2_($__i$04,$__j$02)|0);
   if ($39) {
    $40 = $__i$04;
    $41 = $40;
    $42 = HEAP32[$41>>2]|0;
    $43 = (($40) + 4)|0;
    $44 = $43;
    $45 = HEAP32[$44>>2]|0;
    $46 = $__t;
    $47 = $46;
    HEAP32[$47>>2] = $42;
    $48 = (($46) + 4)|0;
    $49 = $48;
    HEAP32[$49>>2] = $45;
    $__j$1 = $__i$04;$__k$0 = $__j$02;
    while(1) {
     $50 = $__k$0;
     $51 = $50;
     $52 = HEAP32[$51>>2]|0;
     $53 = (($50) + 4)|0;
     $54 = $53;
     $55 = HEAP32[$54>>2]|0;
     $56 = $__j$1;
     $57 = $56;
     HEAP32[$57>>2] = $52;
     $58 = (($56) + 4)|0;
     $59 = $58;
     HEAP32[$59>>2] = $55;
     $60 = ($__k$0|0)==($__first|0);
     if ($60) {
      break;
     }
     $61 = (($__k$0) + -8|0);
     $62 = (__ZltRKN16b2ParticleSystem5ProxyES2_($__t,$61)|0);
     if ($62) {
      $__j$1$phi = $__k$0;$__k$0 = $61;$__j$1 = $__j$1$phi;
     } else {
      break;
     }
    }
    $63 = $__t;
    $64 = $63;
    $65 = HEAP32[$64>>2]|0;
    $66 = (($63) + 4)|0;
    $67 = $66;
    $68 = HEAP32[$67>>2]|0;
    $69 = $__k$0;
    $70 = $69;
    HEAP32[$70>>2] = $65;
    $71 = (($69) + 4)|0;
    $72 = $71;
    HEAP32[$72>>2] = $68;
    $73 = (($__count$03) + 1)|0;
    $74 = ($73|0)==(8);
    if ($74) {
     break;
    } else {
     $__count$1 = $73;
    }
   } else {
    $__count$1 = $__count$03;
   }
   $77 = (($__i$04) + 8|0);
   $78 = ($77|0)==($__last|0);
   if ($78) {
    $$0 = 1;
    label = 15;
    break;
   } else {
    $__j$02$phi = $__i$04;$__count$03 = $__count$1;$__i$04 = $77;$__j$02 = $__j$02$phi;
   }
  }
  if ((label|0) == 15) {
   STACKTOP = sp;return ($$0|0);
  }
  $75 = (($__i$04) + 8|0);
  $76 = ($75|0)==($__last|0);
  $$0 = $76;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return (0)|0;
}
function __ZNSt3__19remove_ifIP17b2ParticleContact32b2ParticleContactRemovePredicateEET_S4_S4_T0_($__first,$__last,$__pred) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__pred = $__pred|0;
 var $$0$lcssa$i = 0, $$0$ph = 0, $$01$i = 0, $$1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $__i$0 = 0, $__i$0$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__first|0)==($__last|0);
 L1: do {
  if ($0) {
   $$0$lcssa$i = $__first;
  } else {
   $$01$i = $__first;
   while(1) {
    $3 = (__ZN32b2ParticleContactRemovePredicateclERK17b2ParticleContact($__pred,$$01$i)|0);
    $1 = (($$01$i) + 24|0);
    if ($3) {
     $$0$lcssa$i = $$01$i;
     break L1;
    }
    $2 = ($1|0)==($__last|0);
    if ($2) {
     $$0$lcssa$i = $1;
     break;
    } else {
     $$01$i = $1;
    }
   }
  }
 } while(0);
 $4 = ($$0$lcssa$i|0)==($__last|0);
 if ($4) {
  $$1 = $$0$lcssa$i;
  STACKTOP = sp;return ($$1|0);
 } else {
  $$0$ph = $$0$lcssa$i;$__i$0$ph = $$0$lcssa$i;
 }
 L8: while(1) {
  $__i$0 = $__i$0$ph;
  while(1) {
   $5 = (($__i$0) + 24|0);
   $6 = ($5|0)==($__last|0);
   if ($6) {
    $$1 = $$0$ph;
    break L8;
   }
   $7 = (__ZN32b2ParticleContactRemovePredicateclERK17b2ParticleContact($__pred,$5)|0);
   if ($7) {
    $__i$0 = $5;
   } else {
    break;
   }
  }
  ;HEAP32[$$0$ph+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$$0$ph+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$$0$ph+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$$0$ph+12>>2]=HEAP32[$5+12>>2]|0;HEAP32[$$0$ph+16>>2]=HEAP32[$5+16>>2]|0;HEAP32[$$0$ph+20>>2]=HEAP32[$5+20>>2]|0;
  $8 = (($$0$ph) + 24|0);
  $$0$ph = $8;$__i$0$ph = $5;
 }
 STACKTOP = sp;return ($$1|0);
}
function __ZN12_GLOBAL__N_117FixedSetAllocator8AllocateEii($this,$count) {
 $this = $this|0;
 $count = $count|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12_GLOBAL__N_117FixedSetAllocator5ClearEv($this);
 $0 = ($count|0)==(0);
 if ($0) {
  $9 = (($this) + 8|0);
  $10 = HEAP32[$9>>2]|0;
  STACKTOP = sp;return ($10|0);
 }
 $1 = (($this) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($count*9)|0;
 $4 = (__ZN16b2StackAllocator8AllocateEi($2,$3)|0);
 HEAP32[$this>>2] = $4;
 $5 = $count << 3;
 $6 = (($4) + ($5)|0);
 $7 = (($this) + 4|0);
 HEAP32[$7>>2] = $6;
 _memset(($6|0),1,($count|0))|0;
 $8 = (($this) + 8|0);
 HEAP32[$8>>2] = $count;
 $9 = (($this) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 STACKTOP = sp;return ($10|0);
}
function __ZN12_GLOBAL__N_117FixedSetAllocator9GetBufferEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__17__sort3IRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEjT0_SA_SA_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__c>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$0 & 63]($__y,$__x)|0);
 $2 = HEAP32[$__c>>2]|0;
 $3 = (FUNCTION_TABLE_iii[$2 & 63]($__z,$__y)|0);
 if (!($1)) {
  if (!($3)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $4 = $__y;
  $5 = $4;
  $6 = HEAP32[$5>>2]|0;
  $7 = (($4) + 4)|0;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = $__z;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $13 = (($10) + 4)|0;
  $14 = $13;
  $15 = HEAP32[$14>>2]|0;
  $16 = $__y;
  $17 = $16;
  HEAP32[$17>>2] = $12;
  $18 = (($16) + 4)|0;
  $19 = $18;
  HEAP32[$19>>2] = $15;
  $20 = $__z;
  $21 = $20;
  HEAP32[$21>>2] = $6;
  $22 = (($20) + 4)|0;
  $23 = $22;
  HEAP32[$23>>2] = $9;
  $24 = HEAP32[$__c>>2]|0;
  $25 = (FUNCTION_TABLE_iii[$24 & 63]($__y,$__x)|0);
  if (!($25)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $26 = $__x;
  $27 = $26;
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + 4)|0;
  $30 = $29;
  $31 = HEAP32[$30>>2]|0;
  $32 = $__y;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = (($32) + 4)|0;
  $36 = $35;
  $37 = HEAP32[$36>>2]|0;
  $38 = $__x;
  $39 = $38;
  HEAP32[$39>>2] = $34;
  $40 = (($38) + 4)|0;
  $41 = $40;
  HEAP32[$41>>2] = $37;
  $42 = $__y;
  $43 = $42;
  HEAP32[$43>>2] = $28;
  $44 = (($42) + 4)|0;
  $45 = $44;
  HEAP32[$45>>2] = $31;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $46 = $__x;
 $47 = $46;
 $48 = HEAP32[$47>>2]|0;
 $49 = (($46) + 4)|0;
 $50 = $49;
 $51 = HEAP32[$50>>2]|0;
 if ($3) {
  $52 = $__z;
  $53 = $52;
  $54 = HEAP32[$53>>2]|0;
  $55 = (($52) + 4)|0;
  $56 = $55;
  $57 = HEAP32[$56>>2]|0;
  $58 = $__x;
  $59 = $58;
  HEAP32[$59>>2] = $54;
  $60 = (($58) + 4)|0;
  $61 = $60;
  HEAP32[$61>>2] = $57;
  $62 = $__z;
  $63 = $62;
  HEAP32[$63>>2] = $48;
  $64 = (($62) + 4)|0;
  $65 = $64;
  HEAP32[$65>>2] = $51;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $66 = $__y;
 $67 = $66;
 $68 = HEAP32[$67>>2]|0;
 $69 = (($66) + 4)|0;
 $70 = $69;
 $71 = HEAP32[$70>>2]|0;
 $72 = $__x;
 $73 = $72;
 HEAP32[$73>>2] = $68;
 $74 = (($72) + 4)|0;
 $75 = $74;
 HEAP32[$75>>2] = $71;
 $76 = $__y;
 $77 = $76;
 HEAP32[$77>>2] = $48;
 $78 = (($76) + 4)|0;
 $79 = $78;
 HEAP32[$79>>2] = $51;
 $80 = HEAP32[$__c>>2]|0;
 $81 = (FUNCTION_TABLE_iii[$80 & 63]($__z,$__y)|0);
 if (!($81)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $82 = $__y;
 $83 = $82;
 $84 = HEAP32[$83>>2]|0;
 $85 = (($82) + 4)|0;
 $86 = $85;
 $87 = HEAP32[$86>>2]|0;
 $88 = $__z;
 $89 = $88;
 $90 = HEAP32[$89>>2]|0;
 $91 = (($88) + 4)|0;
 $92 = $91;
 $93 = HEAP32[$92>>2]|0;
 $94 = $__y;
 $95 = $94;
 HEAP32[$95>>2] = $90;
 $96 = (($94) + 4)|0;
 $97 = $96;
 HEAP32[$97>>2] = $93;
 $98 = $__z;
 $99 = $98;
 HEAP32[$99>>2] = $84;
 $100 = (($98) + 4)|0;
 $101 = $100;
 HEAP32[$101>>2] = $87;
 $$0 = 2;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17__sort4IRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEjT0_SA_SA_SA_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__17__sort3IRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEjT0_SA_SA_T_($__x1,$__x2,$__x3,$__c)|0);
 $1 = HEAP32[$__c>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$1 & 63]($__x4,$__x3)|0);
 if (!($2)) {
  $__r$0 = $0;
  STACKTOP = sp;return ($__r$0|0);
 }
 $3 = $__x3;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $__x4;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = $__x3;
 $16 = $15;
 HEAP32[$16>>2] = $11;
 $17 = (($15) + 4)|0;
 $18 = $17;
 HEAP32[$18>>2] = $14;
 $19 = $__x4;
 $20 = $19;
 HEAP32[$20>>2] = $5;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $8;
 $23 = (($0) + 1)|0;
 $24 = HEAP32[$__c>>2]|0;
 $25 = (FUNCTION_TABLE_iii[$24 & 63]($__x3,$__x2)|0);
 if (!($25)) {
  $__r$0 = $23;
  STACKTOP = sp;return ($__r$0|0);
 }
 $26 = $__x2;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($26) + 4)|0;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = $__x3;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = (($32) + 4)|0;
 $36 = $35;
 $37 = HEAP32[$36>>2]|0;
 $38 = $__x2;
 $39 = $38;
 HEAP32[$39>>2] = $34;
 $40 = (($38) + 4)|0;
 $41 = $40;
 HEAP32[$41>>2] = $37;
 $42 = $__x3;
 $43 = $42;
 HEAP32[$43>>2] = $28;
 $44 = (($42) + 4)|0;
 $45 = $44;
 HEAP32[$45>>2] = $31;
 $46 = (($0) + 2)|0;
 $47 = HEAP32[$__c>>2]|0;
 $48 = (FUNCTION_TABLE_iii[$47 & 63]($__x2,$__x1)|0);
 if (!($48)) {
  $__r$0 = $46;
  STACKTOP = sp;return ($__r$0|0);
 }
 $49 = $__x1;
 $50 = $49;
 $51 = HEAP32[$50>>2]|0;
 $52 = (($49) + 4)|0;
 $53 = $52;
 $54 = HEAP32[$53>>2]|0;
 $55 = $__x2;
 $56 = $55;
 $57 = HEAP32[$56>>2]|0;
 $58 = (($55) + 4)|0;
 $59 = $58;
 $60 = HEAP32[$59>>2]|0;
 $61 = $__x1;
 $62 = $61;
 HEAP32[$62>>2] = $57;
 $63 = (($61) + 4)|0;
 $64 = $63;
 HEAP32[$64>>2] = $60;
 $65 = $__x2;
 $66 = $65;
 HEAP32[$66>>2] = $51;
 $67 = (($65) + 4)|0;
 $68 = $67;
 HEAP32[$68>>2] = $54;
 $69 = (($0) + 3)|0;
 $__r$0 = $69;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__17__sort5IRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEjT0_SA_SA_SA_SA_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__17__sort4IRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEjT0_SA_SA_SA_T_($__x1,$__x2,$__x3,$__x4,$__c)|0);
 $1 = HEAP32[$__c>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$1 & 63]($__x5,$__x4)|0);
 if (!($2)) {
  $__r$0 = $0;
  STACKTOP = sp;return ($__r$0|0);
 }
 $3 = $__x4;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $__x5;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = $__x4;
 $16 = $15;
 HEAP32[$16>>2] = $11;
 $17 = (($15) + 4)|0;
 $18 = $17;
 HEAP32[$18>>2] = $14;
 $19 = $__x5;
 $20 = $19;
 HEAP32[$20>>2] = $5;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $8;
 $23 = (($0) + 1)|0;
 $24 = HEAP32[$__c>>2]|0;
 $25 = (FUNCTION_TABLE_iii[$24 & 63]($__x4,$__x3)|0);
 if (!($25)) {
  $__r$0 = $23;
  STACKTOP = sp;return ($__r$0|0);
 }
 $26 = $__x3;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($26) + 4)|0;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = $__x4;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = (($32) + 4)|0;
 $36 = $35;
 $37 = HEAP32[$36>>2]|0;
 $38 = $__x3;
 $39 = $38;
 HEAP32[$39>>2] = $34;
 $40 = (($38) + 4)|0;
 $41 = $40;
 HEAP32[$41>>2] = $37;
 $42 = $__x4;
 $43 = $42;
 HEAP32[$43>>2] = $28;
 $44 = (($42) + 4)|0;
 $45 = $44;
 HEAP32[$45>>2] = $31;
 $46 = (($0) + 2)|0;
 $47 = HEAP32[$__c>>2]|0;
 $48 = (FUNCTION_TABLE_iii[$47 & 63]($__x3,$__x2)|0);
 if (!($48)) {
  $__r$0 = $46;
  STACKTOP = sp;return ($__r$0|0);
 }
 $49 = $__x2;
 $50 = $49;
 $51 = HEAP32[$50>>2]|0;
 $52 = (($49) + 4)|0;
 $53 = $52;
 $54 = HEAP32[$53>>2]|0;
 $55 = $__x3;
 $56 = $55;
 $57 = HEAP32[$56>>2]|0;
 $58 = (($55) + 4)|0;
 $59 = $58;
 $60 = HEAP32[$59>>2]|0;
 $61 = $__x2;
 $62 = $61;
 HEAP32[$62>>2] = $57;
 $63 = (($61) + 4)|0;
 $64 = $63;
 HEAP32[$64>>2] = $60;
 $65 = $__x3;
 $66 = $65;
 HEAP32[$66>>2] = $51;
 $67 = (($65) + 4)|0;
 $68 = $67;
 HEAP32[$68>>2] = $54;
 $69 = (($0) + 3)|0;
 $70 = HEAP32[$__c>>2]|0;
 $71 = (FUNCTION_TABLE_iii[$70 & 63]($__x2,$__x1)|0);
 if (!($71)) {
  $__r$0 = $69;
  STACKTOP = sp;return ($__r$0|0);
 }
 $72 = $__x1;
 $73 = $72;
 $74 = HEAP32[$73>>2]|0;
 $75 = (($72) + 4)|0;
 $76 = $75;
 $77 = HEAP32[$76>>2]|0;
 $78 = $__x2;
 $79 = $78;
 $80 = HEAP32[$79>>2]|0;
 $81 = (($78) + 4)|0;
 $82 = $81;
 $83 = HEAP32[$82>>2]|0;
 $84 = $__x1;
 $85 = $84;
 HEAP32[$85>>2] = $80;
 $86 = (($84) + 4)|0;
 $87 = $86;
 HEAP32[$87>>2] = $83;
 $88 = $__x2;
 $89 = $88;
 HEAP32[$89>>2] = $74;
 $90 = (($88) + 4)|0;
 $91 = $90;
 HEAP32[$91>>2] = $77;
 $92 = (($0) + 4)|0;
 $__r$0 = $92;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEvT0_SA_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $__i$02 = 0, $__j$01 = 0, $__j$01$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__t = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t = sp;
 $0 = (($__first) + 16|0);
 $1 = (($__first) + 8|0);
 (__ZNSt3__17__sort3IRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEjT0_SA_SA_T_($__first,$1,$0,$__comp)|0);
 $2 = (($__first) + 24|0);
 $3 = ($2|0)==($__last|0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $__i$02 = $2;$__j$01 = $0;
 }
 while(1) {
  $4 = HEAP32[$__comp>>2]|0;
  $5 = (FUNCTION_TABLE_iii[$4 & 63]($__i$02,$__j$01)|0);
  if ($5) {
   $6 = $__i$02;
   $7 = $6;
   $8 = HEAP32[$7>>2]|0;
   $9 = (($6) + 4)|0;
   $10 = $9;
   $11 = HEAP32[$10>>2]|0;
   $12 = $__t;
   $13 = $12;
   HEAP32[$13>>2] = $8;
   $14 = (($12) + 4)|0;
   $15 = $14;
   HEAP32[$15>>2] = $11;
   $__j$1 = $__i$02;$__k$0 = $__j$01;
   while(1) {
    $16 = $__k$0;
    $17 = $16;
    $18 = HEAP32[$17>>2]|0;
    $19 = (($16) + 4)|0;
    $20 = $19;
    $21 = HEAP32[$20>>2]|0;
    $22 = $__j$1;
    $23 = $22;
    HEAP32[$23>>2] = $18;
    $24 = (($22) + 4)|0;
    $25 = $24;
    HEAP32[$25>>2] = $21;
    $26 = ($__k$0|0)==($__first|0);
    if ($26) {
     break;
    }
    $27 = HEAP32[$__comp>>2]|0;
    $28 = (($__k$0) + -8|0);
    $29 = (FUNCTION_TABLE_iii[$27 & 63]($__t,$28)|0);
    if ($29) {
     $__j$1$phi = $__k$0;$__k$0 = $28;$__j$1 = $__j$1$phi;
    } else {
     break;
    }
   }
   $30 = $__t;
   $31 = $30;
   $32 = HEAP32[$31>>2]|0;
   $33 = (($30) + 4)|0;
   $34 = $33;
   $35 = HEAP32[$34>>2]|0;
   $36 = $__k$0;
   $37 = $36;
   HEAP32[$37>>2] = $32;
   $38 = (($36) + 4)|0;
   $39 = $38;
   HEAP32[$39>>2] = $35;
  }
  $40 = (($__i$02) + 8|0);
  $41 = ($40|0)==($__last|0);
  if ($41) {
   break;
  } else {
   $__j$01$phi = $__i$02;$__i$02 = $40;$__j$01 = $__j$01$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEbT0_SA_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $9 = 0, $__count$03 = 0, $__count$1 = 0, $__i$04 = 0, $__j$02 = 0, $__j$02$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__t = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t = sp;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 3;
 switch ($3|0) {
 case 2:  {
  $4 = HEAP32[$__comp>>2]|0;
  $5 = (($__last) + -8|0);
  $6 = (FUNCTION_TABLE_iii[$4 & 63]($5,$__first)|0);
  if (!($6)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $7 = $__first;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) + 4)|0;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $13 = $5;
  $14 = $13;
  $15 = HEAP32[$14>>2]|0;
  $16 = (($13) + 4)|0;
  $17 = $16;
  $18 = HEAP32[$17>>2]|0;
  $19 = $__first;
  $20 = $19;
  HEAP32[$20>>2] = $15;
  $21 = (($19) + 4)|0;
  $22 = $21;
  HEAP32[$22>>2] = $18;
  $23 = $5;
  $24 = $23;
  HEAP32[$24>>2] = $9;
  $25 = (($23) + 4)|0;
  $26 = $25;
  HEAP32[$26>>2] = $12;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $27 = (($__first) + 8|0);
  $28 = (($__last) + -8|0);
  (__ZNSt3__17__sort3IRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEjT0_SA_SA_T_($__first,$27,$28,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $29 = (($__first) + 8|0);
  $30 = (($__first) + 16|0);
  $31 = (($__last) + -8|0);
  (__ZNSt3__17__sort4IRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEjT0_SA_SA_SA_T_($__first,$29,$30,$31,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $32 = (($__first) + 8|0);
  $33 = (($__first) + 16|0);
  $34 = (($__first) + 24|0);
  $35 = (($__last) + -8|0);
  (__ZNSt3__17__sort5IRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEjT0_SA_SA_SA_SA_T_($__first,$32,$33,$34,$35,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $36 = (($__first) + 16|0);
  $37 = (($__first) + 8|0);
  (__ZNSt3__17__sort3IRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS3_EEjT0_SA_SA_T_($__first,$37,$36,$__comp)|0);
  $38 = (($__first) + 24|0);
  $39 = ($38|0)==($__last|0);
  if ($39) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $__count$03 = 0;$__i$04 = $38;$__j$02 = $36;
  }
  while(1) {
   $40 = HEAP32[$__comp>>2]|0;
   $41 = (FUNCTION_TABLE_iii[$40 & 63]($__i$04,$__j$02)|0);
   if ($41) {
    $42 = $__i$04;
    $43 = $42;
    $44 = HEAP32[$43>>2]|0;
    $45 = (($42) + 4)|0;
    $46 = $45;
    $47 = HEAP32[$46>>2]|0;
    $48 = $__t;
    $49 = $48;
    HEAP32[$49>>2] = $44;
    $50 = (($48) + 4)|0;
    $51 = $50;
    HEAP32[$51>>2] = $47;
    $__j$1 = $__i$04;$__k$0 = $__j$02;
    while(1) {
     $52 = $__k$0;
     $53 = $52;
     $54 = HEAP32[$53>>2]|0;
     $55 = (($52) + 4)|0;
     $56 = $55;
     $57 = HEAP32[$56>>2]|0;
     $58 = $__j$1;
     $59 = $58;
     HEAP32[$59>>2] = $54;
     $60 = (($58) + 4)|0;
     $61 = $60;
     HEAP32[$61>>2] = $57;
     $62 = ($__k$0|0)==($__first|0);
     if ($62) {
      break;
     }
     $63 = HEAP32[$__comp>>2]|0;
     $64 = (($__k$0) + -8|0);
     $65 = (FUNCTION_TABLE_iii[$63 & 63]($__t,$64)|0);
     if ($65) {
      $__j$1$phi = $__k$0;$__k$0 = $64;$__j$1 = $__j$1$phi;
     } else {
      break;
     }
    }
    $66 = $__t;
    $67 = $66;
    $68 = HEAP32[$67>>2]|0;
    $69 = (($66) + 4)|0;
    $70 = $69;
    $71 = HEAP32[$70>>2]|0;
    $72 = $__k$0;
    $73 = $72;
    HEAP32[$73>>2] = $68;
    $74 = (($72) + 4)|0;
    $75 = $74;
    HEAP32[$75>>2] = $71;
    $76 = (($__count$03) + 1)|0;
    $77 = ($76|0)==(8);
    if ($77) {
     break;
    } else {
     $__count$1 = $76;
    }
   } else {
    $__count$1 = $__count$03;
   }
   $80 = (($__i$04) + 8|0);
   $81 = ($80|0)==($__last|0);
   if ($81) {
    $$0 = 1;
    label = 15;
    break;
   } else {
    $__j$02$phi = $__i$04;$__count$03 = $__count$1;$__i$04 = $80;$__j$02 = $__j$02$phi;
   }
  }
  if ((label|0) == 15) {
   STACKTOP = sp;return ($$0|0);
  }
  $78 = (($__i$04) + 8|0);
  $79 = ($78|0)==($__last|0);
  $$0 = $79;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return (0)|0;
}
function __ZL23FindItemIndexInFixedSetIN12_GLOBAL__N_115LightweightPairIiiEEEiRKNS0_22TypedFixedSetAllocatorIT_EERKS4_($set,$item) {
 $set = $set|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZNK12_GLOBAL__N_117FixedSetAllocator8GetCountEv($set)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (__ZNK12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIiiEEE9GetBufferEv($set)|0);
 $4 = (($3) + ($1<<3)|0);
 HEAP32[$0>>2] = 31;
 $5 = (__ZNSt3__113__lower_boundIRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS4_S3_EET0_SA_SA_RKT1_T_($3,$4,$item,$0)|0);
 $6 = ($5|0)==($4|0);
 if ($6) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (__ZNK12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIiiEEE8GetIndexEPKS2_($set,$5)|0);
 $$0 = $7;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16b2GrowableBufferIiE4GrowEv($this) {
 $this = $this|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 $3 = $1 << 1;
 $$ = $2 ? 256 : $3;
 __ZN16b2GrowableBufferIiE7ReserveEi($this,$$);
 STACKTOP = sp;return;
}
function __ZNSt3__17__sort3IRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEjT0_SC_SC_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__c>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$0 & 63]($__y,$__x)|0);
 $2 = HEAP32[$__c>>2]|0;
 $3 = (FUNCTION_TABLE_iii[$2 & 63]($__z,$__y)|0);
 if (!($1)) {
  if (!($3)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $4 = $__y;
  $5 = $4;
  $6 = HEAP32[$5>>2]|0;
  $7 = (($4) + 4)|0;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = $__z;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $13 = (($10) + 4)|0;
  $14 = $13;
  $15 = HEAP32[$14>>2]|0;
  $16 = $__y;
  $17 = $16;
  HEAP32[$17>>2] = $12;
  $18 = (($16) + 4)|0;
  $19 = $18;
  HEAP32[$19>>2] = $15;
  $20 = $__z;
  $21 = $20;
  HEAP32[$21>>2] = $6;
  $22 = (($20) + 4)|0;
  $23 = $22;
  HEAP32[$23>>2] = $9;
  $24 = HEAP32[$__c>>2]|0;
  $25 = (FUNCTION_TABLE_iii[$24 & 63]($__y,$__x)|0);
  if (!($25)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $26 = $__x;
  $27 = $26;
  $28 = HEAP32[$27>>2]|0;
  $29 = (($26) + 4)|0;
  $30 = $29;
  $31 = HEAP32[$30>>2]|0;
  $32 = $__y;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = (($32) + 4)|0;
  $36 = $35;
  $37 = HEAP32[$36>>2]|0;
  $38 = $__x;
  $39 = $38;
  HEAP32[$39>>2] = $34;
  $40 = (($38) + 4)|0;
  $41 = $40;
  HEAP32[$41>>2] = $37;
  $42 = $__y;
  $43 = $42;
  HEAP32[$43>>2] = $28;
  $44 = (($42) + 4)|0;
  $45 = $44;
  HEAP32[$45>>2] = $31;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 $46 = $__x;
 $47 = $46;
 $48 = HEAP32[$47>>2]|0;
 $49 = (($46) + 4)|0;
 $50 = $49;
 $51 = HEAP32[$50>>2]|0;
 if ($3) {
  $52 = $__z;
  $53 = $52;
  $54 = HEAP32[$53>>2]|0;
  $55 = (($52) + 4)|0;
  $56 = $55;
  $57 = HEAP32[$56>>2]|0;
  $58 = $__x;
  $59 = $58;
  HEAP32[$59>>2] = $54;
  $60 = (($58) + 4)|0;
  $61 = $60;
  HEAP32[$61>>2] = $57;
  $62 = $__z;
  $63 = $62;
  HEAP32[$63>>2] = $48;
  $64 = (($62) + 4)|0;
  $65 = $64;
  HEAP32[$65>>2] = $51;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $66 = $__y;
 $67 = $66;
 $68 = HEAP32[$67>>2]|0;
 $69 = (($66) + 4)|0;
 $70 = $69;
 $71 = HEAP32[$70>>2]|0;
 $72 = $__x;
 $73 = $72;
 HEAP32[$73>>2] = $68;
 $74 = (($72) + 4)|0;
 $75 = $74;
 HEAP32[$75>>2] = $71;
 $76 = $__y;
 $77 = $76;
 HEAP32[$77>>2] = $48;
 $78 = (($76) + 4)|0;
 $79 = $78;
 HEAP32[$79>>2] = $51;
 $80 = HEAP32[$__c>>2]|0;
 $81 = (FUNCTION_TABLE_iii[$80 & 63]($__z,$__y)|0);
 if (!($81)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $82 = $__y;
 $83 = $82;
 $84 = HEAP32[$83>>2]|0;
 $85 = (($82) + 4)|0;
 $86 = $85;
 $87 = HEAP32[$86>>2]|0;
 $88 = $__z;
 $89 = $88;
 $90 = HEAP32[$89>>2]|0;
 $91 = (($88) + 4)|0;
 $92 = $91;
 $93 = HEAP32[$92>>2]|0;
 $94 = $__y;
 $95 = $94;
 HEAP32[$95>>2] = $90;
 $96 = (($94) + 4)|0;
 $97 = $96;
 HEAP32[$97>>2] = $93;
 $98 = $__z;
 $99 = $98;
 HEAP32[$99>>2] = $84;
 $100 = (($98) + 4)|0;
 $101 = $100;
 HEAP32[$101>>2] = $87;
 $$0 = 2;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17__sort4IRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEjT0_SC_SC_SC_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__17__sort3IRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEjT0_SC_SC_T_($__x1,$__x2,$__x3,$__c)|0);
 $1 = HEAP32[$__c>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$1 & 63]($__x4,$__x3)|0);
 if (!($2)) {
  $__r$0 = $0;
  STACKTOP = sp;return ($__r$0|0);
 }
 $3 = $__x3;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $__x4;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = $__x3;
 $16 = $15;
 HEAP32[$16>>2] = $11;
 $17 = (($15) + 4)|0;
 $18 = $17;
 HEAP32[$18>>2] = $14;
 $19 = $__x4;
 $20 = $19;
 HEAP32[$20>>2] = $5;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $8;
 $23 = (($0) + 1)|0;
 $24 = HEAP32[$__c>>2]|0;
 $25 = (FUNCTION_TABLE_iii[$24 & 63]($__x3,$__x2)|0);
 if (!($25)) {
  $__r$0 = $23;
  STACKTOP = sp;return ($__r$0|0);
 }
 $26 = $__x2;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($26) + 4)|0;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = $__x3;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = (($32) + 4)|0;
 $36 = $35;
 $37 = HEAP32[$36>>2]|0;
 $38 = $__x2;
 $39 = $38;
 HEAP32[$39>>2] = $34;
 $40 = (($38) + 4)|0;
 $41 = $40;
 HEAP32[$41>>2] = $37;
 $42 = $__x3;
 $43 = $42;
 HEAP32[$43>>2] = $28;
 $44 = (($42) + 4)|0;
 $45 = $44;
 HEAP32[$45>>2] = $31;
 $46 = (($0) + 2)|0;
 $47 = HEAP32[$__c>>2]|0;
 $48 = (FUNCTION_TABLE_iii[$47 & 63]($__x2,$__x1)|0);
 if (!($48)) {
  $__r$0 = $46;
  STACKTOP = sp;return ($__r$0|0);
 }
 $49 = $__x1;
 $50 = $49;
 $51 = HEAP32[$50>>2]|0;
 $52 = (($49) + 4)|0;
 $53 = $52;
 $54 = HEAP32[$53>>2]|0;
 $55 = $__x2;
 $56 = $55;
 $57 = HEAP32[$56>>2]|0;
 $58 = (($55) + 4)|0;
 $59 = $58;
 $60 = HEAP32[$59>>2]|0;
 $61 = $__x1;
 $62 = $61;
 HEAP32[$62>>2] = $57;
 $63 = (($61) + 4)|0;
 $64 = $63;
 HEAP32[$64>>2] = $60;
 $65 = $__x2;
 $66 = $65;
 HEAP32[$66>>2] = $51;
 $67 = (($65) + 4)|0;
 $68 = $67;
 HEAP32[$68>>2] = $54;
 $69 = (($0) + 3)|0;
 $__r$0 = $69;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__17__sort5IRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEjT0_SC_SC_SC_SC_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__17__sort4IRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEjT0_SC_SC_SC_T_($__x1,$__x2,$__x3,$__x4,$__c)|0);
 $1 = HEAP32[$__c>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$1 & 63]($__x5,$__x4)|0);
 if (!($2)) {
  $__r$0 = $0;
  STACKTOP = sp;return ($__r$0|0);
 }
 $3 = $__x4;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) + 4)|0;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = $__x5;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = (($9) + 4)|0;
 $13 = $12;
 $14 = HEAP32[$13>>2]|0;
 $15 = $__x4;
 $16 = $15;
 HEAP32[$16>>2] = $11;
 $17 = (($15) + 4)|0;
 $18 = $17;
 HEAP32[$18>>2] = $14;
 $19 = $__x5;
 $20 = $19;
 HEAP32[$20>>2] = $5;
 $21 = (($19) + 4)|0;
 $22 = $21;
 HEAP32[$22>>2] = $8;
 $23 = (($0) + 1)|0;
 $24 = HEAP32[$__c>>2]|0;
 $25 = (FUNCTION_TABLE_iii[$24 & 63]($__x4,$__x3)|0);
 if (!($25)) {
  $__r$0 = $23;
  STACKTOP = sp;return ($__r$0|0);
 }
 $26 = $__x3;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (($26) + 4)|0;
 $30 = $29;
 $31 = HEAP32[$30>>2]|0;
 $32 = $__x4;
 $33 = $32;
 $34 = HEAP32[$33>>2]|0;
 $35 = (($32) + 4)|0;
 $36 = $35;
 $37 = HEAP32[$36>>2]|0;
 $38 = $__x3;
 $39 = $38;
 HEAP32[$39>>2] = $34;
 $40 = (($38) + 4)|0;
 $41 = $40;
 HEAP32[$41>>2] = $37;
 $42 = $__x4;
 $43 = $42;
 HEAP32[$43>>2] = $28;
 $44 = (($42) + 4)|0;
 $45 = $44;
 HEAP32[$45>>2] = $31;
 $46 = (($0) + 2)|0;
 $47 = HEAP32[$__c>>2]|0;
 $48 = (FUNCTION_TABLE_iii[$47 & 63]($__x3,$__x2)|0);
 if (!($48)) {
  $__r$0 = $46;
  STACKTOP = sp;return ($__r$0|0);
 }
 $49 = $__x2;
 $50 = $49;
 $51 = HEAP32[$50>>2]|0;
 $52 = (($49) + 4)|0;
 $53 = $52;
 $54 = HEAP32[$53>>2]|0;
 $55 = $__x3;
 $56 = $55;
 $57 = HEAP32[$56>>2]|0;
 $58 = (($55) + 4)|0;
 $59 = $58;
 $60 = HEAP32[$59>>2]|0;
 $61 = $__x2;
 $62 = $61;
 HEAP32[$62>>2] = $57;
 $63 = (($61) + 4)|0;
 $64 = $63;
 HEAP32[$64>>2] = $60;
 $65 = $__x3;
 $66 = $65;
 HEAP32[$66>>2] = $51;
 $67 = (($65) + 4)|0;
 $68 = $67;
 HEAP32[$68>>2] = $54;
 $69 = (($0) + 3)|0;
 $70 = HEAP32[$__c>>2]|0;
 $71 = (FUNCTION_TABLE_iii[$70 & 63]($__x2,$__x1)|0);
 if (!($71)) {
  $__r$0 = $69;
  STACKTOP = sp;return ($__r$0|0);
 }
 $72 = $__x1;
 $73 = $72;
 $74 = HEAP32[$73>>2]|0;
 $75 = (($72) + 4)|0;
 $76 = $75;
 $77 = HEAP32[$76>>2]|0;
 $78 = $__x2;
 $79 = $78;
 $80 = HEAP32[$79>>2]|0;
 $81 = (($78) + 4)|0;
 $82 = $81;
 $83 = HEAP32[$82>>2]|0;
 $84 = $__x1;
 $85 = $84;
 HEAP32[$85>>2] = $80;
 $86 = (($84) + 4)|0;
 $87 = $86;
 HEAP32[$87>>2] = $83;
 $88 = $__x2;
 $89 = $88;
 HEAP32[$89>>2] = $74;
 $90 = (($88) + 4)|0;
 $91 = $90;
 HEAP32[$91>>2] = $77;
 $92 = (($0) + 4)|0;
 $__r$0 = $92;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEvT0_SC_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $__i$02 = 0, $__j$01 = 0, $__j$01$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__t = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t = sp;
 $0 = (($__first) + 16|0);
 $1 = (($__first) + 8|0);
 (__ZNSt3__17__sort3IRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEjT0_SC_SC_T_($__first,$1,$0,$__comp)|0);
 $2 = (($__first) + 24|0);
 $3 = ($2|0)==($__last|0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $__i$02 = $2;$__j$01 = $0;
 }
 while(1) {
  $4 = HEAP32[$__comp>>2]|0;
  $5 = (FUNCTION_TABLE_iii[$4 & 63]($__i$02,$__j$01)|0);
  if ($5) {
   $6 = $__i$02;
   $7 = $6;
   $8 = HEAP32[$7>>2]|0;
   $9 = (($6) + 4)|0;
   $10 = $9;
   $11 = HEAP32[$10>>2]|0;
   $12 = $__t;
   $13 = $12;
   HEAP32[$13>>2] = $8;
   $14 = (($12) + 4)|0;
   $15 = $14;
   HEAP32[$15>>2] = $11;
   $__j$1 = $__i$02;$__k$0 = $__j$01;
   while(1) {
    $16 = $__k$0;
    $17 = $16;
    $18 = HEAP32[$17>>2]|0;
    $19 = (($16) + 4)|0;
    $20 = $19;
    $21 = HEAP32[$20>>2]|0;
    $22 = $__j$1;
    $23 = $22;
    HEAP32[$23>>2] = $18;
    $24 = (($22) + 4)|0;
    $25 = $24;
    HEAP32[$25>>2] = $21;
    $26 = ($__k$0|0)==($__first|0);
    if ($26) {
     break;
    }
    $27 = HEAP32[$__comp>>2]|0;
    $28 = (($__k$0) + -8|0);
    $29 = (FUNCTION_TABLE_iii[$27 & 63]($__t,$28)|0);
    if ($29) {
     $__j$1$phi = $__k$0;$__k$0 = $28;$__j$1 = $__j$1$phi;
    } else {
     break;
    }
   }
   $30 = $__t;
   $31 = $30;
   $32 = HEAP32[$31>>2]|0;
   $33 = (($30) + 4)|0;
   $34 = $33;
   $35 = HEAP32[$34>>2]|0;
   $36 = $__k$0;
   $37 = $36;
   HEAP32[$37>>2] = $32;
   $38 = (($36) + 4)|0;
   $39 = $38;
   HEAP32[$39>>2] = $35;
  }
  $40 = (($__i$02) + 8|0);
  $41 = ($40|0)==($__last|0);
  if ($41) {
   break;
  } else {
   $__j$01$phi = $__i$02;$__i$02 = $40;$__j$01 = $__j$01$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEbT0_SC_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $9 = 0, $__count$03 = 0, $__count$1 = 0, $__i$04 = 0, $__j$02 = 0, $__j$02$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__t = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $__t = sp;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 3;
 switch ($3|0) {
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = HEAP32[$__comp>>2]|0;
  $5 = (($__last) + -8|0);
  $6 = (FUNCTION_TABLE_iii[$4 & 63]($5,$__first)|0);
  if (!($6)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $7 = $__first;
  $8 = $7;
  $9 = HEAP32[$8>>2]|0;
  $10 = (($7) + 4)|0;
  $11 = $10;
  $12 = HEAP32[$11>>2]|0;
  $13 = $5;
  $14 = $13;
  $15 = HEAP32[$14>>2]|0;
  $16 = (($13) + 4)|0;
  $17 = $16;
  $18 = HEAP32[$17>>2]|0;
  $19 = $__first;
  $20 = $19;
  HEAP32[$20>>2] = $15;
  $21 = (($19) + 4)|0;
  $22 = $21;
  HEAP32[$22>>2] = $18;
  $23 = $5;
  $24 = $23;
  HEAP32[$24>>2] = $9;
  $25 = (($23) + 4)|0;
  $26 = $25;
  HEAP32[$26>>2] = $12;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $27 = (($__first) + 8|0);
  $28 = (($__last) + -8|0);
  (__ZNSt3__17__sort3IRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEjT0_SC_SC_T_($__first,$27,$28,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $32 = (($__first) + 8|0);
  $33 = (($__first) + 16|0);
  $34 = (($__first) + 24|0);
  $35 = (($__last) + -8|0);
  (__ZNSt3__17__sort5IRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEjT0_SC_SC_SC_SC_T_($__first,$32,$33,$34,$35,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $29 = (($__first) + 8|0);
  $30 = (($__first) + 16|0);
  $31 = (($__last) + -8|0);
  (__ZNSt3__17__sort4IRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEjT0_SC_SC_SC_T_($__first,$29,$30,$31,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $36 = (($__first) + 16|0);
  $37 = (($__first) + 8|0);
  (__ZNSt3__17__sort3IRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS5_EEjT0_SC_SC_T_($__first,$37,$36,$__comp)|0);
  $38 = (($__first) + 24|0);
  $39 = ($38|0)==($__last|0);
  if ($39) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $__count$03 = 0;$__i$04 = $38;$__j$02 = $36;
  }
  while(1) {
   $40 = HEAP32[$__comp>>2]|0;
   $41 = (FUNCTION_TABLE_iii[$40 & 63]($__i$04,$__j$02)|0);
   if ($41) {
    $42 = $__i$04;
    $43 = $42;
    $44 = HEAP32[$43>>2]|0;
    $45 = (($42) + 4)|0;
    $46 = $45;
    $47 = HEAP32[$46>>2]|0;
    $48 = $__t;
    $49 = $48;
    HEAP32[$49>>2] = $44;
    $50 = (($48) + 4)|0;
    $51 = $50;
    HEAP32[$51>>2] = $47;
    $__j$1 = $__i$04;$__k$0 = $__j$02;
    while(1) {
     $52 = $__k$0;
     $53 = $52;
     $54 = HEAP32[$53>>2]|0;
     $55 = (($52) + 4)|0;
     $56 = $55;
     $57 = HEAP32[$56>>2]|0;
     $58 = $__j$1;
     $59 = $58;
     HEAP32[$59>>2] = $54;
     $60 = (($58) + 4)|0;
     $61 = $60;
     HEAP32[$61>>2] = $57;
     $62 = ($__k$0|0)==($__first|0);
     if ($62) {
      break;
     }
     $63 = HEAP32[$__comp>>2]|0;
     $64 = (($__k$0) + -8|0);
     $65 = (FUNCTION_TABLE_iii[$63 & 63]($__t,$64)|0);
     if ($65) {
      $__j$1$phi = $__k$0;$__k$0 = $64;$__j$1 = $__j$1$phi;
     } else {
      break;
     }
    }
    $66 = $__t;
    $67 = $66;
    $68 = HEAP32[$67>>2]|0;
    $69 = (($66) + 4)|0;
    $70 = $69;
    $71 = HEAP32[$70>>2]|0;
    $72 = $__k$0;
    $73 = $72;
    HEAP32[$73>>2] = $68;
    $74 = (($72) + 4)|0;
    $75 = $74;
    HEAP32[$75>>2] = $71;
    $76 = (($__count$03) + 1)|0;
    $77 = ($76|0)==(8);
    if ($77) {
     break;
    } else {
     $__count$1 = $76;
    }
   } else {
    $__count$1 = $__count$03;
   }
   $80 = (($__i$04) + 8|0);
   $81 = ($80|0)==($__last|0);
   if ($81) {
    $$0 = 1;
    label = 15;
    break;
   } else {
    $__j$02$phi = $__i$04;$__count$03 = $__count$1;$__i$04 = $80;$__j$02 = $__j$02$phi;
   }
  }
  if ((label|0) == 15) {
   STACKTOP = sp;return ($$0|0);
  }
  $78 = (($__i$04) + 8|0);
  $79 = ($78|0)==($__last|0);
  $$0 = $79;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return (0)|0;
}
function __ZL23FindItemIndexInFixedSetIN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEEEiRKNS0_22TypedFixedSetAllocatorIT_EERKS6_($set,$item) {
 $set = $set|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (__ZNK12_GLOBAL__N_117FixedSetAllocator8GetCountEv($set)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = (__ZNK12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIP9b2FixtureiEEE9GetBufferEv($set)|0);
 $4 = (($3) + ($1<<3)|0);
 HEAP32[$0>>2] = 32;
 $5 = (__ZNSt3__113__lower_boundIRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS6_S5_EET0_SC_SC_RKT1_T_($3,$4,$item,$0)|0);
 $6 = ($5|0)==($4|0);
 if ($6) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $7 = (__ZNK12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIP9b2FixtureiEEE8GetIndexEPKS4_($set,$5)|0);
 $$0 = $7;
 STACKTOP = sp;return ($$0|0);
}
function __ZN12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIP9b2FixtureiEEEC2EP16b2StackAllocator($this,$allocator) {
 $this = $this|0;
 $allocator = $allocator|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN12_GLOBAL__N_117FixedSetAllocatorC2EP16b2StackAllocator($this,$allocator);
 STACKTOP = sp;return;
}
function __ZN30b2FixtureParticleQueryCallbackC2EP16b2ParticleSystem($this,$system) {
 $this = $this|0;
 $system = $system|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN15b2QueryCallbackC2Ev($this);
 HEAP32[$this>>2] = ((8424 + 8|0));
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $system;
 STACKTOP = sp;return;
}
function __ZNSt3__17__sort3IRPFbRK21b2ParticleBodyContactS3_EPS1_EEjT0_S8_S8_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $__t$i4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i4 = sp;
 $0 = HEAP32[$__c>>2]|0;
 $1 = (FUNCTION_TABLE_iii[$0 & 63]($__y,$__x)|0);
 $2 = HEAP32[$__c>>2]|0;
 $3 = (FUNCTION_TABLE_iii[$2 & 63]($__z,$__y)|0);
 if (!($1)) {
  if (!($3)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__t$i4+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__t$i4+8>>2]=HEAP32[$__y+8>>2]|0;HEAP32[$__t$i4+12>>2]=HEAP32[$__y+12>>2]|0;HEAP32[$__t$i4+16>>2]=HEAP32[$__y+16>>2]|0;HEAP32[$__t$i4+20>>2]=HEAP32[$__y+20>>2]|0;HEAP32[$__t$i4+24>>2]=HEAP32[$__y+24>>2]|0;
  ;HEAP32[$__y+0>>2]=HEAP32[$__z+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__z+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__z+8>>2]|0;HEAP32[$__y+12>>2]=HEAP32[$__z+12>>2]|0;HEAP32[$__y+16>>2]=HEAP32[$__z+16>>2]|0;HEAP32[$__y+20>>2]=HEAP32[$__z+20>>2]|0;HEAP32[$__y+24>>2]=HEAP32[$__z+24>>2]|0;
  ;HEAP32[$__z+0>>2]=HEAP32[$__t$i4+0>>2]|0;HEAP32[$__z+4>>2]=HEAP32[$__t$i4+4>>2]|0;HEAP32[$__z+8>>2]=HEAP32[$__t$i4+8>>2]|0;HEAP32[$__z+12>>2]=HEAP32[$__t$i4+12>>2]|0;HEAP32[$__z+16>>2]=HEAP32[$__t$i4+16>>2]|0;HEAP32[$__z+20>>2]=HEAP32[$__t$i4+20>>2]|0;HEAP32[$__z+24>>2]=HEAP32[$__t$i4+24>>2]|0;
  $4 = HEAP32[$__c>>2]|0;
  $5 = (FUNCTION_TABLE_iii[$4 & 63]($__y,$__x)|0);
  if (!($5)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i4+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$__t$i4+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$__t$i4+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$__t$i4+12>>2]=HEAP32[$__x+12>>2]|0;HEAP32[$__t$i4+16>>2]=HEAP32[$__x+16>>2]|0;HEAP32[$__t$i4+20>>2]=HEAP32[$__x+20>>2]|0;HEAP32[$__t$i4+24>>2]=HEAP32[$__x+24>>2]|0;
  ;HEAP32[$__x+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__x+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__x+8>>2]=HEAP32[$__y+8>>2]|0;HEAP32[$__x+12>>2]=HEAP32[$__y+12>>2]|0;HEAP32[$__x+16>>2]=HEAP32[$__y+16>>2]|0;HEAP32[$__x+20>>2]=HEAP32[$__y+20>>2]|0;HEAP32[$__x+24>>2]=HEAP32[$__y+24>>2]|0;
  ;HEAP32[$__y+0>>2]=HEAP32[$__t$i4+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__t$i4+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__t$i4+8>>2]|0;HEAP32[$__y+12>>2]=HEAP32[$__t$i4+12>>2]|0;HEAP32[$__y+16>>2]=HEAP32[$__t$i4+16>>2]|0;HEAP32[$__y+20>>2]=HEAP32[$__t$i4+20>>2]|0;HEAP32[$__y+24>>2]=HEAP32[$__t$i4+24>>2]|0;
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 if ($3) {
  ;HEAP32[$__t$i4+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$__t$i4+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$__t$i4+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$__t$i4+12>>2]=HEAP32[$__x+12>>2]|0;HEAP32[$__t$i4+16>>2]=HEAP32[$__x+16>>2]|0;HEAP32[$__t$i4+20>>2]=HEAP32[$__x+20>>2]|0;HEAP32[$__t$i4+24>>2]=HEAP32[$__x+24>>2]|0;
  ;HEAP32[$__x+0>>2]=HEAP32[$__z+0>>2]|0;HEAP32[$__x+4>>2]=HEAP32[$__z+4>>2]|0;HEAP32[$__x+8>>2]=HEAP32[$__z+8>>2]|0;HEAP32[$__x+12>>2]=HEAP32[$__z+12>>2]|0;HEAP32[$__x+16>>2]=HEAP32[$__z+16>>2]|0;HEAP32[$__x+20>>2]=HEAP32[$__z+20>>2]|0;HEAP32[$__x+24>>2]=HEAP32[$__z+24>>2]|0;
  ;HEAP32[$__z+0>>2]=HEAP32[$__t$i4+0>>2]|0;HEAP32[$__z+4>>2]=HEAP32[$__t$i4+4>>2]|0;HEAP32[$__z+8>>2]=HEAP32[$__t$i4+8>>2]|0;HEAP32[$__z+12>>2]=HEAP32[$__t$i4+12>>2]|0;HEAP32[$__z+16>>2]=HEAP32[$__t$i4+16>>2]|0;HEAP32[$__z+20>>2]=HEAP32[$__t$i4+20>>2]|0;HEAP32[$__z+24>>2]=HEAP32[$__t$i4+24>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$__t$i4+0>>2]=HEAP32[$__x+0>>2]|0;HEAP32[$__t$i4+4>>2]=HEAP32[$__x+4>>2]|0;HEAP32[$__t$i4+8>>2]=HEAP32[$__x+8>>2]|0;HEAP32[$__t$i4+12>>2]=HEAP32[$__x+12>>2]|0;HEAP32[$__t$i4+16>>2]=HEAP32[$__x+16>>2]|0;HEAP32[$__t$i4+20>>2]=HEAP32[$__x+20>>2]|0;HEAP32[$__t$i4+24>>2]=HEAP32[$__x+24>>2]|0;
 ;HEAP32[$__x+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__x+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__x+8>>2]=HEAP32[$__y+8>>2]|0;HEAP32[$__x+12>>2]=HEAP32[$__y+12>>2]|0;HEAP32[$__x+16>>2]=HEAP32[$__y+16>>2]|0;HEAP32[$__x+20>>2]=HEAP32[$__y+20>>2]|0;HEAP32[$__x+24>>2]=HEAP32[$__y+24>>2]|0;
 ;HEAP32[$__y+0>>2]=HEAP32[$__t$i4+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__t$i4+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__t$i4+8>>2]|0;HEAP32[$__y+12>>2]=HEAP32[$__t$i4+12>>2]|0;HEAP32[$__y+16>>2]=HEAP32[$__t$i4+16>>2]|0;HEAP32[$__y+20>>2]=HEAP32[$__t$i4+20>>2]|0;HEAP32[$__y+24>>2]=HEAP32[$__t$i4+24>>2]|0;
 $6 = HEAP32[$__c>>2]|0;
 $7 = (FUNCTION_TABLE_iii[$6 & 63]($__z,$__y)|0);
 if (!($7)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$__t$i4+0>>2]=HEAP32[$__y+0>>2]|0;HEAP32[$__t$i4+4>>2]=HEAP32[$__y+4>>2]|0;HEAP32[$__t$i4+8>>2]=HEAP32[$__y+8>>2]|0;HEAP32[$__t$i4+12>>2]=HEAP32[$__y+12>>2]|0;HEAP32[$__t$i4+16>>2]=HEAP32[$__y+16>>2]|0;HEAP32[$__t$i4+20>>2]=HEAP32[$__y+20>>2]|0;HEAP32[$__t$i4+24>>2]=HEAP32[$__y+24>>2]|0;
 ;HEAP32[$__y+0>>2]=HEAP32[$__z+0>>2]|0;HEAP32[$__y+4>>2]=HEAP32[$__z+4>>2]|0;HEAP32[$__y+8>>2]=HEAP32[$__z+8>>2]|0;HEAP32[$__y+12>>2]=HEAP32[$__z+12>>2]|0;HEAP32[$__y+16>>2]=HEAP32[$__z+16>>2]|0;HEAP32[$__y+20>>2]=HEAP32[$__z+20>>2]|0;HEAP32[$__y+24>>2]=HEAP32[$__z+24>>2]|0;
 ;HEAP32[$__z+0>>2]=HEAP32[$__t$i4+0>>2]|0;HEAP32[$__z+4>>2]=HEAP32[$__t$i4+4>>2]|0;HEAP32[$__z+8>>2]=HEAP32[$__t$i4+8>>2]|0;HEAP32[$__z+12>>2]=HEAP32[$__t$i4+12>>2]|0;HEAP32[$__z+16>>2]=HEAP32[$__t$i4+16>>2]|0;HEAP32[$__z+20>>2]=HEAP32[$__t$i4+20>>2]|0;HEAP32[$__z+24>>2]=HEAP32[$__t$i4+24>>2]|0;
 $$0 = 2;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17__sort4IRPFbRK21b2ParticleBodyContactS3_EPS1_EEjT0_S8_S8_S8_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, $__t$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i2 = sp;
 $0 = (__ZNSt3__17__sort3IRPFbRK21b2ParticleBodyContactS3_EPS1_EEjT0_S8_S8_T_($__x1,$__x2,$__x3,$__c)|0);
 $1 = HEAP32[$__c>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$1 & 63]($__x4,$__x3)|0);
 if (!($2)) {
  $__r$0 = $0;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__t$i2+16>>2]=HEAP32[$__x3+16>>2]|0;HEAP32[$__t$i2+20>>2]=HEAP32[$__x3+20>>2]|0;HEAP32[$__t$i2+24>>2]=HEAP32[$__x3+24>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__x4+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__x4+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__x4+16>>2]|0;HEAP32[$__x3+20>>2]=HEAP32[$__x4+20>>2]|0;HEAP32[$__x3+24>>2]=HEAP32[$__x4+24>>2]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x4+12>>2]=HEAP32[$__t$i2+12>>2]|0;HEAP32[$__x4+16>>2]=HEAP32[$__t$i2+16>>2]|0;HEAP32[$__x4+20>>2]=HEAP32[$__t$i2+20>>2]|0;HEAP32[$__x4+24>>2]=HEAP32[$__t$i2+24>>2]|0;
 $3 = (($0) + 1)|0;
 $4 = HEAP32[$__c>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$4 & 63]($__x3,$__x2)|0);
 if (!($5)) {
  $__r$0 = $3;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__t$i2+16>>2]=HEAP32[$__x2+16>>2]|0;HEAP32[$__t$i2+20>>2]=HEAP32[$__x2+20>>2]|0;HEAP32[$__t$i2+24>>2]=HEAP32[$__x2+24>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__x3+16>>2]|0;HEAP32[$__x2+20>>2]=HEAP32[$__x3+20>>2]|0;HEAP32[$__x2+24>>2]=HEAP32[$__x3+24>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i2+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__t$i2+16>>2]|0;HEAP32[$__x3+20>>2]=HEAP32[$__t$i2+20>>2]|0;HEAP32[$__x3+24>>2]=HEAP32[$__t$i2+24>>2]|0;
 $6 = (($0) + 2)|0;
 $7 = HEAP32[$__c>>2]|0;
 $8 = (FUNCTION_TABLE_iii[$7 & 63]($__x2,$__x1)|0);
 if (!($8)) {
  $__r$0 = $6;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i2+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i2+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i2+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i2+12>>2]=HEAP32[$__x1+12>>2]|0;HEAP32[$__t$i2+16>>2]=HEAP32[$__x1+16>>2]|0;HEAP32[$__t$i2+20>>2]=HEAP32[$__x1+20>>2]|0;HEAP32[$__t$i2+24>>2]=HEAP32[$__x1+24>>2]|0;
 ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__x1+16>>2]=HEAP32[$__x2+16>>2]|0;HEAP32[$__x1+20>>2]=HEAP32[$__x2+20>>2]|0;HEAP32[$__x1+24>>2]=HEAP32[$__x2+24>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i2+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i2+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i2+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i2+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__t$i2+16>>2]|0;HEAP32[$__x2+20>>2]=HEAP32[$__t$i2+20>>2]|0;HEAP32[$__x2+24>>2]=HEAP32[$__t$i2+24>>2]|0;
 $9 = (($0) + 3)|0;
 $__r$0 = $9;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__17__sort5IRPFbRK21b2ParticleBodyContactS3_EPS1_EEjT0_S8_S8_S8_S8_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, $__t$i3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t$i3 = sp;
 $0 = (__ZNSt3__17__sort4IRPFbRK21b2ParticleBodyContactS3_EPS1_EEjT0_S8_S8_S8_T_($__x1,$__x2,$__x3,$__x4,$__c)|0);
 $1 = HEAP32[$__c>>2]|0;
 $2 = (FUNCTION_TABLE_iii[$1 & 63]($__x5,$__x4)|0);
 if (!($2)) {
  $__r$0 = $0;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i3+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__t$i3+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__t$i3+8>>2]=HEAP32[$__x4+8>>2]|0;HEAP32[$__t$i3+12>>2]=HEAP32[$__x4+12>>2]|0;HEAP32[$__t$i3+16>>2]=HEAP32[$__x4+16>>2]|0;HEAP32[$__t$i3+20>>2]=HEAP32[$__x4+20>>2]|0;HEAP32[$__t$i3+24>>2]=HEAP32[$__x4+24>>2]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__x5+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__x5+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__x5+8>>2]|0;HEAP32[$__x4+12>>2]=HEAP32[$__x5+12>>2]|0;HEAP32[$__x4+16>>2]=HEAP32[$__x5+16>>2]|0;HEAP32[$__x4+20>>2]=HEAP32[$__x5+20>>2]|0;HEAP32[$__x4+24>>2]=HEAP32[$__x5+24>>2]|0;
 ;HEAP32[$__x5+0>>2]=HEAP32[$__t$i3+0>>2]|0;HEAP32[$__x5+4>>2]=HEAP32[$__t$i3+4>>2]|0;HEAP32[$__x5+8>>2]=HEAP32[$__t$i3+8>>2]|0;HEAP32[$__x5+12>>2]=HEAP32[$__t$i3+12>>2]|0;HEAP32[$__x5+16>>2]=HEAP32[$__t$i3+16>>2]|0;HEAP32[$__x5+20>>2]=HEAP32[$__t$i3+20>>2]|0;HEAP32[$__x5+24>>2]=HEAP32[$__t$i3+24>>2]|0;
 $3 = (($0) + 1)|0;
 $4 = HEAP32[$__c>>2]|0;
 $5 = (FUNCTION_TABLE_iii[$4 & 63]($__x4,$__x3)|0);
 if (!($5)) {
  $__r$0 = $3;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i3+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__t$i3+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__t$i3+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__t$i3+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__t$i3+16>>2]=HEAP32[$__x3+16>>2]|0;HEAP32[$__t$i3+20>>2]=HEAP32[$__x3+20>>2]|0;HEAP32[$__t$i3+24>>2]=HEAP32[$__x3+24>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__x4+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__x4+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__x4+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__x4+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__x4+16>>2]|0;HEAP32[$__x3+20>>2]=HEAP32[$__x4+20>>2]|0;HEAP32[$__x3+24>>2]=HEAP32[$__x4+24>>2]|0;
 ;HEAP32[$__x4+0>>2]=HEAP32[$__t$i3+0>>2]|0;HEAP32[$__x4+4>>2]=HEAP32[$__t$i3+4>>2]|0;HEAP32[$__x4+8>>2]=HEAP32[$__t$i3+8>>2]|0;HEAP32[$__x4+12>>2]=HEAP32[$__t$i3+12>>2]|0;HEAP32[$__x4+16>>2]=HEAP32[$__t$i3+16>>2]|0;HEAP32[$__x4+20>>2]=HEAP32[$__t$i3+20>>2]|0;HEAP32[$__x4+24>>2]=HEAP32[$__t$i3+24>>2]|0;
 $6 = (($0) + 2)|0;
 $7 = HEAP32[$__c>>2]|0;
 $8 = (FUNCTION_TABLE_iii[$7 & 63]($__x3,$__x2)|0);
 if (!($8)) {
  $__r$0 = $6;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i3+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__t$i3+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__t$i3+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__t$i3+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__t$i3+16>>2]=HEAP32[$__x2+16>>2]|0;HEAP32[$__t$i3+20>>2]=HEAP32[$__x2+20>>2]|0;HEAP32[$__t$i3+24>>2]=HEAP32[$__x2+24>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__x3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__x3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__x3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__x3+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__x3+16>>2]|0;HEAP32[$__x2+20>>2]=HEAP32[$__x3+20>>2]|0;HEAP32[$__x2+24>>2]=HEAP32[$__x3+24>>2]|0;
 ;HEAP32[$__x3+0>>2]=HEAP32[$__t$i3+0>>2]|0;HEAP32[$__x3+4>>2]=HEAP32[$__t$i3+4>>2]|0;HEAP32[$__x3+8>>2]=HEAP32[$__t$i3+8>>2]|0;HEAP32[$__x3+12>>2]=HEAP32[$__t$i3+12>>2]|0;HEAP32[$__x3+16>>2]=HEAP32[$__t$i3+16>>2]|0;HEAP32[$__x3+20>>2]=HEAP32[$__t$i3+20>>2]|0;HEAP32[$__x3+24>>2]=HEAP32[$__t$i3+24>>2]|0;
 $9 = (($0) + 3)|0;
 $10 = HEAP32[$__c>>2]|0;
 $11 = (FUNCTION_TABLE_iii[$10 & 63]($__x2,$__x1)|0);
 if (!($11)) {
  $__r$0 = $9;
  STACKTOP = sp;return ($__r$0|0);
 }
 ;HEAP32[$__t$i3+0>>2]=HEAP32[$__x1+0>>2]|0;HEAP32[$__t$i3+4>>2]=HEAP32[$__x1+4>>2]|0;HEAP32[$__t$i3+8>>2]=HEAP32[$__x1+8>>2]|0;HEAP32[$__t$i3+12>>2]=HEAP32[$__x1+12>>2]|0;HEAP32[$__t$i3+16>>2]=HEAP32[$__x1+16>>2]|0;HEAP32[$__t$i3+20>>2]=HEAP32[$__x1+20>>2]|0;HEAP32[$__t$i3+24>>2]=HEAP32[$__x1+24>>2]|0;
 ;HEAP32[$__x1+0>>2]=HEAP32[$__x2+0>>2]|0;HEAP32[$__x1+4>>2]=HEAP32[$__x2+4>>2]|0;HEAP32[$__x1+8>>2]=HEAP32[$__x2+8>>2]|0;HEAP32[$__x1+12>>2]=HEAP32[$__x2+12>>2]|0;HEAP32[$__x1+16>>2]=HEAP32[$__x2+16>>2]|0;HEAP32[$__x1+20>>2]=HEAP32[$__x2+20>>2]|0;HEAP32[$__x1+24>>2]=HEAP32[$__x2+24>>2]|0;
 ;HEAP32[$__x2+0>>2]=HEAP32[$__t$i3+0>>2]|0;HEAP32[$__x2+4>>2]=HEAP32[$__t$i3+4>>2]|0;HEAP32[$__x2+8>>2]=HEAP32[$__t$i3+8>>2]|0;HEAP32[$__x2+12>>2]=HEAP32[$__t$i3+12>>2]|0;HEAP32[$__x2+16>>2]=HEAP32[$__t$i3+16>>2]|0;HEAP32[$__x2+20>>2]=HEAP32[$__t$i3+20>>2]|0;HEAP32[$__x2+24>>2]=HEAP32[$__t$i3+24>>2]|0;
 $12 = (($0) + 4)|0;
 $__r$0 = $12;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IRPFbRK21b2ParticleBodyContactS3_EPS1_EEvT0_S8_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$02 = 0, $__j$01 = 0, $__j$01$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, $__t = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__t = sp;
 $0 = (($__first) + 56|0);
 $1 = (($__first) + 28|0);
 (__ZNSt3__17__sort3IRPFbRK21b2ParticleBodyContactS3_EPS1_EEjT0_S8_S8_T_($__first,$1,$0,$__comp)|0);
 $2 = (($__first) + 84|0);
 $3 = ($2|0)==($__last|0);
 if ($3) {
  STACKTOP = sp;return;
 }
 $__i$02 = $2;$__j$01 = $0;
 while(1) {
  $4 = HEAP32[$__comp>>2]|0;
  $5 = (FUNCTION_TABLE_iii[$4 & 63]($__i$02,$__j$01)|0);
  if ($5) {
   ;HEAP32[$__t+0>>2]=HEAP32[$__i$02+0>>2]|0;HEAP32[$__t+4>>2]=HEAP32[$__i$02+4>>2]|0;HEAP32[$__t+8>>2]=HEAP32[$__i$02+8>>2]|0;HEAP32[$__t+12>>2]=HEAP32[$__i$02+12>>2]|0;HEAP32[$__t+16>>2]=HEAP32[$__i$02+16>>2]|0;HEAP32[$__t+20>>2]=HEAP32[$__i$02+20>>2]|0;HEAP32[$__t+24>>2]=HEAP32[$__i$02+24>>2]|0;
   $__j$1 = $__i$02;$__k$0 = $__j$01;
   while(1) {
    ;HEAP32[$__j$1+0>>2]=HEAP32[$__k$0+0>>2]|0;HEAP32[$__j$1+4>>2]=HEAP32[$__k$0+4>>2]|0;HEAP32[$__j$1+8>>2]=HEAP32[$__k$0+8>>2]|0;HEAP32[$__j$1+12>>2]=HEAP32[$__k$0+12>>2]|0;HEAP32[$__j$1+16>>2]=HEAP32[$__k$0+16>>2]|0;HEAP32[$__j$1+20>>2]=HEAP32[$__k$0+20>>2]|0;HEAP32[$__j$1+24>>2]=HEAP32[$__k$0+24>>2]|0;
    $6 = ($__k$0|0)==($__first|0);
    if ($6) {
     break;
    }
    $7 = HEAP32[$__comp>>2]|0;
    $8 = (($__k$0) + -28|0);
    $9 = (FUNCTION_TABLE_iii[$7 & 63]($__t,$8)|0);
    if ($9) {
     $__j$1$phi = $__k$0;$__k$0 = $8;$__j$1 = $__j$1$phi;
    } else {
     break;
    }
   }
   ;HEAP32[$__k$0+0>>2]=HEAP32[$__t+0>>2]|0;HEAP32[$__k$0+4>>2]=HEAP32[$__t+4>>2]|0;HEAP32[$__k$0+8>>2]=HEAP32[$__t+8>>2]|0;HEAP32[$__k$0+12>>2]=HEAP32[$__t+12>>2]|0;HEAP32[$__k$0+16>>2]=HEAP32[$__t+16>>2]|0;HEAP32[$__k$0+20>>2]=HEAP32[$__t+20>>2]|0;HEAP32[$__k$0+24>>2]=HEAP32[$__t+24>>2]|0;
  }
  $10 = (($__i$02) + 28|0);
  $11 = ($10|0)==($__last|0);
  if ($11) {
   break;
  } else {
   $__j$01$phi = $__i$02;$__i$02 = $10;$__j$01 = $__j$01$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIRPFbRK21b2ParticleBodyContactS3_EPS1_EEbT0_S8_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__count$03 = 0, $__count$1 = 0, $__i$04 = 0, $__j$02 = 0, $__j$02$phi = 0, $__j$1 = 0, $__j$1$phi = 0;
 var $__k$0 = 0, $__t = 0, $__t$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $__t$i = sp + 28|0;
 $__t = sp;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = (($2|0) / 28)&-1;
 switch ($3|0) {
 case 4:  {
  $9 = (($__first) + 28|0);
  $10 = (($__first) + 56|0);
  $11 = (($__last) + -28|0);
  (__ZNSt3__17__sort4IRPFbRK21b2ParticleBodyContactS3_EPS1_EEjT0_S8_S8_S8_T_($__first,$9,$10,$11,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = HEAP32[$__comp>>2]|0;
  $5 = (($__last) + -28|0);
  $6 = (FUNCTION_TABLE_iii[$4 & 63]($5,$__first)|0);
  if (!($6)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  ;HEAP32[$__t$i+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__t$i+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__t$i+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__t$i+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__t$i+16>>2]=HEAP32[$__first+16>>2]|0;HEAP32[$__t$i+20>>2]=HEAP32[$__first+20>>2]|0;HEAP32[$__t$i+24>>2]=HEAP32[$__first+24>>2]|0;
  ;HEAP32[$__first+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$5+12>>2]|0;HEAP32[$__first+16>>2]=HEAP32[$5+16>>2]|0;HEAP32[$__first+20>>2]=HEAP32[$5+20>>2]|0;HEAP32[$__first+24>>2]=HEAP32[$5+24>>2]|0;
  ;HEAP32[$5+0>>2]=HEAP32[$__t$i+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$__t$i+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$__t$i+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$__t$i+12>>2]|0;HEAP32[$5+16>>2]=HEAP32[$__t$i+16>>2]|0;HEAP32[$5+20>>2]=HEAP32[$__t$i+20>>2]|0;HEAP32[$5+24>>2]=HEAP32[$__t$i+24>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $12 = (($__first) + 28|0);
  $13 = (($__first) + 56|0);
  $14 = (($__first) + 84|0);
  $15 = (($__last) + -28|0);
  (__ZNSt3__17__sort5IRPFbRK21b2ParticleBodyContactS3_EPS1_EEjT0_S8_S8_S8_S8_T_($__first,$12,$13,$14,$15,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $7 = (($__first) + 28|0);
  $8 = (($__last) + -28|0);
  (__ZNSt3__17__sort3IRPFbRK21b2ParticleBodyContactS3_EPS1_EEjT0_S8_S8_T_($__first,$7,$8,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $16 = (($__first) + 56|0);
  $17 = (($__first) + 28|0);
  (__ZNSt3__17__sort3IRPFbRK21b2ParticleBodyContactS3_EPS1_EEjT0_S8_S8_T_($__first,$17,$16,$__comp)|0);
  $18 = (($__first) + 84|0);
  $19 = ($18|0)==($__last|0);
  if ($19) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  $__count$03 = 0;$__i$04 = $18;$__j$02 = $16;
  while(1) {
   $20 = HEAP32[$__comp>>2]|0;
   $21 = (FUNCTION_TABLE_iii[$20 & 63]($__i$04,$__j$02)|0);
   if ($21) {
    ;HEAP32[$__t+0>>2]=HEAP32[$__i$04+0>>2]|0;HEAP32[$__t+4>>2]=HEAP32[$__i$04+4>>2]|0;HEAP32[$__t+8>>2]=HEAP32[$__i$04+8>>2]|0;HEAP32[$__t+12>>2]=HEAP32[$__i$04+12>>2]|0;HEAP32[$__t+16>>2]=HEAP32[$__i$04+16>>2]|0;HEAP32[$__t+20>>2]=HEAP32[$__i$04+20>>2]|0;HEAP32[$__t+24>>2]=HEAP32[$__i$04+24>>2]|0;
    $__j$1 = $__i$04;$__k$0 = $__j$02;
    while(1) {
     ;HEAP32[$__j$1+0>>2]=HEAP32[$__k$0+0>>2]|0;HEAP32[$__j$1+4>>2]=HEAP32[$__k$0+4>>2]|0;HEAP32[$__j$1+8>>2]=HEAP32[$__k$0+8>>2]|0;HEAP32[$__j$1+12>>2]=HEAP32[$__k$0+12>>2]|0;HEAP32[$__j$1+16>>2]=HEAP32[$__k$0+16>>2]|0;HEAP32[$__j$1+20>>2]=HEAP32[$__k$0+20>>2]|0;HEAP32[$__j$1+24>>2]=HEAP32[$__k$0+24>>2]|0;
     $22 = ($__k$0|0)==($__first|0);
     if ($22) {
      break;
     }
     $23 = HEAP32[$__comp>>2]|0;
     $24 = (($__k$0) + -28|0);
     $25 = (FUNCTION_TABLE_iii[$23 & 63]($__t,$24)|0);
     if ($25) {
      $__j$1$phi = $__k$0;$__k$0 = $24;$__j$1 = $__j$1$phi;
     } else {
      break;
     }
    }
    ;HEAP32[$__k$0+0>>2]=HEAP32[$__t+0>>2]|0;HEAP32[$__k$0+4>>2]=HEAP32[$__t+4>>2]|0;HEAP32[$__k$0+8>>2]=HEAP32[$__t+8>>2]|0;HEAP32[$__k$0+12>>2]=HEAP32[$__t+12>>2]|0;HEAP32[$__k$0+16>>2]=HEAP32[$__t+16>>2]|0;HEAP32[$__k$0+20>>2]=HEAP32[$__t+20>>2]|0;HEAP32[$__k$0+24>>2]=HEAP32[$__t+24>>2]|0;
    $26 = (($__count$03) + 1)|0;
    $27 = ($26|0)==(8);
    if ($27) {
     break;
    } else {
     $__count$1 = $26;
    }
   } else {
    $__count$1 = $__count$03;
   }
   $30 = (($__i$04) + 28|0);
   $31 = ($30|0)==($__last|0);
   if ($31) {
    $$0 = 1;
    label = 16;
    break;
   } else {
    $__j$02$phi = $__i$04;$__count$03 = $__count$1;$__i$04 = $30;$__j$02 = $__j$02$phi;
   }
  }
  if ((label|0) == 16) {
   STACKTOP = sp;return ($$0|0);
  }
  $28 = (($__i$04) + 28|0);
  $29 = ($28|0)==($__last|0);
  $$0 = $29;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return (0)|0;
}
function __ZN36b2ParticleBodyContactRemovePredicateclERK21b2ParticleBodyContact($this,$contact) {
 $this = $this|0;
 $contact = $contact|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0.0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $childIndex$01 = 0, $distance = 0, $n = 0;
 var $normal = 0, $pos = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $n = sp;
 $pos = sp + 24|0;
 $distance = sp + 16|0;
 $normal = sp + 8|0;
 $0 = HEAP32[$contact>>2]|0;
 $1 = (($this) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($0|0)==($2|0);
 if (!($3)) {
  $4 = (($this) + 8|0);
  HEAP32[$4>>2] = 0;
  $5 = HEAP32[$contact>>2]|0;
  HEAP32[$1>>2] = $5;
 }
 $6 = (($this) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + 1)|0;
 HEAP32[$6>>2] = $8;
 $9 = ($7|0)>(3);
 if ($9) {
  $10 = (($this) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 1)|0;
  HEAP32[$11>>2] = $13;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $14 = (($contact) + 16|0);
 $15 = $14;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 $21 = $n;
 $22 = $21;
 HEAP32[$22>>2] = $17;
 $23 = (($21) + 4)|0;
 $24 = $23;
 HEAP32[$24>>2] = $20;
 $25 = HEAP32[$this>>2]|0;
 $26 = (($25) + 32|0);
 $27 = +HEAPF32[$26>>2];
 $28 = (($contact) + 12|0);
 $29 = +HEAPF32[$28>>2];
 $30 = 1.0 - $29;
 $31 = $27 * $30;
 __ZN6b2Vec2mLEf($n,$31);
 $32 = HEAP32[$contact>>2]|0;
 $33 = HEAP32[$this>>2]|0;
 $34 = (($33) + 96|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = (($35) + ($32<<3)|0);
 __ZplRK6b2Vec2S1_($pos,$36,$n);
 $37 = (($contact) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = (__ZNK9b2Fixture9TestPointERK6b2Vec2($38,$pos)|0);
 if ($39) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $40 = HEAP32[$37>>2]|0;
 $41 = (__ZN9b2Fixture8GetShapeEv($40)|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($42) + 12|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (FUNCTION_TABLE_ii[$44 & 15]($41)|0);
 $46 = ($45|0)>(0);
 L11: do {
  if ($46) {
   $childIndex$01 = 0;
   while(1) {
    $49 = HEAP32[$37>>2]|0;
    __ZNK9b2Fixture15ComputeDistanceERK6b2Vec2PfPS0_i($49,$pos,$distance,$normal,$childIndex$01);
    $50 = +HEAPF32[$distance>>2];
    $51 = $50 < 0.004999999888241291;
    $47 = (($childIndex$01) + 1)|0;
    if ($51) {
     $$0 = 0;
     break;
    }
    $48 = ($47|0)<($45|0);
    if ($48) {
     $childIndex$01 = $47;
    } else {
     break L11;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $52 = (($this) + 12|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = HEAP32[$53>>2]|0;
 $55 = (($54) + 1)|0;
 HEAP32[$53>>2] = $55;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function __ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($this,$particleIndexA,$particleIndexB) {
 $this = $this|0;
 $particleIndexA = $particleIndexA|0;
 $particleIndexB = $particleIndexB|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0, $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 $1 = (($0) + ($particleIndexA<<2)|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + ($particleIndexB<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (+($2|0));
 $6 = $5 <= 0.0;
 $7 = (+($4|0));
 $8 = $7 <= 0.0;
 $tmp = $6 ^ $8;
 $9 = ($2|0)>($4|0);
 $$ = $tmp ? $6 : $9;
 STACKTOP = sp;return ($$|0);
}
function __ZNSt3__17__sort3IRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEjT0_S5_S5_T_($__x,$__y,$__z,$__c) {
 $__x = $__x|0;
 $__y = $__y|0;
 $__z = $__z|0;
 $__c = $__c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__y>>2]|0;
 $1 = HEAP32[$__x>>2]|0;
 $2 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__c,$0,$1)|0);
 $3 = HEAP32[$__z>>2]|0;
 $4 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__c,$3,$0)|0);
 do {
  if ($2) {
   if ($4) {
    HEAP32[$__x>>2] = $3;
    HEAP32[$__z>>2] = $1;
    $$0 = 1;
    break;
   }
   HEAP32[$__x>>2] = $0;
   HEAP32[$__y>>2] = $1;
   $8 = HEAP32[$__z>>2]|0;
   $9 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__c,$8,$1)|0);
   if ($9) {
    HEAP32[$__y>>2] = $8;
    HEAP32[$__z>>2] = $1;
    $$0 = 2;
   } else {
    $$0 = 1;
   }
  } else {
   if ($4) {
    HEAP32[$__y>>2] = $3;
    HEAP32[$__z>>2] = $0;
    $5 = HEAP32[$__y>>2]|0;
    $6 = HEAP32[$__x>>2]|0;
    $7 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__c,$5,$6)|0);
    if ($7) {
     HEAP32[$__x>>2] = $5;
     HEAP32[$__y>>2] = $6;
     $$0 = 2;
    } else {
     $$0 = 1;
    }
   } else {
    $$0 = 0;
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__17__sort4IRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEjT0_S5_S5_S5_T_($__x1,$__x2,$__x3,$__x4,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__17__sort3IRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEjT0_S5_S5_T_($__x1,$__x2,$__x3,$__c)|0);
 $1 = HEAP32[$__x4>>2]|0;
 $2 = HEAP32[$__x3>>2]|0;
 $3 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__c,$1,$2)|0);
 if (!($3)) {
  $__r$0 = $0;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x3>>2] = $1;
 HEAP32[$__x4>>2] = $2;
 $4 = (($0) + 1)|0;
 $5 = HEAP32[$__x3>>2]|0;
 $6 = HEAP32[$__x2>>2]|0;
 $7 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__c,$5,$6)|0);
 if (!($7)) {
  $__r$0 = $4;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x2>>2] = $5;
 HEAP32[$__x3>>2] = $6;
 $8 = (($0) + 2)|0;
 $9 = HEAP32[$__x2>>2]|0;
 $10 = HEAP32[$__x1>>2]|0;
 $11 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__c,$9,$10)|0);
 if (!($11)) {
  $__r$0 = $8;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x1>>2] = $9;
 HEAP32[$__x2>>2] = $10;
 $12 = (($0) + 3)|0;
 $__r$0 = $12;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__17__sort5IRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEjT0_S5_S5_S5_S5_T_($__x1,$__x2,$__x3,$__x4,$__x5,$__c) {
 $__x1 = $__x1|0;
 $__x2 = $__x2|0;
 $__x3 = $__x3|0;
 $__x4 = $__x4|0;
 $__x5 = $__x5|0;
 $__c = $__c|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__r$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNSt3__17__sort4IRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEjT0_S5_S5_S5_T_($__x1,$__x2,$__x3,$__x4,$__c)|0);
 $1 = HEAP32[$__x5>>2]|0;
 $2 = HEAP32[$__x4>>2]|0;
 $3 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__c,$1,$2)|0);
 if (!($3)) {
  $__r$0 = $0;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x4>>2] = $1;
 HEAP32[$__x5>>2] = $2;
 $4 = (($0) + 1)|0;
 $5 = HEAP32[$__x4>>2]|0;
 $6 = HEAP32[$__x3>>2]|0;
 $7 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__c,$5,$6)|0);
 if (!($7)) {
  $__r$0 = $4;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x3>>2] = $5;
 HEAP32[$__x4>>2] = $6;
 $8 = (($0) + 2)|0;
 $9 = HEAP32[$__x3>>2]|0;
 $10 = HEAP32[$__x2>>2]|0;
 $11 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__c,$9,$10)|0);
 if (!($11)) {
  $__r$0 = $8;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x2>>2] = $9;
 HEAP32[$__x3>>2] = $10;
 $12 = (($0) + 3)|0;
 $13 = HEAP32[$__x2>>2]|0;
 $14 = HEAP32[$__x1>>2]|0;
 $15 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__c,$13,$14)|0);
 if (!($15)) {
  $__r$0 = $12;
  STACKTOP = sp;return ($__r$0|0);
 }
 HEAP32[$__x1>>2] = $13;
 HEAP32[$__x2>>2] = $14;
 $16 = (($0) + 4)|0;
 $__r$0 = $16;
 STACKTOP = sp;return ($__r$0|0);
}
function __ZNSt3__118__insertion_sort_3IRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEvT0_S5_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$02 = 0, $__j$01 = 0, $__j$01$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($__first) + 8|0);
 $1 = (($__first) + 4|0);
 (__ZNSt3__17__sort3IRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEjT0_S5_S5_T_($__first,$1,$0,$__comp)|0);
 $2 = (($__first) + 12|0);
 $3 = ($2|0)==($__last|0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $__i$02 = $2;$__j$01 = $0;
 }
 while(1) {
  $4 = HEAP32[$__i$02>>2]|0;
  $5 = HEAP32[$__j$01>>2]|0;
  $6 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__comp,$4,$5)|0);
  if ($6) {
   $__j$1 = $__i$02;$__k$0 = $__j$01;
   while(1) {
    $7 = HEAP32[$__k$0>>2]|0;
    HEAP32[$__j$1>>2] = $7;
    $8 = ($__k$0|0)==($__first|0);
    if ($8) {
     break;
    }
    $9 = (($__k$0) + -4|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__comp,$4,$10)|0);
    if ($11) {
     $__j$1$phi = $__k$0;$__k$0 = $9;$__j$1 = $__j$1$phi;
    } else {
     break;
    }
   }
   HEAP32[$__k$0>>2] = $4;
  }
  $12 = (($__i$02) + 4|0);
  $13 = ($12|0)==($__last|0);
  if ($13) {
   break;
  } else {
   $__j$01$phi = $__i$02;$__i$02 = $12;$__j$01 = $__j$01$phi;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__127__insertion_sort_incompleteIRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEbT0_S5_T_($__first,$__last,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__count$03 = 0, $__count$1 = 0, $__i$04 = 0, $__j$02 = 0;
 var $__j$02$phi = 0, $__j$1 = 0, $__j$1$phi = 0, $__k$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 2;
 switch ($3|0) {
 case 3:  {
  $8 = (($__first) + 4|0);
  $9 = (($__last) + -4|0);
  (__ZNSt3__17__sort3IRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEjT0_S5_S5_T_($__first,$8,$9,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 5:  {
  $13 = (($__first) + 4|0);
  $14 = (($__first) + 8|0);
  $15 = (($__first) + 12|0);
  $16 = (($__last) + -4|0);
  (__ZNSt3__17__sort5IRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEjT0_S5_S5_S5_S5_T_($__first,$13,$14,$15,$16,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 4:  {
  $10 = (($__first) + 4|0);
  $11 = (($__first) + 8|0);
  $12 = (($__last) + -4|0);
  (__ZNSt3__17__sort4IRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEjT0_S5_S5_S5_T_($__first,$10,$11,$12,$__comp)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $4 = (($__last) + -4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = HEAP32[$__first>>2]|0;
  $7 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__comp,$5,$6)|0);
  if (!($7)) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  HEAP32[$__first>>2] = $5;
  HEAP32[$4>>2] = $6;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1: case 0:  {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $17 = (($__first) + 8|0);
  $18 = (($__first) + 4|0);
  (__ZNSt3__17__sort3IRN12_GLOBAL__N_124ExpirationTimeComparatorEPiEEjT0_S5_S5_T_($__first,$18,$17,$__comp)|0);
  $19 = (($__first) + 12|0);
  $20 = ($19|0)==($__last|0);
  if ($20) {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $__count$03 = 0;$__i$04 = $19;$__j$02 = $17;
  }
  while(1) {
   $21 = HEAP32[$__i$04>>2]|0;
   $22 = HEAP32[$__j$02>>2]|0;
   $23 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__comp,$21,$22)|0);
   if ($23) {
    $__j$1 = $__i$04;$__k$0 = $__j$02;
    while(1) {
     $24 = HEAP32[$__k$0>>2]|0;
     HEAP32[$__j$1>>2] = $24;
     $25 = ($__k$0|0)==($__first|0);
     if ($25) {
      break;
     }
     $26 = (($__k$0) + -4|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = (__ZNK12_GLOBAL__N_124ExpirationTimeComparatorclEii($__comp,$21,$27)|0);
     if ($28) {
      $__j$1$phi = $__k$0;$__k$0 = $26;$__j$1 = $__j$1$phi;
     } else {
      break;
     }
    }
    HEAP32[$__k$0>>2] = $21;
    $29 = (($__count$03) + 1)|0;
    $30 = ($29|0)==(8);
    if ($30) {
     break;
    } else {
     $__count$1 = $29;
    }
   } else {
    $__count$1 = $__count$03;
   }
   $33 = (($__i$04) + 4|0);
   $34 = ($33|0)==($__last|0);
   if ($34) {
    $$0 = 1;
    label = 14;
    break;
   } else {
    $__j$02$phi = $__i$04;$__count$03 = $__count$1;$__i$04 = $33;$__j$02 = $__j$02$phi;
   }
  }
  if ((label|0) == 14) {
   STACKTOP = sp;return ($$0|0);
  }
  $31 = (($__i$04) + 4|0);
  $32 = ($31|0)==($__last|0);
  $$0 = $32;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return (0)|0;
}
function __Z5b2MulRK5b2RotS1_($agg$result,$q,$r) {
 $agg$result = $agg$result|0;
 $q = $q|0;
 $r = $r|0;
 var $0 = 0.0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0, $2 = 0.0, $3 = 0.0, $4 = 0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$q>>2];
 $1 = (($r) + 4|0);
 $2 = +HEAPF32[$1>>2];
 $3 = $0 * $2;
 $4 = (($q) + 4|0);
 $5 = +HEAPF32[$4>>2];
 $6 = +HEAPF32[$r>>2];
 $7 = $5 * $6;
 $8 = $3 + $7;
 HEAPF32[$agg$result>>2] = $8;
 $9 = +HEAPF32[$4>>2];
 $10 = +HEAPF32[$1>>2];
 $11 = $9 * $10;
 $12 = +HEAPF32[$q>>2];
 $13 = +HEAPF32[$r>>2];
 $14 = $12 * $13;
 $15 = $11 - $14;
 $16 = (($agg$result) + 4|0);
 HEAPF32[$16>>2] = $15;
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferI21b2ParticleBodyContactE4GrowEv($this) {
 $this = $this|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 $3 = $1 << 1;
 $$ = $2 ? 256 : $3;
 __ZN16b2GrowableBufferI21b2ParticleBodyContactE7ReserveEi($this,$$);
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferI15b2ParticleTriadE4GrowEv($this) {
 $this = $this|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 $3 = $1 << 1;
 $$ = $2 ? 256 : $3;
 __ZN16b2GrowableBufferI15b2ParticleTriadE7ReserveEi($this,$$);
 STACKTOP = sp;return;
}
function __ZN24b2TypedIntrusiveListNodeI14b2TrackedBlockEC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN19b2IntrusiveListNodeC2Ev($this);
 STACKTOP = sp;return;
}
function __ZN10b2FreeListC2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN19b2IntrusiveListNodeC2Ev($this);
 $0 = (($this) + 8|0);
 __ZN19b2IntrusiveListNodeC2Ev($0);
 STACKTOP = sp;return;
}
function __ZN24b2TypedIntrusiveListNodeI14b2TrackedBlockED2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN19b2IntrusiveListNodeD2Ev($this);
 STACKTOP = sp;return;
}
function __ZNK23b2TrackedBlockAllocator7GetListEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($this|0);
}
function __ZNK24b2TypedIntrusiveListNodeI14b2TrackedBlockE7IsEmptyEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK24b2TypedIntrusiveListNodeI14b2TrackedBlockE11GetListNodeEv($this)|0);
 $1 = (__ZNK19b2IntrusiveListNode7IsEmptyEv($0)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZNK24b2TypedIntrusiveListNodeI14b2TrackedBlockE7GetNextEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK24b2TypedIntrusiveListNodeI14b2TrackedBlockE11GetListNodeEv($this)|0);
 $1 = (__ZNK19b2IntrusiveListNode7GetNextEv($0)|0);
 $2 = (__ZN24b2TypedIntrusiveListNodeI14b2TrackedBlockE23GetInstanceFromListNodeEP19b2IntrusiveListNode($1)|0);
 STACKTOP = sp;return ($2|0);
}
function __ZN15b2SlabAllocatorI16b2ParticleHandleE12BlockGetSlabEPv($this,$memory) {
 $this = $this|0;
 $memory = $memory|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($memory|0);
}
function __ZN15b2SlabAllocatorI16b2ParticleHandleE8FreeSlabEPNS1_4SlabE($this,$slab) {
 $this = $this|0;
 $slab = $slab|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $exitcond = 0, $i$02 = 0, $item$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK15b2SlabAllocatorI16b2ParticleHandleE4Slab16GetNumberOfItemsEv($slab)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  __ZN23b2TrackedBlockAllocator4FreeEPv($this,$slab);
  STACKTOP = sp;return;
 }
 $2 = (__ZNK15b2SlabAllocatorI16b2ParticleHandleE4Slab12GetFirstItemEv($slab)|0);
 $i$02 = 0;$item$01 = $2;
 while(1) {
  __ZN24b2TypedIntrusiveListNodeI16b2ParticleHandleED2Ev($item$01);
  $3 = (($i$02) + 1)|0;
  $4 = (($item$01) + 12|0);
  $exitcond = ($3|0)==($0|0);
  if ($exitcond) {
   break;
  } else {
   $i$02 = $3;$item$01 = $4;
  }
 }
 __ZN23b2TrackedBlockAllocator4FreeEPv($this,$slab);
 STACKTOP = sp;return;
}
function __ZN10b2FreeListD2Ev($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 __ZN19b2IntrusiveListNodeD2Ev($0);
 __ZN19b2IntrusiveListNodeD2Ev($this);
 STACKTOP = sp;return;
}
function __ZN16b2ParticleSystem16ReallocateBufferIP16b2ParticleHandleEEPT_S4_ii($this,$oldBuffer,$oldCapacity,$newCapacity) {
 $this = $this|0;
 $oldBuffer = $oldBuffer|0;
 $oldCapacity = $oldCapacity|0;
 $newCapacity = $newCapacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 400|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $newCapacity << 2;
 $3 = (__ZN16b2BlockAllocator8AllocateEi($1,$2)|0);
 $4 = ($oldBuffer|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return ($3|0);
 }
 $5 = $oldCapacity << 2;
 _memcpy(($3|0),($oldBuffer|0),($5|0))|0;
 $6 = HEAP32[$0>>2]|0;
 __ZN16b2BlockAllocator4FreeEPvi($6,$oldBuffer,$5);
 STACKTOP = sp;return ($3|0);
}
function __ZN16b2ParticleSystem16ReallocateBufferIjEEPT_S2_ii($this,$oldBuffer,$oldCapacity,$newCapacity) {
 $this = $this|0;
 $oldBuffer = $oldBuffer|0;
 $oldCapacity = $oldCapacity|0;
 $newCapacity = $newCapacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 400|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $newCapacity << 2;
 $3 = (__ZN16b2BlockAllocator8AllocateEi($1,$2)|0);
 $4 = ($oldBuffer|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return ($3|0);
 }
 $5 = $oldCapacity << 2;
 _memcpy(($3|0),($oldBuffer|0),($5|0))|0;
 $6 = HEAP32[$0>>2]|0;
 __ZN16b2BlockAllocator4FreeEPvi($6,$oldBuffer,$5);
 STACKTOP = sp;return ($3|0);
}
function __ZN16b2ParticleSystem16ReallocateBufferIiEEPT_S2_ii($this,$oldBuffer,$oldCapacity,$newCapacity) {
 $this = $this|0;
 $oldBuffer = $oldBuffer|0;
 $oldCapacity = $oldCapacity|0;
 $newCapacity = $newCapacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 400|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $newCapacity << 2;
 $3 = (__ZN16b2BlockAllocator8AllocateEi($1,$2)|0);
 $4 = ($oldBuffer|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return ($3|0);
 }
 $5 = $oldCapacity << 2;
 _memcpy(($3|0),($oldBuffer|0),($5|0))|0;
 $6 = HEAP32[$0>>2]|0;
 __ZN16b2BlockAllocator4FreeEPvi($6,$oldBuffer,$5);
 STACKTOP = sp;return ($3|0);
}
function __ZN16b2ParticleSystem16ReallocateBufferI15b2ParticleColorEEPT_S3_ii($this,$oldBuffer,$oldCapacity,$newCapacity) {
 $this = $this|0;
 $oldBuffer = $oldBuffer|0;
 $oldCapacity = $oldCapacity|0;
 $newCapacity = $newCapacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 400|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $newCapacity << 2;
 $3 = (__ZN16b2BlockAllocator8AllocateEi($1,$2)|0);
 $4 = ($oldBuffer|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return ($3|0);
 }
 $5 = $oldCapacity << 2;
 _memcpy(($3|0),($oldBuffer|0),($5|0))|0;
 $6 = HEAP32[$0>>2]|0;
 __ZN16b2BlockAllocator4FreeEPvi($6,$oldBuffer,$5);
 STACKTOP = sp;return ($3|0);
}
function __ZN16b2ParticleSystem16ReallocateBufferIPvEEPT_S3_ii($this,$oldBuffer,$oldCapacity,$newCapacity) {
 $this = $this|0;
 $oldBuffer = $oldBuffer|0;
 $oldCapacity = $oldCapacity|0;
 $newCapacity = $newCapacity|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 400|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $newCapacity << 2;
 $3 = (__ZN16b2BlockAllocator8AllocateEi($1,$2)|0);
 $4 = ($oldBuffer|0)==(0|0);
 if ($4) {
  STACKTOP = sp;return ($3|0);
 }
 $5 = $oldCapacity << 2;
 _memcpy(($3|0),($oldBuffer|0),($5|0))|0;
 $6 = HEAP32[$0>>2]|0;
 __ZN16b2BlockAllocator4FreeEPvi($6,$oldBuffer,$5);
 STACKTOP = sp;return ($3|0);
}
function __ZN16b2GrowableBufferIN16b2ParticleSystem5ProxyEE7ReserveEi($this,$newCapacity) {
 $this = $this|0;
 $newCapacity = $newCapacity|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)<($newCapacity|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $newCapacity << 3;
 $6 = (__ZN16b2BlockAllocator8AllocateEi($4,$5)|0);
 $7 = HEAP32[$this>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = (($this) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 << 3;
  _memcpy(($6|0),($7|0),($11|0))|0;
  $12 = HEAP32[$3>>2]|0;
  $13 = HEAP32[$this>>2]|0;
  $14 = HEAP32[$0>>2]|0;
  $15 = $14 << 3;
  __ZN16b2BlockAllocator4FreeEPvi($12,$13,$15);
 }
 HEAP32[$0>>2] = $newCapacity;
 HEAP32[$this>>2] = $6;
 STACKTOP = sp;return;
}
function __ZN24b2TypedIntrusiveListNodeI16b2ParticleHandleE11GetListNodeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($this|0);
}
function __ZNK19b2IntrusiveListNode7GetNextEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZNK15b2SlabAllocatorI16b2ParticleHandleE4Slab12GetFirstItemEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 32|0);
 STACKTOP = sp;return ($0|0);
}
function __ZN12_GLOBAL__N_117FixedSetAllocatorC2EP16b2StackAllocator($this,$allocator) {
 $this = $this|0;
 $allocator = $allocator|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$this>>2] = 0;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 12|0);
 HEAP32[$2>>2] = $allocator;
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferI14b2ParticlePairE7ReserveEi($this,$newCapacity) {
 $this = $this|0;
 $newCapacity = $newCapacity|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)<($newCapacity|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($newCapacity*20)|0;
 $6 = (__ZN16b2BlockAllocator8AllocateEi($4,$5)|0);
 $7 = HEAP32[$this>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = (($this) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10*20)|0;
  _memcpy(($6|0),($7|0),($11|0))|0;
  $12 = HEAP32[$3>>2]|0;
  $13 = HEAP32[$this>>2]|0;
  $14 = HEAP32[$0>>2]|0;
  $15 = ($14*20)|0;
  __ZN16b2BlockAllocator4FreeEPvi($12,$13,$15);
 }
 HEAP32[$0>>2] = $newCapacity;
 HEAP32[$this>>2] = $6;
 STACKTOP = sp;return;
}
function __ZNSt3__121__insertion_sort_moveIRPFbRK14b2ParticlePairS3_EPS1_EEvT0_S8_PNS_15iterator_traitsIS8_E10value_typeET_($__first1,$__last1,$__first2,$__comp) {
 $__first1 = $__first1|0;
 $__last1 = $__last1|0;
 $__first2 = $__first2|0;
 $__comp = $__comp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__first2$pn$ph = 0, $__first2$pn$ph$pn = 0, $__i2$02 = 0, $__j2$0$lcssa = 0, $__last2$06 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ($__first1|0)==($__last1|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = ($__first2|0)==(0|0);
 if ($1) {
  $__first2$pn$ph = 0;
 } else {
  ;HEAP32[$__first2+0>>2]=HEAP32[$__first1+0>>2]|0;HEAP32[$__first2+4>>2]=HEAP32[$__first1+4>>2]|0;HEAP32[$__first2+8>>2]=HEAP32[$__first1+8>>2]|0;HEAP32[$__first2+12>>2]=HEAP32[$__first1+12>>2]|0;HEAP32[$__first2+16>>2]=HEAP32[$__first1+16>>2]|0;
  $__first2$pn$ph = $__first2;
 }
 $2 = (($__first1) + 20|0);
 $3 = ($2|0)==($__last1|0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $5 = $2;$__first2$pn$ph$pn = $__first2$pn$ph;
 }
 while(1) {
  $__last2$06 = (($__first2$pn$ph$pn) + 20|0);
  $4 = HEAP32[$__comp>>2]|0;
  $6 = (FUNCTION_TABLE_iii[$4 & 63]($5,$__first2$pn$ph$pn)|0);
  if ($6) {
   ;HEAP32[$__last2$06+0>>2]=HEAP32[$__first2$pn$ph$pn+0>>2]|0;HEAP32[$__last2$06+4>>2]=HEAP32[$__first2$pn$ph$pn+4>>2]|0;HEAP32[$__last2$06+8>>2]=HEAP32[$__first2$pn$ph$pn+8>>2]|0;HEAP32[$__last2$06+12>>2]=HEAP32[$__first2$pn$ph$pn+12>>2]|0;HEAP32[$__last2$06+16>>2]=HEAP32[$__first2$pn$ph$pn+16>>2]|0;
   $7 = ($__first2$pn$ph$pn|0)==($__first2|0);
   L13: do {
    if ($7) {
     $__j2$0$lcssa = $__first2$pn$ph$pn;
    } else {
     $__i2$02 = $__first2$pn$ph$pn;
     while(1) {
      $8 = HEAP32[$__comp>>2]|0;
      $9 = (($__i2$02) + -20|0);
      $10 = (FUNCTION_TABLE_iii[$8 & 63]($5,$9)|0);
      if (!($10)) {
       $__j2$0$lcssa = $__i2$02;
       break L13;
      }
      ;HEAP32[$__i2$02+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$__i2$02+4>>2]=HEAP32[$9+4>>2]|0;HEAP32[$__i2$02+8>>2]=HEAP32[$9+8>>2]|0;HEAP32[$__i2$02+12>>2]=HEAP32[$9+12>>2]|0;HEAP32[$__i2$02+16>>2]=HEAP32[$9+16>>2]|0;
      $11 = ($9|0)==($__first2|0);
      if ($11) {
       $__j2$0$lcssa = $9;
       break;
      } else {
       $__i2$02 = $9;
      }
     }
    }
   } while(0);
   ;HEAP32[$__j2$0$lcssa+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$__j2$0$lcssa+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$__j2$0$lcssa+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$__j2$0$lcssa+12>>2]=HEAP32[$5+12>>2]|0;HEAP32[$__j2$0$lcssa+16>>2]=HEAP32[$5+16>>2]|0;
  } else {
   ;HEAP32[$__last2$06+0>>2]=HEAP32[$5+0>>2]|0;HEAP32[$__last2$06+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$__last2$06+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$__last2$06+12>>2]=HEAP32[$5+12>>2]|0;HEAP32[$__last2$06+16>>2]=HEAP32[$5+16>>2]|0;
  }
  $12 = (($5) + 20|0);
  $13 = ($12|0)==($__last1|0);
  if ($13) {
   break;
  } else {
   $5 = $12;$__first2$pn$ph$pn = $__last2$06;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__122__merge_move_constructIRPFbRK14b2ParticlePairS3_EPS1_S7_EEvT0_S8_T1_S9_PNS_15iterator_traitsIS8_E10value_typeET_($__first1,$__last1,$__first2,$__last2,$__result,$__comp) {
 $__first1 = $__first1|0;
 $__last1 = $__last1|0;
 $__first2 = $__first2|0;
 $__last2 = $__last2|0;
 $__result = $__result|0;
 $__comp = $__comp|0;
 var $$01$lcssa = 0, $$0118 = 0, $$019 = 0, $$04$lcssa = 0, $$0417 = 0, $$112 = 0, $$128 = 0, $$157 = 0, $$2 = 0, $$23 = 0, $$2611 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($__first1|0)==($__last1|0);
 L1: do {
  if ($0) {
   $$01$lcssa = $__first2;$$04$lcssa = $__result;
  } else {
   $$0118 = $__first2;$$019 = $__first1;$$0417 = $__result;
   while(1) {
    $6 = ($$0118|0)==($__last2|0);
    if ($6) {
     break;
    }
    $12 = HEAP32[$__comp>>2]|0;
    $13 = (FUNCTION_TABLE_iii[$12 & 63]($$0118,$$019)|0);
    $14 = ($$0417|0)==(0|0);
    if ($13) {
     if (!($14)) {
      ;HEAP32[$$0417+0>>2]=HEAP32[$$0118+0>>2]|0;HEAP32[$$0417+4>>2]=HEAP32[$$0118+4>>2]|0;HEAP32[$$0417+8>>2]=HEAP32[$$0118+8>>2]|0;HEAP32[$$0417+12>>2]=HEAP32[$$0118+12>>2]|0;HEAP32[$$0417+16>>2]=HEAP32[$$0118+16>>2]|0;
     }
     $15 = (($$0118) + 20|0);
     $$2 = $$019;$$23 = $15;
    } else {
     if (!($14)) {
      ;HEAP32[$$0417+0>>2]=HEAP32[$$019+0>>2]|0;HEAP32[$$0417+4>>2]=HEAP32[$$019+4>>2]|0;HEAP32[$$0417+8>>2]=HEAP32[$$019+8>>2]|0;HEAP32[$$0417+12>>2]=HEAP32[$$019+12>>2]|0;HEAP32[$$0417+16>>2]=HEAP32[$$019+16>>2]|0;
     }
     $16 = (($$019) + 20|0);
     $$2 = $16;$$23 = $$0118;
    }
    $17 = (($$0417) + 20|0);
    $18 = ($$2|0)==($__last1|0);
    if ($18) {
     $$01$lcssa = $$23;$$04$lcssa = $17;
     break L1;
    } else {
     $$0118 = $$23;$$019 = $$2;$$0417 = $17;
    }
   }
   $7 = ($$019|0)==($__last1|0);
   if ($7) {
    STACKTOP = sp;return;
   } else {
    $$112 = $$019;$$2611 = $$0417;
   }
   while(1) {
    $8 = ($$2611|0)==(0|0);
    if (!($8)) {
     ;HEAP32[$$2611+0>>2]=HEAP32[$$112+0>>2]|0;HEAP32[$$2611+4>>2]=HEAP32[$$112+4>>2]|0;HEAP32[$$2611+8>>2]=HEAP32[$$112+8>>2]|0;HEAP32[$$2611+12>>2]=HEAP32[$$112+12>>2]|0;HEAP32[$$2611+16>>2]=HEAP32[$$112+16>>2]|0;
    }
    $9 = (($$112) + 20|0);
    $10 = (($$2611) + 20|0);
    $11 = ($9|0)==($__last1|0);
    if ($11) {
     break;
    } else {
     $$112 = $9;$$2611 = $10;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $1 = ($$01$lcssa|0)==($__last2|0);
 if ($1) {
  STACKTOP = sp;return;
 } else {
  $$128 = $$01$lcssa;$$157 = $$04$lcssa;
 }
 while(1) {
  $2 = ($$157|0)==(0|0);
  if (!($2)) {
   ;HEAP32[$$157+0>>2]=HEAP32[$$128+0>>2]|0;HEAP32[$$157+4>>2]=HEAP32[$$128+4>>2]|0;HEAP32[$$157+8>>2]=HEAP32[$$128+8>>2]|0;HEAP32[$$157+12>>2]=HEAP32[$$128+12>>2]|0;HEAP32[$$157+16>>2]=HEAP32[$$128+16>>2]|0;
  }
  $3 = (($$128) + 20|0);
  $4 = (($$157) + 20|0);
  $5 = ($3|0)==($__last2|0);
  if ($5) {
   break;
  } else {
   $$128 = $3;$$157 = $4;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__124__buffered_inplace_mergeIRPFbRK14b2ParticlePairS3_EPS1_EEvT0_S8_S8_T_NS_15iterator_traitsIS8_E15difference_typeESC_PNSB_10value_typeE($__first,$__middle,$__last,$__comp,$__len1,$__len2,$__buff) {
 $__first = $__first|0;
 $__middle = $__middle|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 $__len1 = $__len1|0;
 $__len2 = $__len2|0;
 $__buff = $__buff|0;
 var $$byval_copy4 = 0, $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$028 = 0, $__i2$026 = 0, $__p$0$lcssa = 0, $__p$029 = 0, $__p1$0$lcssa = 0, $__p1$025 = 0, $scevgep = 0;
 var $scevgep35 = 0, $scevgep36 = 0, $scevgep40 = 0, $tmpcast$byval_copy = 0, $tmpcast22$byval_copy = 0, $tmpcast23$byval_copy = 0, $tmpcast24$byval_copy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy5 = sp + 112|0;
 $$byval_copy4 = sp + 104|0;
 $tmpcast24$byval_copy = sp + 96|0;
 $tmpcast23$byval_copy = sp + 88|0;
 $tmpcast22$byval_copy = sp + 80|0;
 $tmpcast$byval_copy = sp + 72|0;
 $0 = $__first;
 $1 = $__middle;
 $2 = sp + 68|0;
 $3 = sp + 64|0;
 $4 = sp + 60|0;
 $5 = sp + 56|0;
 $6 = sp + 24|0;
 $7 = sp + 16|0;
 $8 = sp + 8|0;
 $9 = sp;
 $10 = sp + 48|0;
 $11 = sp + 40|0;
 $12 = sp + 32|0;
 $13 = ($__len1|0)>($__len2|0);
 if ($13) {
  $19 = ($__middle|0)==($__last|0);
  if ($19) {
   $__p1$0$lcssa = $__buff;
  } else {
   $scevgep = (($__last) + -20|0);
   $20 = $scevgep;
   $21 = (($20) - ($1))|0;
   $22 = (($21>>>0) / 20)&-1;
   $23 = (($22) + 1)|0;
   $__i2$026 = $__middle;$__p1$025 = $__buff;
   while(1) {
    $28 = ($__p1$025|0)==(0|0);
    if (!($28)) {
     ;HEAP32[$__p1$025+0>>2]=HEAP32[$__i2$026+0>>2]|0;HEAP32[$__p1$025+4>>2]=HEAP32[$__i2$026+4>>2]|0;HEAP32[$__p1$025+8>>2]=HEAP32[$__i2$026+8>>2]|0;HEAP32[$__p1$025+12>>2]=HEAP32[$__i2$026+12>>2]|0;HEAP32[$__p1$025+16>>2]=HEAP32[$__i2$026+16>>2]|0;
    }
    $29 = (($__i2$026) + 20|0);
    $30 = (($__p1$025) + 20|0);
    $31 = ($29|0)==($__last|0);
    if ($31) {
     break;
    } else {
     $__i2$026 = $29;$__p1$025 = $30;
    }
   }
   $scevgep35 = (($__buff) + (($23*20)|0)|0);
   $__p1$0$lcssa = $scevgep35;
  }
  $32 = $6;
  $33 = $32;
  HEAP32[$33>>2] = $1;
  $34 = (($32) + 4)|0;
  $35 = $34;
  HEAP32[$35>>2] = $1;
  $36 = $7;
  $37 = $36;
  HEAP32[$37>>2] = $0;
  $38 = (($36) + 4)|0;
  $39 = $38;
  HEAP32[$39>>2] = $0;
  $40 = $__p1$0$lcssa;
  $41 = $8;
  $42 = $41;
  HEAP32[$42>>2] = $40;
  $43 = (($41) + 4)|0;
  $44 = $43;
  HEAP32[$44>>2] = $40;
  $45 = $__buff;
  $46 = $9;
  $47 = $46;
  HEAP32[$47>>2] = $45;
  $48 = (($46) + 4)|0;
  $49 = $48;
  HEAP32[$49>>2] = $45;
  HEAP32[$10>>2] = $__last;
  $50 = (($10) + 4|0);
  HEAP32[$50>>2] = $__last;
  HEAP32[$11>>2] = $__comp;
  ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$6+4>>2]|0;
  ;HEAP32[$tmpcast22$byval_copy+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$tmpcast22$byval_copy+4>>2]=HEAP32[$7+4>>2]|0;
  ;HEAP32[$tmpcast23$byval_copy+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$tmpcast23$byval_copy+4>>2]=HEAP32[$8+4>>2]|0;
  ;HEAP32[$tmpcast24$byval_copy+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$tmpcast24$byval_copy+4>>2]=HEAP32[$9+4>>2]|0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$$byval_copy4+4>>2]=HEAP32[$10+4>>2]|0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$11+0>>2]|0;
  __ZNSt3__17__mergeINS_8__negateIRPFbRK14b2ParticlePairS4_EEENS_13move_iteratorINS_16reverse_iteratorIPS2_EEEESD_SC_EET2_T0_SF_T1_SG_SE_T_($12,$tmpcast$byval_copy,$tmpcast22$byval_copy,$tmpcast23$byval_copy,$tmpcast24$byval_copy,$$byval_copy4,$$byval_copy5);
  STACKTOP = sp;return;
 } else {
  $14 = ($__first|0)==($__middle|0);
  if ($14) {
   $__p$0$lcssa = $__buff;
  } else {
   $scevgep36 = (($__middle) + -20|0);
   $15 = $scevgep36;
   $16 = (($15) - ($0))|0;
   $17 = (($16>>>0) / 20)&-1;
   $18 = (($17) + 1)|0;
   $__i$028 = $__first;$__p$029 = $__buff;
   while(1) {
    $24 = ($__p$029|0)==(0|0);
    if (!($24)) {
     ;HEAP32[$__p$029+0>>2]=HEAP32[$__i$028+0>>2]|0;HEAP32[$__p$029+4>>2]=HEAP32[$__i$028+4>>2]|0;HEAP32[$__p$029+8>>2]=HEAP32[$__i$028+8>>2]|0;HEAP32[$__p$029+12>>2]=HEAP32[$__i$028+12>>2]|0;HEAP32[$__p$029+16>>2]=HEAP32[$__i$028+16>>2]|0;
    }
    $25 = (($__i$028) + 20|0);
    $26 = (($__p$029) + 20|0);
    $27 = ($25|0)==($__middle|0);
    if ($27) {
     break;
    } else {
     $__i$028 = $25;$__p$029 = $26;
    }
   }
   $scevgep40 = (($__buff) + (($18*20)|0)|0);
   $__p$0$lcssa = $scevgep40;
  }
  HEAP32[$2>>2] = $__buff;
  HEAP32[$3>>2] = $__p$0$lcssa;
  HEAP32[$4>>2] = $__middle;
  HEAP32[$5>>2] = $__last;
  ;HEAP32[$tmpcast23$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
  ;HEAP32[$tmpcast24$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$4+0>>2]|0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$5+0>>2]|0;
  (__ZNSt3__17__mergeIRPFbRK14b2ParticlePairS3_ENS_13move_iteratorIPS1_EES9_S8_EET2_T0_SB_T1_SC_SA_T_($tmpcast23$byval_copy,$tmpcast24$byval_copy,$$byval_copy4,$$byval_copy5,$__first,$__comp)|0);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__113__upper_boundIRPFbRK14b2ParticlePairS3_EPS1_S1_EET0_S8_S8_RKT1_T_($__first,$__last,$__value_,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__value_ = $__value_|0;
 $__comp = $__comp|0;
 var $$0$ph = 0, $$neg1 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0 = 0, $__len$0$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = (($2|0) / 20)&-1;
 $$0$ph = $__first;$__len$0$ph = $3;
 L1: while(1) {
  $__len$0 = $__len$0$ph;
  while(1) {
   $4 = ($__len$0|0)==(0);
   if ($4) {
    break L1;
   }
   $5 = (($__len$0|0) / 2)&-1;
   $6 = (($$0$ph) + (($5*20)|0)|0);
   $7 = HEAP32[$__comp>>2]|0;
   $8 = (FUNCTION_TABLE_iii[$7 & 63]($__value_,$6)|0);
   if ($8) {
    $__len$0 = $5;
   } else {
    break;
   }
  }
  $$sum = (($5) + 1)|0;
  $9 = (($$0$ph) + (($$sum*20)|0)|0);
  $$neg1 = (($__len$0) + -1)|0;
  $10 = (($$neg1) - ($5))|0;
  $$0$ph = $9;$__len$0$ph = $10;
 }
 STACKTOP = sp;return ($$0$ph|0);
}
function __ZNSt3__113__lower_boundIRPFbRK14b2ParticlePairS3_EPS1_S1_EET0_S8_S8_RKT1_T_($__first,$__last,$__value_,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__value_ = $__value_|0;
 $__comp = $__comp|0;
 var $$0$ph = 0, $$neg1 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0 = 0, $__len$0$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = (($2|0) / 20)&-1;
 $$0$ph = $__first;$__len$0$ph = $3;
 L1: while(1) {
  $__len$0 = $__len$0$ph;
  while(1) {
   $4 = ($__len$0|0)==(0);
   if ($4) {
    break L1;
   }
   $5 = (($__len$0|0) / 2)&-1;
   $6 = (($$0$ph) + (($5*20)|0)|0);
   $7 = HEAP32[$__comp>>2]|0;
   $8 = (FUNCTION_TABLE_iii[$7 & 63]($6,$__value_)|0);
   if ($8) {
    break;
   } else {
    $__len$0 = $5;
   }
  }
  $$sum = (($5) + 1)|0;
  $9 = (($$0$ph) + (($$sum*20)|0)|0);
  $$neg1 = (($__len$0) + -1)|0;
  $10 = (($$neg1) - ($5))|0;
  $$0$ph = $9;$__len$0$ph = $10;
 }
 STACKTOP = sp;return ($$0$ph|0);
}
function __ZNSt3__113__rotate_leftIP14b2ParticlePairEET_S3_S3_($__first,$__last) {
 $__first = $__first|0;
 $__last = $__last|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $__tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__tmp = sp;
 ;HEAP32[$__tmp+0>>2]=HEAP32[$__first+0>>2]|0;HEAP32[$__tmp+4>>2]=HEAP32[$__first+4>>2]|0;HEAP32[$__tmp+8>>2]=HEAP32[$__first+8>>2]|0;HEAP32[$__tmp+12>>2]=HEAP32[$__first+12>>2]|0;HEAP32[$__tmp+16>>2]=HEAP32[$__first+16>>2]|0;
 $0 = (($__first) + 20|0);
 $1 = $__last;
 $2 = $0;
 $3 = (($1) - ($2))|0;
 $4 = (($3|0) / 20)&-1;
 _memmove(($__first|0),($0|0),($3|0))|0;
 $5 = (($__first) + (($4*20)|0)|0);
 ;HEAP32[$5+0>>2]=HEAP32[$__tmp+0>>2]|0;HEAP32[$5+4>>2]=HEAP32[$__tmp+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$__tmp+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$__tmp+12>>2]|0;HEAP32[$5+16>>2]=HEAP32[$__tmp+16>>2]|0;
 STACKTOP = sp;return ($5|0);
}
function __ZNSt3__114__rotate_rightIP14b2ParticlePairEET_S3_S3_($__first,$__last) {
 $__first = $__first|0;
 $__last = $__last|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $__tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0;
 $__tmp = sp;
 $0 = (($__last) + -20|0);
 ;HEAP32[$__tmp+0>>2]=HEAP32[$0+0>>2]|0;HEAP32[$__tmp+4>>2]=HEAP32[$0+4>>2]|0;HEAP32[$__tmp+8>>2]=HEAP32[$0+8>>2]|0;HEAP32[$__tmp+12>>2]=HEAP32[$0+12>>2]|0;HEAP32[$__tmp+16>>2]=HEAP32[$0+16>>2]|0;
 $1 = $0;
 $2 = $__first;
 $3 = (($1) - ($2))|0;
 $4 = (($3|0) / -20)&-1;
 $5 = (($__last) + (($4*20)|0)|0);
 _memmove(($5|0),($__first|0),($3|0))|0;
 ;HEAP32[$__first+0>>2]=HEAP32[$__tmp+0>>2]|0;HEAP32[$__first+4>>2]=HEAP32[$__tmp+4>>2]|0;HEAP32[$__first+8>>2]=HEAP32[$__tmp+8>>2]|0;HEAP32[$__first+12>>2]=HEAP32[$__tmp+12>>2]|0;HEAP32[$__first+16>>2]=HEAP32[$__tmp+16>>2]|0;
 STACKTOP = sp;return ($5|0);
}
function __ZNSt3__112__rotate_gcdIP14b2ParticlePairEET_S3_S3_S3_($__first,$__middle,$__last) {
 $__first = $__first|0;
 $__middle = $__middle|0;
 $__last = $__last|0;
 var $$0 = 0, $$0$i = 0, $$0$i$phi = 0, $$01$i = 0, $$012$i = 0, $$03$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$01 = 0, $__p1$0 = 0, $__p1$0$phi = 0, $__p2$0 = 0, $__p2$1 = 0;
 var $__t = 0, $__t$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $__t$i$i = sp + 20|0;
 $__t = sp;
 $0 = $__middle;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = (($2|0) / 20)&-1;
 $4 = $__last;
 $5 = (($4) - ($0))|0;
 $6 = (($5|0) / 20)&-1;
 $7 = ($3|0)==($6|0);
 if ($7) {
  $8 = ($__first|0)==($__middle|0);
  if ($8) {
   $$0 = $__middle;
   STACKTOP = sp;return ($$0|0);
  }
  $$012$i = $__first;$$03$i = $__middle;
  while(1) {
   ;HEAP32[$__t$i$i+0>>2]=HEAP32[$$012$i+0>>2]|0;HEAP32[$__t$i$i+4>>2]=HEAP32[$$012$i+4>>2]|0;HEAP32[$__t$i$i+8>>2]=HEAP32[$$012$i+8>>2]|0;HEAP32[$__t$i$i+12>>2]=HEAP32[$$012$i+12>>2]|0;HEAP32[$__t$i$i+16>>2]=HEAP32[$$012$i+16>>2]|0;
   ;HEAP32[$$012$i+0>>2]=HEAP32[$$03$i+0>>2]|0;HEAP32[$$012$i+4>>2]=HEAP32[$$03$i+4>>2]|0;HEAP32[$$012$i+8>>2]=HEAP32[$$03$i+8>>2]|0;HEAP32[$$012$i+12>>2]=HEAP32[$$03$i+12>>2]|0;HEAP32[$$012$i+16>>2]=HEAP32[$$03$i+16>>2]|0;
   ;HEAP32[$$03$i+0>>2]=HEAP32[$__t$i$i+0>>2]|0;HEAP32[$$03$i+4>>2]=HEAP32[$__t$i$i+4>>2]|0;HEAP32[$$03$i+8>>2]=HEAP32[$__t$i$i+8>>2]|0;HEAP32[$$03$i+12>>2]=HEAP32[$__t$i$i+12>>2]|0;HEAP32[$$03$i+16>>2]=HEAP32[$__t$i$i+16>>2]|0;
   $9 = (($$012$i) + 20|0);
   $10 = (($$03$i) + 20|0);
   $11 = ($9|0)==($__middle|0);
   if ($11) {
    $$0 = $__middle;
    break;
   } else {
    $$012$i = $9;$$03$i = $10;
   }
  }
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0$i = $3;$$01$i = $6;
 }
 while(1) {
  $12 = (($$0$i|0) % ($$01$i|0))&-1;
  $13 = ($12|0)==(0);
  if ($13) {
   break;
  } else {
   $$0$i$phi = $$01$i;$$01$i = $12;$$0$i = $$0$i$phi;
  }
 }
 $14 = ($$01$i|0)==(0);
 if (!($14)) {
  $15 = (($__first) + (($$01$i*20)|0)|0);
  $$sum = (($3) + -1)|0;
  $__p$01 = $15;
  while(1) {
   $16 = (($__p$01) + -20|0);
   ;HEAP32[$__t+0>>2]=HEAP32[$16+0>>2]|0;HEAP32[$__t+4>>2]=HEAP32[$16+4>>2]|0;HEAP32[$__t+8>>2]=HEAP32[$16+8>>2]|0;HEAP32[$__t+12>>2]=HEAP32[$16+12>>2]|0;HEAP32[$__t+16>>2]=HEAP32[$16+16>>2]|0;
   $17 = (($__p$01) + (($$sum*20)|0)|0);
   $__p1$0 = $16;$__p2$0 = $17;
   while(1) {
    ;HEAP32[$__p1$0+0>>2]=HEAP32[$__p2$0+0>>2]|0;HEAP32[$__p1$0+4>>2]=HEAP32[$__p2$0+4>>2]|0;HEAP32[$__p1$0+8>>2]=HEAP32[$__p2$0+8>>2]|0;HEAP32[$__p1$0+12>>2]=HEAP32[$__p2$0+12>>2]|0;HEAP32[$__p1$0+16>>2]=HEAP32[$__p2$0+16>>2]|0;
    $18 = $__p2$0;
    $19 = (($4) - ($18))|0;
    $20 = (($19|0) / 20)&-1;
    $21 = ($3|0)<($20|0);
    if ($21) {
     $22 = (($__p2$0) + (($3*20)|0)|0);
     $__p2$1 = $22;
    } else {
     $23 = (($3) - ($20))|0;
     $24 = (($__first) + (($23*20)|0)|0);
     $__p2$1 = $24;
    }
    $25 = ($__p2$1|0)==($16|0);
    if ($25) {
     break;
    } else {
     $__p1$0$phi = $__p2$0;$__p2$0 = $__p2$1;$__p1$0 = $__p1$0$phi;
    }
   }
   ;HEAP32[$__p2$0+0>>2]=HEAP32[$__t+0>>2]|0;HEAP32[$__p2$0+4>>2]=HEAP32[$__t+4>>2]|0;HEAP32[$__p2$0+8>>2]=HEAP32[$__t+8>>2]|0;HEAP32[$__p2$0+12>>2]=HEAP32[$__t+12>>2]|0;HEAP32[$__p2$0+16>>2]=HEAP32[$__t+16>>2]|0;
   $26 = ($16|0)==($__first|0);
   if ($26) {
    break;
   } else {
    $__p$01 = $16;
   }
  }
 }
 $27 = (($__first) + (($6*20)|0)|0);
 $$0 = $27;
 STACKTOP = sp;return ($$0|0);
}
function __ZNSt3__121__insertion_sort_moveIRPFbRK15b2ParticleTriadS3_EPS1_EEvT0_S8_PNS_15iterator_traitsIS8_E10value_typeET_($__first1,$__last1,$__first2,$__comp) {
 $__first1 = $__first1|0;
 $__last1 = $__last1|0;
 $__first2 = $__first2|0;
 $__comp = $__comp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__first2$pn$ph = 0, $__first2$pn$ph$pn = 0, $__i2$02 = 0, $__j2$0$lcssa = 0, $__last2$06 = 0, dest = 0;
 var label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = ($__first1|0)==($__last1|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = ($__first2|0)==(0|0);
 if ($1) {
  $__first2$pn$ph = 0;
 } else {
  dest=$__first2+0|0; src=$__first1+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $__first2$pn$ph = $__first2;
 }
 $2 = (($__first1) + 60|0);
 $3 = ($2|0)==($__last1|0);
 if ($3) {
  STACKTOP = sp;return;
 } else {
  $5 = $2;$__first2$pn$ph$pn = $__first2$pn$ph;
 }
 while(1) {
  $__last2$06 = (($__first2$pn$ph$pn) + 60|0);
  $4 = HEAP32[$__comp>>2]|0;
  $6 = (FUNCTION_TABLE_iii[$4 & 63]($5,$__first2$pn$ph$pn)|0);
  if ($6) {
   dest=$__last2$06+0|0; src=$__first2$pn$ph$pn+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $7 = ($__first2$pn$ph$pn|0)==($__first2|0);
   L14: do {
    if ($7) {
     $__j2$0$lcssa = $__first2$pn$ph$pn;
    } else {
     $__i2$02 = $__first2$pn$ph$pn;
     while(1) {
      $8 = HEAP32[$__comp>>2]|0;
      $9 = (($__i2$02) + -60|0);
      $10 = (FUNCTION_TABLE_iii[$8 & 63]($5,$9)|0);
      if (!($10)) {
       $__j2$0$lcssa = $__i2$02;
       break L14;
      }
      dest=$__i2$02+0|0; src=$9+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
      $11 = ($9|0)==($__first2|0);
      if ($11) {
       $__j2$0$lcssa = $9;
       break;
      } else {
       $__i2$02 = $9;
      }
     }
    }
   } while(0);
   dest=$__j2$0$lcssa+0|0; src=$5+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  } else {
   dest=$__last2$06+0|0; src=$5+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  }
  $12 = (($5) + 60|0);
  $13 = ($12|0)==($__last1|0);
  if ($13) {
   break;
  } else {
   $5 = $12;$__first2$pn$ph$pn = $__last2$06;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__122__merge_move_constructIRPFbRK15b2ParticleTriadS3_EPS1_S7_EEvT0_S8_T1_S9_PNS_15iterator_traitsIS8_E10value_typeET_($__first1,$__last1,$__first2,$__last2,$__result,$__comp) {
 $__first1 = $__first1|0;
 $__last1 = $__last1|0;
 $__first2 = $__first2|0;
 $__last2 = $__last2|0;
 $__result = $__result|0;
 $__comp = $__comp|0;
 var $$01$lcssa = 0, $$0118 = 0, $$019 = 0, $$04$lcssa = 0, $$0417 = 0, $$112 = 0, $$128 = 0, $$157 = 0, $$2 = 0, $$23 = 0, $$2611 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = ($__first1|0)==($__last1|0);
 L1: do {
  if ($0) {
   $$01$lcssa = $__first2;$$04$lcssa = $__result;
  } else {
   $$0118 = $__first2;$$019 = $__first1;$$0417 = $__result;
   while(1) {
    $6 = ($$0118|0)==($__last2|0);
    if ($6) {
     break;
    }
    $12 = HEAP32[$__comp>>2]|0;
    $13 = (FUNCTION_TABLE_iii[$12 & 63]($$0118,$$019)|0);
    $14 = ($$0417|0)==(0|0);
    if ($13) {
     if (!($14)) {
      dest=$$0417+0|0; src=$$0118+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     }
     $15 = (($$0118) + 60|0);
     $$2 = $$019;$$23 = $15;
    } else {
     if (!($14)) {
      dest=$$0417+0|0; src=$$019+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     }
     $16 = (($$019) + 60|0);
     $$2 = $16;$$23 = $$0118;
    }
    $17 = (($$0417) + 60|0);
    $18 = ($$2|0)==($__last1|0);
    if ($18) {
     $$01$lcssa = $$23;$$04$lcssa = $17;
     break L1;
    } else {
     $$0118 = $$23;$$019 = $$2;$$0417 = $17;
    }
   }
   $7 = ($$019|0)==($__last1|0);
   if ($7) {
    STACKTOP = sp;return;
   } else {
    $$112 = $$019;$$2611 = $$0417;
   }
   while(1) {
    $8 = ($$2611|0)==(0|0);
    if (!($8)) {
     dest=$$2611+0|0; src=$$112+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    }
    $9 = (($$112) + 60|0);
    $10 = (($$2611) + 60|0);
    $11 = ($9|0)==($__last1|0);
    if ($11) {
     break;
    } else {
     $$112 = $9;$$2611 = $10;
    }
   }
   STACKTOP = sp;return;
  }
 } while(0);
 $1 = ($$01$lcssa|0)==($__last2|0);
 if ($1) {
  STACKTOP = sp;return;
 } else {
  $$128 = $$01$lcssa;$$157 = $$04$lcssa;
 }
 while(1) {
  $2 = ($$157|0)==(0|0);
  if (!($2)) {
   dest=$$157+0|0; src=$$128+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  }
  $3 = (($$128) + 60|0);
  $4 = (($$157) + 60|0);
  $5 = ($3|0)==($__last2|0);
  if ($5) {
   break;
  } else {
   $$128 = $3;$$157 = $4;
  }
 }
 STACKTOP = sp;return;
}
function __ZNSt3__124__buffered_inplace_mergeIRPFbRK15b2ParticleTriadS3_EPS1_EEvT0_S8_S8_T_NS_15iterator_traitsIS8_E15difference_typeESC_PNSB_10value_typeE($__first,$__middle,$__last,$__comp,$__len1,$__len2,$__buff) {
 $__first = $__first|0;
 $__middle = $__middle|0;
 $__last = $__last|0;
 $__comp = $__comp|0;
 $__len1 = $__len1|0;
 $__len2 = $__len2|0;
 $__buff = $__buff|0;
 var $$byval_copy4 = 0, $$byval_copy5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__i$028 = 0, $__i2$026 = 0, $__p$0$lcssa = 0, $__p$029 = 0, $__p1$0$lcssa = 0, $__p1$025 = 0, $scevgep = 0;
 var $scevgep35 = 0, $scevgep36 = 0, $scevgep40 = 0, $tmpcast$byval_copy = 0, $tmpcast22$byval_copy = 0, $tmpcast23$byval_copy = 0, $tmpcast24$byval_copy = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0;
 $$byval_copy5 = sp + 112|0;
 $$byval_copy4 = sp + 104|0;
 $tmpcast24$byval_copy = sp + 96|0;
 $tmpcast23$byval_copy = sp + 88|0;
 $tmpcast22$byval_copy = sp + 80|0;
 $tmpcast$byval_copy = sp + 72|0;
 $0 = $__first;
 $1 = $__middle;
 $2 = sp + 68|0;
 $3 = sp + 64|0;
 $4 = sp + 60|0;
 $5 = sp + 56|0;
 $6 = sp + 24|0;
 $7 = sp + 16|0;
 $8 = sp + 8|0;
 $9 = sp;
 $10 = sp + 48|0;
 $11 = sp + 40|0;
 $12 = sp + 32|0;
 $13 = ($__len1|0)>($__len2|0);
 if ($13) {
  $19 = ($__middle|0)==($__last|0);
  if ($19) {
   $__p1$0$lcssa = $__buff;
  } else {
   $scevgep = (($__last) + -60|0);
   $20 = $scevgep;
   $21 = (($20) - ($1))|0;
   $22 = (($21>>>0) / 60)&-1;
   $23 = (($22) + 1)|0;
   $__i2$026 = $__middle;$__p1$025 = $__buff;
   while(1) {
    $28 = ($__p1$025|0)==(0|0);
    if (!($28)) {
     dest=$__p1$025+0|0; src=$__i2$026+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    }
    $29 = (($__i2$026) + 60|0);
    $30 = (($__p1$025) + 60|0);
    $31 = ($29|0)==($__last|0);
    if ($31) {
     break;
    } else {
     $__i2$026 = $29;$__p1$025 = $30;
    }
   }
   $scevgep35 = (($__buff) + (($23*60)|0)|0);
   $__p1$0$lcssa = $scevgep35;
  }
  $32 = $6;
  $33 = $32;
  HEAP32[$33>>2] = $1;
  $34 = (($32) + 4)|0;
  $35 = $34;
  HEAP32[$35>>2] = $1;
  $36 = $7;
  $37 = $36;
  HEAP32[$37>>2] = $0;
  $38 = (($36) + 4)|0;
  $39 = $38;
  HEAP32[$39>>2] = $0;
  $40 = $__p1$0$lcssa;
  $41 = $8;
  $42 = $41;
  HEAP32[$42>>2] = $40;
  $43 = (($41) + 4)|0;
  $44 = $43;
  HEAP32[$44>>2] = $40;
  $45 = $__buff;
  $46 = $9;
  $47 = $46;
  HEAP32[$47>>2] = $45;
  $48 = (($46) + 4)|0;
  $49 = $48;
  HEAP32[$49>>2] = $45;
  HEAP32[$10>>2] = $__last;
  $50 = (($10) + 4|0);
  HEAP32[$50>>2] = $__last;
  HEAP32[$11>>2] = $__comp;
  ;HEAP32[$tmpcast$byval_copy+0>>2]=HEAP32[$6+0>>2]|0;HEAP32[$tmpcast$byval_copy+4>>2]=HEAP32[$6+4>>2]|0;
  ;HEAP32[$tmpcast22$byval_copy+0>>2]=HEAP32[$7+0>>2]|0;HEAP32[$tmpcast22$byval_copy+4>>2]=HEAP32[$7+4>>2]|0;
  ;HEAP32[$tmpcast23$byval_copy+0>>2]=HEAP32[$8+0>>2]|0;HEAP32[$tmpcast23$byval_copy+4>>2]=HEAP32[$8+4>>2]|0;
  ;HEAP32[$tmpcast24$byval_copy+0>>2]=HEAP32[$9+0>>2]|0;HEAP32[$tmpcast24$byval_copy+4>>2]=HEAP32[$9+4>>2]|0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$10+0>>2]|0;HEAP32[$$byval_copy4+4>>2]=HEAP32[$10+4>>2]|0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$11+0>>2]|0;
  __ZNSt3__17__mergeINS_8__negateIRPFbRK15b2ParticleTriadS4_EEENS_13move_iteratorINS_16reverse_iteratorIPS2_EEEESD_SC_EET2_T0_SF_T1_SG_SE_T_($12,$tmpcast$byval_copy,$tmpcast22$byval_copy,$tmpcast23$byval_copy,$tmpcast24$byval_copy,$$byval_copy4,$$byval_copy5);
  STACKTOP = sp;return;
 } else {
  $14 = ($__first|0)==($__middle|0);
  if ($14) {
   $__p$0$lcssa = $__buff;
  } else {
   $scevgep36 = (($__middle) + -60|0);
   $15 = $scevgep36;
   $16 = (($15) - ($0))|0;
   $17 = (($16>>>0) / 60)&-1;
   $18 = (($17) + 1)|0;
   $__i$028 = $__first;$__p$029 = $__buff;
   while(1) {
    $24 = ($__p$029|0)==(0|0);
    if (!($24)) {
     dest=$__p$029+0|0; src=$__i$028+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    }
    $25 = (($__i$028) + 60|0);
    $26 = (($__p$029) + 60|0);
    $27 = ($25|0)==($__middle|0);
    if ($27) {
     break;
    } else {
     $__i$028 = $25;$__p$029 = $26;
    }
   }
   $scevgep40 = (($__buff) + (($18*60)|0)|0);
   $__p$0$lcssa = $scevgep40;
  }
  HEAP32[$2>>2] = $__buff;
  HEAP32[$3>>2] = $__p$0$lcssa;
  HEAP32[$4>>2] = $__middle;
  HEAP32[$5>>2] = $__last;
  ;HEAP32[$tmpcast23$byval_copy+0>>2]=HEAP32[$2+0>>2]|0;
  ;HEAP32[$tmpcast24$byval_copy+0>>2]=HEAP32[$3+0>>2]|0;
  ;HEAP32[$$byval_copy4+0>>2]=HEAP32[$4+0>>2]|0;
  ;HEAP32[$$byval_copy5+0>>2]=HEAP32[$5+0>>2]|0;
  (__ZNSt3__17__mergeIRPFbRK15b2ParticleTriadS3_ENS_13move_iteratorIPS1_EES9_S8_EET2_T0_SB_T1_SC_SA_T_($tmpcast23$byval_copy,$tmpcast24$byval_copy,$$byval_copy4,$$byval_copy5,$__first,$__comp)|0);
  STACKTOP = sp;return;
 }
}
function __ZNSt3__113__upper_boundIRPFbRK15b2ParticleTriadS3_EPS1_S1_EET0_S8_S8_RKT1_T_($__first,$__last,$__value_,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__value_ = $__value_|0;
 $__comp = $__comp|0;
 var $$0$ph = 0, $$neg1 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0 = 0, $__len$0$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = (($2|0) / 60)&-1;
 $$0$ph = $__first;$__len$0$ph = $3;
 L1: while(1) {
  $__len$0 = $__len$0$ph;
  while(1) {
   $4 = ($__len$0|0)==(0);
   if ($4) {
    break L1;
   }
   $5 = (($__len$0|0) / 2)&-1;
   $6 = (($$0$ph) + (($5*60)|0)|0);
   $7 = HEAP32[$__comp>>2]|0;
   $8 = (FUNCTION_TABLE_iii[$7 & 63]($__value_,$6)|0);
   if ($8) {
    $__len$0 = $5;
   } else {
    break;
   }
  }
  $$sum = (($5) + 1)|0;
  $9 = (($$0$ph) + (($$sum*60)|0)|0);
  $$neg1 = (($__len$0) + -1)|0;
  $10 = (($$neg1) - ($5))|0;
  $$0$ph = $9;$__len$0$ph = $10;
 }
 STACKTOP = sp;return ($$0$ph|0);
}
function __ZNSt3__113__lower_boundIRPFbRK15b2ParticleTriadS3_EPS1_S1_EET0_S8_S8_RKT1_T_($__first,$__last,$__value_,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__value_ = $__value_|0;
 $__comp = $__comp|0;
 var $$0$ph = 0, $$neg1 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0 = 0, $__len$0$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = (($2|0) / 60)&-1;
 $$0$ph = $__first;$__len$0$ph = $3;
 L1: while(1) {
  $__len$0 = $__len$0$ph;
  while(1) {
   $4 = ($__len$0|0)==(0);
   if ($4) {
    break L1;
   }
   $5 = (($__len$0|0) / 2)&-1;
   $6 = (($$0$ph) + (($5*60)|0)|0);
   $7 = HEAP32[$__comp>>2]|0;
   $8 = (FUNCTION_TABLE_iii[$7 & 63]($6,$__value_)|0);
   if ($8) {
    break;
   } else {
    $__len$0 = $5;
   }
  }
  $$sum = (($5) + 1)|0;
  $9 = (($$0$ph) + (($$sum*60)|0)|0);
  $$neg1 = (($__len$0) + -1)|0;
  $10 = (($$neg1) - ($5))|0;
  $$0$ph = $9;$__len$0$ph = $10;
 }
 STACKTOP = sp;return ($$0$ph|0);
}
function __ZNSt3__113__rotate_leftIP15b2ParticleTriadEET_S3_S3_($__first,$__last) {
 $__first = $__first|0;
 $__last = $__last|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $__tmp = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $__tmp = sp;
 dest=$__tmp+0|0; src=$__first+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $0 = (($__first) + 60|0);
 $1 = $__last;
 $2 = $0;
 $3 = (($1) - ($2))|0;
 $4 = (($3|0) / 60)&-1;
 _memmove(($__first|0),($0|0),($3|0))|0;
 $5 = (($__first) + (($4*60)|0)|0);
 dest=$5+0|0; src=$__tmp+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return ($5|0);
}
function __ZNSt3__114__rotate_rightIP15b2ParticleTriadEET_S3_S3_($__first,$__last) {
 $__first = $__first|0;
 $__last = $__last|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $__tmp = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $__tmp = sp;
 $0 = (($__last) + -60|0);
 dest=$__tmp+0|0; src=$0+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $1 = $0;
 $2 = $__first;
 $3 = (($1) - ($2))|0;
 $4 = (($3|0) / -60)&-1;
 $5 = (($__last) + (($4*60)|0)|0);
 _memmove(($5|0),($__first|0),($3|0))|0;
 dest=$__first+0|0; src=$__tmp+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 STACKTOP = sp;return ($5|0);
}
function __ZNSt3__112__rotate_gcdIP15b2ParticleTriadEET_S3_S3_S3_($__first,$__middle,$__last) {
 $__first = $__first|0;
 $__middle = $__middle|0;
 $__last = $__last|0;
 var $$0 = 0, $$0$i = 0, $$0$i$phi = 0, $$01$i = 0, $$012$i = 0, $$03$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__p$01 = 0, $__p1$0 = 0, $__p1$0$phi = 0, $__p2$0 = 0, $__p2$1 = 0;
 var $__t$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $__t$i$i = sp;
 $0 = $__middle;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = (($2|0) / 60)&-1;
 $4 = $__last;
 $5 = (($4) - ($0))|0;
 $6 = (($5|0) / 60)&-1;
 $7 = ($3|0)==($6|0);
 if ($7) {
  $8 = ($__first|0)==($__middle|0);
  if ($8) {
   $$0 = $__middle;
   STACKTOP = sp;return ($$0|0);
  }
  $$012$i = $__first;$$03$i = $__middle;
  while(1) {
   dest=$__t$i$i+0|0; src=$$012$i+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   dest=$$012$i+0|0; src=$$03$i+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   dest=$$03$i+0|0; src=$__t$i$i+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $9 = (($$012$i) + 60|0);
   $10 = (($$03$i) + 60|0);
   $11 = ($9|0)==($__middle|0);
   if ($11) {
    $$0 = $__middle;
    break;
   } else {
    $$012$i = $9;$$03$i = $10;
   }
  }
  STACKTOP = sp;return ($$0|0);
 } else {
  $$0$i = $3;$$01$i = $6;
 }
 while(1) {
  $12 = (($$0$i|0) % ($$01$i|0))&-1;
  $13 = ($12|0)==(0);
  if ($13) {
   break;
  } else {
   $$0$i$phi = $$01$i;$$01$i = $12;$$0$i = $$0$i$phi;
  }
 }
 $14 = ($$01$i|0)==(0);
 if (!($14)) {
  $15 = (($__first) + (($$01$i*60)|0)|0);
  $$sum = (($3) + -1)|0;
  $__p$01 = $15;
  while(1) {
   $16 = (($__p$01) + -60|0);
   dest=$__t$i$i+0|0; src=$16+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $17 = (($__p$01) + (($$sum*60)|0)|0);
   $__p1$0 = $16;$__p2$0 = $17;
   while(1) {
    dest=$__p1$0+0|0; src=$__p2$0+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
    $18 = $__p2$0;
    $19 = (($4) - ($18))|0;
    $20 = (($19|0) / 60)&-1;
    $21 = ($3|0)<($20|0);
    if ($21) {
     $22 = (($__p2$0) + (($3*60)|0)|0);
     $__p2$1 = $22;
    } else {
     $23 = (($3) - ($20))|0;
     $24 = (($__first) + (($23*60)|0)|0);
     $__p2$1 = $24;
    }
    $25 = ($__p2$1|0)==($16|0);
    if ($25) {
     break;
    } else {
     $__p1$0$phi = $__p2$0;$__p2$0 = $__p2$1;$__p1$0 = $__p1$0$phi;
    }
   }
   dest=$__p2$0+0|0; src=$__t$i$i+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $26 = ($16|0)==($__first|0);
   if ($26) {
    break;
   } else {
    $__p$01 = $16;
   }
  }
 }
 $27 = (($__first) + (($6*60)|0)|0);
 $$0 = $27;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16b2GrowableBufferI17b2ParticleContactE4GrowEv($this) {
 $this = $this|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 $3 = $1 << 1;
 $$ = $2 ? 256 : $3;
 __ZN16b2GrowableBufferI17b2ParticleContactE7ReserveEi($this,$$);
 STACKTOP = sp;return;
}
function __ZN32b2ParticleContactRemovePredicateclERK17b2ParticleContact($this,$contact) {
 $this = $this|0;
 $contact = $contact|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK17b2ParticleContact8GetFlagsEv($contact)|0);
 $1 = $0 & 131072;
 $2 = ($1|0)==(0);
 if ($2) {
  $13 = 0;
  STACKTOP = sp;return ($13|0);
 }
 $3 = (($this) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = HEAP32[$this>>2]|0;
 $9 = (__ZNK17b2ParticleContact9GetIndexAEv($contact)|0);
 $10 = (__ZNK17b2ParticleContact9GetIndexBEv($contact)|0);
 $11 = (FUNCTION_TABLE_iiiii[$7 & 7]($4,$8,$9,$10)|0);
 $12 = $11 ^ 1;
 $13 = $12;
 STACKTOP = sp;return ($13|0);
}
function __ZNK12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIiiEEE9GetBufferEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK12_GLOBAL__N_117FixedSetAllocator9GetBufferEv($this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__113__lower_boundIRPFbRKN12_GLOBAL__N_115LightweightPairIiiEES5_EPS4_S3_EET0_SA_SA_RKT1_T_($__first,$__last,$__value_,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__value_ = $__value_|0;
 $__comp = $__comp|0;
 var $$0$ph = 0, $$neg1 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0 = 0, $__len$0$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 3;
 $$0$ph = $__first;$__len$0$ph = $3;
 L1: while(1) {
  $__len$0 = $__len$0$ph;
  while(1) {
   $4 = ($__len$0|0)==(0);
   if ($4) {
    break L1;
   }
   $5 = (($__len$0|0) / 2)&-1;
   $6 = (($$0$ph) + ($5<<3)|0);
   $7 = HEAP32[$__comp>>2]|0;
   $8 = (FUNCTION_TABLE_iii[$7 & 63]($6,$__value_)|0);
   if ($8) {
    break;
   } else {
    $__len$0 = $5;
   }
  }
  $$sum = (($5) + 1)|0;
  $9 = (($$0$ph) + ($$sum<<3)|0);
  $$neg1 = (($__len$0) + -1)|0;
  $10 = (($$neg1) - ($5))|0;
  $$0$ph = $9;$__len$0$ph = $10;
 }
 STACKTOP = sp;return ($$0$ph|0);
}
function __ZNK12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIiiEEE8GetIndexEPKS2_($this,$item) {
 $this = $this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($item|0)==(0|0);
 if (!($0)) {
  $1 = (__ZNK12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIiiEEE9GetBufferEv($this)|0);
  $2 = $item;
  $3 = $1;
  $4 = (($2) - ($3))|0;
  $5 = $4 >>> 3;
  $6 = (__ZNK12_GLOBAL__N_117FixedSetAllocator14GetValidBufferEv($this)|0);
  $7 = (($6) + ($5)|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  if (!($9)) {
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16b2GrowableBufferIiE7ReserveEi($this,$newCapacity) {
 $this = $this|0;
 $newCapacity = $newCapacity|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)<($newCapacity|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $newCapacity << 2;
 $6 = (__ZN16b2BlockAllocator8AllocateEi($4,$5)|0);
 $7 = HEAP32[$this>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = (($this) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = $10 << 2;
  _memcpy(($6|0),($7|0),($11|0))|0;
  $12 = HEAP32[$3>>2]|0;
  $13 = HEAP32[$this>>2]|0;
  $14 = HEAP32[$0>>2]|0;
  $15 = $14 << 2;
  __ZN16b2BlockAllocator4FreeEPvi($12,$13,$15);
 }
 HEAP32[$0>>2] = $newCapacity;
 HEAP32[$this>>2] = $6;
 STACKTOP = sp;return;
}
function __ZNK12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIP9b2FixtureiEEE9GetBufferEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK12_GLOBAL__N_117FixedSetAllocator9GetBufferEv($this)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZNSt3__113__lower_boundIRPFbRKN12_GLOBAL__N_115LightweightPairIP9b2FixtureiEES7_EPS6_S5_EET0_SC_SC_RKT1_T_($__first,$__last,$__value_,$__comp) {
 $__first = $__first|0;
 $__last = $__last|0;
 $__value_ = $__value_|0;
 $__comp = $__comp|0;
 var $$0$ph = 0, $$neg1 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $__len$0 = 0, $__len$0$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__last;
 $1 = $__first;
 $2 = (($0) - ($1))|0;
 $3 = $2 >> 3;
 $$0$ph = $__first;$__len$0$ph = $3;
 L1: while(1) {
  $__len$0 = $__len$0$ph;
  while(1) {
   $4 = ($__len$0|0)==(0);
   if ($4) {
    break L1;
   }
   $5 = (($__len$0|0) / 2)&-1;
   $6 = (($$0$ph) + ($5<<3)|0);
   $7 = HEAP32[$__comp>>2]|0;
   $8 = (FUNCTION_TABLE_iii[$7 & 63]($6,$__value_)|0);
   if ($8) {
    break;
   } else {
    $__len$0 = $5;
   }
  }
  $$sum = (($5) + 1)|0;
  $9 = (($$0$ph) + ($$sum<<3)|0);
  $$neg1 = (($__len$0) + -1)|0;
  $10 = (($$neg1) - ($5))|0;
  $$0$ph = $9;$__len$0$ph = $10;
 }
 STACKTOP = sp;return ($$0$ph|0);
}
function __ZNK12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIP9b2FixtureiEEE8GetIndexEPKS4_($this,$item) {
 $this = $this|0;
 $item = $item|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($item|0)==(0|0);
 if (!($0)) {
  $1 = (__ZNK12_GLOBAL__N_122TypedFixedSetAllocatorINS_15LightweightPairIP9b2FixtureiEEE9GetBufferEv($this)|0);
  $2 = $item;
  $3 = $1;
  $4 = (($2) - ($3))|0;
  $5 = $4 >>> 3;
  $6 = (__ZNK12_GLOBAL__N_117FixedSetAllocator14GetValidBufferEv($this)|0);
  $7 = (($6) + ($5)|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = ($8<<24>>24)==(0);
  if (!($9)) {
   $$0 = $5;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16b2GrowableBufferI21b2ParticleBodyContactE7ReserveEi($this,$newCapacity) {
 $this = $this|0;
 $newCapacity = $newCapacity|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)<($newCapacity|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($newCapacity*28)|0;
 $6 = (__ZN16b2BlockAllocator8AllocateEi($4,$5)|0);
 $7 = HEAP32[$this>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = (($this) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10*28)|0;
  _memcpy(($6|0),($7|0),($11|0))|0;
  $12 = HEAP32[$3>>2]|0;
  $13 = HEAP32[$this>>2]|0;
  $14 = HEAP32[$0>>2]|0;
  $15 = ($14*28)|0;
  __ZN16b2BlockAllocator4FreeEPvi($12,$13,$15);
 }
 HEAP32[$0>>2] = $newCapacity;
 HEAP32[$this>>2] = $6;
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferI15b2ParticleTriadE7ReserveEi($this,$newCapacity) {
 $this = $this|0;
 $newCapacity = $newCapacity|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)<($newCapacity|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($newCapacity*60)|0;
 $6 = (__ZN16b2BlockAllocator8AllocateEi($4,$5)|0);
 $7 = HEAP32[$this>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = (($this) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10*60)|0;
  _memcpy(($6|0),($7|0),($11|0))|0;
  $12 = HEAP32[$3>>2]|0;
  $13 = HEAP32[$this>>2]|0;
  $14 = HEAP32[$0>>2]|0;
  $15 = ($14*60)|0;
  __ZN16b2BlockAllocator4FreeEPvi($12,$13,$15);
 }
 HEAP32[$0>>2] = $newCapacity;
 HEAP32[$this>>2] = $6;
 STACKTOP = sp;return;
}
function __ZN19b2IntrusiveListNodeC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN19b2IntrusiveListNode10InitializeEv($this);
 STACKTOP = sp;return;
}
function __ZN19b2IntrusiveListNodeD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN19b2IntrusiveListNode6RemoveEv($this)|0);
 STACKTOP = sp;return;
}
function __ZNK24b2TypedIntrusiveListNodeI14b2TrackedBlockE11GetListNodeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($this|0);
}
function __ZN24b2TypedIntrusiveListNodeI14b2TrackedBlockE23GetInstanceFromListNodeEP19b2IntrusiveListNode($node) {
 $node = $node|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($node|0);
}
function __ZNK15b2SlabAllocatorI16b2ParticleHandleE4Slab16GetNumberOfItemsEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN24b2TypedIntrusiveListNodeI16b2ParticleHandleED2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN19b2IntrusiveListNodeD2Ev($this);
 STACKTOP = sp;return;
}
function __ZNSt3__17__mergeIRPFbRK14b2ParticlePairS3_ENS_13move_iteratorIPS1_EES9_S8_EET2_T0_SB_T1_SC_SA_T_($__first1,$__last1,$__first2,$__last2,$__result,$__comp) {
 $__first1 = $__first1|0;
 $__last1 = $__last1|0;
 $__first2 = $__first2|0;
 $__last2 = $__last2|0;
 $__result = $__result|0;
 $__comp = $__comp|0;
 var $$01$lcssa = 0, $$0117 = 0, $$0123 = 0, $$lcssa = 0, $$lcssa21 = 0, $$sink = 0, $$sink$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__first1>>2]|0;
 $1 = HEAP32[$__last1>>2]|0;
 $2 = ($0|0)==($1|0);
 $3 = HEAP32[$__first2>>2]|0;
 $4 = HEAP32[$__last2>>2]|0;
 L1: do {
  if ($2) {
   $$01$lcssa = $__result;$$lcssa = $3;$$lcssa21 = $4;
  } else {
   $5 = HEAP32[$__last1>>2]|0;
   $6 = HEAP32[$__last2>>2]|0;
   $$0123 = $__result;$10 = $1;$12 = $0;$7 = $3;$9 = $4;
   while(1) {
    $8 = ($7|0)==($9|0);
    if ($8) {
     break;
    }
    $15 = HEAP32[$__comp>>2]|0;
    $16 = (FUNCTION_TABLE_iii[$15 & 63]($7,$12)|0);
    if ($16) {
     $17 = HEAP32[$__first2>>2]|0;
     ;HEAP32[$$0123+0>>2]=HEAP32[$17+0>>2]|0;HEAP32[$$0123+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$$0123+8>>2]=HEAP32[$17+8>>2]|0;HEAP32[$$0123+12>>2]=HEAP32[$17+12>>2]|0;HEAP32[$$0123+16>>2]=HEAP32[$17+16>>2]|0;
     $18 = HEAP32[$__first2>>2]|0;
     $19 = (($18) + 20|0);
     HEAP32[$__first2>>2] = $19;
    } else {
     $20 = HEAP32[$__first1>>2]|0;
     ;HEAP32[$$0123+0>>2]=HEAP32[$20+0>>2]|0;HEAP32[$$0123+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$$0123+8>>2]=HEAP32[$20+8>>2]|0;HEAP32[$$0123+12>>2]=HEAP32[$20+12>>2]|0;HEAP32[$$0123+16>>2]=HEAP32[$20+16>>2]|0;
     $21 = HEAP32[$__first1>>2]|0;
     $22 = (($21) + 20|0);
     HEAP32[$__first1>>2] = $22;
    }
    $23 = (($$0123) + 20|0);
    $24 = HEAP32[$__first1>>2]|0;
    $25 = ($24|0)==($5|0);
    $26 = HEAP32[$__first2>>2]|0;
    if ($25) {
     $$01$lcssa = $23;$$lcssa = $26;$$lcssa21 = $6;
     break L1;
    } else {
     $$0123 = $23;$10 = $5;$12 = $24;$7 = $26;$9 = $6;
    }
   }
   $11 = $10;
   $13 = $12;
   $14 = (($11) - ($13))|0;
   _memmove(($$0123|0),($12|0),($14|0))|0;
   $$0117 = $$0123;$$sink$in = $14;
   $$sink = (($$sink$in|0) / 20)&-1;
   $30 = (($$0117) + (($$sink*20)|0)|0);
   STACKTOP = sp;return ($30|0);
  }
 } while(0);
 $27 = $$lcssa21;
 $28 = $$lcssa;
 $29 = (($27) - ($28))|0;
 _memmove(($$01$lcssa|0),($$lcssa|0),($29|0))|0;
 $$0117 = $$01$lcssa;$$sink$in = $29;
 $$sink = (($$sink$in|0) / 20)&-1;
 $30 = (($$0117) + (($$sink*20)|0)|0);
 STACKTOP = sp;return ($30|0);
}
function __ZNSt3__17__mergeINS_8__negateIRPFbRK14b2ParticlePairS4_EEENS_13move_iteratorINS_16reverse_iteratorIPS2_EEEESD_SC_EET2_T0_SF_T1_SG_SE_T_($agg$result,$__first1,$__last1,$__first2,$__last2,$__result,$__comp) {
 $agg$result = $agg$result|0;
 $__first1 = $__first1|0;
 $__last1 = $__last1|0;
 $__first2 = $__first2|0;
 $__last2 = $__last2|0;
 $__result = $__result|0;
 $__comp = $__comp|0;
 var $$lcssa$off32 = 0, $$off32 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i = 0, $scevgep$i23 = 0, $scevgep24$i = 0, $scevgep24$i29 = 0, $uglygep$i = 0, $uglygep$i25 = 0, $uglygep23$i = 0, $uglygep23$i26 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $__first1;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $5;
 $7 = $__last1;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 4)|0;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = $12;
 $14 = ($6|0)==($13|0);
 $15 = $__first2;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 do {
  if ($14) {
   $$lcssa$off32 = $20;
  } else {
   $21 = (($__first2) + 4|0);
   $22 = (($__first1) + 4|0);
   $23 = HEAP32[$__comp>>2]|0;
   $24 = (($__result) + 4|0);
   $$off32 = $20;$41 = $6;$43 = $13;$45 = $12;
   while(1) {
    $25 = $$off32;
    $26 = $__last2;
    $27 = $26;
    $28 = HEAP32[$27>>2]|0;
    $29 = (($26) + 4)|0;
    $30 = $29;
    $31 = HEAP32[$30>>2]|0;
    $32 = $31;
    $33 = ($25|0)==($32|0);
    if ($33) {
     break;
    }
    $59 = HEAP32[$21>>2]|0;
    $60 = (($59) + -20|0);
    $61 = HEAP32[$22>>2]|0;
    $62 = (($61) + -20|0);
    $63 = HEAP32[$23>>2]|0;
    $64 = (FUNCTION_TABLE_iii[$63 & 63]($60,$62)|0);
    $65 = HEAP32[$24>>2]|0;
    $66 = (($65) + -20|0);
    if ($64) {
     $71 = HEAP32[$22>>2]|0;
     $72 = (($71) + -20|0);
     ;HEAP32[$66+0>>2]=HEAP32[$72+0>>2]|0;HEAP32[$66+4>>2]=HEAP32[$72+4>>2]|0;HEAP32[$66+8>>2]=HEAP32[$72+8>>2]|0;HEAP32[$66+12>>2]=HEAP32[$72+12>>2]|0;HEAP32[$66+16>>2]=HEAP32[$72+16>>2]|0;
     $73 = HEAP32[$22>>2]|0;
     $74 = (($73) + -20|0);
     HEAP32[$22>>2] = $74;
    } else {
     $67 = HEAP32[$21>>2]|0;
     $68 = (($67) + -20|0);
     ;HEAP32[$66+0>>2]=HEAP32[$68+0>>2]|0;HEAP32[$66+4>>2]=HEAP32[$68+4>>2]|0;HEAP32[$66+8>>2]=HEAP32[$68+8>>2]|0;HEAP32[$66+12>>2]=HEAP32[$68+12>>2]|0;HEAP32[$66+16>>2]=HEAP32[$68+16>>2]|0;
     $69 = HEAP32[$21>>2]|0;
     $70 = (($69) + -20|0);
     HEAP32[$21>>2] = $70;
    }
    $75 = HEAP32[$24>>2]|0;
    $76 = (($75) + -20|0);
    HEAP32[$24>>2] = $76;
    $77 = $__first1;
    $78 = $77;
    $79 = HEAP32[$78>>2]|0;
    $80 = (($77) + 4)|0;
    $81 = $80;
    $82 = HEAP32[$81>>2]|0;
    $83 = $82;
    $84 = $__last1;
    $85 = $84;
    $86 = HEAP32[$85>>2]|0;
    $87 = (($84) + 4)|0;
    $88 = $87;
    $89 = HEAP32[$88>>2]|0;
    $90 = $89;
    $91 = ($83|0)==($90|0);
    $92 = $__first2;
    $93 = $92;
    $94 = HEAP32[$93>>2]|0;
    $95 = (($92) + 4)|0;
    $96 = $95;
    $97 = HEAP32[$96>>2]|0;
    if ($91) {
     label = 13;
     break;
    } else {
     $$off32 = $97;$41 = $83;$43 = $90;$45 = $89;
    }
   }
   if ((label|0) == 13) {
    $$lcssa$off32 = $97;
    break;
   }
   $34 = $__result;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $39;
   $42 = ($41|0)==($43|0);
   if ($42) {
    $53 = $40;
   } else {
    $scevgep$i23 = (($41) + -20|0);
    $44 = (0 - ($45))|0;
    $uglygep$i25 = (($scevgep$i23) + ($44)|0);
    $uglygep23$i26 = $uglygep$i25;
    $46 = (($uglygep23$i26>>>0) / 20)&-1;
    $48 = $40;$50 = $41;
    while(1) {
     $47 = (($48) + -20|0);
     $49 = (($50) + -20|0);
     ;HEAP32[$47+0>>2]=HEAP32[$49+0>>2]|0;HEAP32[$47+4>>2]=HEAP32[$49+4>>2]|0;HEAP32[$47+8>>2]=HEAP32[$49+8>>2]|0;HEAP32[$47+12>>2]=HEAP32[$49+12>>2]|0;HEAP32[$47+16>>2]=HEAP32[$49+16>>2]|0;
     $51 = ($49|0)==($43|0);
     if ($51) {
      break;
     } else {
      $48 = $47;$50 = $49;
     }
    }
    $52 = $46 ^ -1;
    $scevgep24$i29 = (($40) + (($52*20)|0)|0);
    $53 = $scevgep24$i29;
   }
   $54 = $53;
   $55 = $agg$result;
   $56 = $55;
   HEAP32[$56>>2] = $36;
   $57 = (($55) + 4)|0;
   $58 = $57;
   HEAP32[$58>>2] = $54;
   STACKTOP = sp;return;
  }
 } while(0);
 $98 = $__last2;
 $99 = $98;
 $100 = HEAP32[$99>>2]|0;
 $101 = (($98) + 4)|0;
 $102 = $101;
 $103 = HEAP32[$102>>2]|0;
 $104 = $__result;
 $105 = $104;
 $106 = HEAP32[$105>>2]|0;
 $107 = (($104) + 4)|0;
 $108 = $107;
 $109 = HEAP32[$108>>2]|0;
 $110 = $109;
 $111 = $$lcssa$off32;
 $112 = $103;
 $113 = ($111|0)==($112|0);
 if ($113) {
  $122 = $110;
 } else {
  $scevgep$i = (($111) + -20|0);
  $114 = (0 - ($103))|0;
  $uglygep$i = (($scevgep$i) + ($114)|0);
  $uglygep23$i = $uglygep$i;
  $115 = (($uglygep23$i>>>0) / 20)&-1;
  $117 = $110;$119 = $111;
  while(1) {
   $116 = (($117) + -20|0);
   $118 = (($119) + -20|0);
   ;HEAP32[$116+0>>2]=HEAP32[$118+0>>2]|0;HEAP32[$116+4>>2]=HEAP32[$118+4>>2]|0;HEAP32[$116+8>>2]=HEAP32[$118+8>>2]|0;HEAP32[$116+12>>2]=HEAP32[$118+12>>2]|0;HEAP32[$116+16>>2]=HEAP32[$118+16>>2]|0;
   $120 = ($118|0)==($112|0);
   if ($120) {
    break;
   } else {
    $117 = $116;$119 = $118;
   }
  }
  $121 = $115 ^ -1;
  $scevgep24$i = (($110) + (($121*20)|0)|0);
  $122 = $scevgep24$i;
 }
 $123 = $122;
 $124 = $agg$result;
 $125 = $124;
 HEAP32[$125>>2] = $106;
 $126 = (($124) + 4)|0;
 $127 = $126;
 HEAP32[$127>>2] = $123;
 STACKTOP = sp;return;
}
function __ZNSt3__17__mergeIRPFbRK15b2ParticleTriadS3_ENS_13move_iteratorIPS1_EES9_S8_EET2_T0_SB_T1_SC_SA_T_($__first1,$__last1,$__first2,$__last2,$__result,$__comp) {
 $__first1 = $__first1|0;
 $__last1 = $__last1|0;
 $__first2 = $__first2|0;
 $__last2 = $__last2|0;
 $__result = $__result|0;
 $__comp = $__comp|0;
 var $$01$lcssa = 0, $$0117 = 0, $$0123 = 0, $$lcssa = 0, $$lcssa21 = 0, $$sink = 0, $$sink$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = HEAP32[$__first1>>2]|0;
 $1 = HEAP32[$__last1>>2]|0;
 $2 = ($0|0)==($1|0);
 $3 = HEAP32[$__first2>>2]|0;
 $4 = HEAP32[$__last2>>2]|0;
 L1: do {
  if ($2) {
   $$01$lcssa = $__result;$$lcssa = $3;$$lcssa21 = $4;
  } else {
   $5 = HEAP32[$__last1>>2]|0;
   $6 = HEAP32[$__last2>>2]|0;
   $$0123 = $__result;$10 = $1;$12 = $0;$7 = $3;$9 = $4;
   while(1) {
    $8 = ($7|0)==($9|0);
    if ($8) {
     break;
    }
    $15 = HEAP32[$__comp>>2]|0;
    $16 = (FUNCTION_TABLE_iii[$15 & 63]($7,$12)|0);
    if ($16) {
     $17 = HEAP32[$__first2>>2]|0;
     dest=$$0123+0|0; src=$17+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     $18 = HEAP32[$__first2>>2]|0;
     $19 = (($18) + 60|0);
     HEAP32[$__first2>>2] = $19;
    } else {
     $20 = HEAP32[$__first1>>2]|0;
     dest=$$0123+0|0; src=$20+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     $21 = HEAP32[$__first1>>2]|0;
     $22 = (($21) + 60|0);
     HEAP32[$__first1>>2] = $22;
    }
    $23 = (($$0123) + 60|0);
    $24 = HEAP32[$__first1>>2]|0;
    $25 = ($24|0)==($5|0);
    $26 = HEAP32[$__first2>>2]|0;
    if ($25) {
     $$01$lcssa = $23;$$lcssa = $26;$$lcssa21 = $6;
     break L1;
    } else {
     $$0123 = $23;$10 = $5;$12 = $24;$7 = $26;$9 = $6;
    }
   }
   $11 = $10;
   $13 = $12;
   $14 = (($11) - ($13))|0;
   _memmove(($$0123|0),($12|0),($14|0))|0;
   $$0117 = $$0123;$$sink$in = $14;
   $$sink = (($$sink$in|0) / 60)&-1;
   $30 = (($$0117) + (($$sink*60)|0)|0);
   STACKTOP = sp;return ($30|0);
  }
 } while(0);
 $27 = $$lcssa21;
 $28 = $$lcssa;
 $29 = (($27) - ($28))|0;
 _memmove(($$01$lcssa|0),($$lcssa|0),($29|0))|0;
 $$0117 = $$01$lcssa;$$sink$in = $29;
 $$sink = (($$sink$in|0) / 60)&-1;
 $30 = (($$0117) + (($$sink*60)|0)|0);
 STACKTOP = sp;return ($30|0);
}
function __ZNSt3__17__mergeINS_8__negateIRPFbRK15b2ParticleTriadS4_EEENS_13move_iteratorINS_16reverse_iteratorIPS2_EEEESD_SC_EET2_T0_SF_T1_SG_SE_T_($agg$result,$__first1,$__last1,$__first2,$__last2,$__result,$__comp) {
 $agg$result = $agg$result|0;
 $__first1 = $__first1|0;
 $__last1 = $__last1|0;
 $__first2 = $__first2|0;
 $__last2 = $__last2|0;
 $__result = $__result|0;
 $__comp = $__comp|0;
 var $$lcssa$off32 = 0, $$off32 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $scevgep$i = 0, $scevgep$i23 = 0, $scevgep24$i = 0, $scevgep24$i29 = 0, $uglygep$i = 0, $uglygep$i25 = 0, $uglygep23$i = 0, $uglygep23$i26 = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = $__first1;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = $5;
 $7 = $__last1;
 $8 = $7;
 $9 = HEAP32[$8>>2]|0;
 $10 = (($7) + 4)|0;
 $11 = $10;
 $12 = HEAP32[$11>>2]|0;
 $13 = $12;
 $14 = ($6|0)==($13|0);
 $15 = $__first2;
 $16 = $15;
 $17 = HEAP32[$16>>2]|0;
 $18 = (($15) + 4)|0;
 $19 = $18;
 $20 = HEAP32[$19>>2]|0;
 do {
  if ($14) {
   $$lcssa$off32 = $20;
  } else {
   $21 = (($__first2) + 4|0);
   $22 = (($__first1) + 4|0);
   $23 = HEAP32[$__comp>>2]|0;
   $24 = (($__result) + 4|0);
   $$off32 = $20;$41 = $6;$43 = $13;$45 = $12;
   while(1) {
    $25 = $$off32;
    $26 = $__last2;
    $27 = $26;
    $28 = HEAP32[$27>>2]|0;
    $29 = (($26) + 4)|0;
    $30 = $29;
    $31 = HEAP32[$30>>2]|0;
    $32 = $31;
    $33 = ($25|0)==($32|0);
    if ($33) {
     break;
    }
    $59 = HEAP32[$21>>2]|0;
    $60 = (($59) + -60|0);
    $61 = HEAP32[$22>>2]|0;
    $62 = (($61) + -60|0);
    $63 = HEAP32[$23>>2]|0;
    $64 = (FUNCTION_TABLE_iii[$63 & 63]($60,$62)|0);
    $65 = HEAP32[$24>>2]|0;
    $66 = (($65) + -60|0);
    if ($64) {
     $71 = HEAP32[$22>>2]|0;
     $72 = (($71) + -60|0);
     dest=$66+0|0; src=$72+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     $73 = HEAP32[$22>>2]|0;
     $74 = (($73) + -60|0);
     HEAP32[$22>>2] = $74;
    } else {
     $67 = HEAP32[$21>>2]|0;
     $68 = (($67) + -60|0);
     dest=$66+0|0; src=$68+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     $69 = HEAP32[$21>>2]|0;
     $70 = (($69) + -60|0);
     HEAP32[$21>>2] = $70;
    }
    $75 = HEAP32[$24>>2]|0;
    $76 = (($75) + -60|0);
    HEAP32[$24>>2] = $76;
    $77 = $__first1;
    $78 = $77;
    $79 = HEAP32[$78>>2]|0;
    $80 = (($77) + 4)|0;
    $81 = $80;
    $82 = HEAP32[$81>>2]|0;
    $83 = $82;
    $84 = $__last1;
    $85 = $84;
    $86 = HEAP32[$85>>2]|0;
    $87 = (($84) + 4)|0;
    $88 = $87;
    $89 = HEAP32[$88>>2]|0;
    $90 = $89;
    $91 = ($83|0)==($90|0);
    $92 = $__first2;
    $93 = $92;
    $94 = HEAP32[$93>>2]|0;
    $95 = (($92) + 4)|0;
    $96 = $95;
    $97 = HEAP32[$96>>2]|0;
    if ($91) {
     label = 13;
     break;
    } else {
     $$off32 = $97;$41 = $83;$43 = $90;$45 = $89;
    }
   }
   if ((label|0) == 13) {
    $$lcssa$off32 = $97;
    break;
   }
   $34 = $__result;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = (($34) + 4)|0;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = $39;
   $42 = ($41|0)==($43|0);
   if ($42) {
    $53 = $40;
   } else {
    $scevgep$i23 = (($41) + -60|0);
    $44 = (0 - ($45))|0;
    $uglygep$i25 = (($scevgep$i23) + ($44)|0);
    $uglygep23$i26 = $uglygep$i25;
    $46 = (($uglygep23$i26>>>0) / 60)&-1;
    $48 = $40;$50 = $41;
    while(1) {
     $47 = (($48) + -60|0);
     $49 = (($50) + -60|0);
     dest=$47+0|0; src=$49+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
     $51 = ($49|0)==($43|0);
     if ($51) {
      break;
     } else {
      $48 = $47;$50 = $49;
     }
    }
    $52 = $46 ^ -1;
    $scevgep24$i29 = (($40) + (($52*60)|0)|0);
    $53 = $scevgep24$i29;
   }
   $54 = $53;
   $55 = $agg$result;
   $56 = $55;
   HEAP32[$56>>2] = $36;
   $57 = (($55) + 4)|0;
   $58 = $57;
   HEAP32[$58>>2] = $54;
   STACKTOP = sp;return;
  }
 } while(0);
 $98 = $__last2;
 $99 = $98;
 $100 = HEAP32[$99>>2]|0;
 $101 = (($98) + 4)|0;
 $102 = $101;
 $103 = HEAP32[$102>>2]|0;
 $104 = $__result;
 $105 = $104;
 $106 = HEAP32[$105>>2]|0;
 $107 = (($104) + 4)|0;
 $108 = $107;
 $109 = HEAP32[$108>>2]|0;
 $110 = $109;
 $111 = $$lcssa$off32;
 $112 = $103;
 $113 = ($111|0)==($112|0);
 if ($113) {
  $122 = $110;
 } else {
  $scevgep$i = (($111) + -60|0);
  $114 = (0 - ($103))|0;
  $uglygep$i = (($scevgep$i) + ($114)|0);
  $uglygep23$i = $uglygep$i;
  $115 = (($uglygep23$i>>>0) / 60)&-1;
  $117 = $110;$119 = $111;
  while(1) {
   $116 = (($117) + -60|0);
   $118 = (($119) + -60|0);
   dest=$116+0|0; src=$118+0|0; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
   $120 = ($118|0)==($112|0);
   if ($120) {
    break;
   } else {
    $117 = $116;$119 = $118;
   }
  }
  $121 = $115 ^ -1;
  $scevgep24$i = (($110) + (($121*60)|0)|0);
  $122 = $scevgep24$i;
 }
 $123 = $122;
 $124 = $agg$result;
 $125 = $124;
 HEAP32[$125>>2] = $106;
 $126 = (($124) + 4)|0;
 $127 = $126;
 HEAP32[$127>>2] = $123;
 STACKTOP = sp;return;
}
function __ZN16b2GrowableBufferI17b2ParticleContactE7ReserveEi($this,$newCapacity) {
 $this = $this|0;
 $newCapacity = $newCapacity|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)<($newCapacity|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = (($this) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($newCapacity*24)|0;
 $6 = (__ZN16b2BlockAllocator8AllocateEi($4,$5)|0);
 $7 = HEAP32[$this>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = (($this) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10*24)|0;
  _memcpy(($6|0),($7|0),($11|0))|0;
  $12 = HEAP32[$3>>2]|0;
  $13 = HEAP32[$this>>2]|0;
  $14 = HEAP32[$0>>2]|0;
  $15 = ($14*24)|0;
  __ZN16b2BlockAllocator4FreeEPvi($12,$13,$15);
 }
 HEAP32[$0>>2] = $newCapacity;
 HEAP32[$this>>2] = $6;
 STACKTOP = sp;return;
}
function __ZNK12_GLOBAL__N_117FixedSetAllocator9GetBufferEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$this>>2]|0;
 STACKTOP = sp;return ($0|0);
}
function __ZN19b2IntrusiveListNode10InitializeEv($this) {
 $this = $this|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 HEAP32[$0>>2] = $this;
 HEAP32[$this>>2] = $this;
 STACKTOP = sp;return;
}
function __ZN19b2IntrusiveListNode6RemoveEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 4|0);
 HEAP32[$3>>2] = $1;
 $4 = HEAP32[$this>>2]|0;
 $5 = HEAP32[$0>>2]|0;
 HEAP32[$5>>2] = $4;
 __ZN19b2IntrusiveListNode10InitializeEv($this);
 STACKTOP = sp;return ($this|0);
}
function __ZN10b2FreeList4FreeEP19b2IntrusiveListNode($this,$node) {
 $this = $this|0;
 $node = $node|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__ZN19b2IntrusiveListNode6RemoveEv($node)|0);
 $0 = (($this) + 8|0);
 __ZN19b2IntrusiveListNode11InsertAfterEPS_($0,$node);
 STACKTOP = sp;return;
}
function __ZN19b2IntrusiveListNode12InsertBeforeEPS_($this,$node) {
 $this = $this|0;
 $node = $node|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($node) + 4|0);
 HEAP32[$0>>2] = $this;
 $1 = HEAP32[$this>>2]|0;
 HEAP32[$node>>2] = $1;
 $2 = HEAP32[$this>>2]|0;
 $3 = (($2) + 4|0);
 HEAP32[$3>>2] = $node;
 HEAP32[$this>>2] = $node;
 STACKTOP = sp;return;
}
function __ZN19b2IntrusiveListNode11InsertAfterEPS_($this,$node) {
 $this = $this|0;
 $node = $node|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($node) + 4|0);
 HEAP32[$2>>2] = $1;
 HEAP32[$node>>2] = $this;
 $3 = HEAP32[$0>>2]|0;
 HEAP32[$3>>2] = $node;
 HEAP32[$0>>2] = $node;
 STACKTOP = sp;return;
}
function __ZN16b2BlockAllocatorC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $exitcond = 0, $i$02 = 0, $j$01 = 0, $j$1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = (($this) + 68|0);
 __ZN23b2TrackedBlockAllocatorC2Ev($0);
 $1 = (($this) + 8|0);
 HEAP32[$1>>2] = 128;
 $2 = (($this) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = HEAP32[$1>>2]|0;
 $4 = $3 << 3;
 $5 = (__Z7b2Alloci($4)|0);
 HEAP32[$this>>2] = $5;
 $6 = HEAP32[$1>>2]|0;
 $7 = $6 << 3;
 _memset(($5|0),0,($7|0))|0;
 $8 = (($this) + 12|0);
 dest=$8+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $9 = HEAP8[10216>>0]|0;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  $i$02 = 1;$j$01 = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $11 = (9512 + ($j$01<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($i$02|0)>($12|0);
  if ($13) {
   $16 = (($j$01) + 1)|0;
   $17 = $16&255;
   $18 = (9568 + ($i$02)|0);
   HEAP8[$18>>0] = $17;
   $j$1 = $16;
  } else {
   $14 = $j$01&255;
   $15 = (9568 + ($i$02)|0);
   HEAP8[$15>>0] = $14;
   $j$1 = $j$01;
  }
  $19 = (($i$02) + 1)|0;
  $exitcond = ($19|0)==(641);
  if ($exitcond) {
   break;
  } else {
   $i$02 = $19;$j$01 = $j$1;
  }
 }
 HEAP8[10216>>0] = 1;
 STACKTOP = sp;return;
}
function __ZN16b2BlockAllocatorD2Ev($this) {
 $this = $this|0;
 var $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 $3 = HEAP32[$this>>2]|0;
 if ($2) {
  $5 = $3;$i$02 = 0;
  while(1) {
   $4 = ((($5) + ($i$02<<3)|0) + 4|0);
   $6 = HEAP32[$4>>2]|0;
   __Z6b2FreePv($6);
   $7 = (($i$02) + 1)|0;
   $8 = HEAP32[$0>>2]|0;
   $9 = ($7|0)<($8|0);
   $10 = HEAP32[$this>>2]|0;
   if ($9) {
    $5 = $10;$i$02 = $7;
   } else {
    $$lcssa = $10;
    break;
   }
  }
 } else {
  $$lcssa = $3;
 }
 __Z6b2FreePv($$lcssa);
 $11 = (($this) + 68|0);
 __ZN23b2TrackedBlockAllocatorD2Ev($11);
 STACKTOP = sp;return;
}
function __ZN16b2BlockAllocator8AllocateEi($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $$0 = 0, $$lcssa1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = ($size|0)>(640);
 if ($1) {
  $2 = (($this) + 68|0);
  $3 = (__ZN23b2TrackedBlockAllocator8AllocateEj($2,$size)|0);
  $$0 = $3;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (9568 + ($size)|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = ((($this) + ($6<<2)|0) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = HEAP32[$8>>2]|0;
  HEAP32[$7>>2] = $10;
  $$0 = $8;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (($this) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (($this) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($12|0)==($14|0);
 if ($15) {
  $16 = HEAP32[$this>>2]|0;
  $17 = (($14) + 128)|0;
  HEAP32[$13>>2] = $17;
  $18 = $17 << 3;
  $19 = (__Z7b2Alloci($18)|0);
  HEAP32[$this>>2] = $19;
  $20 = HEAP32[$11>>2]|0;
  $21 = $20 << 3;
  _memcpy(($19|0),($16|0),($21|0))|0;
  $22 = HEAP32[$this>>2]|0;
  $23 = HEAP32[$11>>2]|0;
  $24 = (($22) + ($23<<3)|0);
  _memset(($24|0),0,1024)|0;
  __Z6b2FreePv($16);
 }
 $25 = HEAP32[$this>>2]|0;
 $26 = HEAP32[$11>>2]|0;
 $27 = (__Z7b2Alloci(16384)|0);
 $28 = ((($25) + ($26<<3)|0) + 4|0);
 HEAP32[$28>>2] = $27;
 $29 = (9512 + ($6<<2)|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (($25) + ($26<<3)|0);
 HEAP32[$31>>2] = $30;
 $32 = (16384 / ($30|0))&-1;
 $33 = (($32) + -1)|0;
 $34 = ($33|0)>(0);
 $35 = HEAP32[$28>>2]|0;
 if ($34) {
  $36 = HEAP32[$28>>2]|0;
  $37 = (($32) + -1)|0;
  $40 = $35;$i$02 = 0;
  while(1) {
   $38 = Math_imul($i$02, $30)|0;
   $39 = (($40) + ($38)|0);
   $41 = (($i$02) + 1)|0;
   $42 = Math_imul($41, $30)|0;
   $43 = (($40) + ($42)|0);
   HEAP32[$39>>2] = $43;
   $exitcond = ($41|0)==($37|0);
   if ($exitcond) {
    $$lcssa1 = $36;
    break;
   } else {
    $40 = $36;$i$02 = $41;
   }
  }
 } else {
  $$lcssa1 = $35;
 }
 $44 = Math_imul($33, $30)|0;
 $45 = (($$lcssa1) + ($44)|0);
 HEAP32[$45>>2] = 0;
 $46 = HEAP32[$28>>2]|0;
 $47 = HEAP32[$46>>2]|0;
 HEAP32[$7>>2] = $47;
 $48 = HEAP32[$11>>2]|0;
 $49 = (($48) + 1)|0;
 HEAP32[$11>>2] = $49;
 $50 = HEAP32[$28>>2]|0;
 $$0 = $50;
 STACKTOP = sp;return ($$0|0);
}
function __ZN16b2BlockAllocator4FreeEPvi($this,$p,$size) {
 $this = $this|0;
 $p = $p|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = ($size|0)>(640);
 if ($1) {
  $2 = (($this) + 68|0);
  __ZN23b2TrackedBlockAllocator4FreeEPv($2,$p);
  STACKTOP = sp;return;
 } else {
  $3 = (9568 + ($size)|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = $4&255;
  $6 = ((($this) + ($5<<2)|0) + 12|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$p>>2] = $7;
  HEAP32[$6>>2] = $p;
  STACKTOP = sp;return;
 }
}
function __ZNK7b2Mat337Solve33ERK6b2Vec3($agg$result,$this,$b) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, $det$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0;
 $0 = sp + 36|0;
 $1 = sp + 24|0;
 $2 = sp + 12|0;
 $3 = sp;
 $4 = (($this) + 12|0);
 $5 = (($this) + 24|0);
 __Z7b2CrossRK6b2Vec3S1_($0,$4,$5);
 $6 = (+__Z5b2DotRK6b2Vec3S1_($this,$0));
 $7 = $6 != 0.0;
 if ($7) {
  $8 = 1.0 / $6;
  $det$0 = $8;
 } else {
  $det$0 = $6;
 }
 __Z7b2CrossRK6b2Vec3S1_($1,$4,$5);
 $9 = (+__Z5b2DotRK6b2Vec3S1_($b,$1));
 $10 = $det$0 * $9;
 HEAPF32[$agg$result>>2] = $10;
 __Z7b2CrossRK6b2Vec3S1_($2,$b,$5);
 $11 = (+__Z5b2DotRK6b2Vec3S1_($this,$2));
 $12 = $det$0 * $11;
 $13 = (($agg$result) + 4|0);
 HEAPF32[$13>>2] = $12;
 __Z7b2CrossRK6b2Vec3S1_($3,$4,$b);
 $14 = (+__Z5b2DotRK6b2Vec3S1_($this,$3));
 $15 = $det$0 * $14;
 $16 = (($agg$result) + 8|0);
 HEAPF32[$16>>2] = $15;
 STACKTOP = sp;return;
}
function __ZNK7b2Mat337Solve22ERK6b2Vec2($agg$result,$this,$b) {
 $agg$result = $agg$result|0;
 $this = $this|0;
 $b = $b|0;
 var $0 = 0.0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0.0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0, $3 = 0;
 var $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, $det$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$this>>2];
 $1 = (($this) + 12|0);
 $2 = +HEAPF32[$1>>2];
 $3 = (($this) + 4|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($this) + 16|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $0 * $6;
 $8 = $2 * $4;
 $9 = $7 - $8;
 $10 = $9 != 0.0;
 if ($10) {
  $11 = 1.0 / $9;
  $det$0 = $11;
 } else {
  $det$0 = $9;
 }
 $12 = +HEAPF32[$b>>2];
 $13 = $6 * $12;
 $14 = (($b) + 4|0);
 $15 = +HEAPF32[$14>>2];
 $16 = $2 * $15;
 $17 = $13 - $16;
 $18 = $det$0 * $17;
 HEAPF32[$agg$result>>2] = $18;
 $19 = +HEAPF32[$14>>2];
 $20 = $0 * $19;
 $21 = +HEAPF32[$b>>2];
 $22 = $4 * $21;
 $23 = $20 - $22;
 $24 = $det$0 * $23;
 $25 = (($agg$result) + 4|0);
 HEAPF32[$25>>2] = $24;
 STACKTOP = sp;return;
}
function __ZNK7b2Mat3312GetInverse22EPS_($this,$M) {
 $this = $this|0;
 $M = $M|0;
 var $0 = 0.0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0.0, $20 = 0, $21 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0;
 var $8 = 0.0, $9 = 0.0, $det$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$this>>2];
 $1 = (($this) + 12|0);
 $2 = +HEAPF32[$1>>2];
 $3 = (($this) + 4|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($this) + 16|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $0 * $6;
 $8 = $2 * $4;
 $9 = $7 - $8;
 $10 = $9 != 0.0;
 if ($10) {
  $11 = 1.0 / $9;
  $det$0 = $11;
 } else {
  $det$0 = $9;
 }
 $12 = $6 * $det$0;
 HEAPF32[$M>>2] = $12;
 $13 = -$det$0;
 $14 = $2 * $13;
 $15 = (($M) + 12|0);
 HEAPF32[$15>>2] = $14;
 $16 = (($M) + 8|0);
 HEAPF32[$16>>2] = 0.0;
 $17 = $4 * $13;
 $18 = (($M) + 4|0);
 HEAPF32[$18>>2] = $17;
 $19 = $0 * $det$0;
 $20 = (($M) + 16|0);
 HEAPF32[$20>>2] = $19;
 $21 = (($M) + 20|0);
 ;HEAP32[$21+0>>2]=0|0;HEAP32[$21+4>>2]=0|0;HEAP32[$21+8>>2]=0|0;HEAP32[$21+12>>2]=0|0;
 STACKTOP = sp;return;
}
function __ZNK7b2Mat3315GetSymInverse33EPS_($this,$M) {
 $this = $this|0;
 $M = $M|0;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0, $24 = 0.0, $25 = 0.0, $26 = 0.0;
 var $27 = 0.0, $28 = 0, $29 = 0.0, $3 = 0.0, $30 = 0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0, $41 = 0.0, $42 = 0, $43 = 0.0, $44 = 0;
 var $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0, $5 = 0.0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0, $det$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $0 = sp;
 $1 = (($this) + 12|0);
 $2 = (($this) + 24|0);
 __Z7b2CrossRK6b2Vec3S1_($0,$1,$2);
 $3 = (+__Z5b2DotRK6b2Vec3S1_($this,$0));
 $4 = $3 != 0.0;
 if ($4) {
  $5 = 1.0 / $3;
  $det$0 = $5;
 } else {
  $det$0 = $3;
 }
 $6 = +HEAPF32[$this>>2];
 $7 = +HEAPF32[$1>>2];
 $8 = +HEAPF32[$2>>2];
 $9 = (($this) + 16|0);
 $10 = +HEAPF32[$9>>2];
 $11 = (($this) + 28|0);
 $12 = +HEAPF32[$11>>2];
 $13 = (($this) + 32|0);
 $14 = +HEAPF32[$13>>2];
 $15 = $10 * $14;
 $16 = $12 * $12;
 $17 = $15 - $16;
 $18 = $det$0 * $17;
 HEAPF32[$M>>2] = $18;
 $19 = $8 * $12;
 $20 = $7 * $14;
 $21 = $19 - $20;
 $22 = $det$0 * $21;
 $23 = (($M) + 4|0);
 HEAPF32[$23>>2] = $22;
 $24 = $7 * $12;
 $25 = $8 * $10;
 $26 = $24 - $25;
 $27 = $det$0 * $26;
 $28 = (($M) + 8|0);
 HEAPF32[$28>>2] = $27;
 $29 = +HEAPF32[$23>>2];
 $30 = (($M) + 12|0);
 HEAPF32[$30>>2] = $29;
 $31 = $6 * $14;
 $32 = $8 * $8;
 $33 = $31 - $32;
 $34 = $det$0 * $33;
 $35 = (($M) + 16|0);
 HEAPF32[$35>>2] = $34;
 $36 = $7 * $8;
 $37 = $6 * $12;
 $38 = $36 - $37;
 $39 = $det$0 * $38;
 $40 = (($M) + 20|0);
 HEAPF32[$40>>2] = $39;
 $41 = +HEAPF32[$28>>2];
 $42 = (($M) + 24|0);
 HEAPF32[$42>>2] = $41;
 $43 = +HEAPF32[$40>>2];
 $44 = (($M) + 28|0);
 HEAPF32[$44>>2] = $43;
 $45 = $6 * $10;
 $46 = $7 * $7;
 $47 = $45 - $46;
 $48 = $det$0 * $47;
 $49 = (($M) + 32|0);
 HEAPF32[$49>>2] = $48;
 STACKTOP = sp;return;
}
function __Z7b2CrossRK6b2Vec3S1_($agg$result,$a,$b) {
 $agg$result = $agg$result|0;
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0.0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $2 = 0, $3 = 0.0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0, $8 = 0.0, $9 = 0.0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (($a) + 4|0);
 $1 = +HEAPF32[$0>>2];
 $2 = (($b) + 8|0);
 $3 = +HEAPF32[$2>>2];
 $4 = $1 * $3;
 $5 = (($a) + 8|0);
 $6 = +HEAPF32[$5>>2];
 $7 = (($b) + 4|0);
 $8 = +HEAPF32[$7>>2];
 $9 = $6 * $8;
 $10 = $4 - $9;
 $11 = +HEAPF32[$b>>2];
 $12 = $6 * $11;
 $13 = +HEAPF32[$a>>2];
 $14 = $3 * $13;
 $15 = $12 - $14;
 $16 = $8 * $13;
 $17 = $1 * $11;
 $18 = $16 - $17;
 __ZN6b2Vec3C2Efff($agg$result,$10,$15,$18);
 STACKTOP = sp;return;
}
function __Z5b2DotRK6b2Vec3S1_($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0.0, $1 = 0.0, $10 = 0.0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $2 = 0.0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = +HEAPF32[$a>>2];
 $1 = +HEAPF32[$b>>2];
 $2 = $0 * $1;
 $3 = (($a) + 4|0);
 $4 = +HEAPF32[$3>>2];
 $5 = (($b) + 4|0);
 $6 = +HEAPF32[$5>>2];
 $7 = $4 * $6;
 $8 = $2 + $7;
 $9 = (($a) + 8|0);
 $10 = +HEAPF32[$9>>2];
 $11 = (($b) + 8|0);
 $12 = +HEAPF32[$11>>2];
 $13 = $10 * $12;
 $14 = $8 + $13;
 STACKTOP = sp;return (+$14);
}
function __ZN7b2TimerC2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN7b2Timer5ResetEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK7b2Timer15GetMillisecondsEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return +0;
}
function __Z7b2Alloci($size) {
 $size = $size|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[10296>>2]|0;
 $1 = (($0) + 1)|0;
 HEAP32[10296>>2] = $1;
 $2 = HEAP32[10272>>2]|0;
 $3 = HEAP32[10288>>2]|0;
 $4 = (FUNCTION_TABLE_iii[$2 & 63]($size,$3)|0);
 STACKTOP = sp;return ($4|0);
}
function __Z6b2FreePv($mem) {
 $mem = $mem|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[10296>>2]|0;
 $1 = (($0) + -1)|0;
 HEAP32[10296>>2] = $1;
 $2 = HEAP32[10280>>2]|0;
 $3 = HEAP32[10288>>2]|0;
 FUNCTION_TABLE_vii[$2 & 63]($mem,$3);
 STACKTOP = sp;return;
}
function __Z5b2LogPKcz($string,$varargs) {
 $string = $string|0;
 $varargs = $varargs|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZL14b2AllocDefaultiPv($size,$callbackData) {
 $size = $size|0;
 $callbackData = $callbackData|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_malloc($size)|0);
 STACKTOP = sp;return ($0|0);
}
function __ZL13b2FreeDefaultPvS_($mem,$callbackData) {
 $mem = $mem|0;
 $callbackData = $callbackData|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _free($mem);
 STACKTOP = sp;return;
}
function __ZN14b2TrackedBlockC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 __ZN24b2TypedIntrusiveListNodeI14b2TrackedBlockEC2Ev($this);
 $0 = (__ZNK14b2TrackedBlock9GetMemoryEv($this)|0);
 $1 = (($0) + -4|0);
 HEAP32[$1>>2] = $this;
 STACKTOP = sp;return;
}
function __ZNK14b2TrackedBlock9GetMemoryEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $this;
 $1 = (($0) + 43)|0;
 $2 = $1 & -32;
 $3 = $2;
 STACKTOP = sp;return ($3|0);
}
function __ZN14b2TrackedBlock8AllocateEj($size) {
 $size = $size|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($size) + 44)|0;
 $1 = (__Z7b2Alloci($0)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 __ZN14b2TrackedBlockC2Ev($1);
 $3 = (__ZNK14b2TrackedBlock9GetMemoryEv($1)|0);
 $$0 = $3;
 STACKTOP = sp;return ($$0|0);
}
function __ZN14b2TrackedBlock13GetFromMemoryEPv($memory) {
 $memory = $memory|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($memory) + -4|0);
 $1 = HEAP32[$0>>2]|0;
 STACKTOP = sp;return ($1|0);
}
function __ZN14b2TrackedBlock4FreeEPv($memory) {
 $memory = $memory|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN14b2TrackedBlock13GetFromMemoryEPv($memory)|0);
 __ZN14b2TrackedBlock4FreeEPS_($0);
 STACKTOP = sp;return;
}
function __ZN14b2TrackedBlock4FreeEPS_($block) {
 $block = $block|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN24b2TypedIntrusiveListNodeI14b2TrackedBlockED2Ev($block);
 __Z6b2FreePv($block);
 STACKTOP = sp;return;
}
function __ZN23b2TrackedBlockAllocator8AllocateEj($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN14b2TrackedBlock8AllocateEj($size)|0);
 $1 = (__ZN14b2TrackedBlock13GetFromMemoryEPv($0)|0);
 __ZN24b2TypedIntrusiveListNodeI14b2TrackedBlockE12InsertBeforeEPS0_($this,$1);
 STACKTOP = sp;return ($0|0);
}
function __ZN23b2TrackedBlockAllocator4FreeEPv($this,$memory) {
 $this = $this|0;
 $memory = $memory|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZN14b2TrackedBlock4FreeEPv($memory);
 STACKTOP = sp;return;
}
function __ZN23b2TrackedBlockAllocator7FreeAllEv($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZNK24b2TypedIntrusiveListNodeI14b2TrackedBlockE7IsEmptyEv($this)|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 while(1) {
  $1 = (__ZNK24b2TypedIntrusiveListNodeI14b2TrackedBlockE7GetNextEv($this)|0);
  __ZN14b2TrackedBlock4FreeEPS_($1);
  $2 = (__ZNK24b2TypedIntrusiveListNodeI14b2TrackedBlockE7IsEmptyEv($this)|0);
  if ($2) {
   break;
  }
 }
 STACKTOP = sp;return;
}
function __ZN24b2TypedIntrusiveListNodeI14b2TrackedBlockE12InsertBeforeEPS0_($this,$obj) {
 $this = $this|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__ZN24b2TypedIntrusiveListNodeI14b2TrackedBlockE11GetListNodeEv($this)|0);
 $1 = (__ZN24b2TypedIntrusiveListNodeI14b2TrackedBlockE11GetListNodeEv($obj)|0);
 __ZN19b2IntrusiveListNode12InsertBeforeEPS_($0,$1);
 STACKTOP = sp;return;
}
function __ZN24b2TypedIntrusiveListNodeI14b2TrackedBlockE11GetListNodeEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return ($this|0);
}
function __ZN16b2StackAllocatorC2Ev($this) {
 $this = $this|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 102400|0);
 HEAP32[$0>>2] = 0;
 $1 = (($this) + 102404|0);
 HEAP32[$1>>2] = 0;
 $2 = (($this) + 102408|0);
 HEAP32[$2>>2] = 0;
 $3 = (($this) + 102796|0);
 HEAP32[$3>>2] = 0;
 STACKTOP = sp;return;
}
function __ZN16b2StackAllocatorD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN16b2StackAllocator8AllocateEi($this,$size) {
 $this = $this|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($size) + 3)|0;
 $1 = $0 & -4;
 $2 = (($this) + 102796|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($this) + (($3*12)|0)|0) + 102412|0);
 $5 = ((($this) + (($3*12)|0)|0) + 102416|0);
 HEAP32[$5>>2] = $1;
 $6 = (($this) + 102400|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = (($7) + ($1))|0;
 $9 = ($8|0)>(102400);
 if ($9) {
  $10 = (__Z7b2Alloci($1)|0);
  HEAP32[$4>>2] = $10;
  $11 = ((($this) + (($3*12)|0)|0) + 102420|0);
  HEAP8[$11>>0] = 1;
 } else {
  $12 = (($this) + ($7)|0);
  HEAP32[$4>>2] = $12;
  $13 = ((($this) + (($3*12)|0)|0) + 102420|0);
  HEAP8[$13>>0] = 0;
  $14 = HEAP32[$6>>2]|0;
  $15 = (($14) + ($1))|0;
  HEAP32[$6>>2] = $15;
 }
 $16 = (($this) + 102404|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + ($1))|0;
 HEAP32[$16>>2] = $18;
 $19 = (($this) + 102408|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (__Z5b2MaxIiET_S0_S0_($20,$18)|0);
 HEAP32[$19>>2] = $21;
 $22 = HEAP32[$2>>2]|0;
 $23 = (($22) + 1)|0;
 HEAP32[$2>>2] = $23;
 $24 = HEAP32[$4>>2]|0;
 STACKTOP = sp;return ($24|0);
}
function __ZN16b2StackAllocator10ReallocateEPvi($this,$p,$size) {
 $this = $this|0;
 $p = $p|0;
 $size = $size|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 102796|0);
 $1 = HEAP32[$0>>2]|0;
 $$sum = (($1) + -1)|0;
 $2 = ((($this) + (($$sum*12)|0)|0) + 102412|0);
 $3 = ((($this) + (($$sum*12)|0)|0) + 102416|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($size) - ($4))|0;
 $6 = ($5|0)>(0);
 if (!($6)) {
  $30 = HEAP32[$2>>2]|0;
  STACKTOP = sp;return ($30|0);
 }
 $7 = ((($this) + (($$sum*12)|0)|0) + 102420|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 do {
  if ($9) {
   $14 = (($this) + 102400|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (($15) + ($5))|0;
   $17 = ($16|0)>(102400);
   if ($17) {
    $18 = (__Z7b2Alloci($size)|0);
    $19 = HEAP32[$2>>2]|0;
    $20 = HEAP32[$3>>2]|0;
    _memcpy(($18|0),($19|0),($20|0))|0;
    $21 = HEAP32[$3>>2]|0;
    $22 = HEAP32[$14>>2]|0;
    $23 = (($22) - ($21))|0;
    HEAP32[$14>>2] = $23;
    HEAP32[$2>>2] = $18;
    HEAP8[$7>>0] = 1;
    break;
   } else {
    HEAP32[$14>>2] = $16;
    $24 = (($this) + 102404|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (($25) + ($5))|0;
    HEAP32[$24>>2] = $26;
    $27 = (($this) + 102408|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (__Z5b2MaxIiET_S0_S0_($28,$26)|0);
    HEAP32[$27>>2] = $29;
    break;
   }
  } else {
   $10 = (__Z7b2Alloci($size)|0);
   $11 = HEAP32[$2>>2]|0;
   $12 = HEAP32[$3>>2]|0;
   _memcpy(($10|0),($11|0),($12|0))|0;
   $13 = HEAP32[$2>>2]|0;
   __Z6b2FreePv($13);
   HEAP32[$2>>2] = $10;
  }
 } while(0);
 HEAP32[$3>>2] = $size;
 $30 = HEAP32[$2>>2]|0;
 STACKTOP = sp;return ($30|0);
}
function __ZN16b2StackAllocator4FreeEPv($this,$p) {
 $this = $this|0;
 $p = $p|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($this) + 102796|0);
 $1 = HEAP32[$0>>2]|0;
 $$sum = (($1) + -1)|0;
 $2 = ((($this) + (($$sum*12)|0)|0) + 102420|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $5 = ((($this) + (($$sum*12)|0)|0) + 102416|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($this) + 102400|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (($8) - ($6))|0;
  HEAP32[$7>>2] = $9;
 } else {
  __Z6b2FreePv($p);
 }
 $10 = ((($this) + (($$sum*12)|0)|0) + 102416|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($this) + 102404|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (($13) - ($11))|0;
 HEAP32[$12>>2] = $14;
 $15 = HEAP32[$0>>2]|0;
 $16 = (($15) + -1)|0;
 HEAP32[$0>>2] = $16;
 STACKTOP = sp;return;
}
function _abort_message($format,$varargs) {
 $format = $format|0;
 $varargs = $varargs|0;
 var $0 = 0, $list = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $list = sp;
 HEAP32[$list>>2] = $varargs;
 $0 = HEAP32[_stderr>>2]|0;
 (_vfprintf(($0|0),($format|0),($list|0))|0);
 (_fputc(10,($0|0))|0);
 _abort();
 // unreachable;
}
function ___cxa_get_globals_fast() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (_pthread_once((10496|0),(3|0))|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = HEAP32[10488>>2]|0;
  $3 = (_pthread_getspecific(($2|0))|0);
  STACKTOP = sp;return ($3|0);
 } else {
  _abort_message(10504,$vararg_buffer);
  // unreachable;
 }
 return (0)|0;
}
function __Znwj($size) {
 $size = $size|0;
 var $$lcssa = 0, $$size = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($size|0)==(0);
 $$size = $0 ? 1 : $size;
 $1 = (_malloc($$size)|0);
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $$lcssa = $1;
  STACKTOP = sp;return ($$lcssa|0);
 }
 while(1) {
  $3 = (__ZSt15get_new_handlerv()|0);
  $4 = ($3|0)==(0|0);
  if ($4) {
   label = 4;
   break;
  }
  FUNCTION_TABLE_v[$3 & 3]();
  $5 = (_malloc($$size)|0);
  $6 = ($5|0)==(0|0);
  if (!($6)) {
   $$lcssa = $5;
   label = 5;
   break;
  }
 }
 if ((label|0) == 4) {
  $7 = (___cxa_allocate_exception(4)|0);
  HEAP32[$7>>2] = ((10672 + 8|0));
  ___cxa_throw(($7|0),(10728|0),(65|0));
  // unreachable;
 }
 else if ((label|0) == 5) {
  STACKTOP = sp;return ($$lcssa|0);
 }
 return (0)|0;
}
function __ZnwjRKSt9nothrow_t($size,$0) {
 $size = $size|0;
 $0 = $0|0;
 var $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $1 = (__Znwj($size)|0);
 STACKTOP = sp;return ($1|0);
}
function __ZdlPv($ptr) {
 $ptr = $ptr|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _free($ptr);
 STACKTOP = sp;return;
}
function __ZNSt9bad_allocD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNSt9bad_allocD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNKSt9bad_alloc4whatEv($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return (10696|0);
}
function __ZSt11__terminatePFvvE($func) {
 $func = $func|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 FUNCTION_TABLE_v[$func & 3]();
 _abort_message(10744,$vararg_buffer);
 // unreachable;
}
function __ZSt9terminatev() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = (___cxa_get_globals_fast()|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = HEAP32[$0>>2]|0;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $4 = (($2) + 48|0);
   $5 = $4;
   $6 = $5;
   $7 = HEAP32[$6>>2]|0;
   $8 = (($5) + 4)|0;
   $9 = $8;
   $10 = HEAP32[$9>>2]|0;
   $11 = $7 & -256;
   $12 = ($11|0)==(1126902528);
   $13 = ($10|0)==(1129074247);
   $14 = $12 & $13;
   if ($14) {
    $15 = (($2) + 12|0);
    $16 = HEAP32[$15>>2]|0;
    __ZSt11__terminatePFvvE($16);
    // unreachable;
   }
  }
 }
 $17 = HEAP32[2576]|0;HEAP32[2576] = (($17+0)|0);
 $18 = $17;
 __ZSt11__terminatePFvvE($18);
 // unreachable;
}
function __ZSt15get_new_handlerv() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[10840>>2]|0;HEAP32[10840>>2] = (($0+0)|0);
 $1 = $0;
 STACKTOP = sp;return ($1|0);
}
function __ZNSt9exceptionD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNSt9type_infoD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN10__cxxabiv116__shim_type_infoD2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK10__cxxabiv116__shim_type_info5noop1Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZNK10__cxxabiv116__shim_type_info5noop2Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = sp;return;
}
function __ZN10__cxxabiv117__class_type_infoD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZN10__cxxabiv120__si_class_type_infoD0Ev($this) {
 $this = $this|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 __ZdlPv($this);
 STACKTOP = sp;return;
}
function __ZNK10__cxxabiv117__class_type_info9can_catchEPKNS_16__shim_type_infoERPv($this,$thrown_type,$adjustedPtr) {
 $this = $this|0;
 $thrown_type = $thrown_type|0;
 $adjustedPtr = $adjustedPtr|0;
 var $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $info = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $info = sp;
 $0 = ($this|0)==($thrown_type|0);
 if ($0) {
  $$1 = 1;
  STACKTOP = sp;return ($$1|0);
 }
 $1 = ($thrown_type|0)==(0|0);
 if ($1) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $2 = (___dynamic_cast($thrown_type,10936,10992,0)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 dest=$info+0|0; stop=dest+56|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$info>>2] = $2;
 $4 = (($info) + 8|0);
 HEAP32[$4>>2] = $this;
 $5 = (($info) + 12|0);
 HEAP32[$5>>2] = -1;
 $6 = (($info) + 48|0);
 HEAP32[$6>>2] = 1;
 $7 = HEAP32[$2>>2]|0;
 $8 = (($7) + 28|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = HEAP32[$adjustedPtr>>2]|0;
 FUNCTION_TABLE_viiii[$9 & 31]($2,$info,$10,1);
 $11 = (($info) + 24|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(1);
 if (!($13)) {
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 $14 = (($info) + 16|0);
 $15 = HEAP32[$14>>2]|0;
 HEAP32[$adjustedPtr>>2] = $15;
 $$1 = 1;
 STACKTOP = sp;return ($$1|0);
}
function __ZNK10__cxxabiv117__class_type_info24process_found_base_classEPNS_19__dynamic_cast_infoEPvi($this,$info,$adjustedPtr,$path_below) {
 $this = $this|0;
 $info = $info|0;
 $adjustedPtr = $adjustedPtr|0;
 $path_below = $path_below|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  HEAP32[$0>>2] = $adjustedPtr;
  $3 = (($info) + 24|0);
  HEAP32[$3>>2] = $path_below;
  $4 = (($info) + 36|0);
  HEAP32[$4>>2] = 1;
  STACKTOP = sp;return;
 }
 $5 = ($1|0)==($adjustedPtr|0);
 if (!($5)) {
  $9 = (($info) + 36|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = (($10) + 1)|0;
  HEAP32[$9>>2] = $11;
  $12 = (($info) + 24|0);
  HEAP32[$12>>2] = 2;
  $13 = (($info) + 54|0);
  HEAP8[$13>>0] = 1;
  STACKTOP = sp;return;
 }
 $6 = (($info) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(2);
 if (!($8)) {
  STACKTOP = sp;return;
 }
 HEAP32[$6>>2] = $path_below;
 STACKTOP = sp;return;
}
function __ZNK10__cxxabiv117__class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi($this,$info,$adjustedPtr,$path_below) {
 $this = $this|0;
 $info = $info|0;
 $adjustedPtr = $adjustedPtr|0;
 $path_below = $path_below|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($this|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZNK10__cxxabiv117__class_type_info24process_found_base_classEPNS_19__dynamic_cast_infoEPvi(0,$info,$adjustedPtr,$path_below);
 STACKTOP = sp;return;
}
function __ZNK10__cxxabiv120__si_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi($this,$info,$adjustedPtr,$path_below) {
 $this = $this|0;
 $info = $info|0;
 $adjustedPtr = $adjustedPtr|0;
 $path_below = $path_below|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($this|0)==($1|0);
 if ($2) {
  __ZNK10__cxxabiv117__class_type_info24process_found_base_classEPNS_19__dynamic_cast_infoEPvi(0,$info,$adjustedPtr,$path_below);
  STACKTOP = sp;return;
 } else {
  $3 = (($this) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 28|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_viiii[$7 & 31]($4,$info,$adjustedPtr,$path_below);
  STACKTOP = sp;return;
 }
}
function ___dynamic_cast($static_ptr,$static_type,$dst_type,$src2dst_offset) {
 $static_ptr = $static_ptr|0;
 $static_type = $static_type|0;
 $dst_type = $dst_type|0;
 $src2dst_offset = $src2dst_offset|0;
 var $$ = 0, $$8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dst_ptr$0 = 0, $info = 0, $or$cond = 0, $or$cond3 = 0, $or$cond5 = 0, $or$cond7 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0;
 $info = sp;
 $0 = HEAP32[$static_ptr>>2]|0;
 $1 = (($0) + -8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2;
 $4 = (($static_ptr) + ($3)|0);
 $5 = (($0) + -4|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$info>>2] = $dst_type;
 $7 = (($info) + 4|0);
 HEAP32[$7>>2] = $static_ptr;
 $8 = (($info) + 8|0);
 HEAP32[$8>>2] = $static_type;
 $9 = (($info) + 12|0);
 HEAP32[$9>>2] = $src2dst_offset;
 $10 = (($info) + 16|0);
 $11 = (($info) + 20|0);
 $12 = (($info) + 24|0);
 $13 = (($info) + 28|0);
 $14 = (($info) + 32|0);
 $15 = (($info) + 40|0);
 $16 = ($6|0)==($dst_type|0);
 dest=$10+0|0; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));HEAP16[$10+36>>1]=0|0;HEAP8[$10+38>>0]=0|0;
 if ($16) {
  $17 = (($info) + 48|0);
  HEAP32[$17>>2] = 1;
  $18 = HEAP32[$6>>2]|0;
  $19 = (($18) + 20|0);
  $20 = HEAP32[$19>>2]|0;
  FUNCTION_TABLE_viiiiii[$20 & 7]($6,$info,$4,$4,1,0);
  $21 = HEAP32[$12>>2]|0;
  $22 = ($21|0)==(1);
  $$ = $22 ? $4 : 0;
  $dst_ptr$0 = $$;
  STACKTOP = sp;return ($dst_ptr$0|0);
 }
 $23 = (($info) + 36|0);
 $24 = HEAP32[$6>>2]|0;
 $25 = (($24) + 24|0);
 $26 = HEAP32[$25>>2]|0;
 FUNCTION_TABLE_viiiii[$26 & 3]($6,$info,$4,1,0);
 $27 = HEAP32[$23>>2]|0;
 if ((($27|0) == 1)) {
  $35 = HEAP32[$12>>2]|0;
  $36 = ($35|0)==(1);
  if (!($36)) {
   $37 = HEAP32[$15>>2]|0;
   $38 = ($37|0)==(0);
   $39 = HEAP32[$13>>2]|0;
   $40 = ($39|0)==(1);
   $or$cond5 = $38 & $40;
   $41 = HEAP32[$14>>2]|0;
   $42 = ($41|0)==(1);
   $or$cond7 = $or$cond5 & $42;
   if (!($or$cond7)) {
    $dst_ptr$0 = 0;
    STACKTOP = sp;return ($dst_ptr$0|0);
   }
  }
  $43 = HEAP32[$10>>2]|0;
  $dst_ptr$0 = $43;
  STACKTOP = sp;return ($dst_ptr$0|0);
 } else if ((($27|0) == 0)) {
  $28 = HEAP32[$15>>2]|0;
  $29 = ($28|0)==(1);
  $30 = HEAP32[$13>>2]|0;
  $31 = ($30|0)==(1);
  $or$cond = $29 & $31;
  $32 = HEAP32[$14>>2]|0;
  $33 = ($32|0)==(1);
  $or$cond3 = $or$cond & $33;
  $34 = HEAP32[$11>>2]|0;
  $$8 = $or$cond3 ? $34 : 0;
  $dst_ptr$0 = $$8;
  STACKTOP = sp;return ($dst_ptr$0|0);
 } else {
  $dst_ptr$0 = 0;
  STACKTOP = sp;return ($dst_ptr$0|0);
 }
 return (0)|0;
}
function __ZNK10__cxxabiv117__class_type_info29process_static_type_above_dstEPNS_19__dynamic_cast_infoEPKvS4_i($this,$info,$dst_ptr,$current_ptr,$path_below) {
 $this = $this|0;
 $info = $info|0;
 $dst_ptr = $dst_ptr|0;
 $current_ptr = $current_ptr|0;
 $path_below = $path_below|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 53|0);
 HEAP8[$0>>0] = 1;
 $1 = (($info) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==($current_ptr|0);
 if (!($3)) {
  STACKTOP = sp;return;
 }
 $4 = (($info) + 52|0);
 HEAP8[$4>>0] = 1;
 $5 = (($info) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  HEAP32[$5>>2] = $dst_ptr;
  $8 = (($info) + 24|0);
  HEAP32[$8>>2] = $path_below;
  $9 = (($info) + 36|0);
  HEAP32[$9>>2] = 1;
  $10 = (($info) + 48|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(1);
  $13 = ($path_below|0)==(1);
  $or$cond = $12 & $13;
  if (!($or$cond)) {
   STACKTOP = sp;return;
  }
  $14 = (($info) + 54|0);
  HEAP8[$14>>0] = 1;
  STACKTOP = sp;return;
 }
 $15 = ($6|0)==($dst_ptr|0);
 if (!($15)) {
  $25 = (($info) + 36|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = (($26) + 1)|0;
  HEAP32[$25>>2] = $27;
  $28 = (($info) + 54|0);
  HEAP8[$28>>0] = 1;
  STACKTOP = sp;return;
 }
 $16 = (($info) + 24|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(2);
 if ($18) {
  HEAP32[$16>>2] = $path_below;
  $22 = $path_below;
 } else {
  $22 = $17;
 }
 $19 = (($info) + 48|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ($20|0)==(1);
 $23 = ($22|0)==(1);
 $or$cond1 = $21 & $23;
 if (!($or$cond1)) {
  STACKTOP = sp;return;
 }
 $24 = (($info) + 54|0);
 HEAP8[$24>>0] = 1;
 STACKTOP = sp;return;
}
function __ZNK10__cxxabiv120__si_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib($this,$info,$current_ptr,$path_below,$use_strcmp) {
 $this = $this|0;
 $info = $info|0;
 $current_ptr = $current_ptr|0;
 $path_below = $path_below|0;
 $use_strcmp = $use_strcmp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $is_dst_type_derived_from_static_type$0$off01 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($this|0)==($1|0);
 if ($2) {
  $3 = (($info) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==($current_ptr|0);
  if (!($5)) {
   STACKTOP = sp;return;
  }
  $6 = (($info) + 28|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(1);
  if ($8) {
   STACKTOP = sp;return;
  }
  HEAP32[$6>>2] = $path_below;
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$info>>2]|0;
 $10 = ($this|0)==($9|0);
 if (!($10)) {
  $43 = (($this) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = HEAP32[$44>>2]|0;
  $46 = (($45) + 24|0);
  $47 = HEAP32[$46>>2]|0;
  FUNCTION_TABLE_viiiii[$47 & 3]($44,$info,$current_ptr,$path_below,$use_strcmp);
  STACKTOP = sp;return;
 }
 $11 = (($info) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==($current_ptr|0);
 if (!($13)) {
  $14 = (($info) + 20|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==($current_ptr|0);
  if (!($16)) {
   $19 = (($info) + 32|0);
   HEAP32[$19>>2] = $path_below;
   $20 = (($info) + 44|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==(4);
   if ($22) {
    STACKTOP = sp;return;
   }
   $23 = (($info) + 52|0);
   HEAP8[$23>>0] = 0;
   $24 = (($info) + 53|0);
   HEAP8[$24>>0] = 0;
   $25 = (($this) + 8|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = HEAP32[$26>>2]|0;
   $28 = (($27) + 20|0);
   $29 = HEAP32[$28>>2]|0;
   FUNCTION_TABLE_viiiiii[$29 & 7]($26,$info,$current_ptr,$current_ptr,1,$use_strcmp);
   $30 = HEAP8[$24>>0]|0;
   $31 = ($30<<24>>24)==(0);
   if ($31) {
    $is_dst_type_derived_from_static_type$0$off01 = 0;
    label = 13;
   } else {
    $32 = HEAP8[$23>>0]|0;
    $not$ = ($32<<24>>24)==(0);
    if ($not$) {
     $is_dst_type_derived_from_static_type$0$off01 = 1;
     label = 13;
    }
   }
   do {
    if ((label|0) == 13) {
     HEAP32[$14>>2] = $current_ptr;
     $33 = (($info) + 40|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = (($34) + 1)|0;
     HEAP32[$33>>2] = $35;
     $36 = (($info) + 36|0);
     $37 = HEAP32[$36>>2]|0;
     $38 = ($37|0)==(1);
     if ($38) {
      $39 = (($info) + 24|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = ($40|0)==(2);
      if ($41) {
       $42 = (($info) + 54|0);
       HEAP8[$42>>0] = 1;
       if ($is_dst_type_derived_from_static_type$0$off01) {
        break;
       }
      } else {
       label = 16;
      }
     } else {
      label = 16;
     }
     if ((label|0) == 16) {
      if ($is_dst_type_derived_from_static_type$0$off01) {
       break;
      }
     }
     HEAP32[$20>>2] = 4;
     STACKTOP = sp;return;
    }
   } while(0);
   HEAP32[$20>>2] = 3;
   STACKTOP = sp;return;
  }
 }
 $17 = ($path_below|0)==(1);
 if (!($17)) {
  STACKTOP = sp;return;
 }
 $18 = (($info) + 32|0);
 HEAP32[$18>>2] = 1;
 STACKTOP = sp;return;
}
function __ZNK10__cxxabiv117__class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib($this,$info,$current_ptr,$path_below,$use_strcmp) {
 $this = $this|0;
 $info = $info|0;
 $current_ptr = $current_ptr|0;
 $path_below = $path_below|0;
 $use_strcmp = $use_strcmp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($this|0);
 if ($2) {
  $3 = (($info) + 4|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==($current_ptr|0);
  if (!($5)) {
   STACKTOP = sp;return;
  }
  $6 = (($info) + 28|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(1);
  if ($8) {
   STACKTOP = sp;return;
  }
  HEAP32[$6>>2] = $path_below;
  STACKTOP = sp;return;
 }
 $9 = HEAP32[$info>>2]|0;
 $10 = ($9|0)==($this|0);
 if (!($10)) {
  STACKTOP = sp;return;
 }
 $11 = (($info) + 16|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==($current_ptr|0);
 if (!($13)) {
  $14 = (($info) + 20|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ($15|0)==($current_ptr|0);
  if (!($16)) {
   $19 = (($info) + 32|0);
   HEAP32[$19>>2] = $path_below;
   HEAP32[$14>>2] = $current_ptr;
   $20 = (($info) + 40|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + 1)|0;
   HEAP32[$20>>2] = $22;
   $23 = (($info) + 36|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(1);
   if ($25) {
    $26 = (($info) + 24|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ($27|0)==(2);
    if ($28) {
     $29 = (($info) + 54|0);
     HEAP8[$29>>0] = 1;
    }
   }
   $30 = (($info) + 44|0);
   HEAP32[$30>>2] = 4;
   STACKTOP = sp;return;
  }
 }
 $17 = ($path_below|0)==(1);
 if (!($17)) {
  STACKTOP = sp;return;
 }
 $18 = (($info) + 32|0);
 HEAP32[$18>>2] = 1;
 STACKTOP = sp;return;
}
function __ZNK10__cxxabiv120__si_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib($this,$info,$dst_ptr,$current_ptr,$path_below,$use_strcmp) {
 $this = $this|0;
 $info = $info|0;
 $dst_ptr = $dst_ptr|0;
 $current_ptr = $current_ptr|0;
 $path_below = $path_below|0;
 $use_strcmp = $use_strcmp|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($this|0)==($1|0);
 if ($2) {
  __ZNK10__cxxabiv117__class_type_info29process_static_type_above_dstEPNS_19__dynamic_cast_infoEPKvS4_i(0,$info,$dst_ptr,$current_ptr,$path_below);
  STACKTOP = sp;return;
 } else {
  $3 = (($this) + 8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + 20|0);
  $7 = HEAP32[$6>>2]|0;
  FUNCTION_TABLE_viiiiii[$7 & 7]($4,$info,$dst_ptr,$current_ptr,$path_below,$use_strcmp);
  STACKTOP = sp;return;
 }
}
function __ZNK10__cxxabiv117__class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib($this,$info,$dst_ptr,$current_ptr,$path_below,$use_strcmp) {
 $this = $this|0;
 $info = $info|0;
 $dst_ptr = $dst_ptr|0;
 $current_ptr = $current_ptr|0;
 $path_below = $path_below|0;
 $use_strcmp = $use_strcmp|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($info) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($this|0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 __ZNK10__cxxabiv117__class_type_info29process_static_type_above_dstEPNS_19__dynamic_cast_infoEPKvS4_i(0,$info,$dst_ptr,$current_ptr,$path_below);
 STACKTOP = sp;return;
}
function ___cxa_can_catch($catchType,$excpType,$thrown) {
 $catchType = $catchType|0;
 $excpType = $excpType|0;
 $thrown = $thrown|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $temp = sp;
 $0 = HEAP32[$thrown>>2]|0;
 HEAP32[$temp>>2] = $0;
 $1 = HEAP32[$catchType>>2]|0;
 $2 = (($1) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (FUNCTION_TABLE_iiii[$3 & 15]($catchType,$excpType,$temp)|0);
 $5 = $4&1;
 if (!($4)) {
  STACKTOP = sp;return ($5|0);
 }
 $6 = HEAP32[$temp>>2]|0;
 HEAP32[$thrown>>2] = $6;
 STACKTOP = sp;return ($5|0);
}
function ___cxa_is_pointer_type($type) {
 $type = $type|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($type|0)==(0|0);
 if ($0) {
  $3 = 0;
 } else {
  $1 = (___dynamic_cast($type,10936,11104,0)|0);
  $phitmp = ($1|0)!=(0|0);
  $3 = $phitmp;
 }
 $2 = $3&1;
 STACKTOP = sp;return ($2|0);
}
function __ZL25default_terminate_handlerv() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $thrown_object = 0, $vararg_buffer10 = 0, $vararg_ptr1 = 0;
 var $vararg_ptr2 = 0, $vararg_ptr6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer10 = sp;
 $thrown_object = sp + 12|0;
 $0 = (___cxa_get_globals_fast()|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  _abort_message(10472,$vararg_buffer10);
  // unreachable;
 }
 $2 = HEAP32[$0>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  _abort_message(10472,$vararg_buffer10);
  // unreachable;
 }
 $4 = (($2) + 80|0);
 $5 = (($2) + 48|0);
 $6 = $5;
 $7 = $6;
 $8 = HEAP32[$7>>2]|0;
 $9 = (($6) + 4)|0;
 $10 = $9;
 $11 = HEAP32[$10>>2]|0;
 $12 = $8 & -256;
 $13 = ($12|0)==(1126902528);
 $14 = ($11|0)==(1129074247);
 $15 = $13 & $14;
 if (!($15)) {
  $36 = HEAP32[10312>>2]|0;
  HEAP32[$vararg_buffer10>>2] = $36;
  _abort_message(10432,$vararg_buffer10);
  // unreachable;
 }
 $16 = ($8|0)==(1126902529);
 $17 = ($11|0)==(1129074247);
 $18 = $16 & $17;
 if ($18) {
  $19 = (($2) + 44|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = $20;
 } else {
  $21 = $4;
 }
 HEAP32[$thrown_object>>2] = $21;
 $22 = HEAP32[$2>>2]|0;
 $23 = (($22) + 4|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[10864>>2]|0;
 $26 = (($25) + 16|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = (FUNCTION_TABLE_iiii[$27 & 15](10864,$22,$thrown_object)|0);
 if ($28) {
  $29 = HEAP32[$thrown_object>>2]|0;
  $30 = HEAP32[10312>>2]|0;
  $31 = HEAP32[$29>>2]|0;
  $32 = (($31) + 8|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = (FUNCTION_TABLE_ii[$33 & 15]($29)|0);
  HEAP32[$vararg_buffer10>>2] = $30;
  $vararg_ptr1 = (($vararg_buffer10) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $24;
  $vararg_ptr2 = (($vararg_buffer10) + 8|0);
  HEAP32[$vararg_ptr2>>2] = $34;
  _abort_message(10336,$vararg_buffer10);
  // unreachable;
 } else {
  $35 = HEAP32[10312>>2]|0;
  HEAP32[$vararg_buffer10>>2] = $35;
  $vararg_ptr6 = (($vararg_buffer10) + 4|0);
  HEAP32[$vararg_ptr6>>2] = $24;
  _abort_message(10384,$vararg_buffer10);
  // unreachable;
 }
}
function __ZN10__cxxabiv112_GLOBAL__N_110construct_Ev() {
 var $0 = 0, $1 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 $0 = (_pthread_key_create((10488|0),(72|0))|0);
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 } else {
  _abort_message(10560,$vararg_buffer);
  // unreachable;
 }
}
function __ZN10__cxxabiv112_GLOBAL__N_19destruct_EPv($p) {
 $p = $p|0;
 var $0 = 0, $1 = 0, $2 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0;
 $vararg_buffer = sp;
 _free($p);
 $0 = HEAP32[10488>>2]|0;
 $1 = (_pthread_setspecific(($0|0),(0|0))|0);
 $2 = ($1|0)==(0);
 if ($2) {
  STACKTOP = sp;return;
 } else {
  _abort_message(10616,$vararg_buffer);
  // unreachable;
 }
}
function _malloc($bytes) {
 $bytes = $bytes|0;
 var $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i23$i = 0, $$pre$i25 = 0, $$pre$phi$i$iZ2D = 0, $$pre$phi$i24$iZ2D = 0, $$pre$phi$i26Z2D = 0, $$pre$phi$iZ2D = 0, $$pre$phi59$i$iZ2D = 0, $$pre$phiZ2D = 0, $$pre105 = 0, $$pre58$i$i = 0, $$rsize$0$i = 0, $$rsize$3$i = 0, $$sum = 0, $$sum$i$i = 0, $$sum$i$i$i = 0, $$sum$i12$i = 0, $$sum$i13$i = 0;
 var $$sum$i16$i = 0, $$sum$i19$i = 0, $$sum$i2338 = 0, $$sum$i32 = 0, $$sum$i39 = 0, $$sum1 = 0, $$sum1$i = 0, $$sum1$i$i = 0, $$sum1$i14$i = 0, $$sum1$i20$i = 0, $$sum1$i24 = 0, $$sum10 = 0, $$sum10$i = 0, $$sum10$i$i = 0, $$sum10$pre$i$i = 0, $$sum102$i = 0, $$sum103$i = 0, $$sum104$i = 0, $$sum105$i = 0, $$sum106$i = 0;
 var $$sum107$i = 0, $$sum108$i = 0, $$sum109$i = 0, $$sum11$i = 0, $$sum11$i$i = 0, $$sum11$i22$i = 0, $$sum110$i = 0, $$sum111$i = 0, $$sum1112 = 0, $$sum112$i = 0, $$sum113$i = 0, $$sum114$i = 0, $$sum115$i = 0, $$sum12$i = 0, $$sum12$i$i = 0, $$sum13$i = 0, $$sum13$i$i = 0, $$sum14$i$i = 0, $$sum14$pre$i = 0, $$sum15$i = 0;
 var $$sum15$i$i = 0, $$sum16$i = 0, $$sum16$i$i = 0, $$sum17$i = 0, $$sum17$i$i = 0, $$sum18$i = 0, $$sum1819$i$i = 0, $$sum2 = 0, $$sum2$i = 0, $$sum2$i$i = 0, $$sum2$i$i$i = 0, $$sum2$i15$i = 0, $$sum2$i17$i = 0, $$sum2$i21$i = 0, $$sum2$pre$i = 0, $$sum20$i$i = 0, $$sum21$i$i = 0, $$sum22$i$i = 0, $$sum23$i$i = 0, $$sum24$i$i = 0;
 var $$sum25$i$i = 0, $$sum26$pre$i$i = 0, $$sum27$i$i = 0, $$sum28$i$i = 0, $$sum29$i$i = 0, $$sum3$i = 0, $$sum3$i$i = 0, $$sum3$i27 = 0, $$sum30$i$i = 0, $$sum3132$i$i = 0, $$sum34$i$i = 0, $$sum3536$i$i = 0, $$sum3738$i$i = 0, $$sum39$i$i = 0, $$sum4 = 0, $$sum4$i = 0, $$sum4$i28 = 0, $$sum40$i$i = 0, $$sum41$i$i = 0, $$sum42$i$i = 0;
 var $$sum5$i = 0, $$sum5$i$i = 0, $$sum56 = 0, $$sum6$i = 0, $$sum67$i$i = 0, $$sum7$i = 0, $$sum8$i = 0, $$sum8$pre = 0, $$sum9 = 0, $$sum9$i = 0, $$sum9$i$i = 0, $$tsize$1$i = 0, $$v$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0;
 var $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0;
 var $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0;
 var $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0;
 var $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0;
 var $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0;
 var $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0;
 var $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0;
 var $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0;
 var $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0;
 var $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0;
 var $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0;
 var $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0;
 var $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0;
 var $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0;
 var $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0;
 var $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0;
 var $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0;
 var $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0;
 var $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0;
 var $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0;
 var $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0;
 var $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0;
 var $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0;
 var $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0;
 var $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0;
 var $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0;
 var $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0;
 var $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0;
 var $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0;
 var $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0;
 var $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0;
 var $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0;
 var $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0;
 var $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0;
 var $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0;
 var $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0;
 var $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0;
 var $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0;
 var $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0;
 var $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0;
 var $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0;
 var $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $F$0$i$i = 0, $F1$0$i = 0, $F4$0 = 0, $F4$0$i$i = 0, $F5$0$i = 0, $I1$0$c$i$i = 0, $I1$0$i$i = 0, $I7$0$i = 0, $I7$0$i$i = 0, $K12$027$i = 0, $K2$015$i$i = 0, $K8$053$i$i = 0;
 var $R$0$i = 0, $R$0$i$i = 0, $R$0$i18 = 0, $R$1$i = 0, $R$1$i$i = 0, $R$1$i20 = 0, $RP$0$i = 0, $RP$0$i$i = 0, $RP$0$i17 = 0, $T$0$lcssa$i = 0, $T$0$lcssa$i$i = 0, $T$0$lcssa$i26$i = 0, $T$014$i$i = 0, $T$026$i = 0, $T$052$i$i = 0, $br$0$i = 0, $br$030$i = 0, $cond$i = 0, $cond$i$i = 0, $cond$i21 = 0;
 var $exitcond$i$i = 0, $i$02$i$i = 0, $idx$0$i = 0, $mem$0 = 0, $nb$0 = 0, $oldfirst$0$i$i = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond$i27$i = 0, $or$cond$i29 = 0, $or$cond1$i = 0, $or$cond19$i = 0, $or$cond2$i = 0, $or$cond24$i = 0, $or$cond3$i = 0, $or$cond4$i = 0, $or$cond47$i = 0, $or$cond5$i = 0, $or$cond6$i = 0, $or$cond8$i = 0;
 var $qsize$0$i$i = 0, $rsize$0$i = 0, $rsize$0$i15 = 0, $rsize$1$i = 0, $rsize$2$i = 0, $rsize$3$lcssa$i = 0, $rsize$331$i = 0, $rst$0$i = 0, $rst$1$i = 0, $sizebits$0$i = 0, $sp$0$i$i = 0, $sp$0$i$i$i = 0, $sp$073$i = 0, $sp$166$i = 0, $ssize$0$i = 0, $ssize$1$i = 0, $ssize$129$i = 0, $ssize$2$i = 0, $t$0$i = 0, $t$0$i14 = 0;
 var $t$1$i = 0, $t$2$ph$i = 0, $t$2$v$3$i = 0, $t$230$i = 0, $tbase$245$i = 0, $tsize$03141$i = 0, $tsize$1$i = 0, $tsize$244$i = 0, $v$0$i = 0, $v$0$i16 = 0, $v$1$i = 0, $v$2$i = 0, $v$3$lcssa$i = 0, $v$332$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($bytes>>>0)<(245);
 do {
  if ($0) {
   $1 = ($bytes>>>0)<(11);
   if ($1) {
    $5 = 16;
   } else {
    $2 = (($bytes) + 11)|0;
    $3 = $2 & -8;
    $5 = $3;
   }
   $4 = $5 >>> 3;
   $6 = HEAP32[11264>>2]|0;
   $7 = $6 >>> $4;
   $8 = $7 & 3;
   $9 = ($8|0)==(0);
   if (!($9)) {
    $10 = $7 & 1;
    $11 = $10 ^ 1;
    $12 = (($11) + ($4))|0;
    $13 = $12 << 1;
    $14 = ((11264 + ($13<<2)|0) + 40|0);
    $$sum10 = (($13) + 2)|0;
    $15 = ((11264 + ($$sum10<<2)|0) + 40|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = (($16) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($14|0)==($18|0);
    do {
     if ($19) {
      $20 = 1 << $12;
      $21 = $20 ^ -1;
      $22 = $6 & $21;
      HEAP32[11264>>2] = $22;
     } else {
      $23 = HEAP32[((11264 + 16|0))>>2]|0;
      $24 = ($18>>>0)<($23>>>0);
      if ($24) {
       _abort();
       // unreachable;
      }
      $25 = (($18) + 12|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = ($26|0)==($16|0);
      if ($27) {
       HEAP32[$25>>2] = $14;
       HEAP32[$15>>2] = $18;
       break;
      } else {
       _abort();
       // unreachable;
      }
     }
    } while(0);
    $28 = $12 << 3;
    $29 = $28 | 3;
    $30 = (($16) + 4|0);
    HEAP32[$30>>2] = $29;
    $$sum1112 = $28 | 4;
    $31 = (($16) + ($$sum1112)|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = $32 | 1;
    HEAP32[$31>>2] = $33;
    $mem$0 = $17;
    STACKTOP = sp;return ($mem$0|0);
   }
   $34 = HEAP32[((11264 + 8|0))>>2]|0;
   $35 = ($5>>>0)>($34>>>0);
   if ($35) {
    $36 = ($7|0)==(0);
    if (!($36)) {
     $37 = $7 << $4;
     $38 = 2 << $4;
     $39 = (0 - ($38))|0;
     $40 = $38 | $39;
     $41 = $37 & $40;
     $42 = (0 - ($41))|0;
     $43 = $41 & $42;
     $44 = (($43) + -1)|0;
     $45 = $44 >>> 12;
     $46 = $45 & 16;
     $47 = $44 >>> $46;
     $48 = $47 >>> 5;
     $49 = $48 & 8;
     $50 = $49 | $46;
     $51 = $47 >>> $49;
     $52 = $51 >>> 2;
     $53 = $52 & 4;
     $54 = $50 | $53;
     $55 = $51 >>> $53;
     $56 = $55 >>> 1;
     $57 = $56 & 2;
     $58 = $54 | $57;
     $59 = $55 >>> $57;
     $60 = $59 >>> 1;
     $61 = $60 & 1;
     $62 = $58 | $61;
     $63 = $59 >>> $61;
     $64 = (($62) + ($63))|0;
     $65 = $64 << 1;
     $66 = ((11264 + ($65<<2)|0) + 40|0);
     $$sum4 = (($65) + 2)|0;
     $67 = ((11264 + ($$sum4<<2)|0) + 40|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = (($68) + 8|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = ($66|0)==($70|0);
     do {
      if ($71) {
       $72 = 1 << $64;
       $73 = $72 ^ -1;
       $74 = $6 & $73;
       HEAP32[11264>>2] = $74;
       $88 = $34;
      } else {
       $75 = HEAP32[((11264 + 16|0))>>2]|0;
       $76 = ($70>>>0)<($75>>>0);
       if ($76) {
        _abort();
        // unreachable;
       }
       $77 = (($70) + 12|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = ($78|0)==($68|0);
       if ($79) {
        HEAP32[$77>>2] = $66;
        HEAP32[$67>>2] = $70;
        $$pre = HEAP32[((11264 + 8|0))>>2]|0;
        $88 = $$pre;
        break;
       } else {
        _abort();
        // unreachable;
       }
      }
     } while(0);
     $80 = $64 << 3;
     $81 = (($80) - ($5))|0;
     $82 = $5 | 3;
     $83 = (($68) + 4|0);
     HEAP32[$83>>2] = $82;
     $84 = (($68) + ($5)|0);
     $85 = $81 | 1;
     $$sum56 = $5 | 4;
     $86 = (($68) + ($$sum56)|0);
     HEAP32[$86>>2] = $85;
     $87 = (($68) + ($80)|0);
     HEAP32[$87>>2] = $81;
     $89 = ($88|0)==(0);
     if (!($89)) {
      $90 = HEAP32[((11264 + 20|0))>>2]|0;
      $91 = $88 >>> 3;
      $92 = $91 << 1;
      $93 = ((11264 + ($92<<2)|0) + 40|0);
      $94 = HEAP32[11264>>2]|0;
      $95 = 1 << $91;
      $96 = $94 & $95;
      $97 = ($96|0)==(0);
      if ($97) {
       $98 = $94 | $95;
       HEAP32[11264>>2] = $98;
       $$sum8$pre = (($92) + 2)|0;
       $$pre105 = ((11264 + ($$sum8$pre<<2)|0) + 40|0);
       $$pre$phiZ2D = $$pre105;$F4$0 = $93;
      } else {
       $$sum9 = (($92) + 2)|0;
       $99 = ((11264 + ($$sum9<<2)|0) + 40|0);
       $100 = HEAP32[$99>>2]|0;
       $101 = HEAP32[((11264 + 16|0))>>2]|0;
       $102 = ($100>>>0)<($101>>>0);
       if ($102) {
        _abort();
        // unreachable;
       } else {
        $$pre$phiZ2D = $99;$F4$0 = $100;
       }
      }
      HEAP32[$$pre$phiZ2D>>2] = $90;
      $103 = (($F4$0) + 12|0);
      HEAP32[$103>>2] = $90;
      $104 = (($90) + 8|0);
      HEAP32[$104>>2] = $F4$0;
      $105 = (($90) + 12|0);
      HEAP32[$105>>2] = $93;
     }
     HEAP32[((11264 + 8|0))>>2] = $81;
     HEAP32[((11264 + 20|0))>>2] = $84;
     $mem$0 = $69;
     STACKTOP = sp;return ($mem$0|0);
    }
    $106 = HEAP32[((11264 + 4|0))>>2]|0;
    $107 = ($106|0)==(0);
    if ($107) {
     $nb$0 = $5;
    } else {
     $108 = (0 - ($106))|0;
     $109 = $106 & $108;
     $110 = (($109) + -1)|0;
     $111 = $110 >>> 12;
     $112 = $111 & 16;
     $113 = $110 >>> $112;
     $114 = $113 >>> 5;
     $115 = $114 & 8;
     $116 = $115 | $112;
     $117 = $113 >>> $115;
     $118 = $117 >>> 2;
     $119 = $118 & 4;
     $120 = $116 | $119;
     $121 = $117 >>> $119;
     $122 = $121 >>> 1;
     $123 = $122 & 2;
     $124 = $120 | $123;
     $125 = $121 >>> $123;
     $126 = $125 >>> 1;
     $127 = $126 & 1;
     $128 = $124 | $127;
     $129 = $125 >>> $127;
     $130 = (($128) + ($129))|0;
     $131 = ((11264 + ($130<<2)|0) + 304|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = (($132) + 4|0);
     $134 = HEAP32[$133>>2]|0;
     $135 = $134 & -8;
     $136 = (($135) - ($5))|0;
     $rsize$0$i = $136;$t$0$i = $132;$v$0$i = $132;
     while(1) {
      $137 = (($t$0$i) + 16|0);
      $138 = HEAP32[$137>>2]|0;
      $139 = ($138|0)==(0|0);
      if ($139) {
       $140 = (($t$0$i) + 20|0);
       $141 = HEAP32[$140>>2]|0;
       $142 = ($141|0)==(0|0);
       if ($142) {
        break;
       } else {
        $144 = $141;
       }
      } else {
       $144 = $138;
      }
      $143 = (($144) + 4|0);
      $145 = HEAP32[$143>>2]|0;
      $146 = $145 & -8;
      $147 = (($146) - ($5))|0;
      $148 = ($147>>>0)<($rsize$0$i>>>0);
      $$rsize$0$i = $148 ? $147 : $rsize$0$i;
      $$v$0$i = $148 ? $144 : $v$0$i;
      $rsize$0$i = $$rsize$0$i;$t$0$i = $144;$v$0$i = $$v$0$i;
     }
     $149 = HEAP32[((11264 + 16|0))>>2]|0;
     $150 = ($v$0$i>>>0)<($149>>>0);
     if ($150) {
      _abort();
      // unreachable;
     }
     $151 = (($v$0$i) + ($5)|0);
     $152 = ($v$0$i>>>0)<($151>>>0);
     if (!($152)) {
      _abort();
      // unreachable;
     }
     $153 = (($v$0$i) + 24|0);
     $154 = HEAP32[$153>>2]|0;
     $155 = (($v$0$i) + 12|0);
     $156 = HEAP32[$155>>2]|0;
     $157 = ($156|0)==($v$0$i|0);
     do {
      if ($157) {
       $167 = (($v$0$i) + 20|0);
       $168 = HEAP32[$167>>2]|0;
       $169 = ($168|0)==(0|0);
       if ($169) {
        $170 = (($v$0$i) + 16|0);
        $171 = HEAP32[$170>>2]|0;
        $172 = ($171|0)==(0|0);
        if ($172) {
         $R$1$i = 0;
         break;
        } else {
         $R$0$i = $171;$RP$0$i = $170;
        }
       } else {
        $R$0$i = $168;$RP$0$i = $167;
       }
       while(1) {
        $173 = (($R$0$i) + 20|0);
        $174 = HEAP32[$173>>2]|0;
        $175 = ($174|0)==(0|0);
        if (!($175)) {
         $R$0$i = $174;$RP$0$i = $173;
         continue;
        }
        $176 = (($R$0$i) + 16|0);
        $177 = HEAP32[$176>>2]|0;
        $178 = ($177|0)==(0|0);
        if ($178) {
         break;
        } else {
         $R$0$i = $177;$RP$0$i = $176;
        }
       }
       $179 = ($RP$0$i>>>0)<($149>>>0);
       if ($179) {
        _abort();
        // unreachable;
       } else {
        HEAP32[$RP$0$i>>2] = 0;
        $R$1$i = $R$0$i;
        break;
       }
      } else {
       $158 = (($v$0$i) + 8|0);
       $159 = HEAP32[$158>>2]|0;
       $160 = ($159>>>0)<($149>>>0);
       if ($160) {
        _abort();
        // unreachable;
       }
       $161 = (($159) + 12|0);
       $162 = HEAP32[$161>>2]|0;
       $163 = ($162|0)==($v$0$i|0);
       if (!($163)) {
        _abort();
        // unreachable;
       }
       $164 = (($156) + 8|0);
       $165 = HEAP32[$164>>2]|0;
       $166 = ($165|0)==($v$0$i|0);
       if ($166) {
        HEAP32[$161>>2] = $156;
        HEAP32[$164>>2] = $159;
        $R$1$i = $156;
        break;
       } else {
        _abort();
        // unreachable;
       }
      }
     } while(0);
     $180 = ($154|0)==(0|0);
     do {
      if (!($180)) {
       $181 = (($v$0$i) + 28|0);
       $182 = HEAP32[$181>>2]|0;
       $183 = ((11264 + ($182<<2)|0) + 304|0);
       $184 = HEAP32[$183>>2]|0;
       $185 = ($v$0$i|0)==($184|0);
       if ($185) {
        HEAP32[$183>>2] = $R$1$i;
        $cond$i = ($R$1$i|0)==(0|0);
        if ($cond$i) {
         $186 = 1 << $182;
         $187 = $186 ^ -1;
         $188 = HEAP32[((11264 + 4|0))>>2]|0;
         $189 = $188 & $187;
         HEAP32[((11264 + 4|0))>>2] = $189;
         break;
        }
       } else {
        $190 = HEAP32[((11264 + 16|0))>>2]|0;
        $191 = ($154>>>0)<($190>>>0);
        if ($191) {
         _abort();
         // unreachable;
        }
        $192 = (($154) + 16|0);
        $193 = HEAP32[$192>>2]|0;
        $194 = ($193|0)==($v$0$i|0);
        if ($194) {
         HEAP32[$192>>2] = $R$1$i;
        } else {
         $195 = (($154) + 20|0);
         HEAP32[$195>>2] = $R$1$i;
        }
        $196 = ($R$1$i|0)==(0|0);
        if ($196) {
         break;
        }
       }
       $197 = HEAP32[((11264 + 16|0))>>2]|0;
       $198 = ($R$1$i>>>0)<($197>>>0);
       if ($198) {
        _abort();
        // unreachable;
       }
       $199 = (($R$1$i) + 24|0);
       HEAP32[$199>>2] = $154;
       $200 = (($v$0$i) + 16|0);
       $201 = HEAP32[$200>>2]|0;
       $202 = ($201|0)==(0|0);
       do {
        if (!($202)) {
         $203 = ($201>>>0)<($197>>>0);
         if ($203) {
          _abort();
          // unreachable;
         } else {
          $204 = (($R$1$i) + 16|0);
          HEAP32[$204>>2] = $201;
          $205 = (($201) + 24|0);
          HEAP32[$205>>2] = $R$1$i;
          break;
         }
        }
       } while(0);
       $206 = (($v$0$i) + 20|0);
       $207 = HEAP32[$206>>2]|0;
       $208 = ($207|0)==(0|0);
       if (!($208)) {
        $209 = HEAP32[((11264 + 16|0))>>2]|0;
        $210 = ($207>>>0)<($209>>>0);
        if ($210) {
         _abort();
         // unreachable;
        } else {
         $211 = (($R$1$i) + 20|0);
         HEAP32[$211>>2] = $207;
         $212 = (($207) + 24|0);
         HEAP32[$212>>2] = $R$1$i;
         break;
        }
       }
      }
     } while(0);
     $213 = ($rsize$0$i>>>0)<(16);
     if ($213) {
      $214 = (($rsize$0$i) + ($5))|0;
      $215 = $214 | 3;
      $216 = (($v$0$i) + 4|0);
      HEAP32[$216>>2] = $215;
      $$sum4$i = (($214) + 4)|0;
      $217 = (($v$0$i) + ($$sum4$i)|0);
      $218 = HEAP32[$217>>2]|0;
      $219 = $218 | 1;
      HEAP32[$217>>2] = $219;
     } else {
      $220 = $5 | 3;
      $221 = (($v$0$i) + 4|0);
      HEAP32[$221>>2] = $220;
      $222 = $rsize$0$i | 1;
      $$sum$i39 = $5 | 4;
      $223 = (($v$0$i) + ($$sum$i39)|0);
      HEAP32[$223>>2] = $222;
      $$sum1$i = (($rsize$0$i) + ($5))|0;
      $224 = (($v$0$i) + ($$sum1$i)|0);
      HEAP32[$224>>2] = $rsize$0$i;
      $225 = HEAP32[((11264 + 8|0))>>2]|0;
      $226 = ($225|0)==(0);
      if (!($226)) {
       $227 = HEAP32[((11264 + 20|0))>>2]|0;
       $228 = $225 >>> 3;
       $229 = $228 << 1;
       $230 = ((11264 + ($229<<2)|0) + 40|0);
       $231 = HEAP32[11264>>2]|0;
       $232 = 1 << $228;
       $233 = $231 & $232;
       $234 = ($233|0)==(0);
       if ($234) {
        $235 = $231 | $232;
        HEAP32[11264>>2] = $235;
        $$sum2$pre$i = (($229) + 2)|0;
        $$pre$i = ((11264 + ($$sum2$pre$i<<2)|0) + 40|0);
        $$pre$phi$iZ2D = $$pre$i;$F1$0$i = $230;
       } else {
        $$sum3$i = (($229) + 2)|0;
        $236 = ((11264 + ($$sum3$i<<2)|0) + 40|0);
        $237 = HEAP32[$236>>2]|0;
        $238 = HEAP32[((11264 + 16|0))>>2]|0;
        $239 = ($237>>>0)<($238>>>0);
        if ($239) {
         _abort();
         // unreachable;
        } else {
         $$pre$phi$iZ2D = $236;$F1$0$i = $237;
        }
       }
       HEAP32[$$pre$phi$iZ2D>>2] = $227;
       $240 = (($F1$0$i) + 12|0);
       HEAP32[$240>>2] = $227;
       $241 = (($227) + 8|0);
       HEAP32[$241>>2] = $F1$0$i;
       $242 = (($227) + 12|0);
       HEAP32[$242>>2] = $230;
      }
      HEAP32[((11264 + 8|0))>>2] = $rsize$0$i;
      HEAP32[((11264 + 20|0))>>2] = $151;
     }
     $243 = (($v$0$i) + 8|0);
     $mem$0 = $243;
     STACKTOP = sp;return ($mem$0|0);
    }
   } else {
    $nb$0 = $5;
   }
  } else {
   $244 = ($bytes>>>0)>(4294967231);
   if ($244) {
    $nb$0 = -1;
   } else {
    $245 = (($bytes) + 11)|0;
    $246 = $245 & -8;
    $247 = HEAP32[((11264 + 4|0))>>2]|0;
    $248 = ($247|0)==(0);
    if ($248) {
     $nb$0 = $246;
    } else {
     $249 = (0 - ($246))|0;
     $250 = $245 >>> 8;
     $251 = ($250|0)==(0);
     if ($251) {
      $idx$0$i = 0;
     } else {
      $252 = ($246>>>0)>(16777215);
      if ($252) {
       $idx$0$i = 31;
      } else {
       $253 = (($250) + 1048320)|0;
       $254 = $253 >>> 16;
       $255 = $254 & 8;
       $256 = $250 << $255;
       $257 = (($256) + 520192)|0;
       $258 = $257 >>> 16;
       $259 = $258 & 4;
       $260 = $259 | $255;
       $261 = $256 << $259;
       $262 = (($261) + 245760)|0;
       $263 = $262 >>> 16;
       $264 = $263 & 2;
       $265 = $260 | $264;
       $266 = (14 - ($265))|0;
       $267 = $261 << $264;
       $268 = $267 >>> 15;
       $269 = (($266) + ($268))|0;
       $270 = $269 << 1;
       $271 = (($269) + 7)|0;
       $272 = $246 >>> $271;
       $273 = $272 & 1;
       $274 = $273 | $270;
       $idx$0$i = $274;
      }
     }
     $275 = ((11264 + ($idx$0$i<<2)|0) + 304|0);
     $276 = HEAP32[$275>>2]|0;
     $277 = ($276|0)==(0|0);
     L9: do {
      if ($277) {
       $rsize$2$i = $249;$t$1$i = 0;$v$2$i = 0;
      } else {
       $278 = ($idx$0$i|0)==(31);
       if ($278) {
        $282 = 0;
       } else {
        $279 = $idx$0$i >>> 1;
        $280 = (25 - ($279))|0;
        $282 = $280;
       }
       $281 = $246 << $282;
       $rsize$0$i15 = $249;$rst$0$i = 0;$sizebits$0$i = $281;$t$0$i14 = $276;$v$0$i16 = 0;
       while(1) {
        $283 = (($t$0$i14) + 4|0);
        $284 = HEAP32[$283>>2]|0;
        $285 = $284 & -8;
        $286 = (($285) - ($246))|0;
        $287 = ($286>>>0)<($rsize$0$i15>>>0);
        if ($287) {
         $288 = ($285|0)==($246|0);
         if ($288) {
          $rsize$2$i = $286;$t$1$i = $t$0$i14;$v$2$i = $t$0$i14;
          break L9;
         } else {
          $rsize$1$i = $286;$v$1$i = $t$0$i14;
         }
        } else {
         $rsize$1$i = $rsize$0$i15;$v$1$i = $v$0$i16;
        }
        $289 = (($t$0$i14) + 20|0);
        $290 = HEAP32[$289>>2]|0;
        $291 = $sizebits$0$i >>> 31;
        $292 = ((($t$0$i14) + ($291<<2)|0) + 16|0);
        $293 = HEAP32[$292>>2]|0;
        $294 = ($290|0)==(0|0);
        $295 = ($290|0)==($293|0);
        $or$cond19$i = $294 | $295;
        $rst$1$i = $or$cond19$i ? $rst$0$i : $290;
        $296 = ($293|0)==(0|0);
        $297 = $sizebits$0$i << 1;
        if ($296) {
         $rsize$2$i = $rsize$1$i;$t$1$i = $rst$1$i;$v$2$i = $v$1$i;
         break;
        } else {
         $rsize$0$i15 = $rsize$1$i;$rst$0$i = $rst$1$i;$sizebits$0$i = $297;$t$0$i14 = $293;$v$0$i16 = $v$1$i;
        }
       }
      }
     } while(0);
     $298 = ($t$1$i|0)==(0|0);
     $299 = ($v$2$i|0)==(0|0);
     $or$cond$i = $298 & $299;
     if ($or$cond$i) {
      $300 = 2 << $idx$0$i;
      $301 = (0 - ($300))|0;
      $302 = $300 | $301;
      $303 = $247 & $302;
      $304 = ($303|0)==(0);
      if ($304) {
       $nb$0 = $246;
       break;
      }
      $305 = (0 - ($303))|0;
      $306 = $303 & $305;
      $307 = (($306) + -1)|0;
      $308 = $307 >>> 12;
      $309 = $308 & 16;
      $310 = $307 >>> $309;
      $311 = $310 >>> 5;
      $312 = $311 & 8;
      $313 = $312 | $309;
      $314 = $310 >>> $312;
      $315 = $314 >>> 2;
      $316 = $315 & 4;
      $317 = $313 | $316;
      $318 = $314 >>> $316;
      $319 = $318 >>> 1;
      $320 = $319 & 2;
      $321 = $317 | $320;
      $322 = $318 >>> $320;
      $323 = $322 >>> 1;
      $324 = $323 & 1;
      $325 = $321 | $324;
      $326 = $322 >>> $324;
      $327 = (($325) + ($326))|0;
      $328 = ((11264 + ($327<<2)|0) + 304|0);
      $329 = HEAP32[$328>>2]|0;
      $t$2$ph$i = $329;
     } else {
      $t$2$ph$i = $t$1$i;
     }
     $330 = ($t$2$ph$i|0)==(0|0);
     if ($330) {
      $rsize$3$lcssa$i = $rsize$2$i;$v$3$lcssa$i = $v$2$i;
     } else {
      $rsize$331$i = $rsize$2$i;$t$230$i = $t$2$ph$i;$v$332$i = $v$2$i;
      while(1) {
       $331 = (($t$230$i) + 4|0);
       $332 = HEAP32[$331>>2]|0;
       $333 = $332 & -8;
       $334 = (($333) - ($246))|0;
       $335 = ($334>>>0)<($rsize$331$i>>>0);
       $$rsize$3$i = $335 ? $334 : $rsize$331$i;
       $t$2$v$3$i = $335 ? $t$230$i : $v$332$i;
       $336 = (($t$230$i) + 16|0);
       $337 = HEAP32[$336>>2]|0;
       $338 = ($337|0)==(0|0);
       if (!($338)) {
        $rsize$331$i = $$rsize$3$i;$t$230$i = $337;$v$332$i = $t$2$v$3$i;
        continue;
       }
       $339 = (($t$230$i) + 20|0);
       $340 = HEAP32[$339>>2]|0;
       $341 = ($340|0)==(0|0);
       if ($341) {
        $rsize$3$lcssa$i = $$rsize$3$i;$v$3$lcssa$i = $t$2$v$3$i;
        break;
       } else {
        $rsize$331$i = $$rsize$3$i;$t$230$i = $340;$v$332$i = $t$2$v$3$i;
       }
      }
     }
     $342 = ($v$3$lcssa$i|0)==(0|0);
     if ($342) {
      $nb$0 = $246;
     } else {
      $343 = HEAP32[((11264 + 8|0))>>2]|0;
      $344 = (($343) - ($246))|0;
      $345 = ($rsize$3$lcssa$i>>>0)<($344>>>0);
      if ($345) {
       $346 = HEAP32[((11264 + 16|0))>>2]|0;
       $347 = ($v$3$lcssa$i>>>0)<($346>>>0);
       if ($347) {
        _abort();
        // unreachable;
       }
       $348 = (($v$3$lcssa$i) + ($246)|0);
       $349 = ($v$3$lcssa$i>>>0)<($348>>>0);
       if (!($349)) {
        _abort();
        // unreachable;
       }
       $350 = (($v$3$lcssa$i) + 24|0);
       $351 = HEAP32[$350>>2]|0;
       $352 = (($v$3$lcssa$i) + 12|0);
       $353 = HEAP32[$352>>2]|0;
       $354 = ($353|0)==($v$3$lcssa$i|0);
       do {
        if ($354) {
         $364 = (($v$3$lcssa$i) + 20|0);
         $365 = HEAP32[$364>>2]|0;
         $366 = ($365|0)==(0|0);
         if ($366) {
          $367 = (($v$3$lcssa$i) + 16|0);
          $368 = HEAP32[$367>>2]|0;
          $369 = ($368|0)==(0|0);
          if ($369) {
           $R$1$i20 = 0;
           break;
          } else {
           $R$0$i18 = $368;$RP$0$i17 = $367;
          }
         } else {
          $R$0$i18 = $365;$RP$0$i17 = $364;
         }
         while(1) {
          $370 = (($R$0$i18) + 20|0);
          $371 = HEAP32[$370>>2]|0;
          $372 = ($371|0)==(0|0);
          if (!($372)) {
           $R$0$i18 = $371;$RP$0$i17 = $370;
           continue;
          }
          $373 = (($R$0$i18) + 16|0);
          $374 = HEAP32[$373>>2]|0;
          $375 = ($374|0)==(0|0);
          if ($375) {
           break;
          } else {
           $R$0$i18 = $374;$RP$0$i17 = $373;
          }
         }
         $376 = ($RP$0$i17>>>0)<($346>>>0);
         if ($376) {
          _abort();
          // unreachable;
         } else {
          HEAP32[$RP$0$i17>>2] = 0;
          $R$1$i20 = $R$0$i18;
          break;
         }
        } else {
         $355 = (($v$3$lcssa$i) + 8|0);
         $356 = HEAP32[$355>>2]|0;
         $357 = ($356>>>0)<($346>>>0);
         if ($357) {
          _abort();
          // unreachable;
         }
         $358 = (($356) + 12|0);
         $359 = HEAP32[$358>>2]|0;
         $360 = ($359|0)==($v$3$lcssa$i|0);
         if (!($360)) {
          _abort();
          // unreachable;
         }
         $361 = (($353) + 8|0);
         $362 = HEAP32[$361>>2]|0;
         $363 = ($362|0)==($v$3$lcssa$i|0);
         if ($363) {
          HEAP32[$358>>2] = $353;
          HEAP32[$361>>2] = $356;
          $R$1$i20 = $353;
          break;
         } else {
          _abort();
          // unreachable;
         }
        }
       } while(0);
       $377 = ($351|0)==(0|0);
       do {
        if (!($377)) {
         $378 = (($v$3$lcssa$i) + 28|0);
         $379 = HEAP32[$378>>2]|0;
         $380 = ((11264 + ($379<<2)|0) + 304|0);
         $381 = HEAP32[$380>>2]|0;
         $382 = ($v$3$lcssa$i|0)==($381|0);
         if ($382) {
          HEAP32[$380>>2] = $R$1$i20;
          $cond$i21 = ($R$1$i20|0)==(0|0);
          if ($cond$i21) {
           $383 = 1 << $379;
           $384 = $383 ^ -1;
           $385 = HEAP32[((11264 + 4|0))>>2]|0;
           $386 = $385 & $384;
           HEAP32[((11264 + 4|0))>>2] = $386;
           break;
          }
         } else {
          $387 = HEAP32[((11264 + 16|0))>>2]|0;
          $388 = ($351>>>0)<($387>>>0);
          if ($388) {
           _abort();
           // unreachable;
          }
          $389 = (($351) + 16|0);
          $390 = HEAP32[$389>>2]|0;
          $391 = ($390|0)==($v$3$lcssa$i|0);
          if ($391) {
           HEAP32[$389>>2] = $R$1$i20;
          } else {
           $392 = (($351) + 20|0);
           HEAP32[$392>>2] = $R$1$i20;
          }
          $393 = ($R$1$i20|0)==(0|0);
          if ($393) {
           break;
          }
         }
         $394 = HEAP32[((11264 + 16|0))>>2]|0;
         $395 = ($R$1$i20>>>0)<($394>>>0);
         if ($395) {
          _abort();
          // unreachable;
         }
         $396 = (($R$1$i20) + 24|0);
         HEAP32[$396>>2] = $351;
         $397 = (($v$3$lcssa$i) + 16|0);
         $398 = HEAP32[$397>>2]|0;
         $399 = ($398|0)==(0|0);
         do {
          if (!($399)) {
           $400 = ($398>>>0)<($394>>>0);
           if ($400) {
            _abort();
            // unreachable;
           } else {
            $401 = (($R$1$i20) + 16|0);
            HEAP32[$401>>2] = $398;
            $402 = (($398) + 24|0);
            HEAP32[$402>>2] = $R$1$i20;
            break;
           }
          }
         } while(0);
         $403 = (($v$3$lcssa$i) + 20|0);
         $404 = HEAP32[$403>>2]|0;
         $405 = ($404|0)==(0|0);
         if (!($405)) {
          $406 = HEAP32[((11264 + 16|0))>>2]|0;
          $407 = ($404>>>0)<($406>>>0);
          if ($407) {
           _abort();
           // unreachable;
          } else {
           $408 = (($R$1$i20) + 20|0);
           HEAP32[$408>>2] = $404;
           $409 = (($404) + 24|0);
           HEAP32[$409>>2] = $R$1$i20;
           break;
          }
         }
        }
       } while(0);
       $410 = ($rsize$3$lcssa$i>>>0)<(16);
       L87: do {
        if ($410) {
         $411 = (($rsize$3$lcssa$i) + ($246))|0;
         $412 = $411 | 3;
         $413 = (($v$3$lcssa$i) + 4|0);
         HEAP32[$413>>2] = $412;
         $$sum18$i = (($411) + 4)|0;
         $414 = (($v$3$lcssa$i) + ($$sum18$i)|0);
         $415 = HEAP32[$414>>2]|0;
         $416 = $415 | 1;
         HEAP32[$414>>2] = $416;
        } else {
         $417 = $246 | 3;
         $418 = (($v$3$lcssa$i) + 4|0);
         HEAP32[$418>>2] = $417;
         $419 = $rsize$3$lcssa$i | 1;
         $$sum$i2338 = $246 | 4;
         $420 = (($v$3$lcssa$i) + ($$sum$i2338)|0);
         HEAP32[$420>>2] = $419;
         $$sum1$i24 = (($rsize$3$lcssa$i) + ($246))|0;
         $421 = (($v$3$lcssa$i) + ($$sum1$i24)|0);
         HEAP32[$421>>2] = $rsize$3$lcssa$i;
         $422 = $rsize$3$lcssa$i >>> 3;
         $423 = ($rsize$3$lcssa$i>>>0)<(256);
         if ($423) {
          $424 = $422 << 1;
          $425 = ((11264 + ($424<<2)|0) + 40|0);
          $426 = HEAP32[11264>>2]|0;
          $427 = 1 << $422;
          $428 = $426 & $427;
          $429 = ($428|0)==(0);
          do {
           if ($429) {
            $430 = $426 | $427;
            HEAP32[11264>>2] = $430;
            $$sum14$pre$i = (($424) + 2)|0;
            $$pre$i25 = ((11264 + ($$sum14$pre$i<<2)|0) + 40|0);
            $$pre$phi$i26Z2D = $$pre$i25;$F5$0$i = $425;
           } else {
            $$sum17$i = (($424) + 2)|0;
            $431 = ((11264 + ($$sum17$i<<2)|0) + 40|0);
            $432 = HEAP32[$431>>2]|0;
            $433 = HEAP32[((11264 + 16|0))>>2]|0;
            $434 = ($432>>>0)<($433>>>0);
            if (!($434)) {
             $$pre$phi$i26Z2D = $431;$F5$0$i = $432;
             break;
            }
            _abort();
            // unreachable;
           }
          } while(0);
          HEAP32[$$pre$phi$i26Z2D>>2] = $348;
          $435 = (($F5$0$i) + 12|0);
          HEAP32[$435>>2] = $348;
          $$sum15$i = (($246) + 8)|0;
          $436 = (($v$3$lcssa$i) + ($$sum15$i)|0);
          HEAP32[$436>>2] = $F5$0$i;
          $$sum16$i = (($246) + 12)|0;
          $437 = (($v$3$lcssa$i) + ($$sum16$i)|0);
          HEAP32[$437>>2] = $425;
          break;
         }
         $438 = $rsize$3$lcssa$i >>> 8;
         $439 = ($438|0)==(0);
         if ($439) {
          $I7$0$i = 0;
         } else {
          $440 = ($rsize$3$lcssa$i>>>0)>(16777215);
          if ($440) {
           $I7$0$i = 31;
          } else {
           $441 = (($438) + 1048320)|0;
           $442 = $441 >>> 16;
           $443 = $442 & 8;
           $444 = $438 << $443;
           $445 = (($444) + 520192)|0;
           $446 = $445 >>> 16;
           $447 = $446 & 4;
           $448 = $447 | $443;
           $449 = $444 << $447;
           $450 = (($449) + 245760)|0;
           $451 = $450 >>> 16;
           $452 = $451 & 2;
           $453 = $448 | $452;
           $454 = (14 - ($453))|0;
           $455 = $449 << $452;
           $456 = $455 >>> 15;
           $457 = (($454) + ($456))|0;
           $458 = $457 << 1;
           $459 = (($457) + 7)|0;
           $460 = $rsize$3$lcssa$i >>> $459;
           $461 = $460 & 1;
           $462 = $461 | $458;
           $I7$0$i = $462;
          }
         }
         $463 = ((11264 + ($I7$0$i<<2)|0) + 304|0);
         $$sum2$i = (($246) + 28)|0;
         $464 = (($v$3$lcssa$i) + ($$sum2$i)|0);
         HEAP32[$464>>2] = $I7$0$i;
         $$sum3$i27 = (($246) + 16)|0;
         $465 = (($v$3$lcssa$i) + ($$sum3$i27)|0);
         $$sum4$i28 = (($246) + 20)|0;
         $466 = (($v$3$lcssa$i) + ($$sum4$i28)|0);
         HEAP32[$466>>2] = 0;
         HEAP32[$465>>2] = 0;
         $467 = HEAP32[((11264 + 4|0))>>2]|0;
         $468 = 1 << $I7$0$i;
         $469 = $467 & $468;
         $470 = ($469|0)==(0);
         if ($470) {
          $471 = $467 | $468;
          HEAP32[((11264 + 4|0))>>2] = $471;
          HEAP32[$463>>2] = $348;
          $$sum5$i = (($246) + 24)|0;
          $472 = (($v$3$lcssa$i) + ($$sum5$i)|0);
          HEAP32[$472>>2] = $463;
          $$sum6$i = (($246) + 12)|0;
          $473 = (($v$3$lcssa$i) + ($$sum6$i)|0);
          HEAP32[$473>>2] = $348;
          $$sum7$i = (($246) + 8)|0;
          $474 = (($v$3$lcssa$i) + ($$sum7$i)|0);
          HEAP32[$474>>2] = $348;
          break;
         }
         $475 = HEAP32[$463>>2]|0;
         $476 = ($I7$0$i|0)==(31);
         if ($476) {
          $484 = 0;
         } else {
          $477 = $I7$0$i >>> 1;
          $478 = (25 - ($477))|0;
          $484 = $478;
         }
         $479 = (($475) + 4|0);
         $480 = HEAP32[$479>>2]|0;
         $481 = $480 & -8;
         $482 = ($481|0)==($rsize$3$lcssa$i|0);
         L108: do {
          if ($482) {
           $T$0$lcssa$i = $475;
          } else {
           $483 = $rsize$3$lcssa$i << $484;
           $K12$027$i = $483;$T$026$i = $475;
           while(1) {
            $491 = $K12$027$i >>> 31;
            $492 = ((($T$026$i) + ($491<<2)|0) + 16|0);
            $487 = HEAP32[$492>>2]|0;
            $493 = ($487|0)==(0|0);
            if ($493) {
             break;
            }
            $485 = $K12$027$i << 1;
            $486 = (($487) + 4|0);
            $488 = HEAP32[$486>>2]|0;
            $489 = $488 & -8;
            $490 = ($489|0)==($rsize$3$lcssa$i|0);
            if ($490) {
             $T$0$lcssa$i = $487;
             break L108;
            } else {
             $K12$027$i = $485;$T$026$i = $487;
            }
           }
           $494 = HEAP32[((11264 + 16|0))>>2]|0;
           $495 = ($492>>>0)<($494>>>0);
           if ($495) {
            _abort();
            // unreachable;
           } else {
            HEAP32[$492>>2] = $348;
            $$sum11$i = (($246) + 24)|0;
            $496 = (($v$3$lcssa$i) + ($$sum11$i)|0);
            HEAP32[$496>>2] = $T$026$i;
            $$sum12$i = (($246) + 12)|0;
            $497 = (($v$3$lcssa$i) + ($$sum12$i)|0);
            HEAP32[$497>>2] = $348;
            $$sum13$i = (($246) + 8)|0;
            $498 = (($v$3$lcssa$i) + ($$sum13$i)|0);
            HEAP32[$498>>2] = $348;
            break L87;
           }
          }
         } while(0);
         $499 = (($T$0$lcssa$i) + 8|0);
         $500 = HEAP32[$499>>2]|0;
         $501 = HEAP32[((11264 + 16|0))>>2]|0;
         $502 = ($T$0$lcssa$i>>>0)>=($501>>>0);
         $503 = ($500>>>0)>=($501>>>0);
         $or$cond24$i = $502 & $503;
         if ($or$cond24$i) {
          $504 = (($500) + 12|0);
          HEAP32[$504>>2] = $348;
          HEAP32[$499>>2] = $348;
          $$sum8$i = (($246) + 8)|0;
          $505 = (($v$3$lcssa$i) + ($$sum8$i)|0);
          HEAP32[$505>>2] = $500;
          $$sum9$i = (($246) + 12)|0;
          $506 = (($v$3$lcssa$i) + ($$sum9$i)|0);
          HEAP32[$506>>2] = $T$0$lcssa$i;
          $$sum10$i = (($246) + 24)|0;
          $507 = (($v$3$lcssa$i) + ($$sum10$i)|0);
          HEAP32[$507>>2] = 0;
          break;
         } else {
          _abort();
          // unreachable;
         }
        }
       } while(0);
       $508 = (($v$3$lcssa$i) + 8|0);
       $mem$0 = $508;
       STACKTOP = sp;return ($mem$0|0);
      } else {
       $nb$0 = $246;
      }
     }
    }
   }
  }
 } while(0);
 $509 = HEAP32[((11264 + 8|0))>>2]|0;
 $510 = ($509>>>0)<($nb$0>>>0);
 if (!($510)) {
  $511 = (($509) - ($nb$0))|0;
  $512 = HEAP32[((11264 + 20|0))>>2]|0;
  $513 = ($511>>>0)>(15);
  if ($513) {
   $514 = (($512) + ($nb$0)|0);
   HEAP32[((11264 + 20|0))>>2] = $514;
   HEAP32[((11264 + 8|0))>>2] = $511;
   $515 = $511 | 1;
   $$sum2 = (($nb$0) + 4)|0;
   $516 = (($512) + ($$sum2)|0);
   HEAP32[$516>>2] = $515;
   $517 = (($512) + ($509)|0);
   HEAP32[$517>>2] = $511;
   $518 = $nb$0 | 3;
   $519 = (($512) + 4|0);
   HEAP32[$519>>2] = $518;
  } else {
   HEAP32[((11264 + 8|0))>>2] = 0;
   HEAP32[((11264 + 20|0))>>2] = 0;
   $520 = $509 | 3;
   $521 = (($512) + 4|0);
   HEAP32[$521>>2] = $520;
   $$sum1 = (($509) + 4)|0;
   $522 = (($512) + ($$sum1)|0);
   $523 = HEAP32[$522>>2]|0;
   $524 = $523 | 1;
   HEAP32[$522>>2] = $524;
  }
  $525 = (($512) + 8|0);
  $mem$0 = $525;
  STACKTOP = sp;return ($mem$0|0);
 }
 $526 = HEAP32[((11264 + 12|0))>>2]|0;
 $527 = ($526>>>0)>($nb$0>>>0);
 if ($527) {
  $528 = (($526) - ($nb$0))|0;
  HEAP32[((11264 + 12|0))>>2] = $528;
  $529 = HEAP32[((11264 + 24|0))>>2]|0;
  $530 = (($529) + ($nb$0)|0);
  HEAP32[((11264 + 24|0))>>2] = $530;
  $531 = $528 | 1;
  $$sum = (($nb$0) + 4)|0;
  $532 = (($529) + ($$sum)|0);
  HEAP32[$532>>2] = $531;
  $533 = $nb$0 | 3;
  $534 = (($529) + 4|0);
  HEAP32[$534>>2] = $533;
  $535 = (($529) + 8|0);
  $mem$0 = $535;
  STACKTOP = sp;return ($mem$0|0);
 }
 $536 = HEAP32[11736>>2]|0;
 $537 = ($536|0)==(0);
 do {
  if ($537) {
   $538 = (_sysconf(30)|0);
   $539 = (($538) + -1)|0;
   $540 = $539 & $538;
   $541 = ($540|0)==(0);
   if ($541) {
    HEAP32[((11736 + 8|0))>>2] = $538;
    HEAP32[((11736 + 4|0))>>2] = $538;
    HEAP32[((11736 + 12|0))>>2] = -1;
    HEAP32[((11736 + 16|0))>>2] = -1;
    HEAP32[((11736 + 20|0))>>2] = 0;
    HEAP32[((11264 + 444|0))>>2] = 0;
    $542 = (_time((0|0))|0);
    $543 = $542 & -16;
    $544 = $543 ^ 1431655768;
    HEAP32[11736>>2] = $544;
    break;
   } else {
    _abort();
    // unreachable;
   }
  }
 } while(0);
 $545 = (($nb$0) + 48)|0;
 $546 = HEAP32[((11736 + 8|0))>>2]|0;
 $547 = (($nb$0) + 47)|0;
 $548 = (($546) + ($547))|0;
 $549 = (0 - ($546))|0;
 $550 = $548 & $549;
 $551 = ($550>>>0)>($nb$0>>>0);
 if (!($551)) {
  $mem$0 = 0;
  STACKTOP = sp;return ($mem$0|0);
 }
 $552 = HEAP32[((11264 + 440|0))>>2]|0;
 $553 = ($552|0)==(0);
 if (!($553)) {
  $554 = HEAP32[((11264 + 432|0))>>2]|0;
  $555 = (($554) + ($550))|0;
  $556 = ($555>>>0)<=($554>>>0);
  $557 = ($555>>>0)>($552>>>0);
  $or$cond1$i = $556 | $557;
  if ($or$cond1$i) {
   $mem$0 = 0;
   STACKTOP = sp;return ($mem$0|0);
  }
 }
 $558 = HEAP32[((11264 + 444|0))>>2]|0;
 $559 = $558 & 4;
 $560 = ($559|0)==(0);
 L266: do {
  if ($560) {
   $561 = HEAP32[((11264 + 24|0))>>2]|0;
   $562 = ($561|0)==(0|0);
   L268: do {
    if ($562) {
     label = 181;
    } else {
     $sp$0$i$i = ((11264 + 448|0));
     while(1) {
      $563 = HEAP32[$sp$0$i$i>>2]|0;
      $564 = ($563>>>0)>($561>>>0);
      if (!($564)) {
       $565 = (($sp$0$i$i) + 4|0);
       $566 = HEAP32[$565>>2]|0;
       $567 = (($563) + ($566)|0);
       $568 = ($567>>>0)>($561>>>0);
       if ($568) {
        break;
       }
      }
      $569 = (($sp$0$i$i) + 8|0);
      $570 = HEAP32[$569>>2]|0;
      $571 = ($570|0)==(0|0);
      if ($571) {
       label = 181;
       break L268;
      } else {
       $sp$0$i$i = $570;
      }
     }
     $572 = ($sp$0$i$i|0)==(0|0);
     if ($572) {
      label = 181;
     } else {
      $595 = HEAP32[((11264 + 12|0))>>2]|0;
      $596 = (($548) - ($595))|0;
      $597 = $596 & $549;
      $598 = ($597>>>0)<(2147483647);
      if ($598) {
       $599 = (_sbrk(($597|0))|0);
       $600 = HEAP32[$sp$0$i$i>>2]|0;
       $601 = HEAP32[$565>>2]|0;
       $602 = (($600) + ($601)|0);
       $603 = ($599|0)==($602|0);
       if ($603) {
        $br$0$i = $599;$ssize$1$i = $597;
        label = 190;
       } else {
        $br$030$i = $599;$ssize$129$i = $597;
        label = 191;
       }
      } else {
       $tsize$03141$i = 0;
      }
     }
    }
   } while(0);
   do {
    if ((label|0) == 181) {
     $573 = (_sbrk(0)|0);
     $574 = ($573|0)==((-1)|0);
     if ($574) {
      $tsize$03141$i = 0;
     } else {
      $575 = $573;
      $576 = HEAP32[((11736 + 4|0))>>2]|0;
      $577 = (($576) + -1)|0;
      $578 = $577 & $575;
      $579 = ($578|0)==(0);
      if ($579) {
       $ssize$0$i = $550;
      } else {
       $580 = (($577) + ($575))|0;
       $581 = (0 - ($576))|0;
       $582 = $580 & $581;
       $583 = (($550) - ($575))|0;
       $584 = (($583) + ($582))|0;
       $ssize$0$i = $584;
      }
      $585 = HEAP32[((11264 + 432|0))>>2]|0;
      $586 = (($585) + ($ssize$0$i))|0;
      $587 = ($ssize$0$i>>>0)>($nb$0>>>0);
      $588 = ($ssize$0$i>>>0)<(2147483647);
      $or$cond$i29 = $587 & $588;
      if ($or$cond$i29) {
       $589 = HEAP32[((11264 + 440|0))>>2]|0;
       $590 = ($589|0)==(0);
       if (!($590)) {
        $591 = ($586>>>0)<=($585>>>0);
        $592 = ($586>>>0)>($589>>>0);
        $or$cond2$i = $591 | $592;
        if ($or$cond2$i) {
         $tsize$03141$i = 0;
         break;
        }
       }
       $593 = (_sbrk(($ssize$0$i|0))|0);
       $594 = ($593|0)==($573|0);
       if ($594) {
        $br$0$i = $573;$ssize$1$i = $ssize$0$i;
        label = 190;
       } else {
        $br$030$i = $593;$ssize$129$i = $ssize$0$i;
        label = 191;
       }
      } else {
       $tsize$03141$i = 0;
      }
     }
    }
   } while(0);
   L288: do {
    if ((label|0) == 190) {
     $604 = ($br$0$i|0)==((-1)|0);
     if ($604) {
      $tsize$03141$i = $ssize$1$i;
     } else {
      $tbase$245$i = $br$0$i;$tsize$244$i = $ssize$1$i;
      label = 201;
      break L266;
     }
    }
    else if ((label|0) == 191) {
     $605 = (0 - ($ssize$129$i))|0;
     $606 = ($br$030$i|0)!=((-1)|0);
     $607 = ($ssize$129$i>>>0)<(2147483647);
     $or$cond5$i = $606 & $607;
     $608 = ($545>>>0)>($ssize$129$i>>>0);
     $or$cond4$i = $or$cond5$i & $608;
     do {
      if ($or$cond4$i) {
       $609 = HEAP32[((11736 + 8|0))>>2]|0;
       $610 = (($547) - ($ssize$129$i))|0;
       $611 = (($610) + ($609))|0;
       $612 = (0 - ($609))|0;
       $613 = $611 & $612;
       $614 = ($613>>>0)<(2147483647);
       if ($614) {
        $615 = (_sbrk(($613|0))|0);
        $616 = ($615|0)==((-1)|0);
        if ($616) {
         (_sbrk(($605|0))|0);
         $tsize$03141$i = 0;
         break L288;
        } else {
         $617 = (($613) + ($ssize$129$i))|0;
         $ssize$2$i = $617;
         break;
        }
       } else {
        $ssize$2$i = $ssize$129$i;
       }
      } else {
       $ssize$2$i = $ssize$129$i;
      }
     } while(0);
     $618 = ($br$030$i|0)==((-1)|0);
     if ($618) {
      $tsize$03141$i = 0;
     } else {
      $tbase$245$i = $br$030$i;$tsize$244$i = $ssize$2$i;
      label = 201;
      break L266;
     }
    }
   } while(0);
   $619 = HEAP32[((11264 + 444|0))>>2]|0;
   $620 = $619 | 4;
   HEAP32[((11264 + 444|0))>>2] = $620;
   $tsize$1$i = $tsize$03141$i;
   label = 198;
  } else {
   $tsize$1$i = 0;
   label = 198;
  }
 } while(0);
 if ((label|0) == 198) {
  $621 = ($550>>>0)<(2147483647);
  if ($621) {
   $622 = (_sbrk(($550|0))|0);
   $623 = (_sbrk(0)|0);
   $624 = ($622|0)!=((-1)|0);
   $625 = ($623|0)!=((-1)|0);
   $or$cond3$i = $624 & $625;
   $626 = ($622>>>0)<($623>>>0);
   $or$cond6$i = $or$cond3$i & $626;
   if ($or$cond6$i) {
    $627 = $623;
    $628 = $622;
    $629 = (($627) - ($628))|0;
    $630 = (($nb$0) + 40)|0;
    $631 = ($629>>>0)>($630>>>0);
    $$tsize$1$i = $631 ? $629 : $tsize$1$i;
    if ($631) {
     $tbase$245$i = $622;$tsize$244$i = $$tsize$1$i;
     label = 201;
    }
   }
  }
 }
 if ((label|0) == 201) {
  $632 = HEAP32[((11264 + 432|0))>>2]|0;
  $633 = (($632) + ($tsize$244$i))|0;
  HEAP32[((11264 + 432|0))>>2] = $633;
  $634 = HEAP32[((11264 + 436|0))>>2]|0;
  $635 = ($633>>>0)>($634>>>0);
  if ($635) {
   HEAP32[((11264 + 436|0))>>2] = $633;
  }
  $636 = HEAP32[((11264 + 24|0))>>2]|0;
  $637 = ($636|0)==(0|0);
  L308: do {
   if ($637) {
    $638 = HEAP32[((11264 + 16|0))>>2]|0;
    $639 = ($638|0)==(0|0);
    $640 = ($tbase$245$i>>>0)<($638>>>0);
    $or$cond8$i = $639 | $640;
    if ($or$cond8$i) {
     HEAP32[((11264 + 16|0))>>2] = $tbase$245$i;
    }
    HEAP32[((11264 + 448|0))>>2] = $tbase$245$i;
    HEAP32[((11264 + 452|0))>>2] = $tsize$244$i;
    HEAP32[((11264 + 460|0))>>2] = 0;
    $641 = HEAP32[11736>>2]|0;
    HEAP32[((11264 + 36|0))>>2] = $641;
    HEAP32[((11264 + 32|0))>>2] = -1;
    $i$02$i$i = 0;
    while(1) {
     $642 = $i$02$i$i << 1;
     $643 = ((11264 + ($642<<2)|0) + 40|0);
     $$sum$i$i = (($642) + 3)|0;
     $644 = ((11264 + ($$sum$i$i<<2)|0) + 40|0);
     HEAP32[$644>>2] = $643;
     $$sum1$i$i = (($642) + 2)|0;
     $645 = ((11264 + ($$sum1$i$i<<2)|0) + 40|0);
     HEAP32[$645>>2] = $643;
     $646 = (($i$02$i$i) + 1)|0;
     $exitcond$i$i = ($646|0)==(32);
     if ($exitcond$i$i) {
      break;
     } else {
      $i$02$i$i = $646;
     }
    }
    $647 = (($tsize$244$i) + -40)|0;
    $648 = (($tbase$245$i) + 8|0);
    $649 = $648;
    $650 = $649 & 7;
    $651 = ($650|0)==(0);
    if ($651) {
     $655 = 0;
    } else {
     $652 = (0 - ($649))|0;
     $653 = $652 & 7;
     $655 = $653;
    }
    $654 = (($tbase$245$i) + ($655)|0);
    $656 = (($647) - ($655))|0;
    HEAP32[((11264 + 24|0))>>2] = $654;
    HEAP32[((11264 + 12|0))>>2] = $656;
    $657 = $656 | 1;
    $$sum$i12$i = (($655) + 4)|0;
    $658 = (($tbase$245$i) + ($$sum$i12$i)|0);
    HEAP32[$658>>2] = $657;
    $$sum2$i$i = (($tsize$244$i) + -36)|0;
    $659 = (($tbase$245$i) + ($$sum2$i$i)|0);
    HEAP32[$659>>2] = 40;
    $660 = HEAP32[((11736 + 16|0))>>2]|0;
    HEAP32[((11264 + 28|0))>>2] = $660;
   } else {
    $sp$073$i = ((11264 + 448|0));
    while(1) {
     $661 = HEAP32[$sp$073$i>>2]|0;
     $662 = (($sp$073$i) + 4|0);
     $663 = HEAP32[$662>>2]|0;
     $664 = (($661) + ($663)|0);
     $665 = ($tbase$245$i|0)==($664|0);
     if ($665) {
      label = 213;
      break;
     }
     $666 = (($sp$073$i) + 8|0);
     $667 = HEAP32[$666>>2]|0;
     $668 = ($667|0)==(0|0);
     if ($668) {
      break;
     } else {
      $sp$073$i = $667;
     }
    }
    if ((label|0) == 213) {
     $669 = (($sp$073$i) + 12|0);
     $670 = HEAP32[$669>>2]|0;
     $671 = $670 & 8;
     $672 = ($671|0)==(0);
     if ($672) {
      $673 = ($636>>>0)>=($661>>>0);
      $674 = ($636>>>0)<($tbase$245$i>>>0);
      $or$cond47$i = $673 & $674;
      if ($or$cond47$i) {
       $675 = (($663) + ($tsize$244$i))|0;
       HEAP32[$662>>2] = $675;
       $676 = HEAP32[((11264 + 12|0))>>2]|0;
       $677 = (($676) + ($tsize$244$i))|0;
       $678 = (($636) + 8|0);
       $679 = $678;
       $680 = $679 & 7;
       $681 = ($680|0)==(0);
       if ($681) {
        $685 = 0;
       } else {
        $682 = (0 - ($679))|0;
        $683 = $682 & 7;
        $685 = $683;
       }
       $684 = (($636) + ($685)|0);
       $686 = (($677) - ($685))|0;
       HEAP32[((11264 + 24|0))>>2] = $684;
       HEAP32[((11264 + 12|0))>>2] = $686;
       $687 = $686 | 1;
       $$sum$i16$i = (($685) + 4)|0;
       $688 = (($636) + ($$sum$i16$i)|0);
       HEAP32[$688>>2] = $687;
       $$sum2$i17$i = (($677) + 4)|0;
       $689 = (($636) + ($$sum2$i17$i)|0);
       HEAP32[$689>>2] = 40;
       $690 = HEAP32[((11736 + 16|0))>>2]|0;
       HEAP32[((11264 + 28|0))>>2] = $690;
       break;
      }
     }
    }
    $691 = HEAP32[((11264 + 16|0))>>2]|0;
    $692 = ($tbase$245$i>>>0)<($691>>>0);
    if ($692) {
     HEAP32[((11264 + 16|0))>>2] = $tbase$245$i;
     $756 = $tbase$245$i;
    } else {
     $756 = $691;
    }
    $693 = (($tbase$245$i) + ($tsize$244$i)|0);
    $sp$166$i = ((11264 + 448|0));
    while(1) {
     $694 = HEAP32[$sp$166$i>>2]|0;
     $695 = ($694|0)==($693|0);
     if ($695) {
      label = 223;
      break;
     }
     $696 = (($sp$166$i) + 8|0);
     $697 = HEAP32[$696>>2]|0;
     $698 = ($697|0)==(0|0);
     if ($698) {
      break;
     } else {
      $sp$166$i = $697;
     }
    }
    if ((label|0) == 223) {
     $699 = (($sp$166$i) + 12|0);
     $700 = HEAP32[$699>>2]|0;
     $701 = $700 & 8;
     $702 = ($701|0)==(0);
     if ($702) {
      HEAP32[$sp$166$i>>2] = $tbase$245$i;
      $703 = (($sp$166$i) + 4|0);
      $704 = HEAP32[$703>>2]|0;
      $705 = (($704) + ($tsize$244$i))|0;
      HEAP32[$703>>2] = $705;
      $706 = (($tbase$245$i) + 8|0);
      $707 = $706;
      $708 = $707 & 7;
      $709 = ($708|0)==(0);
      if ($709) {
       $713 = 0;
      } else {
       $710 = (0 - ($707))|0;
       $711 = $710 & 7;
       $713 = $711;
      }
      $712 = (($tbase$245$i) + ($713)|0);
      $$sum102$i = (($tsize$244$i) + 8)|0;
      $714 = (($tbase$245$i) + ($$sum102$i)|0);
      $715 = $714;
      $716 = $715 & 7;
      $717 = ($716|0)==(0);
      if ($717) {
       $720 = 0;
      } else {
       $718 = (0 - ($715))|0;
       $719 = $718 & 7;
       $720 = $719;
      }
      $$sum103$i = (($720) + ($tsize$244$i))|0;
      $721 = (($tbase$245$i) + ($$sum103$i)|0);
      $722 = $721;
      $723 = $712;
      $724 = (($722) - ($723))|0;
      $$sum$i19$i = (($713) + ($nb$0))|0;
      $725 = (($tbase$245$i) + ($$sum$i19$i)|0);
      $726 = (($724) - ($nb$0))|0;
      $727 = $nb$0 | 3;
      $$sum1$i20$i = (($713) + 4)|0;
      $728 = (($tbase$245$i) + ($$sum1$i20$i)|0);
      HEAP32[$728>>2] = $727;
      $729 = ($721|0)==($636|0);
      L345: do {
       if ($729) {
        $730 = HEAP32[((11264 + 12|0))>>2]|0;
        $731 = (($730) + ($726))|0;
        HEAP32[((11264 + 12|0))>>2] = $731;
        HEAP32[((11264 + 24|0))>>2] = $725;
        $732 = $731 | 1;
        $$sum42$i$i = (($$sum$i19$i) + 4)|0;
        $733 = (($tbase$245$i) + ($$sum42$i$i)|0);
        HEAP32[$733>>2] = $732;
       } else {
        $734 = HEAP32[((11264 + 20|0))>>2]|0;
        $735 = ($721|0)==($734|0);
        if ($735) {
         $736 = HEAP32[((11264 + 8|0))>>2]|0;
         $737 = (($736) + ($726))|0;
         HEAP32[((11264 + 8|0))>>2] = $737;
         HEAP32[((11264 + 20|0))>>2] = $725;
         $738 = $737 | 1;
         $$sum40$i$i = (($$sum$i19$i) + 4)|0;
         $739 = (($tbase$245$i) + ($$sum40$i$i)|0);
         HEAP32[$739>>2] = $738;
         $$sum41$i$i = (($737) + ($$sum$i19$i))|0;
         $740 = (($tbase$245$i) + ($$sum41$i$i)|0);
         HEAP32[$740>>2] = $737;
         break;
        }
        $$sum2$i21$i = (($tsize$244$i) + 4)|0;
        $$sum104$i = (($$sum2$i21$i) + ($720))|0;
        $741 = (($tbase$245$i) + ($$sum104$i)|0);
        $742 = HEAP32[$741>>2]|0;
        $743 = $742 & 3;
        $744 = ($743|0)==(1);
        if ($744) {
         $745 = $742 & -8;
         $746 = $742 >>> 3;
         $747 = ($742>>>0)<(256);
         L353: do {
          if ($747) {
           $$sum3738$i$i = $720 | 8;
           $$sum114$i = (($$sum3738$i$i) + ($tsize$244$i))|0;
           $748 = (($tbase$245$i) + ($$sum114$i)|0);
           $749 = HEAP32[$748>>2]|0;
           $$sum39$i$i = (($tsize$244$i) + 12)|0;
           $$sum115$i = (($$sum39$i$i) + ($720))|0;
           $750 = (($tbase$245$i) + ($$sum115$i)|0);
           $751 = HEAP32[$750>>2]|0;
           $752 = $746 << 1;
           $753 = ((11264 + ($752<<2)|0) + 40|0);
           $754 = ($749|0)==($753|0);
           do {
            if (!($754)) {
             $755 = ($749>>>0)<($756>>>0);
             if ($755) {
              _abort();
              // unreachable;
             }
             $757 = (($749) + 12|0);
             $758 = HEAP32[$757>>2]|0;
             $759 = ($758|0)==($721|0);
             if ($759) {
              break;
             }
             _abort();
             // unreachable;
            }
           } while(0);
           $760 = ($751|0)==($749|0);
           if ($760) {
            $761 = 1 << $746;
            $762 = $761 ^ -1;
            $763 = HEAP32[11264>>2]|0;
            $764 = $763 & $762;
            HEAP32[11264>>2] = $764;
            break;
           }
           $765 = ($751|0)==($753|0);
           do {
            if ($765) {
             $$pre58$i$i = (($751) + 8|0);
             $$pre$phi59$i$iZ2D = $$pre58$i$i;
            } else {
             $766 = ($751>>>0)<($756>>>0);
             if ($766) {
              _abort();
              // unreachable;
             }
             $767 = (($751) + 8|0);
             $768 = HEAP32[$767>>2]|0;
             $769 = ($768|0)==($721|0);
             if ($769) {
              $$pre$phi59$i$iZ2D = $767;
              break;
             }
             _abort();
             // unreachable;
            }
           } while(0);
           $770 = (($749) + 12|0);
           HEAP32[$770>>2] = $751;
           HEAP32[$$pre$phi59$i$iZ2D>>2] = $749;
          } else {
           $$sum34$i$i = $720 | 24;
           $$sum105$i = (($$sum34$i$i) + ($tsize$244$i))|0;
           $771 = (($tbase$245$i) + ($$sum105$i)|0);
           $772 = HEAP32[$771>>2]|0;
           $$sum5$i$i = (($tsize$244$i) + 12)|0;
           $$sum106$i = (($$sum5$i$i) + ($720))|0;
           $773 = (($tbase$245$i) + ($$sum106$i)|0);
           $774 = HEAP32[$773>>2]|0;
           $775 = ($774|0)==($721|0);
           do {
            if ($775) {
             $$sum67$i$i = $720 | 16;
             $$sum112$i = (($$sum2$i21$i) + ($$sum67$i$i))|0;
             $785 = (($tbase$245$i) + ($$sum112$i)|0);
             $786 = HEAP32[$785>>2]|0;
             $787 = ($786|0)==(0|0);
             if ($787) {
              $$sum113$i = (($$sum67$i$i) + ($tsize$244$i))|0;
              $788 = (($tbase$245$i) + ($$sum113$i)|0);
              $789 = HEAP32[$788>>2]|0;
              $790 = ($789|0)==(0|0);
              if ($790) {
               $R$1$i$i = 0;
               break;
              } else {
               $R$0$i$i = $789;$RP$0$i$i = $788;
              }
             } else {
              $R$0$i$i = $786;$RP$0$i$i = $785;
             }
             while(1) {
              $791 = (($R$0$i$i) + 20|0);
              $792 = HEAP32[$791>>2]|0;
              $793 = ($792|0)==(0|0);
              if (!($793)) {
               $R$0$i$i = $792;$RP$0$i$i = $791;
               continue;
              }
              $794 = (($R$0$i$i) + 16|0);
              $795 = HEAP32[$794>>2]|0;
              $796 = ($795|0)==(0|0);
              if ($796) {
               break;
              } else {
               $R$0$i$i = $795;$RP$0$i$i = $794;
              }
             }
             $797 = ($RP$0$i$i>>>0)<($756>>>0);
             if ($797) {
              _abort();
              // unreachable;
             } else {
              HEAP32[$RP$0$i$i>>2] = 0;
              $R$1$i$i = $R$0$i$i;
              break;
             }
            } else {
             $$sum3536$i$i = $720 | 8;
             $$sum107$i = (($$sum3536$i$i) + ($tsize$244$i))|0;
             $776 = (($tbase$245$i) + ($$sum107$i)|0);
             $777 = HEAP32[$776>>2]|0;
             $778 = ($777>>>0)<($756>>>0);
             if ($778) {
              _abort();
              // unreachable;
             }
             $779 = (($777) + 12|0);
             $780 = HEAP32[$779>>2]|0;
             $781 = ($780|0)==($721|0);
             if (!($781)) {
              _abort();
              // unreachable;
             }
             $782 = (($774) + 8|0);
             $783 = HEAP32[$782>>2]|0;
             $784 = ($783|0)==($721|0);
             if ($784) {
              HEAP32[$779>>2] = $774;
              HEAP32[$782>>2] = $777;
              $R$1$i$i = $774;
              break;
             } else {
              _abort();
              // unreachable;
             }
            }
           } while(0);
           $798 = ($772|0)==(0|0);
           if ($798) {
            break;
           }
           $$sum30$i$i = (($tsize$244$i) + 28)|0;
           $$sum108$i = (($$sum30$i$i) + ($720))|0;
           $799 = (($tbase$245$i) + ($$sum108$i)|0);
           $800 = HEAP32[$799>>2]|0;
           $801 = ((11264 + ($800<<2)|0) + 304|0);
           $802 = HEAP32[$801>>2]|0;
           $803 = ($721|0)==($802|0);
           do {
            if ($803) {
             HEAP32[$801>>2] = $R$1$i$i;
             $cond$i$i = ($R$1$i$i|0)==(0|0);
             if (!($cond$i$i)) {
              break;
             }
             $804 = 1 << $800;
             $805 = $804 ^ -1;
             $806 = HEAP32[((11264 + 4|0))>>2]|0;
             $807 = $806 & $805;
             HEAP32[((11264 + 4|0))>>2] = $807;
             break L353;
            } else {
             $808 = HEAP32[((11264 + 16|0))>>2]|0;
             $809 = ($772>>>0)<($808>>>0);
             if ($809) {
              _abort();
              // unreachable;
             }
             $810 = (($772) + 16|0);
             $811 = HEAP32[$810>>2]|0;
             $812 = ($811|0)==($721|0);
             if ($812) {
              HEAP32[$810>>2] = $R$1$i$i;
             } else {
              $813 = (($772) + 20|0);
              HEAP32[$813>>2] = $R$1$i$i;
             }
             $814 = ($R$1$i$i|0)==(0|0);
             if ($814) {
              break L353;
             }
            }
           } while(0);
           $815 = HEAP32[((11264 + 16|0))>>2]|0;
           $816 = ($R$1$i$i>>>0)<($815>>>0);
           if ($816) {
            _abort();
            // unreachable;
           }
           $817 = (($R$1$i$i) + 24|0);
           HEAP32[$817>>2] = $772;
           $$sum3132$i$i = $720 | 16;
           $$sum109$i = (($$sum3132$i$i) + ($tsize$244$i))|0;
           $818 = (($tbase$245$i) + ($$sum109$i)|0);
           $819 = HEAP32[$818>>2]|0;
           $820 = ($819|0)==(0|0);
           do {
            if (!($820)) {
             $821 = ($819>>>0)<($815>>>0);
             if ($821) {
              _abort();
              // unreachable;
             } else {
              $822 = (($R$1$i$i) + 16|0);
              HEAP32[$822>>2] = $819;
              $823 = (($819) + 24|0);
              HEAP32[$823>>2] = $R$1$i$i;
              break;
             }
            }
           } while(0);
           $$sum110$i = (($$sum2$i21$i) + ($$sum3132$i$i))|0;
           $824 = (($tbase$245$i) + ($$sum110$i)|0);
           $825 = HEAP32[$824>>2]|0;
           $826 = ($825|0)==(0|0);
           if ($826) {
            break;
           }
           $827 = HEAP32[((11264 + 16|0))>>2]|0;
           $828 = ($825>>>0)<($827>>>0);
           if ($828) {
            _abort();
            // unreachable;
           } else {
            $829 = (($R$1$i$i) + 20|0);
            HEAP32[$829>>2] = $825;
            $830 = (($825) + 24|0);
            HEAP32[$830>>2] = $R$1$i$i;
            break;
           }
          }
         } while(0);
         $$sum9$i$i = $745 | $720;
         $$sum111$i = (($$sum9$i$i) + ($tsize$244$i))|0;
         $831 = (($tbase$245$i) + ($$sum111$i)|0);
         $832 = (($745) + ($726))|0;
         $oldfirst$0$i$i = $831;$qsize$0$i$i = $832;
        } else {
         $oldfirst$0$i$i = $721;$qsize$0$i$i = $726;
        }
        $833 = (($oldfirst$0$i$i) + 4|0);
        $834 = HEAP32[$833>>2]|0;
        $835 = $834 & -2;
        HEAP32[$833>>2] = $835;
        $836 = $qsize$0$i$i | 1;
        $$sum10$i$i = (($$sum$i19$i) + 4)|0;
        $837 = (($tbase$245$i) + ($$sum10$i$i)|0);
        HEAP32[$837>>2] = $836;
        $$sum11$i22$i = (($qsize$0$i$i) + ($$sum$i19$i))|0;
        $838 = (($tbase$245$i) + ($$sum11$i22$i)|0);
        HEAP32[$838>>2] = $qsize$0$i$i;
        $839 = $qsize$0$i$i >>> 3;
        $840 = ($qsize$0$i$i>>>0)<(256);
        if ($840) {
         $841 = $839 << 1;
         $842 = ((11264 + ($841<<2)|0) + 40|0);
         $843 = HEAP32[11264>>2]|0;
         $844 = 1 << $839;
         $845 = $843 & $844;
         $846 = ($845|0)==(0);
         do {
          if ($846) {
           $847 = $843 | $844;
           HEAP32[11264>>2] = $847;
           $$sum26$pre$i$i = (($841) + 2)|0;
           $$pre$i23$i = ((11264 + ($$sum26$pre$i$i<<2)|0) + 40|0);
           $$pre$phi$i24$iZ2D = $$pre$i23$i;$F4$0$i$i = $842;
          } else {
           $$sum29$i$i = (($841) + 2)|0;
           $848 = ((11264 + ($$sum29$i$i<<2)|0) + 40|0);
           $849 = HEAP32[$848>>2]|0;
           $850 = HEAP32[((11264 + 16|0))>>2]|0;
           $851 = ($849>>>0)<($850>>>0);
           if (!($851)) {
            $$pre$phi$i24$iZ2D = $848;$F4$0$i$i = $849;
            break;
           }
           _abort();
           // unreachable;
          }
         } while(0);
         HEAP32[$$pre$phi$i24$iZ2D>>2] = $725;
         $852 = (($F4$0$i$i) + 12|0);
         HEAP32[$852>>2] = $725;
         $$sum27$i$i = (($$sum$i19$i) + 8)|0;
         $853 = (($tbase$245$i) + ($$sum27$i$i)|0);
         HEAP32[$853>>2] = $F4$0$i$i;
         $$sum28$i$i = (($$sum$i19$i) + 12)|0;
         $854 = (($tbase$245$i) + ($$sum28$i$i)|0);
         HEAP32[$854>>2] = $842;
         break;
        }
        $855 = $qsize$0$i$i >>> 8;
        $856 = ($855|0)==(0);
        do {
         if ($856) {
          $I7$0$i$i = 0;
         } else {
          $857 = ($qsize$0$i$i>>>0)>(16777215);
          if ($857) {
           $I7$0$i$i = 31;
           break;
          }
          $858 = (($855) + 1048320)|0;
          $859 = $858 >>> 16;
          $860 = $859 & 8;
          $861 = $855 << $860;
          $862 = (($861) + 520192)|0;
          $863 = $862 >>> 16;
          $864 = $863 & 4;
          $865 = $864 | $860;
          $866 = $861 << $864;
          $867 = (($866) + 245760)|0;
          $868 = $867 >>> 16;
          $869 = $868 & 2;
          $870 = $865 | $869;
          $871 = (14 - ($870))|0;
          $872 = $866 << $869;
          $873 = $872 >>> 15;
          $874 = (($871) + ($873))|0;
          $875 = $874 << 1;
          $876 = (($874) + 7)|0;
          $877 = $qsize$0$i$i >>> $876;
          $878 = $877 & 1;
          $879 = $878 | $875;
          $I7$0$i$i = $879;
         }
        } while(0);
        $880 = ((11264 + ($I7$0$i$i<<2)|0) + 304|0);
        $$sum12$i$i = (($$sum$i19$i) + 28)|0;
        $881 = (($tbase$245$i) + ($$sum12$i$i)|0);
        HEAP32[$881>>2] = $I7$0$i$i;
        $$sum13$i$i = (($$sum$i19$i) + 16)|0;
        $882 = (($tbase$245$i) + ($$sum13$i$i)|0);
        $$sum14$i$i = (($$sum$i19$i) + 20)|0;
        $883 = (($tbase$245$i) + ($$sum14$i$i)|0);
        HEAP32[$883>>2] = 0;
        HEAP32[$882>>2] = 0;
        $884 = HEAP32[((11264 + 4|0))>>2]|0;
        $885 = 1 << $I7$0$i$i;
        $886 = $884 & $885;
        $887 = ($886|0)==(0);
        if ($887) {
         $888 = $884 | $885;
         HEAP32[((11264 + 4|0))>>2] = $888;
         HEAP32[$880>>2] = $725;
         $$sum15$i$i = (($$sum$i19$i) + 24)|0;
         $889 = (($tbase$245$i) + ($$sum15$i$i)|0);
         HEAP32[$889>>2] = $880;
         $$sum16$i$i = (($$sum$i19$i) + 12)|0;
         $890 = (($tbase$245$i) + ($$sum16$i$i)|0);
         HEAP32[$890>>2] = $725;
         $$sum17$i$i = (($$sum$i19$i) + 8)|0;
         $891 = (($tbase$245$i) + ($$sum17$i$i)|0);
         HEAP32[$891>>2] = $725;
         break;
        }
        $892 = HEAP32[$880>>2]|0;
        $893 = ($I7$0$i$i|0)==(31);
        if ($893) {
         $901 = 0;
        } else {
         $894 = $I7$0$i$i >>> 1;
         $895 = (25 - ($894))|0;
         $901 = $895;
        }
        $896 = (($892) + 4|0);
        $897 = HEAP32[$896>>2]|0;
        $898 = $897 & -8;
        $899 = ($898|0)==($qsize$0$i$i|0);
        L442: do {
         if ($899) {
          $T$0$lcssa$i26$i = $892;
         } else {
          $900 = $qsize$0$i$i << $901;
          $K8$053$i$i = $900;$T$052$i$i = $892;
          while(1) {
           $908 = $K8$053$i$i >>> 31;
           $909 = ((($T$052$i$i) + ($908<<2)|0) + 16|0);
           $904 = HEAP32[$909>>2]|0;
           $910 = ($904|0)==(0|0);
           if ($910) {
            break;
           }
           $902 = $K8$053$i$i << 1;
           $903 = (($904) + 4|0);
           $905 = HEAP32[$903>>2]|0;
           $906 = $905 & -8;
           $907 = ($906|0)==($qsize$0$i$i|0);
           if ($907) {
            $T$0$lcssa$i26$i = $904;
            break L442;
           } else {
            $K8$053$i$i = $902;$T$052$i$i = $904;
           }
          }
          $911 = HEAP32[((11264 + 16|0))>>2]|0;
          $912 = ($909>>>0)<($911>>>0);
          if ($912) {
           _abort();
           // unreachable;
          } else {
           HEAP32[$909>>2] = $725;
           $$sum23$i$i = (($$sum$i19$i) + 24)|0;
           $913 = (($tbase$245$i) + ($$sum23$i$i)|0);
           HEAP32[$913>>2] = $T$052$i$i;
           $$sum24$i$i = (($$sum$i19$i) + 12)|0;
           $914 = (($tbase$245$i) + ($$sum24$i$i)|0);
           HEAP32[$914>>2] = $725;
           $$sum25$i$i = (($$sum$i19$i) + 8)|0;
           $915 = (($tbase$245$i) + ($$sum25$i$i)|0);
           HEAP32[$915>>2] = $725;
           break L345;
          }
         }
        } while(0);
        $916 = (($T$0$lcssa$i26$i) + 8|0);
        $917 = HEAP32[$916>>2]|0;
        $918 = HEAP32[((11264 + 16|0))>>2]|0;
        $919 = ($T$0$lcssa$i26$i>>>0)>=($918>>>0);
        $920 = ($917>>>0)>=($918>>>0);
        $or$cond$i27$i = $919 & $920;
        if ($or$cond$i27$i) {
         $921 = (($917) + 12|0);
         HEAP32[$921>>2] = $725;
         HEAP32[$916>>2] = $725;
         $$sum20$i$i = (($$sum$i19$i) + 8)|0;
         $922 = (($tbase$245$i) + ($$sum20$i$i)|0);
         HEAP32[$922>>2] = $917;
         $$sum21$i$i = (($$sum$i19$i) + 12)|0;
         $923 = (($tbase$245$i) + ($$sum21$i$i)|0);
         HEAP32[$923>>2] = $T$0$lcssa$i26$i;
         $$sum22$i$i = (($$sum$i19$i) + 24)|0;
         $924 = (($tbase$245$i) + ($$sum22$i$i)|0);
         HEAP32[$924>>2] = 0;
         break;
        } else {
         _abort();
         // unreachable;
        }
       }
      } while(0);
      $$sum1819$i$i = $713 | 8;
      $925 = (($tbase$245$i) + ($$sum1819$i$i)|0);
      $mem$0 = $925;
      STACKTOP = sp;return ($mem$0|0);
     }
    }
    $sp$0$i$i$i = ((11264 + 448|0));
    while(1) {
     $926 = HEAP32[$sp$0$i$i$i>>2]|0;
     $927 = ($926>>>0)>($636>>>0);
     if (!($927)) {
      $928 = (($sp$0$i$i$i) + 4|0);
      $929 = HEAP32[$928>>2]|0;
      $930 = (($926) + ($929)|0);
      $931 = ($930>>>0)>($636>>>0);
      if ($931) {
       break;
      }
     }
     $932 = (($sp$0$i$i$i) + 8|0);
     $933 = HEAP32[$932>>2]|0;
     $sp$0$i$i$i = $933;
    }
    $$sum$i13$i = (($929) + -47)|0;
    $$sum1$i14$i = (($929) + -39)|0;
    $934 = (($926) + ($$sum1$i14$i)|0);
    $935 = $934;
    $936 = $935 & 7;
    $937 = ($936|0)==(0);
    if ($937) {
     $940 = 0;
    } else {
     $938 = (0 - ($935))|0;
     $939 = $938 & 7;
     $940 = $939;
    }
    $$sum2$i15$i = (($$sum$i13$i) + ($940))|0;
    $941 = (($926) + ($$sum2$i15$i)|0);
    $942 = (($636) + 16|0);
    $943 = ($941>>>0)<($942>>>0);
    $944 = $943 ? $636 : $941;
    $945 = (($944) + 8|0);
    $946 = (($tsize$244$i) + -40)|0;
    $947 = (($tbase$245$i) + 8|0);
    $948 = $947;
    $949 = $948 & 7;
    $950 = ($949|0)==(0);
    if ($950) {
     $954 = 0;
    } else {
     $951 = (0 - ($948))|0;
     $952 = $951 & 7;
     $954 = $952;
    }
    $953 = (($tbase$245$i) + ($954)|0);
    $955 = (($946) - ($954))|0;
    HEAP32[((11264 + 24|0))>>2] = $953;
    HEAP32[((11264 + 12|0))>>2] = $955;
    $956 = $955 | 1;
    $$sum$i$i$i = (($954) + 4)|0;
    $957 = (($tbase$245$i) + ($$sum$i$i$i)|0);
    HEAP32[$957>>2] = $956;
    $$sum2$i$i$i = (($tsize$244$i) + -36)|0;
    $958 = (($tbase$245$i) + ($$sum2$i$i$i)|0);
    HEAP32[$958>>2] = 40;
    $959 = HEAP32[((11736 + 16|0))>>2]|0;
    HEAP32[((11264 + 28|0))>>2] = $959;
    $960 = (($944) + 4|0);
    HEAP32[$960>>2] = 27;
    ;HEAP32[$945+0>>2]=HEAP32[((11264 + 448|0))+0>>2]|0;HEAP32[$945+4>>2]=HEAP32[((11264 + 448|0))+4>>2]|0;HEAP32[$945+8>>2]=HEAP32[((11264 + 448|0))+8>>2]|0;HEAP32[$945+12>>2]=HEAP32[((11264 + 448|0))+12>>2]|0;
    HEAP32[((11264 + 448|0))>>2] = $tbase$245$i;
    HEAP32[((11264 + 452|0))>>2] = $tsize$244$i;
    HEAP32[((11264 + 460|0))>>2] = 0;
    HEAP32[((11264 + 456|0))>>2] = $945;
    $961 = (($944) + 28|0);
    HEAP32[$961>>2] = 7;
    $962 = (($944) + 32|0);
    $963 = ($962>>>0)<($930>>>0);
    if ($963) {
     $965 = $961;
     while(1) {
      $964 = (($965) + 4|0);
      HEAP32[$964>>2] = 7;
      $966 = (($965) + 8|0);
      $967 = ($966>>>0)<($930>>>0);
      if ($967) {
       $965 = $964;
      } else {
       break;
      }
     }
    }
    $968 = ($944|0)==($636|0);
    if (!($968)) {
     $969 = $944;
     $970 = $636;
     $971 = (($969) - ($970))|0;
     $972 = (($636) + ($971)|0);
     $$sum3$i$i = (($971) + 4)|0;
     $973 = (($636) + ($$sum3$i$i)|0);
     $974 = HEAP32[$973>>2]|0;
     $975 = $974 & -2;
     HEAP32[$973>>2] = $975;
     $976 = $971 | 1;
     $977 = (($636) + 4|0);
     HEAP32[$977>>2] = $976;
     HEAP32[$972>>2] = $971;
     $978 = $971 >>> 3;
     $979 = ($971>>>0)<(256);
     if ($979) {
      $980 = $978 << 1;
      $981 = ((11264 + ($980<<2)|0) + 40|0);
      $982 = HEAP32[11264>>2]|0;
      $983 = 1 << $978;
      $984 = $982 & $983;
      $985 = ($984|0)==(0);
      do {
       if ($985) {
        $986 = $982 | $983;
        HEAP32[11264>>2] = $986;
        $$sum10$pre$i$i = (($980) + 2)|0;
        $$pre$i$i = ((11264 + ($$sum10$pre$i$i<<2)|0) + 40|0);
        $$pre$phi$i$iZ2D = $$pre$i$i;$F$0$i$i = $981;
       } else {
        $$sum11$i$i = (($980) + 2)|0;
        $987 = ((11264 + ($$sum11$i$i<<2)|0) + 40|0);
        $988 = HEAP32[$987>>2]|0;
        $989 = HEAP32[((11264 + 16|0))>>2]|0;
        $990 = ($988>>>0)<($989>>>0);
        if (!($990)) {
         $$pre$phi$i$iZ2D = $987;$F$0$i$i = $988;
         break;
        }
        _abort();
        // unreachable;
       }
      } while(0);
      HEAP32[$$pre$phi$i$iZ2D>>2] = $636;
      $991 = (($F$0$i$i) + 12|0);
      HEAP32[$991>>2] = $636;
      $992 = (($636) + 8|0);
      HEAP32[$992>>2] = $F$0$i$i;
      $993 = (($636) + 12|0);
      HEAP32[$993>>2] = $981;
      break;
     }
     $994 = $971 >>> 8;
     $995 = ($994|0)==(0);
     if ($995) {
      $I1$0$i$i = 0;
     } else {
      $996 = ($971>>>0)>(16777215);
      if ($996) {
       $I1$0$i$i = 31;
      } else {
       $997 = (($994) + 1048320)|0;
       $998 = $997 >>> 16;
       $999 = $998 & 8;
       $1000 = $994 << $999;
       $1001 = (($1000) + 520192)|0;
       $1002 = $1001 >>> 16;
       $1003 = $1002 & 4;
       $1004 = $1003 | $999;
       $1005 = $1000 << $1003;
       $1006 = (($1005) + 245760)|0;
       $1007 = $1006 >>> 16;
       $1008 = $1007 & 2;
       $1009 = $1004 | $1008;
       $1010 = (14 - ($1009))|0;
       $1011 = $1005 << $1008;
       $1012 = $1011 >>> 15;
       $1013 = (($1010) + ($1012))|0;
       $1014 = $1013 << 1;
       $1015 = (($1013) + 7)|0;
       $1016 = $971 >>> $1015;
       $1017 = $1016 & 1;
       $1018 = $1017 | $1014;
       $I1$0$i$i = $1018;
      }
     }
     $1019 = ((11264 + ($I1$0$i$i<<2)|0) + 304|0);
     $1020 = (($636) + 28|0);
     $I1$0$c$i$i = $I1$0$i$i;
     HEAP32[$1020>>2] = $I1$0$c$i$i;
     $1021 = (($636) + 20|0);
     HEAP32[$1021>>2] = 0;
     $1022 = (($636) + 16|0);
     HEAP32[$1022>>2] = 0;
     $1023 = HEAP32[((11264 + 4|0))>>2]|0;
     $1024 = 1 << $I1$0$i$i;
     $1025 = $1023 & $1024;
     $1026 = ($1025|0)==(0);
     if ($1026) {
      $1027 = $1023 | $1024;
      HEAP32[((11264 + 4|0))>>2] = $1027;
      HEAP32[$1019>>2] = $636;
      $1028 = (($636) + 24|0);
      HEAP32[$1028>>2] = $1019;
      $1029 = (($636) + 12|0);
      HEAP32[$1029>>2] = $636;
      $1030 = (($636) + 8|0);
      HEAP32[$1030>>2] = $636;
      break;
     }
     $1031 = HEAP32[$1019>>2]|0;
     $1032 = ($I1$0$i$i|0)==(31);
     if ($1032) {
      $1040 = 0;
     } else {
      $1033 = $I1$0$i$i >>> 1;
      $1034 = (25 - ($1033))|0;
      $1040 = $1034;
     }
     $1035 = (($1031) + 4|0);
     $1036 = HEAP32[$1035>>2]|0;
     $1037 = $1036 & -8;
     $1038 = ($1037|0)==($971|0);
     L493: do {
      if ($1038) {
       $T$0$lcssa$i$i = $1031;
      } else {
       $1039 = $971 << $1040;
       $K2$015$i$i = $1039;$T$014$i$i = $1031;
       while(1) {
        $1047 = $K2$015$i$i >>> 31;
        $1048 = ((($T$014$i$i) + ($1047<<2)|0) + 16|0);
        $1043 = HEAP32[$1048>>2]|0;
        $1049 = ($1043|0)==(0|0);
        if ($1049) {
         break;
        }
        $1041 = $K2$015$i$i << 1;
        $1042 = (($1043) + 4|0);
        $1044 = HEAP32[$1042>>2]|0;
        $1045 = $1044 & -8;
        $1046 = ($1045|0)==($971|0);
        if ($1046) {
         $T$0$lcssa$i$i = $1043;
         break L493;
        } else {
         $K2$015$i$i = $1041;$T$014$i$i = $1043;
        }
       }
       $1050 = HEAP32[((11264 + 16|0))>>2]|0;
       $1051 = ($1048>>>0)<($1050>>>0);
       if ($1051) {
        _abort();
        // unreachable;
       } else {
        HEAP32[$1048>>2] = $636;
        $1052 = (($636) + 24|0);
        HEAP32[$1052>>2] = $T$014$i$i;
        $1053 = (($636) + 12|0);
        HEAP32[$1053>>2] = $636;
        $1054 = (($636) + 8|0);
        HEAP32[$1054>>2] = $636;
        break L308;
       }
      }
     } while(0);
     $1055 = (($T$0$lcssa$i$i) + 8|0);
     $1056 = HEAP32[$1055>>2]|0;
     $1057 = HEAP32[((11264 + 16|0))>>2]|0;
     $1058 = ($T$0$lcssa$i$i>>>0)>=($1057>>>0);
     $1059 = ($1056>>>0)>=($1057>>>0);
     $or$cond$i$i = $1058 & $1059;
     if ($or$cond$i$i) {
      $1060 = (($1056) + 12|0);
      HEAP32[$1060>>2] = $636;
      HEAP32[$1055>>2] = $636;
      $1061 = (($636) + 8|0);
      HEAP32[$1061>>2] = $1056;
      $1062 = (($636) + 12|0);
      HEAP32[$1062>>2] = $T$0$lcssa$i$i;
      $1063 = (($636) + 24|0);
      HEAP32[$1063>>2] = 0;
      break;
     } else {
      _abort();
      // unreachable;
     }
    }
   }
  } while(0);
  $1064 = HEAP32[((11264 + 12|0))>>2]|0;
  $1065 = ($1064>>>0)>($nb$0>>>0);
  if ($1065) {
   $1066 = (($1064) - ($nb$0))|0;
   HEAP32[((11264 + 12|0))>>2] = $1066;
   $1067 = HEAP32[((11264 + 24|0))>>2]|0;
   $1068 = (($1067) + ($nb$0)|0);
   HEAP32[((11264 + 24|0))>>2] = $1068;
   $1069 = $1066 | 1;
   $$sum$i32 = (($nb$0) + 4)|0;
   $1070 = (($1067) + ($$sum$i32)|0);
   HEAP32[$1070>>2] = $1069;
   $1071 = $nb$0 | 3;
   $1072 = (($1067) + 4|0);
   HEAP32[$1072>>2] = $1071;
   $1073 = (($1067) + 8|0);
   $mem$0 = $1073;
   STACKTOP = sp;return ($mem$0|0);
  }
 }
 $1074 = (___errno_location()|0);
 HEAP32[$1074>>2] = 12;
 $mem$0 = 0;
 STACKTOP = sp;return ($mem$0|0);
}
function _free($mem) {
 $mem = $mem|0;
 var $$pre = 0, $$pre$phi66Z2D = 0, $$pre$phi68Z2D = 0, $$pre$phiZ2D = 0, $$pre65 = 0, $$pre67 = 0, $$sum = 0, $$sum16$pre = 0, $$sum17 = 0, $$sum18 = 0, $$sum19 = 0, $$sum2 = 0, $$sum20 = 0, $$sum2324 = 0, $$sum25 = 0, $$sum26 = 0, $$sum28 = 0, $$sum29 = 0, $$sum3 = 0, $$sum30 = 0;
 var $$sum31 = 0, $$sum32 = 0, $$sum33 = 0, $$sum34 = 0, $$sum35 = 0, $$sum36 = 0, $$sum37 = 0, $$sum5 = 0, $$sum67 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0;
 var $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0;
 var $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0;
 var $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0;
 var $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0;
 var $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0;
 var $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0;
 var $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0;
 var $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0;
 var $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0;
 var $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $F16$0 = 0, $I18$0 = 0, $I18$0$c = 0, $K19$058 = 0, $R$0 = 0, $R$1 = 0, $R7$0 = 0;
 var $R7$1 = 0, $RP$0 = 0, $RP9$0 = 0, $T$0$lcssa = 0, $T$057 = 0, $cond = 0, $cond54 = 0, $or$cond = 0, $p$0 = 0, $psize$0 = 0, $psize$1 = 0, $sp$0$i = 0, $sp$0$in$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($mem|0)==(0|0);
 if ($0) {
  STACKTOP = sp;return;
 }
 $1 = (($mem) + -8|0);
 $2 = HEAP32[((11264 + 16|0))>>2]|0;
 $3 = ($1>>>0)<($2>>>0);
 if ($3) {
  _abort();
  // unreachable;
 }
 $4 = (($mem) + -4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 3;
 $7 = ($6|0)==(1);
 if ($7) {
  _abort();
  // unreachable;
 }
 $8 = $5 & -8;
 $$sum = (($8) + -8)|0;
 $9 = (($mem) + ($$sum)|0);
 $10 = $5 & 1;
 $11 = ($10|0)==(0);
 do {
  if ($11) {
   $12 = HEAP32[$1>>2]|0;
   $13 = ($6|0)==(0);
   if ($13) {
    STACKTOP = sp;return;
   }
   $$sum2 = (-8 - ($12))|0;
   $14 = (($mem) + ($$sum2)|0);
   $15 = (($12) + ($8))|0;
   $16 = ($14>>>0)<($2>>>0);
   if ($16) {
    _abort();
    // unreachable;
   }
   $17 = HEAP32[((11264 + 20|0))>>2]|0;
   $18 = ($14|0)==($17|0);
   if ($18) {
    $$sum3 = (($8) + -4)|0;
    $103 = (($mem) + ($$sum3)|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = $104 & 3;
    $106 = ($105|0)==(3);
    if (!($106)) {
     $p$0 = $14;$psize$0 = $15;
     break;
    }
    HEAP32[((11264 + 8|0))>>2] = $15;
    $107 = $104 & -2;
    HEAP32[$103>>2] = $107;
    $108 = $15 | 1;
    $$sum26 = (($$sum2) + 4)|0;
    $109 = (($mem) + ($$sum26)|0);
    HEAP32[$109>>2] = $108;
    HEAP32[$9>>2] = $15;
    STACKTOP = sp;return;
   }
   $19 = $12 >>> 3;
   $20 = ($12>>>0)<(256);
   if ($20) {
    $$sum36 = (($$sum2) + 8)|0;
    $21 = (($mem) + ($$sum36)|0);
    $22 = HEAP32[$21>>2]|0;
    $$sum37 = (($$sum2) + 12)|0;
    $23 = (($mem) + ($$sum37)|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = $19 << 1;
    $26 = ((11264 + ($25<<2)|0) + 40|0);
    $27 = ($22|0)==($26|0);
    if (!($27)) {
     $28 = ($22>>>0)<($2>>>0);
     if ($28) {
      _abort();
      // unreachable;
     }
     $29 = (($22) + 12|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==($14|0);
     if (!($31)) {
      _abort();
      // unreachable;
     }
    }
    $32 = ($24|0)==($22|0);
    if ($32) {
     $33 = 1 << $19;
     $34 = $33 ^ -1;
     $35 = HEAP32[11264>>2]|0;
     $36 = $35 & $34;
     HEAP32[11264>>2] = $36;
     $p$0 = $14;$psize$0 = $15;
     break;
    }
    $37 = ($24|0)==($26|0);
    if ($37) {
     $$pre67 = (($24) + 8|0);
     $$pre$phi68Z2D = $$pre67;
    } else {
     $38 = ($24>>>0)<($2>>>0);
     if ($38) {
      _abort();
      // unreachable;
     }
     $39 = (($24) + 8|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = ($40|0)==($14|0);
     if ($41) {
      $$pre$phi68Z2D = $39;
     } else {
      _abort();
      // unreachable;
     }
    }
    $42 = (($22) + 12|0);
    HEAP32[$42>>2] = $24;
    HEAP32[$$pre$phi68Z2D>>2] = $22;
    $p$0 = $14;$psize$0 = $15;
    break;
   }
   $$sum28 = (($$sum2) + 24)|0;
   $43 = (($mem) + ($$sum28)|0);
   $44 = HEAP32[$43>>2]|0;
   $$sum29 = (($$sum2) + 12)|0;
   $45 = (($mem) + ($$sum29)|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==($14|0);
   do {
    if ($47) {
     $$sum31 = (($$sum2) + 20)|0;
     $57 = (($mem) + ($$sum31)|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = ($58|0)==(0|0);
     if ($59) {
      $$sum30 = (($$sum2) + 16)|0;
      $60 = (($mem) + ($$sum30)|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($61|0)==(0|0);
      if ($62) {
       $R$1 = 0;
       break;
      } else {
       $R$0 = $61;$RP$0 = $60;
      }
     } else {
      $R$0 = $58;$RP$0 = $57;
     }
     while(1) {
      $63 = (($R$0) + 20|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = ($64|0)==(0|0);
      if (!($65)) {
       $R$0 = $64;$RP$0 = $63;
       continue;
      }
      $66 = (($R$0) + 16|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = ($67|0)==(0|0);
      if ($68) {
       break;
      } else {
       $R$0 = $67;$RP$0 = $66;
      }
     }
     $69 = ($RP$0>>>0)<($2>>>0);
     if ($69) {
      _abort();
      // unreachable;
     } else {
      HEAP32[$RP$0>>2] = 0;
      $R$1 = $R$0;
      break;
     }
    } else {
     $$sum35 = (($$sum2) + 8)|0;
     $48 = (($mem) + ($$sum35)|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($49>>>0)<($2>>>0);
     if ($50) {
      _abort();
      // unreachable;
     }
     $51 = (($49) + 12|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = ($52|0)==($14|0);
     if (!($53)) {
      _abort();
      // unreachable;
     }
     $54 = (($46) + 8|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($55|0)==($14|0);
     if ($56) {
      HEAP32[$51>>2] = $46;
      HEAP32[$54>>2] = $49;
      $R$1 = $46;
      break;
     } else {
      _abort();
      // unreachable;
     }
    }
   } while(0);
   $70 = ($44|0)==(0|0);
   if ($70) {
    $p$0 = $14;$psize$0 = $15;
   } else {
    $$sum32 = (($$sum2) + 28)|0;
    $71 = (($mem) + ($$sum32)|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = ((11264 + ($72<<2)|0) + 304|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = ($14|0)==($74|0);
    if ($75) {
     HEAP32[$73>>2] = $R$1;
     $cond = ($R$1|0)==(0|0);
     if ($cond) {
      $76 = 1 << $72;
      $77 = $76 ^ -1;
      $78 = HEAP32[((11264 + 4|0))>>2]|0;
      $79 = $78 & $77;
      HEAP32[((11264 + 4|0))>>2] = $79;
      $p$0 = $14;$psize$0 = $15;
      break;
     }
    } else {
     $80 = HEAP32[((11264 + 16|0))>>2]|0;
     $81 = ($44>>>0)<($80>>>0);
     if ($81) {
      _abort();
      // unreachable;
     }
     $82 = (($44) + 16|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = ($83|0)==($14|0);
     if ($84) {
      HEAP32[$82>>2] = $R$1;
     } else {
      $85 = (($44) + 20|0);
      HEAP32[$85>>2] = $R$1;
     }
     $86 = ($R$1|0)==(0|0);
     if ($86) {
      $p$0 = $14;$psize$0 = $15;
      break;
     }
    }
    $87 = HEAP32[((11264 + 16|0))>>2]|0;
    $88 = ($R$1>>>0)<($87>>>0);
    if ($88) {
     _abort();
     // unreachable;
    }
    $89 = (($R$1) + 24|0);
    HEAP32[$89>>2] = $44;
    $$sum33 = (($$sum2) + 16)|0;
    $90 = (($mem) + ($$sum33)|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = ($91|0)==(0|0);
    do {
     if (!($92)) {
      $93 = ($91>>>0)<($87>>>0);
      if ($93) {
       _abort();
       // unreachable;
      } else {
       $94 = (($R$1) + 16|0);
       HEAP32[$94>>2] = $91;
       $95 = (($91) + 24|0);
       HEAP32[$95>>2] = $R$1;
       break;
      }
     }
    } while(0);
    $$sum34 = (($$sum2) + 20)|0;
    $96 = (($mem) + ($$sum34)|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = ($97|0)==(0|0);
    if ($98) {
     $p$0 = $14;$psize$0 = $15;
    } else {
     $99 = HEAP32[((11264 + 16|0))>>2]|0;
     $100 = ($97>>>0)<($99>>>0);
     if ($100) {
      _abort();
      // unreachable;
     } else {
      $101 = (($R$1) + 20|0);
      HEAP32[$101>>2] = $97;
      $102 = (($97) + 24|0);
      HEAP32[$102>>2] = $R$1;
      $p$0 = $14;$psize$0 = $15;
      break;
     }
    }
   }
  } else {
   $p$0 = $1;$psize$0 = $8;
  }
 } while(0);
 $110 = ($p$0>>>0)<($9>>>0);
 if (!($110)) {
  _abort();
  // unreachable;
 }
 $$sum25 = (($8) + -4)|0;
 $111 = (($mem) + ($$sum25)|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = $112 & 1;
 $114 = ($113|0)==(0);
 if ($114) {
  _abort();
  // unreachable;
 }
 $115 = $112 & 2;
 $116 = ($115|0)==(0);
 if ($116) {
  $117 = HEAP32[((11264 + 24|0))>>2]|0;
  $118 = ($9|0)==($117|0);
  if ($118) {
   $119 = HEAP32[((11264 + 12|0))>>2]|0;
   $120 = (($119) + ($psize$0))|0;
   HEAP32[((11264 + 12|0))>>2] = $120;
   HEAP32[((11264 + 24|0))>>2] = $p$0;
   $121 = $120 | 1;
   $122 = (($p$0) + 4|0);
   HEAP32[$122>>2] = $121;
   $123 = HEAP32[((11264 + 20|0))>>2]|0;
   $124 = ($p$0|0)==($123|0);
   if (!($124)) {
    STACKTOP = sp;return;
   }
   HEAP32[((11264 + 20|0))>>2] = 0;
   HEAP32[((11264 + 8|0))>>2] = 0;
   STACKTOP = sp;return;
  }
  $125 = HEAP32[((11264 + 20|0))>>2]|0;
  $126 = ($9|0)==($125|0);
  if ($126) {
   $127 = HEAP32[((11264 + 8|0))>>2]|0;
   $128 = (($127) + ($psize$0))|0;
   HEAP32[((11264 + 8|0))>>2] = $128;
   HEAP32[((11264 + 20|0))>>2] = $p$0;
   $129 = $128 | 1;
   $130 = (($p$0) + 4|0);
   HEAP32[$130>>2] = $129;
   $131 = (($p$0) + ($128)|0);
   HEAP32[$131>>2] = $128;
   STACKTOP = sp;return;
  }
  $132 = $112 & -8;
  $133 = (($132) + ($psize$0))|0;
  $134 = $112 >>> 3;
  $135 = ($112>>>0)<(256);
  do {
   if ($135) {
    $136 = (($mem) + ($8)|0);
    $137 = HEAP32[$136>>2]|0;
    $$sum2324 = $8 | 4;
    $138 = (($mem) + ($$sum2324)|0);
    $139 = HEAP32[$138>>2]|0;
    $140 = $134 << 1;
    $141 = ((11264 + ($140<<2)|0) + 40|0);
    $142 = ($137|0)==($141|0);
    if (!($142)) {
     $143 = HEAP32[((11264 + 16|0))>>2]|0;
     $144 = ($137>>>0)<($143>>>0);
     if ($144) {
      _abort();
      // unreachable;
     }
     $145 = (($137) + 12|0);
     $146 = HEAP32[$145>>2]|0;
     $147 = ($146|0)==($9|0);
     if (!($147)) {
      _abort();
      // unreachable;
     }
    }
    $148 = ($139|0)==($137|0);
    if ($148) {
     $149 = 1 << $134;
     $150 = $149 ^ -1;
     $151 = HEAP32[11264>>2]|0;
     $152 = $151 & $150;
     HEAP32[11264>>2] = $152;
     break;
    }
    $153 = ($139|0)==($141|0);
    if ($153) {
     $$pre65 = (($139) + 8|0);
     $$pre$phi66Z2D = $$pre65;
    } else {
     $154 = HEAP32[((11264 + 16|0))>>2]|0;
     $155 = ($139>>>0)<($154>>>0);
     if ($155) {
      _abort();
      // unreachable;
     }
     $156 = (($139) + 8|0);
     $157 = HEAP32[$156>>2]|0;
     $158 = ($157|0)==($9|0);
     if ($158) {
      $$pre$phi66Z2D = $156;
     } else {
      _abort();
      // unreachable;
     }
    }
    $159 = (($137) + 12|0);
    HEAP32[$159>>2] = $139;
    HEAP32[$$pre$phi66Z2D>>2] = $137;
   } else {
    $$sum5 = (($8) + 16)|0;
    $160 = (($mem) + ($$sum5)|0);
    $161 = HEAP32[$160>>2]|0;
    $$sum67 = $8 | 4;
    $162 = (($mem) + ($$sum67)|0);
    $163 = HEAP32[$162>>2]|0;
    $164 = ($163|0)==($9|0);
    do {
     if ($164) {
      $$sum9 = (($8) + 12)|0;
      $175 = (($mem) + ($$sum9)|0);
      $176 = HEAP32[$175>>2]|0;
      $177 = ($176|0)==(0|0);
      if ($177) {
       $$sum8 = (($8) + 8)|0;
       $178 = (($mem) + ($$sum8)|0);
       $179 = HEAP32[$178>>2]|0;
       $180 = ($179|0)==(0|0);
       if ($180) {
        $R7$1 = 0;
        break;
       } else {
        $R7$0 = $179;$RP9$0 = $178;
       }
      } else {
       $R7$0 = $176;$RP9$0 = $175;
      }
      while(1) {
       $181 = (($R7$0) + 20|0);
       $182 = HEAP32[$181>>2]|0;
       $183 = ($182|0)==(0|0);
       if (!($183)) {
        $R7$0 = $182;$RP9$0 = $181;
        continue;
       }
       $184 = (($R7$0) + 16|0);
       $185 = HEAP32[$184>>2]|0;
       $186 = ($185|0)==(0|0);
       if ($186) {
        break;
       } else {
        $R7$0 = $185;$RP9$0 = $184;
       }
      }
      $187 = HEAP32[((11264 + 16|0))>>2]|0;
      $188 = ($RP9$0>>>0)<($187>>>0);
      if ($188) {
       _abort();
       // unreachable;
      } else {
       HEAP32[$RP9$0>>2] = 0;
       $R7$1 = $R7$0;
       break;
      }
     } else {
      $165 = (($mem) + ($8)|0);
      $166 = HEAP32[$165>>2]|0;
      $167 = HEAP32[((11264 + 16|0))>>2]|0;
      $168 = ($166>>>0)<($167>>>0);
      if ($168) {
       _abort();
       // unreachable;
      }
      $169 = (($166) + 12|0);
      $170 = HEAP32[$169>>2]|0;
      $171 = ($170|0)==($9|0);
      if (!($171)) {
       _abort();
       // unreachable;
      }
      $172 = (($163) + 8|0);
      $173 = HEAP32[$172>>2]|0;
      $174 = ($173|0)==($9|0);
      if ($174) {
       HEAP32[$169>>2] = $163;
       HEAP32[$172>>2] = $166;
       $R7$1 = $163;
       break;
      } else {
       _abort();
       // unreachable;
      }
     }
    } while(0);
    $189 = ($161|0)==(0|0);
    if (!($189)) {
     $$sum18 = (($8) + 20)|0;
     $190 = (($mem) + ($$sum18)|0);
     $191 = HEAP32[$190>>2]|0;
     $192 = ((11264 + ($191<<2)|0) + 304|0);
     $193 = HEAP32[$192>>2]|0;
     $194 = ($9|0)==($193|0);
     if ($194) {
      HEAP32[$192>>2] = $R7$1;
      $cond54 = ($R7$1|0)==(0|0);
      if ($cond54) {
       $195 = 1 << $191;
       $196 = $195 ^ -1;
       $197 = HEAP32[((11264 + 4|0))>>2]|0;
       $198 = $197 & $196;
       HEAP32[((11264 + 4|0))>>2] = $198;
       break;
      }
     } else {
      $199 = HEAP32[((11264 + 16|0))>>2]|0;
      $200 = ($161>>>0)<($199>>>0);
      if ($200) {
       _abort();
       // unreachable;
      }
      $201 = (($161) + 16|0);
      $202 = HEAP32[$201>>2]|0;
      $203 = ($202|0)==($9|0);
      if ($203) {
       HEAP32[$201>>2] = $R7$1;
      } else {
       $204 = (($161) + 20|0);
       HEAP32[$204>>2] = $R7$1;
      }
      $205 = ($R7$1|0)==(0|0);
      if ($205) {
       break;
      }
     }
     $206 = HEAP32[((11264 + 16|0))>>2]|0;
     $207 = ($R7$1>>>0)<($206>>>0);
     if ($207) {
      _abort();
      // unreachable;
     }
     $208 = (($R7$1) + 24|0);
     HEAP32[$208>>2] = $161;
     $$sum19 = (($8) + 8)|0;
     $209 = (($mem) + ($$sum19)|0);
     $210 = HEAP32[$209>>2]|0;
     $211 = ($210|0)==(0|0);
     do {
      if (!($211)) {
       $212 = ($210>>>0)<($206>>>0);
       if ($212) {
        _abort();
        // unreachable;
       } else {
        $213 = (($R7$1) + 16|0);
        HEAP32[$213>>2] = $210;
        $214 = (($210) + 24|0);
        HEAP32[$214>>2] = $R7$1;
        break;
       }
      }
     } while(0);
     $$sum20 = (($8) + 12)|0;
     $215 = (($mem) + ($$sum20)|0);
     $216 = HEAP32[$215>>2]|0;
     $217 = ($216|0)==(0|0);
     if (!($217)) {
      $218 = HEAP32[((11264 + 16|0))>>2]|0;
      $219 = ($216>>>0)<($218>>>0);
      if ($219) {
       _abort();
       // unreachable;
      } else {
       $220 = (($R7$1) + 20|0);
       HEAP32[$220>>2] = $216;
       $221 = (($216) + 24|0);
       HEAP32[$221>>2] = $R7$1;
       break;
      }
     }
    }
   }
  } while(0);
  $222 = $133 | 1;
  $223 = (($p$0) + 4|0);
  HEAP32[$223>>2] = $222;
  $224 = (($p$0) + ($133)|0);
  HEAP32[$224>>2] = $133;
  $225 = HEAP32[((11264 + 20|0))>>2]|0;
  $226 = ($p$0|0)==($225|0);
  if ($226) {
   HEAP32[((11264 + 8|0))>>2] = $133;
   STACKTOP = sp;return;
  } else {
   $psize$1 = $133;
  }
 } else {
  $227 = $112 & -2;
  HEAP32[$111>>2] = $227;
  $228 = $psize$0 | 1;
  $229 = (($p$0) + 4|0);
  HEAP32[$229>>2] = $228;
  $230 = (($p$0) + ($psize$0)|0);
  HEAP32[$230>>2] = $psize$0;
  $psize$1 = $psize$0;
 }
 $231 = $psize$1 >>> 3;
 $232 = ($psize$1>>>0)<(256);
 if ($232) {
  $233 = $231 << 1;
  $234 = ((11264 + ($233<<2)|0) + 40|0);
  $235 = HEAP32[11264>>2]|0;
  $236 = 1 << $231;
  $237 = $235 & $236;
  $238 = ($237|0)==(0);
  if ($238) {
   $239 = $235 | $236;
   HEAP32[11264>>2] = $239;
   $$sum16$pre = (($233) + 2)|0;
   $$pre = ((11264 + ($$sum16$pre<<2)|0) + 40|0);
   $$pre$phiZ2D = $$pre;$F16$0 = $234;
  } else {
   $$sum17 = (($233) + 2)|0;
   $240 = ((11264 + ($$sum17<<2)|0) + 40|0);
   $241 = HEAP32[$240>>2]|0;
   $242 = HEAP32[((11264 + 16|0))>>2]|0;
   $243 = ($241>>>0)<($242>>>0);
   if ($243) {
    _abort();
    // unreachable;
   } else {
    $$pre$phiZ2D = $240;$F16$0 = $241;
   }
  }
  HEAP32[$$pre$phiZ2D>>2] = $p$0;
  $244 = (($F16$0) + 12|0);
  HEAP32[$244>>2] = $p$0;
  $245 = (($p$0) + 8|0);
  HEAP32[$245>>2] = $F16$0;
  $246 = (($p$0) + 12|0);
  HEAP32[$246>>2] = $234;
  STACKTOP = sp;return;
 }
 $247 = $psize$1 >>> 8;
 $248 = ($247|0)==(0);
 if ($248) {
  $I18$0 = 0;
 } else {
  $249 = ($psize$1>>>0)>(16777215);
  if ($249) {
   $I18$0 = 31;
  } else {
   $250 = (($247) + 1048320)|0;
   $251 = $250 >>> 16;
   $252 = $251 & 8;
   $253 = $247 << $252;
   $254 = (($253) + 520192)|0;
   $255 = $254 >>> 16;
   $256 = $255 & 4;
   $257 = $256 | $252;
   $258 = $253 << $256;
   $259 = (($258) + 245760)|0;
   $260 = $259 >>> 16;
   $261 = $260 & 2;
   $262 = $257 | $261;
   $263 = (14 - ($262))|0;
   $264 = $258 << $261;
   $265 = $264 >>> 15;
   $266 = (($263) + ($265))|0;
   $267 = $266 << 1;
   $268 = (($266) + 7)|0;
   $269 = $psize$1 >>> $268;
   $270 = $269 & 1;
   $271 = $270 | $267;
   $I18$0 = $271;
  }
 }
 $272 = ((11264 + ($I18$0<<2)|0) + 304|0);
 $273 = (($p$0) + 28|0);
 $I18$0$c = $I18$0;
 HEAP32[$273>>2] = $I18$0$c;
 $274 = (($p$0) + 20|0);
 HEAP32[$274>>2] = 0;
 $275 = (($p$0) + 16|0);
 HEAP32[$275>>2] = 0;
 $276 = HEAP32[((11264 + 4|0))>>2]|0;
 $277 = 1 << $I18$0;
 $278 = $276 & $277;
 $279 = ($278|0)==(0);
 L199: do {
  if ($279) {
   $280 = $276 | $277;
   HEAP32[((11264 + 4|0))>>2] = $280;
   HEAP32[$272>>2] = $p$0;
   $281 = (($p$0) + 24|0);
   HEAP32[$281>>2] = $272;
   $282 = (($p$0) + 12|0);
   HEAP32[$282>>2] = $p$0;
   $283 = (($p$0) + 8|0);
   HEAP32[$283>>2] = $p$0;
  } else {
   $284 = HEAP32[$272>>2]|0;
   $285 = ($I18$0|0)==(31);
   if ($285) {
    $293 = 0;
   } else {
    $286 = $I18$0 >>> 1;
    $287 = (25 - ($286))|0;
    $293 = $287;
   }
   $288 = (($284) + 4|0);
   $289 = HEAP32[$288>>2]|0;
   $290 = $289 & -8;
   $291 = ($290|0)==($psize$1|0);
   L205: do {
    if ($291) {
     $T$0$lcssa = $284;
    } else {
     $292 = $psize$1 << $293;
     $K19$058 = $292;$T$057 = $284;
     while(1) {
      $300 = $K19$058 >>> 31;
      $301 = ((($T$057) + ($300<<2)|0) + 16|0);
      $296 = HEAP32[$301>>2]|0;
      $302 = ($296|0)==(0|0);
      if ($302) {
       break;
      }
      $294 = $K19$058 << 1;
      $295 = (($296) + 4|0);
      $297 = HEAP32[$295>>2]|0;
      $298 = $297 & -8;
      $299 = ($298|0)==($psize$1|0);
      if ($299) {
       $T$0$lcssa = $296;
       break L205;
      } else {
       $K19$058 = $294;$T$057 = $296;
      }
     }
     $303 = HEAP32[((11264 + 16|0))>>2]|0;
     $304 = ($301>>>0)<($303>>>0);
     if ($304) {
      _abort();
      // unreachable;
     } else {
      HEAP32[$301>>2] = $p$0;
      $305 = (($p$0) + 24|0);
      HEAP32[$305>>2] = $T$057;
      $306 = (($p$0) + 12|0);
      HEAP32[$306>>2] = $p$0;
      $307 = (($p$0) + 8|0);
      HEAP32[$307>>2] = $p$0;
      break L199;
     }
    }
   } while(0);
   $308 = (($T$0$lcssa) + 8|0);
   $309 = HEAP32[$308>>2]|0;
   $310 = HEAP32[((11264 + 16|0))>>2]|0;
   $311 = ($T$0$lcssa>>>0)>=($310>>>0);
   $312 = ($309>>>0)>=($310>>>0);
   $or$cond = $311 & $312;
   if ($or$cond) {
    $313 = (($309) + 12|0);
    HEAP32[$313>>2] = $p$0;
    HEAP32[$308>>2] = $p$0;
    $314 = (($p$0) + 8|0);
    HEAP32[$314>>2] = $309;
    $315 = (($p$0) + 12|0);
    HEAP32[$315>>2] = $T$0$lcssa;
    $316 = (($p$0) + 24|0);
    HEAP32[$316>>2] = 0;
    break;
   } else {
    _abort();
    // unreachable;
   }
  }
 } while(0);
 $317 = HEAP32[((11264 + 32|0))>>2]|0;
 $318 = (($317) + -1)|0;
 HEAP32[((11264 + 32|0))>>2] = $318;
 $319 = ($318|0)==(0);
 if ($319) {
  $sp$0$in$i = ((11264 + 456|0));
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $sp$0$i = HEAP32[$sp$0$in$i>>2]|0;
  $320 = ($sp$0$i|0)==(0|0);
  $321 = (($sp$0$i) + 8|0);
  if ($320) {
   break;
  } else {
   $sp$0$in$i = $321;
  }
 }
 HEAP32[((11264 + 32|0))>>2] = -1;
 STACKTOP = sp;return;
}
function runPostSets() {
 
}
function _memset(ptr, value, num) {
    ptr = ptr|0; value = value|0; num = num|0;
    var stop = 0, value4 = 0, stop4 = 0, unaligned = 0;
    stop = (ptr + num)|0;
    if ((num|0) >= 20) {
      // This is unaligned, but quite large, so work hard to get to aligned settings
      value = value & 0xff;
      unaligned = ptr & 3;
      value4 = value | (value << 8) | (value << 16) | (value << 24);
      stop4 = stop & ~3;
      if (unaligned) {
        unaligned = (ptr + 4 - unaligned)|0;
        while ((ptr|0) < (unaligned|0)) { // no need to check for stop, since we have large num
          HEAP8[((ptr)>>0)]=value;
          ptr = (ptr+1)|0;
        }
      }
      while ((ptr|0) < (stop4|0)) {
        HEAP32[((ptr)>>2)]=value4;
        ptr = (ptr+4)|0;
      }
    }
    while ((ptr|0) < (stop|0)) {
      HEAP8[((ptr)>>0)]=value;
      ptr = (ptr+1)|0;
    }
    return (ptr-num)|0;
}
function _strlen(ptr) {
    ptr = ptr|0;
    var curr = 0;
    curr = ptr;
    while (((HEAP8[((curr)>>0)])|0)) {
      curr = (curr + 1)|0;
    }
    return (curr - ptr)|0;
}
function _i64Add(a, b, c, d) {
    /*
      x = a + b*2^32
      y = c + d*2^32
      result = l + h*2^32
    */
    a = a|0; b = b|0; c = c|0; d = d|0;
    var l = 0, h = 0;
    l = (a + c)>>>0;
    h = (b + d + (((l>>>0) < (a>>>0))|0))>>>0; // Add carry from low word to high word on overflow.
    return ((tempRet0 = h,l|0)|0);
}
function _memcpy(dest, src, num) {

    dest = dest|0; src = src|0; num = num|0;
    var ret = 0;
    if ((num|0) >= 4096) return _emscripten_memcpy_big(dest|0, src|0, num|0)|0;
    ret = dest|0;
    if ((dest&3) == (src&3)) {
      while (dest & 3) {
        if ((num|0) == 0) return ret|0;
        HEAP8[((dest)>>0)]=((HEAP8[((src)>>0)])|0);
        dest = (dest+1)|0;
        src = (src+1)|0;
        num = (num-1)|0;
      }
      while ((num|0) >= 4) {
        HEAP32[((dest)>>2)]=((HEAP32[((src)>>2)])|0);
        dest = (dest+4)|0;
        src = (src+4)|0;
        num = (num-4)|0;
      }
    }
    while ((num|0) > 0) {
      HEAP8[((dest)>>0)]=((HEAP8[((src)>>0)])|0);
      dest = (dest+1)|0;
      src = (src+1)|0;
      num = (num-1)|0;
    }
    return ret|0;
}
function _memmove(dest, src, num) {
    dest = dest|0; src = src|0; num = num|0;
    var ret = 0;
    if (((src|0) < (dest|0)) & ((dest|0) < ((src + num)|0))) {
      // Unlikely case: Copy backwards in a safe manner
      ret = dest;
      src = (src + num)|0;
      dest = (dest + num)|0;
      while ((num|0) > 0) {
        dest = (dest - 1)|0;
        src = (src - 1)|0;
        num = (num - 1)|0;
        HEAP8[((dest)>>0)]=((HEAP8[((src)>>0)])|0);
      }
      dest = ret;
    } else {
      _memcpy(dest, src, num) | 0;
    }
    return dest | 0;
}
function _i64Subtract(a, b, c, d) {
    a = a|0; b = b|0; c = c|0; d = d|0;
    var l = 0, h = 0;
    l = (a - c)>>>0;
    h = (b - d)>>>0;
    h = (b - d - (((c>>>0) > (a>>>0))|0))>>>0; // Borrow one from high word to low word on underflow.
    return ((tempRet0 = h,l|0)|0);
  }
function _bitshift64Shl(low, high, bits) {
    low = low|0; high = high|0; bits = bits|0;
    var ander = 0;
    if ((bits|0) < 32) {
      ander = ((1 << bits) - 1)|0;
      tempRet0 = (high << bits) | ((low&(ander << (32 - bits))) >>> (32 - bits));
      return low << bits;
    }
    tempRet0 = low << (bits - 32);
    return 0;
  }
function _bitshift64Lshr(low, high, bits) {
    low = low|0; high = high|0; bits = bits|0;
    var ander = 0;
    if ((bits|0) < 32) {
      ander = ((1 << bits) - 1)|0;
      tempRet0 = high >>> bits;
      return (low >>> bits) | ((high&ander) << (32 - bits));
    }
    tempRet0 = 0;
    return (high >>> (bits - 32))|0;
  }
function _bitshift64Ashr(low, high, bits) {
    low = low|0; high = high|0; bits = bits|0;
    var ander = 0;
    if ((bits|0) < 32) {
      ander = ((1 << bits) - 1)|0;
      tempRet0 = high >> bits;
      return (low >>> bits) | ((high&ander) << (32 - bits));
    }
    tempRet0 = (high|0) < 0 ? -1 : 0;
    return (high >> (bits - 32))|0;
  }
function _llvm_ctlz_i32(x) {
    x = x|0;
    var ret = 0;
    ret = ((HEAP8[(((ctlz_i8)+(x >>> 24))>>0)])|0);
    if ((ret|0) < 8) return ret|0;
    ret = ((HEAP8[(((ctlz_i8)+((x >> 16)&0xff))>>0)])|0);
    if ((ret|0) < 8) return (ret + 8)|0;
    ret = ((HEAP8[(((ctlz_i8)+((x >> 8)&0xff))>>0)])|0);
    if ((ret|0) < 8) return (ret + 16)|0;
    return (((HEAP8[(((ctlz_i8)+(x&0xff))>>0)])|0) + 24)|0;
  }

function _llvm_cttz_i32(x) {
    x = x|0;
    var ret = 0;
    ret = ((HEAP8[(((cttz_i8)+(x & 0xff))>>0)])|0);
    if ((ret|0) < 8) return ret|0;
    ret = ((HEAP8[(((cttz_i8)+((x >> 8)&0xff))>>0)])|0);
    if ((ret|0) < 8) return (ret + 8)|0;
    ret = ((HEAP8[(((cttz_i8)+((x >> 16)&0xff))>>0)])|0);
    if ((ret|0) < 8) return (ret + 16)|0;
    return (((HEAP8[(((cttz_i8)+(x >>> 24))>>0)])|0) + 24)|0;
  }

// ======== compiled code from system/lib/compiler-rt , see readme therein
function ___muldsi3($a, $b) {
  $a = $a | 0;
  $b = $b | 0;
  var $1 = 0, $2 = 0, $3 = 0, $6 = 0, $8 = 0, $11 = 0, $12 = 0;
  $1 = $a & 65535;
  $2 = $b & 65535;
  $3 = Math_imul($2, $1) | 0;
  $6 = $a >>> 16;
  $8 = ($3 >>> 16) + (Math_imul($2, $6) | 0) | 0;
  $11 = $b >>> 16;
  $12 = Math_imul($11, $1) | 0;
  return (tempRet0 = (($8 >>> 16) + (Math_imul($11, $6) | 0) | 0) + ((($8 & 65535) + $12 | 0) >>> 16) | 0, 0 | ($8 + $12 << 16 | $3 & 65535)) | 0;
}
function ___divdi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $1$0 = 0, $1$1 = 0, $2$0 = 0, $2$1 = 0, $4$0 = 0, $4$1 = 0, $6$0 = 0, $7$0 = 0, $7$1 = 0, $8$0 = 0, $10$0 = 0;
  $1$0 = $a$1 >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
  $1$1 = (($a$1 | 0) < 0 ? -1 : 0) >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
  $2$0 = $b$1 >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
  $2$1 = (($b$1 | 0) < 0 ? -1 : 0) >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
  $4$0 = _i64Subtract($1$0 ^ $a$0, $1$1 ^ $a$1, $1$0, $1$1) | 0;
  $4$1 = tempRet0;
  $6$0 = _i64Subtract($2$0 ^ $b$0, $2$1 ^ $b$1, $2$0, $2$1) | 0;
  $7$0 = $2$0 ^ $1$0;
  $7$1 = $2$1 ^ $1$1;
  $8$0 = ___udivmoddi4($4$0, $4$1, $6$0, tempRet0, 0) | 0;
  $10$0 = _i64Subtract($8$0 ^ $7$0, tempRet0 ^ $7$1, $7$0, $7$1) | 0;
  return (tempRet0 = tempRet0, $10$0) | 0;
}
function ___remdi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $rem = 0, $1$0 = 0, $1$1 = 0, $2$0 = 0, $2$1 = 0, $4$0 = 0, $4$1 = 0, $6$0 = 0, $10$0 = 0, $10$1 = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  $rem = __stackBase__ | 0;
  $1$0 = $a$1 >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
  $1$1 = (($a$1 | 0) < 0 ? -1 : 0) >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
  $2$0 = $b$1 >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
  $2$1 = (($b$1 | 0) < 0 ? -1 : 0) >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
  $4$0 = _i64Subtract($1$0 ^ $a$0, $1$1 ^ $a$1, $1$0, $1$1) | 0;
  $4$1 = tempRet0;
  $6$0 = _i64Subtract($2$0 ^ $b$0, $2$1 ^ $b$1, $2$0, $2$1) | 0;
  ___udivmoddi4($4$0, $4$1, $6$0, tempRet0, $rem) | 0;
  $10$0 = _i64Subtract(HEAP32[$rem >> 2] ^ $1$0, HEAP32[$rem + 4 >> 2] ^ $1$1, $1$0, $1$1) | 0;
  $10$1 = tempRet0;
  STACKTOP = __stackBase__;
  return (tempRet0 = $10$1, $10$0) | 0;
}
function ___muldi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $x_sroa_0_0_extract_trunc = 0, $y_sroa_0_0_extract_trunc = 0, $1$0 = 0, $1$1 = 0, $2 = 0;
  $x_sroa_0_0_extract_trunc = $a$0;
  $y_sroa_0_0_extract_trunc = $b$0;
  $1$0 = ___muldsi3($x_sroa_0_0_extract_trunc, $y_sroa_0_0_extract_trunc) | 0;
  $1$1 = tempRet0;
  $2 = Math_imul($a$1, $y_sroa_0_0_extract_trunc) | 0;
  return (tempRet0 = ((Math_imul($b$1, $x_sroa_0_0_extract_trunc) | 0) + $2 | 0) + $1$1 | $1$1 & 0, 0 | $1$0 & -1) | 0;
}
function ___udivdi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $1$0 = 0;
  $1$0 = ___udivmoddi4($a$0, $a$1, $b$0, $b$1, 0) | 0;
  return (tempRet0 = tempRet0, $1$0) | 0;
}
function ___uremdi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $rem = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  $rem = __stackBase__ | 0;
  ___udivmoddi4($a$0, $a$1, $b$0, $b$1, $rem) | 0;
  STACKTOP = __stackBase__;
  return (tempRet0 = HEAP32[$rem + 4 >> 2] | 0, HEAP32[$rem >> 2] | 0) | 0;
}
function ___udivmoddi4($a$0, $a$1, $b$0, $b$1, $rem) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  $rem = $rem | 0;
  var $n_sroa_0_0_extract_trunc = 0, $n_sroa_1_4_extract_shift$0 = 0, $n_sroa_1_4_extract_trunc = 0, $d_sroa_0_0_extract_trunc = 0, $d_sroa_1_4_extract_shift$0 = 0, $d_sroa_1_4_extract_trunc = 0, $4 = 0, $17 = 0, $37 = 0, $49 = 0, $51 = 0, $57 = 0, $58 = 0, $66 = 0, $78 = 0, $86 = 0, $88 = 0, $89 = 0, $91 = 0, $92 = 0, $95 = 0, $105 = 0, $117 = 0, $119 = 0, $125 = 0, $126 = 0, $130 = 0, $q_sroa_1_1_ph = 0, $q_sroa_0_1_ph = 0, $r_sroa_1_1_ph = 0, $r_sroa_0_1_ph = 0, $sr_1_ph = 0, $d_sroa_0_0_insert_insert99$0 = 0, $d_sroa_0_0_insert_insert99$1 = 0, $137$0 = 0, $137$1 = 0, $carry_0203 = 0, $sr_1202 = 0, $r_sroa_0_1201 = 0, $r_sroa_1_1200 = 0, $q_sroa_0_1199 = 0, $q_sroa_1_1198 = 0, $147 = 0, $149 = 0, $r_sroa_0_0_insert_insert42$0 = 0, $r_sroa_0_0_insert_insert42$1 = 0, $150$1 = 0, $151$0 = 0, $152 = 0, $154$0 = 0, $r_sroa_0_0_extract_trunc = 0, $r_sroa_1_4_extract_trunc = 0, $155 = 0, $carry_0_lcssa$0 = 0, $carry_0_lcssa$1 = 0, $r_sroa_0_1_lcssa = 0, $r_sroa_1_1_lcssa = 0, $q_sroa_0_1_lcssa = 0, $q_sroa_1_1_lcssa = 0, $q_sroa_0_0_insert_ext75$0 = 0, $q_sroa_0_0_insert_ext75$1 = 0, $q_sroa_0_0_insert_insert77$1 = 0, $_0$0 = 0, $_0$1 = 0;
  $n_sroa_0_0_extract_trunc = $a$0;
  $n_sroa_1_4_extract_shift$0 = $a$1;
  $n_sroa_1_4_extract_trunc = $n_sroa_1_4_extract_shift$0;
  $d_sroa_0_0_extract_trunc = $b$0;
  $d_sroa_1_4_extract_shift$0 = $b$1;
  $d_sroa_1_4_extract_trunc = $d_sroa_1_4_extract_shift$0;
  if (($n_sroa_1_4_extract_trunc | 0) == 0) {
    $4 = ($rem | 0) != 0;
    if (($d_sroa_1_4_extract_trunc | 0) == 0) {
      if ($4) {
        HEAP32[$rem >> 2] = ($n_sroa_0_0_extract_trunc >>> 0) % ($d_sroa_0_0_extract_trunc >>> 0);
        HEAP32[$rem + 4 >> 2] = 0;
      }
      $_0$1 = 0;
      $_0$0 = ($n_sroa_0_0_extract_trunc >>> 0) / ($d_sroa_0_0_extract_trunc >>> 0) >>> 0;
      return (tempRet0 = $_0$1, $_0$0) | 0;
    } else {
      if (!$4) {
        $_0$1 = 0;
        $_0$0 = 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      HEAP32[$rem >> 2] = $a$0 & -1;
      HEAP32[$rem + 4 >> 2] = $a$1 & 0;
      $_0$1 = 0;
      $_0$0 = 0;
      return (tempRet0 = $_0$1, $_0$0) | 0;
    }
  }
  $17 = ($d_sroa_1_4_extract_trunc | 0) == 0;
  do {
    if (($d_sroa_0_0_extract_trunc | 0) == 0) {
      if ($17) {
        if (($rem | 0) != 0) {
          HEAP32[$rem >> 2] = ($n_sroa_1_4_extract_trunc >>> 0) % ($d_sroa_0_0_extract_trunc >>> 0);
          HEAP32[$rem + 4 >> 2] = 0;
        }
        $_0$1 = 0;
        $_0$0 = ($n_sroa_1_4_extract_trunc >>> 0) / ($d_sroa_0_0_extract_trunc >>> 0) >>> 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      if (($n_sroa_0_0_extract_trunc | 0) == 0) {
        if (($rem | 0) != 0) {
          HEAP32[$rem >> 2] = 0;
          HEAP32[$rem + 4 >> 2] = ($n_sroa_1_4_extract_trunc >>> 0) % ($d_sroa_1_4_extract_trunc >>> 0);
        }
        $_0$1 = 0;
        $_0$0 = ($n_sroa_1_4_extract_trunc >>> 0) / ($d_sroa_1_4_extract_trunc >>> 0) >>> 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      $37 = $d_sroa_1_4_extract_trunc - 1 | 0;
      if (($37 & $d_sroa_1_4_extract_trunc | 0) == 0) {
        if (($rem | 0) != 0) {
          HEAP32[$rem >> 2] = 0 | $a$0 & -1;
          HEAP32[$rem + 4 >> 2] = $37 & $n_sroa_1_4_extract_trunc | $a$1 & 0;
        }
        $_0$1 = 0;
        $_0$0 = $n_sroa_1_4_extract_trunc >>> ((_llvm_cttz_i32($d_sroa_1_4_extract_trunc | 0) | 0) >>> 0);
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      $49 = _llvm_ctlz_i32($d_sroa_1_4_extract_trunc | 0) | 0;
      $51 = $49 - (_llvm_ctlz_i32($n_sroa_1_4_extract_trunc | 0) | 0) | 0;
      if ($51 >>> 0 <= 30) {
        $57 = $51 + 1 | 0;
        $58 = 31 - $51 | 0;
        $sr_1_ph = $57;
        $r_sroa_0_1_ph = $n_sroa_1_4_extract_trunc << $58 | $n_sroa_0_0_extract_trunc >>> ($57 >>> 0);
        $r_sroa_1_1_ph = $n_sroa_1_4_extract_trunc >>> ($57 >>> 0);
        $q_sroa_0_1_ph = 0;
        $q_sroa_1_1_ph = $n_sroa_0_0_extract_trunc << $58;
        break;
      }
      if (($rem | 0) == 0) {
        $_0$1 = 0;
        $_0$0 = 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      HEAP32[$rem >> 2] = 0 | $a$0 & -1;
      HEAP32[$rem + 4 >> 2] = $n_sroa_1_4_extract_shift$0 | $a$1 & 0;
      $_0$1 = 0;
      $_0$0 = 0;
      return (tempRet0 = $_0$1, $_0$0) | 0;
    } else {
      if (!$17) {
        $117 = _llvm_ctlz_i32($d_sroa_1_4_extract_trunc | 0) | 0;
        $119 = $117 - (_llvm_ctlz_i32($n_sroa_1_4_extract_trunc | 0) | 0) | 0;
        if ($119 >>> 0 <= 31) {
          $125 = $119 + 1 | 0;
          $126 = 31 - $119 | 0;
          $130 = $119 - 31 >> 31;
          $sr_1_ph = $125;
          $r_sroa_0_1_ph = $n_sroa_0_0_extract_trunc >>> ($125 >>> 0) & $130 | $n_sroa_1_4_extract_trunc << $126;
          $r_sroa_1_1_ph = $n_sroa_1_4_extract_trunc >>> ($125 >>> 0) & $130;
          $q_sroa_0_1_ph = 0;
          $q_sroa_1_1_ph = $n_sroa_0_0_extract_trunc << $126;
          break;
        }
        if (($rem | 0) == 0) {
          $_0$1 = 0;
          $_0$0 = 0;
          return (tempRet0 = $_0$1, $_0$0) | 0;
        }
        HEAP32[$rem >> 2] = 0 | $a$0 & -1;
        HEAP32[$rem + 4 >> 2] = $n_sroa_1_4_extract_shift$0 | $a$1 & 0;
        $_0$1 = 0;
        $_0$0 = 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      $66 = $d_sroa_0_0_extract_trunc - 1 | 0;
      if (($66 & $d_sroa_0_0_extract_trunc | 0) != 0) {
        $86 = (_llvm_ctlz_i32($d_sroa_0_0_extract_trunc | 0) | 0) + 33 | 0;
        $88 = $86 - (_llvm_ctlz_i32($n_sroa_1_4_extract_trunc | 0) | 0) | 0;
        $89 = 64 - $88 | 0;
        $91 = 32 - $88 | 0;
        $92 = $91 >> 31;
        $95 = $88 - 32 | 0;
        $105 = $95 >> 31;
        $sr_1_ph = $88;
        $r_sroa_0_1_ph = $91 - 1 >> 31 & $n_sroa_1_4_extract_trunc >>> ($95 >>> 0) | ($n_sroa_1_4_extract_trunc << $91 | $n_sroa_0_0_extract_trunc >>> ($88 >>> 0)) & $105;
        $r_sroa_1_1_ph = $105 & $n_sroa_1_4_extract_trunc >>> ($88 >>> 0);
        $q_sroa_0_1_ph = $n_sroa_0_0_extract_trunc << $89 & $92;
        $q_sroa_1_1_ph = ($n_sroa_1_4_extract_trunc << $89 | $n_sroa_0_0_extract_trunc >>> ($95 >>> 0)) & $92 | $n_sroa_0_0_extract_trunc << $91 & $88 - 33 >> 31;
        break;
      }
      if (($rem | 0) != 0) {
        HEAP32[$rem >> 2] = $66 & $n_sroa_0_0_extract_trunc;
        HEAP32[$rem + 4 >> 2] = 0;
      }
      if (($d_sroa_0_0_extract_trunc | 0) == 1) {
        $_0$1 = $n_sroa_1_4_extract_shift$0 | $a$1 & 0;
        $_0$0 = 0 | $a$0 & -1;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      } else {
        $78 = _llvm_cttz_i32($d_sroa_0_0_extract_trunc | 0) | 0;
        $_0$1 = 0 | $n_sroa_1_4_extract_trunc >>> ($78 >>> 0);
        $_0$0 = $n_sroa_1_4_extract_trunc << 32 - $78 | $n_sroa_0_0_extract_trunc >>> ($78 >>> 0) | 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
    }
  } while (0);
  if (($sr_1_ph | 0) == 0) {
    $q_sroa_1_1_lcssa = $q_sroa_1_1_ph;
    $q_sroa_0_1_lcssa = $q_sroa_0_1_ph;
    $r_sroa_1_1_lcssa = $r_sroa_1_1_ph;
    $r_sroa_0_1_lcssa = $r_sroa_0_1_ph;
    $carry_0_lcssa$1 = 0;
    $carry_0_lcssa$0 = 0;
  } else {
    $d_sroa_0_0_insert_insert99$0 = 0 | $b$0 & -1;
    $d_sroa_0_0_insert_insert99$1 = $d_sroa_1_4_extract_shift$0 | $b$1 & 0;
    $137$0 = _i64Add($d_sroa_0_0_insert_insert99$0, $d_sroa_0_0_insert_insert99$1, -1, -1) | 0;
    $137$1 = tempRet0;
    $q_sroa_1_1198 = $q_sroa_1_1_ph;
    $q_sroa_0_1199 = $q_sroa_0_1_ph;
    $r_sroa_1_1200 = $r_sroa_1_1_ph;
    $r_sroa_0_1201 = $r_sroa_0_1_ph;
    $sr_1202 = $sr_1_ph;
    $carry_0203 = 0;
    while (1) {
      $147 = $q_sroa_0_1199 >>> 31 | $q_sroa_1_1198 << 1;
      $149 = $carry_0203 | $q_sroa_0_1199 << 1;
      $r_sroa_0_0_insert_insert42$0 = 0 | ($r_sroa_0_1201 << 1 | $q_sroa_1_1198 >>> 31);
      $r_sroa_0_0_insert_insert42$1 = $r_sroa_0_1201 >>> 31 | $r_sroa_1_1200 << 1 | 0;
      _i64Subtract($137$0, $137$1, $r_sroa_0_0_insert_insert42$0, $r_sroa_0_0_insert_insert42$1) | 0;
      $150$1 = tempRet0;
      $151$0 = $150$1 >> 31 | (($150$1 | 0) < 0 ? -1 : 0) << 1;
      $152 = $151$0 & 1;
      $154$0 = _i64Subtract($r_sroa_0_0_insert_insert42$0, $r_sroa_0_0_insert_insert42$1, $151$0 & $d_sroa_0_0_insert_insert99$0, ((($150$1 | 0) < 0 ? -1 : 0) >> 31 | (($150$1 | 0) < 0 ? -1 : 0) << 1) & $d_sroa_0_0_insert_insert99$1) | 0;
      $r_sroa_0_0_extract_trunc = $154$0;
      $r_sroa_1_4_extract_trunc = tempRet0;
      $155 = $sr_1202 - 1 | 0;
      if (($155 | 0) == 0) {
        break;
      } else {
        $q_sroa_1_1198 = $147;
        $q_sroa_0_1199 = $149;
        $r_sroa_1_1200 = $r_sroa_1_4_extract_trunc;
        $r_sroa_0_1201 = $r_sroa_0_0_extract_trunc;
        $sr_1202 = $155;
        $carry_0203 = $152;
      }
    }
    $q_sroa_1_1_lcssa = $147;
    $q_sroa_0_1_lcssa = $149;
    $r_sroa_1_1_lcssa = $r_sroa_1_4_extract_trunc;
    $r_sroa_0_1_lcssa = $r_sroa_0_0_extract_trunc;
    $carry_0_lcssa$1 = 0;
    $carry_0_lcssa$0 = $152;
  }
  $q_sroa_0_0_insert_ext75$0 = $q_sroa_0_1_lcssa;
  $q_sroa_0_0_insert_ext75$1 = 0;
  $q_sroa_0_0_insert_insert77$1 = $q_sroa_1_1_lcssa | $q_sroa_0_0_insert_ext75$1;
  if (($rem | 0) != 0) {
    HEAP32[$rem >> 2] = 0 | $r_sroa_0_1_lcssa;
    HEAP32[$rem + 4 >> 2] = $r_sroa_1_1_lcssa | 0;
  }
  $_0$1 = (0 | $q_sroa_0_0_insert_ext75$0) >>> 31 | $q_sroa_0_0_insert_insert77$1 << 1 | ($q_sroa_0_0_insert_ext75$1 << 1 | $q_sroa_0_0_insert_ext75$0 >>> 31) & 0 | $carry_0_lcssa$1;
  $_0$0 = ($q_sroa_0_0_insert_ext75$0 << 1 | 0 >>> 31) & -2 | $carry_0_lcssa$0;
  return (tempRet0 = $_0$1, $_0$0) | 0;
}
// =======================================================================



// EMSCRIPTEN_END_FUNCS

  
  function dynCall_diiiiid(index,a1,a2,a3,a4,a5,a6) {
    index = index|0;
    a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=+a6;
    return +FUNCTION_TABLE_diiiiid[index&1](a1|0,a2|0,a3|0,a4|0,a5|0,+a6);
  }


  function dynCall_ii(index,a1) {
    index = index|0;
    a1=a1|0;
    return FUNCTION_TABLE_ii[index&15](a1|0)|0;
  }


  function dynCall_viiiii(index,a1,a2,a3,a4,a5) {
    index = index|0;
    a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0;
    FUNCTION_TABLE_viiiii[index&3](a1|0,a2|0,a3|0,a4|0,a5|0);
  }


  function dynCall_did(index,a1,a2) {
    index = index|0;
    a1=a1|0; a2=+a2;
    return +FUNCTION_TABLE_did[index&15](a1|0,+a2);
  }


  function dynCall_vi(index,a1) {
    index = index|0;
    a1=a1|0;
    FUNCTION_TABLE_vi[index&127](a1|0);
  }


  function dynCall_diiiid(index,a1,a2,a3,a4,a5) {
    index = index|0;
    a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=+a5;
    return +FUNCTION_TABLE_diiiid[index&1](a1|0,a2|0,a3|0,a4|0,+a5);
  }


  function dynCall_vii(index,a1,a2) {
    index = index|0;
    a1=a1|0; a2=a2|0;
    FUNCTION_TABLE_vii[index&63](a1|0,a2|0);
  }


  function dynCall_iiii(index,a1,a2,a3) {
    index = index|0;
    a1=a1|0; a2=a2|0; a3=a3|0;
    return FUNCTION_TABLE_iiii[index&15](a1|0,a2|0,a3|0)|0;
  }


  function dynCall_viii(index,a1,a2,a3) {
    index = index|0;
    a1=a1|0; a2=a2|0; a3=a3|0;
    FUNCTION_TABLE_viii[index&15](a1|0,a2|0,a3|0);
  }


  function dynCall_v(index) {
    index = index|0;
    
    FUNCTION_TABLE_v[index&3]();
  }


  function dynCall_viid(index,a1,a2,a3) {
    index = index|0;
    a1=a1|0; a2=a2|0; a3=+a3;
    FUNCTION_TABLE_viid[index&31](a1|0,a2|0,+a3);
  }


  function dynCall_iiiii(index,a1,a2,a3,a4) {
    index = index|0;
    a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0;
    return FUNCTION_TABLE_iiiii[index&7](a1|0,a2|0,a3|0,a4|0)|0;
  }


  function dynCall_viiiiii(index,a1,a2,a3,a4,a5,a6) {
    index = index|0;
    a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0; a6=a6|0;
    FUNCTION_TABLE_viiiiii[index&7](a1|0,a2|0,a3|0,a4|0,a5|0,a6|0);
  }


  function dynCall_iii(index,a1,a2) {
    index = index|0;
    a1=a1|0; a2=a2|0;
    return FUNCTION_TABLE_iii[index&63](a1|0,a2|0)|0;
  }


  function dynCall_iiiiii(index,a1,a2,a3,a4,a5) {
    index = index|0;
    a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0; a5=a5|0;
    return FUNCTION_TABLE_iiiiii[index&15](a1|0,a2|0,a3|0,a4|0,a5|0)|0;
  }


  function dynCall_viiii(index,a1,a2,a3,a4) {
    index = index|0;
    a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0;
    FUNCTION_TABLE_viiii[index&31](a1|0,a2|0,a3|0,a4|0);
  }

function b0(p0,p1,p2,p3,p4,p5) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = +p5; abort(0);return +0; }
  function b1(p0) { p0 = p0|0; abort(1);return 0; }
  function b2(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0; abort(2); }
  function b3(p0,p1) { p0 = p0|0;p1 = +p1; abort(3);return +0; }
  function b4(p0) { p0 = p0|0; abort(4); }
  function b5(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = +p4; abort(5);return +0; }
  function b6(p0,p1) { p0 = p0|0;p1 = p1|0; abort(6); }
  function b7(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; abort(7);return 0; }
  function b8(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; abort(8); }
  function b9() { ; abort(9); }
  function ___cxa_pure_virtual__wrapper() { ; ___cxa_pure_virtual(); }
  function b10(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = +p2; abort(10); }
  function b11(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; abort(11);return 0; }
  function b12(p0,p1,p2,p3,p4,p5) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0;p5 = p5|0; abort(12); }
  function b13(p0,p1) { p0 = p0|0;p1 = p1|0; abort(13);return 0; }
  function b14(p0,p1,p2,p3,p4) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0;p4 = p4|0; abort(14);return 0; }
  function b15(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; abort(15); }
  // EMSCRIPTEN_END_FUNCS
  var FUNCTION_TABLE_diiiiid = [b0,__ZN17b2RayCastCallback14ReportParticleEPK16b2ParticleSystemiRK6b2Vec2S5_f];
  var FUNCTION_TABLE_ii = [b1,__ZNK11b2EdgeShape13GetChildCountEv,__ZNK14b2PolygonShape13GetChildCountEv,__ZNK13b2CircleShape13GetChildCountEv,__ZNK12b2ChainShape13GetChildCountEv,__ZZN16b2ParticleSystem33CreateParticlesWithShapesForGroupEPKPK7b2ShapeiRK18b2ParticleGroupDefRK11b2TransformENK14CompositeShape13GetChildCountEv,__ZNKSt9bad_alloc4whatEv,__ZZN16b2ParticleSystem11SolveZombieEvEN4Test14IsProxyInvalidERKNS_5ProxyE,__ZZN16b2ParticleSystem11SolveZombieEvEN4Test16IsContactInvalidERK17b2ParticleContact,__ZZN16b2ParticleSystem11SolveZombieEvEN4Test20IsBodyContactInvalidERK21b2ParticleBodyContact,__ZZN16b2ParticleSystem11SolveZombieEvEN4Test13IsPairInvalidERK14b2ParticlePair,__ZZN16b2ParticleSystem11SolveZombieEvEN4Test14IsTriadInvalidERK15b2ParticleTriad,__ZL25b2ParticleContactIsZombieRK17b2ParticleContact,b1,b1,b1];
  var FUNCTION_TABLE_viiiii = [b2,__ZNK10__cxxabiv117__class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib,__ZNK10__cxxabiv120__si_class_type_info16search_below_dstEPNS_19__dynamic_cast_infoEPKvib,b2];
  var FUNCTION_TABLE_did = [b3,__ZNK12b2MouseJoint17GetReactionTorqueEf,__ZNK12b2MotorJoint17GetReactionTorqueEf,__ZNK15b2DistanceJoint17GetReactionTorqueEf,__ZNK15b2FrictionJoint17GetReactionTorqueEf,__ZNK11b2WeldJoint17GetReactionTorqueEf,__ZNK11b2GearJoint17GetReactionTorqueEf,__ZNK16b2PrismaticJoint17GetReactionTorqueEf,__ZNK11b2RopeJoint17GetReactionTorqueEf,__ZNK15b2RevoluteJoint17GetReactionTorqueEf,__ZNK12b2WheelJoint17GetReactionTorqueEf,__ZNK13b2PulleyJoint17GetReactionTorqueEf,b3,b3,b3,b3];
  var FUNCTION_TABLE_vi = [b4,__ZN17b2RayCastCallbackD2Ev,__ZN15RayCastCallbackD0Ev,__ZN17b2RayCastCallbackD0Ev,__ZN15b2QueryCallbackD2Ev,__ZN17QueryAABBCallbackD0Ev,__ZN15b2QueryCallbackD0Ev,__ZN17b2ContactListenerD2Ev,__ZN22b2WorldContactListenerD0Ev,__ZN17b2ContactListenerD0Ev,__ZN7b2ShapeD2Ev,__ZN7b2ShapeD0Ev,__ZN11b2EdgeShapeD0Ev,__ZN14b2PolygonShapeD0Ev,__ZN13b2CircleShapeD0Ev,__ZN12b2ChainShapeD2Ev,__ZN12b2ChainShapeD0Ev,__ZN15b2ContactFilterD2Ev,__ZN15b2ContactFilterD0Ev,__ZN12b2MouseJoint4DumpEv,__ZN7b2JointD2Ev,__ZN12b2MouseJointD0Ev,__ZN12b2MotorJoint4DumpEv,__ZN12b2MotorJointD0Ev,__ZN15b2DistanceJoint4DumpEv,__ZN15b2DistanceJointD0Ev,__ZN15b2FrictionJoint4DumpEv,__ZN15b2FrictionJointD0Ev,__ZN11b2WeldJoint4DumpEv
  ,__ZN11b2WeldJointD0Ev,__ZN11b2GearJoint4DumpEv,__ZN11b2GearJointD0Ev,__ZN16b2PrismaticJoint4DumpEv,__ZN16b2PrismaticJointD0Ev,__ZN11b2RopeJoint4DumpEv,__ZN11b2RopeJointD0Ev,__ZN7b2Joint4DumpEv,__ZN7b2JointD0Ev,__ZN15b2RevoluteJoint4DumpEv,__ZN15b2RevoluteJointD0Ev,__ZN12b2WheelJoint4DumpEv,__ZN12b2WheelJointD0Ev,__ZN13b2PulleyJoint4DumpEv,__ZN13b2PulleyJointD0Ev,__ZN9b2ContactD2Ev,__ZN24b2ChainAndPolygonContactD0Ev,__ZN9b2ContactD0Ev,__ZN25b2PolygonAndCircleContactD0Ev,__ZN15b2CircleContactD0Ev,__ZN22b2EdgeAndCircleContactD0Ev,__ZN23b2ChainAndCircleContactD0Ev,__ZN23b2EdgeAndPolygonContactD0Ev,__ZN16b2PolygonContactD0Ev,__ZZN16b2ParticleSystem14SolveCollisionERK10b2TimeStepEN22SolveCollisionCallbackD0Ev,__ZN30b2FixtureParticleQueryCallbackD0Ev,__ZZN16b2ParticleSystem18UpdateBodyContactsEvEN26UpdateBodyContactsCallbackD0Ev,__ZN16b2VoronoiDiagram12NodeCallbackD2Ev,__ZZN16b2ParticleSystem20UpdatePairsAndTriadsEiiRKNS_16ConnectionFilterEEN20UpdateTriadsCallbackD0Ev,__ZN16b2VoronoiDiagram12NodeCallbackD0Ev
  ,__ZN16b2ParticleSystem16ConnectionFilterD2Ev,__ZZN16b2ParticleSystem41UpdatePairsAndTriadsWithReactiveParticlesEvEN14ReactiveFilterD0Ev,__ZN16b2ParticleSystem16ConnectionFilterD0Ev,__ZZN16b2ParticleSystem18JoinParticleGroupsEP15b2ParticleGroupS1_EN24JoinParticleGroupsFilterD0Ev,__ZZN16b2ParticleSystem33CreateParticlesWithShapesForGroupEPKPK7b2ShapeiRK18b2ParticleGroupDefRK11b2TransformEN14CompositeShapeD0Ev,__ZZN16b2ParticleSystem23DestroyParticlesInShapeERK7b2ShapeRK11b2TransformbEN31DestroyParticlesInShapeCallbackD0Ev,__ZNSt9bad_allocD2Ev,__ZNSt9bad_allocD0Ev,__ZN10__cxxabiv116__shim_type_infoD2Ev,__ZN10__cxxabiv117__class_type_infoD0Ev,__ZNK10__cxxabiv116__shim_type_info5noop1Ev,__ZNK10__cxxabiv116__shim_type_info5noop2Ev,__ZN10__cxxabiv120__si_class_type_infoD0Ev,__ZN10__cxxabiv112_GLOBAL__N_19destruct_EPv,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
  ,b4,b4,b4,b4,b4,b4,b4,b4,b4];
  var FUNCTION_TABLE_diiiid = [b5,__ZN15RayCastCallback13ReportFixtureEP9b2FixtureRK6b2Vec2S4_f];
  var FUNCTION_TABLE_vii = [b6,__ZN22b2WorldContactListener12BeginContactEP9b2Contact,__ZN22b2WorldContactListener10EndContactEP9b2Contact,__ZN17b2ContactListener12BeginContactEP9b2Contact,__ZN17b2ContactListener10EndContactEP9b2Contact,__ZNK12b2MouseJoint10GetAnchorAEv,__ZNK12b2MouseJoint10GetAnchorBEv,__ZN12b2MouseJoint11ShiftOriginERK6b2Vec2,__ZN12b2MouseJoint23InitVelocityConstraintsERK12b2SolverData,__ZN12b2MouseJoint24SolveVelocityConstraintsERK12b2SolverData,__ZNK12b2MotorJoint10GetAnchorAEv,__ZNK12b2MotorJoint10GetAnchorBEv,__ZN7b2Joint11ShiftOriginERK6b2Vec2,__ZN12b2MotorJoint23InitVelocityConstraintsERK12b2SolverData,__ZN12b2MotorJoint24SolveVelocityConstraintsERK12b2SolverData,__ZNK15b2DistanceJoint10GetAnchorAEv,__ZNK15b2DistanceJoint10GetAnchorBEv,__ZN15b2DistanceJoint23InitVelocityConstraintsERK12b2SolverData,__ZN15b2DistanceJoint24SolveVelocityConstraintsERK12b2SolverData,__ZNK15b2FrictionJoint10GetAnchorAEv,__ZNK15b2FrictionJoint10GetAnchorBEv,__ZN15b2FrictionJoint23InitVelocityConstraintsERK12b2SolverData,__ZN15b2FrictionJoint24SolveVelocityConstraintsERK12b2SolverData,__ZNK11b2WeldJoint10GetAnchorAEv,__ZNK11b2WeldJoint10GetAnchorBEv,__ZN11b2WeldJoint23InitVelocityConstraintsERK12b2SolverData,__ZN11b2WeldJoint24SolveVelocityConstraintsERK12b2SolverData,__ZNK11b2GearJoint10GetAnchorAEv,__ZNK11b2GearJoint10GetAnchorBEv
  ,__ZN11b2GearJoint23InitVelocityConstraintsERK12b2SolverData,__ZN11b2GearJoint24SolveVelocityConstraintsERK12b2SolverData,__ZNK16b2PrismaticJoint10GetAnchorAEv,__ZNK16b2PrismaticJoint10GetAnchorBEv,__ZN16b2PrismaticJoint23InitVelocityConstraintsERK12b2SolverData,__ZN16b2PrismaticJoint24SolveVelocityConstraintsERK12b2SolverData,__ZNK11b2RopeJoint10GetAnchorAEv,__ZNK11b2RopeJoint10GetAnchorBEv,__ZN11b2RopeJoint23InitVelocityConstraintsERK12b2SolverData,__ZN11b2RopeJoint24SolveVelocityConstraintsERK12b2SolverData,__ZNK15b2RevoluteJoint10GetAnchorAEv,__ZNK15b2RevoluteJoint10GetAnchorBEv,__ZN15b2RevoluteJoint23InitVelocityConstraintsERK12b2SolverData,__ZN15b2RevoluteJoint24SolveVelocityConstraintsERK12b2SolverData,__ZNK12b2WheelJoint10GetAnchorAEv,__ZNK12b2WheelJoint10GetAnchorBEv,__ZN12b2WheelJoint23InitVelocityConstraintsERK12b2SolverData,__ZN12b2WheelJoint24SolveVelocityConstraintsERK12b2SolverData,__ZNK13b2PulleyJoint10GetAnchorAEv,__ZNK13b2PulleyJoint10GetAnchorBEv,__ZN13b2PulleyJoint11ShiftOriginERK6b2Vec2,__ZN13b2PulleyJoint23InitVelocityConstraintsERK12b2SolverData,__ZN13b2PulleyJoint24SolveVelocityConstraintsERK12b2SolverData,__ZL13b2FreeDefaultPvS_,__ZN15b2CircleContact7DestroyEP9b2ContactP16b2BlockAllocator,__ZN25b2PolygonAndCircleContact7DestroyEP9b2ContactP16b2BlockAllocator,__ZN16b2PolygonContact7DestroyEP9b2ContactP16b2BlockAllocator,__ZN22b2EdgeAndCircleContact7DestroyEP9b2ContactP16b2BlockAllocator,__ZN23b2EdgeAndPolygonContact7DestroyEP9b2ContactP16b2BlockAllocator,__ZN23b2ChainAndCircleContact7DestroyEP9b2ContactP16b2BlockAllocator
  ,__ZN24b2ChainAndPolygonContact7DestroyEP9b2ContactP16b2BlockAllocator,b6,b6,b6,b6];
  var FUNCTION_TABLE_iiii = [b7,__ZN15b2QueryCallback14ReportParticleEPK16b2ParticleSystemi,__ZNK11b2EdgeShape9TestPointERK11b2TransformRK6b2Vec2,__ZNK14b2PolygonShape9TestPointERK11b2TransformRK6b2Vec2,__ZNK13b2CircleShape9TestPointERK11b2TransformRK6b2Vec2,__ZNK12b2ChainShape9TestPointERK11b2TransformRK6b2Vec2,__ZN15b2ContactFilter13ShouldCollideEP9b2FixtureS1_,__ZNK16b2ParticleSystem16ConnectionFilter16ShouldCreatePairEii,__ZZN16b2ParticleSystem18JoinParticleGroupsEP15b2ParticleGroupS1_ENK24JoinParticleGroupsFilter16ShouldCreatePairEii,__ZZN16b2ParticleSystem33CreateParticlesWithShapesForGroupEPKPK7b2ShapeiRK18b2ParticleGroupDefRK11b2TransformENK14CompositeShape9TestPointESA_RK6b2Vec2,__ZZN16b2ParticleSystem23DestroyParticlesInShapeERK7b2ShapeRK11b2TransformbEN31DestroyParticlesInShapeCallback14ReportParticleEPKS_i,__ZNK10__cxxabiv117__class_type_info9can_catchEPKNS_16__shim_type_infoERPv,b7,b7,b7,b7];
  var FUNCTION_TABLE_viii = [b8,__ZN22b2WorldContactListener12BeginContactEP16b2ParticleSystemP21b2ParticleBodyContact,__ZN22b2WorldContactListener12BeginContactEP16b2ParticleSystemP17b2ParticleContact,__ZN22b2WorldContactListener8PreSolveEP9b2ContactPK10b2Manifold,__ZN22b2WorldContactListener9PostSolveEP9b2ContactPK16b2ContactImpulse,__ZN17b2ContactListener12BeginContactEP16b2ParticleSystemP21b2ParticleBodyContact,__ZN17b2ContactListener12BeginContactEP16b2ParticleSystemP17b2ParticleContact,__ZN17b2ContactListener8PreSolveEP9b2ContactPK10b2Manifold,__ZN17b2ContactListener9PostSolveEP9b2ContactPK16b2ContactImpulse,b8,b8,b8,b8,b8,b8,b8];
  var FUNCTION_TABLE_v = [b9,___cxa_pure_virtual__wrapper,__ZL25default_terminate_handlerv,__ZN10__cxxabiv112_GLOBAL__N_110construct_Ev];
  var FUNCTION_TABLE_viid = [b10,__ZNK11b2EdgeShape11ComputeMassEP10b2MassDataf,__ZNK14b2PolygonShape11ComputeMassEP10b2MassDataf,__ZNK13b2CircleShape11ComputeMassEP10b2MassDataf,__ZNK12b2ChainShape11ComputeMassEP10b2MassDataf,__ZNK12b2MouseJoint16GetReactionForceEf,__ZNK12b2MotorJoint16GetReactionForceEf,__ZNK15b2DistanceJoint16GetReactionForceEf,__ZNK15b2FrictionJoint16GetReactionForceEf,__ZNK11b2WeldJoint16GetReactionForceEf,__ZNK11b2GearJoint16GetReactionForceEf,__ZNK16b2PrismaticJoint16GetReactionForceEf,__ZNK11b2RopeJoint16GetReactionForceEf,__ZNK15b2RevoluteJoint16GetReactionForceEf,__ZNK12b2WheelJoint16GetReactionForceEf,__ZNK13b2PulleyJoint16GetReactionForceEf,__ZZN16b2ParticleSystem33CreateParticlesWithShapesForGroupEPKPK7b2ShapeiRK18b2ParticleGroupDefRK11b2TransformENK14CompositeShape11ComputeMassEP10b2MassDataf,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10,b10
  ,b10,b10,b10];
  var FUNCTION_TABLE_iiiii = [b11,__ZN15b2ContactFilter13ShouldCollideEP9b2FixtureP16b2ParticleSystemi,__ZN15b2ContactFilter13ShouldCollideEP16b2ParticleSystemii,__ZNK16b2ParticleSystem16ConnectionFilter17ShouldCreateTriadEiii,__ZZN16b2ParticleSystem18JoinParticleGroupsEP15b2ParticleGroupS1_ENK24JoinParticleGroupsFilter17ShouldCreateTriadEiii,b11,b11,b11];
  var FUNCTION_TABLE_viiiiii = [b12,__ZNK11b2EdgeShape15ComputeDistanceERK11b2TransformRK6b2Vec2PfPS3_i,__ZNK14b2PolygonShape15ComputeDistanceERK11b2TransformRK6b2Vec2PfPS3_i,__ZNK13b2CircleShape15ComputeDistanceERK11b2TransformRK6b2Vec2PfPS3_i,__ZNK12b2ChainShape15ComputeDistanceERK11b2TransformRK6b2Vec2PfPS3_i,__ZZN16b2ParticleSystem33CreateParticlesWithShapesForGroupEPKPK7b2ShapeiRK18b2ParticleGroupDefRK11b2TransformENK14CompositeShape15ComputeDistanceESA_RK6b2Vec2PfPSC_i,__ZNK10__cxxabiv117__class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib,__ZNK10__cxxabiv120__si_class_type_info16search_above_dstEPNS_19__dynamic_cast_infoEPKvS4_ib];
  var FUNCTION_TABLE_iii = [b13,__ZN17b2RayCastCallback25ShouldQueryParticleSystemEPK16b2ParticleSystem,__ZN17QueryAABBCallback13ReportFixtureEP9b2Fixture,__ZN15b2QueryCallback25ShouldQueryParticleSystemEPK16b2ParticleSystem,__ZNK11b2EdgeShape5CloneEP16b2BlockAllocator,__ZNK14b2PolygonShape5CloneEP16b2BlockAllocator,__ZNK13b2CircleShape5CloneEP16b2BlockAllocator,__ZNK12b2ChainShape5CloneEP16b2BlockAllocator,__ZN12b2MouseJoint24SolvePositionConstraintsERK12b2SolverData,__ZN12b2MotorJoint24SolvePositionConstraintsERK12b2SolverData,__ZN15b2DistanceJoint24SolvePositionConstraintsERK12b2SolverData,__ZN15b2FrictionJoint24SolvePositionConstraintsERK12b2SolverData,__ZN11b2WeldJoint24SolvePositionConstraintsERK12b2SolverData,__ZN11b2GearJoint24SolvePositionConstraintsERK12b2SolverData,__ZN16b2PrismaticJoint24SolvePositionConstraintsERK12b2SolverData,__ZN11b2RopeJoint24SolvePositionConstraintsERK12b2SolverData,__ZN15b2RevoluteJoint24SolvePositionConstraintsERK12b2SolverData,__ZN12b2WheelJoint24SolvePositionConstraintsERK12b2SolverData,__ZN13b2PulleyJoint24SolvePositionConstraintsERK12b2SolverData,__ZN30b2FixtureParticleQueryCallback13ReportFixtureEP9b2Fixture,__ZN30b2FixtureParticleQueryCallback25ShouldQueryParticleSystemEPK16b2ParticleSystem,__ZZN16b2ParticleSystem41UpdatePairsAndTriadsWithReactiveParticlesEvENK14ReactiveFilter11IsNecessaryEi,__ZNK16b2ParticleSystem16ConnectionFilter11IsNecessaryEi,__ZZN16b2ParticleSystem33CreateParticlesWithShapesForGroupEPKPK7b2ShapeiRK18b2ParticleGroupDefRK11b2TransformENK14CompositeShape5CloneEP16b2BlockAllocator,__ZZN16b2ParticleSystem23DestroyParticlesInShapeERK7b2ShapeRK11b2TransformbEN31DestroyParticlesInShapeCallback13ReportFixtureEP9b2Fixture,__ZL14b2AllocDefaultiPv,__Z14b2PairLessThanRK6b2PairS1_,__ZN16b2ParticleSystem18ComparePairIndicesERK14b2ParticlePairS2_,__ZN16b2ParticleSystem16MatchPairIndicesERK14b2ParticlePairS2_
  ,__ZN16b2ParticleSystem19CompareTriadIndicesERK15b2ParticleTriadS2_,__ZN16b2ParticleSystem17MatchTriadIndicesERK15b2ParticleTriadS2_,__ZN12_GLOBAL__N_115LightweightPairIiiE7CompareERKS1_S3_,__ZN12_GLOBAL__N_115LightweightPairIP9b2FixtureiE7CompareERKS3_S5_,__ZN16b2ParticleSystem18BodyContactCompareERK21b2ParticleBodyContactS2_,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13,b13
  ,b13,b13,b13,b13,b13];
  var FUNCTION_TABLE_iiiiii = [b14,__ZNK11b2EdgeShape7RayCastEP15b2RayCastOutputRK14b2RayCastInputRK11b2Transformi,__ZNK14b2PolygonShape7RayCastEP15b2RayCastOutputRK14b2RayCastInputRK11b2Transformi,__ZNK13b2CircleShape7RayCastEP15b2RayCastOutputRK14b2RayCastInputRK11b2Transformi,__ZNK12b2ChainShape7RayCastEP15b2RayCastOutputRK14b2RayCastInputRK11b2Transformi,__ZZN16b2ParticleSystem33CreateParticlesWithShapesForGroupEPKPK7b2ShapeiRK18b2ParticleGroupDefRK11b2TransformENK14CompositeShape7RayCastEP15b2RayCastOutputRK14b2RayCastInputSA_i,__ZN15b2CircleContact6CreateEP9b2FixtureiS1_iP16b2BlockAllocator,__ZN25b2PolygonAndCircleContact6CreateEP9b2FixtureiS1_iP16b2BlockAllocator,__ZN16b2PolygonContact6CreateEP9b2FixtureiS1_iP16b2BlockAllocator,__ZN22b2EdgeAndCircleContact6CreateEP9b2FixtureiS1_iP16b2BlockAllocator,__ZN23b2EdgeAndPolygonContact6CreateEP9b2FixtureiS1_iP16b2BlockAllocator,__ZN23b2ChainAndCircleContact6CreateEP9b2FixtureiS1_iP16b2BlockAllocator,__ZN24b2ChainAndPolygonContact6CreateEP9b2FixtureiS1_iP16b2BlockAllocator,b14,b14,b14];
  var FUNCTION_TABLE_viiii = [b15,__ZN22b2WorldContactListener10EndContactEP9b2FixtureP16b2ParticleSystemi,__ZN22b2WorldContactListener10EndContactEP16b2ParticleSystemii,__ZN17b2ContactListener10EndContactEP9b2FixtureP16b2ParticleSystemi,__ZN17b2ContactListener10EndContactEP16b2ParticleSystemii,__ZNK11b2EdgeShape11ComputeAABBEP6b2AABBRK11b2Transformi,__ZNK14b2PolygonShape11ComputeAABBEP6b2AABBRK11b2Transformi,__ZNK13b2CircleShape11ComputeAABBEP6b2AABBRK11b2Transformi,__ZNK12b2ChainShape11ComputeAABBEP6b2AABBRK11b2Transformi,__ZN24b2ChainAndPolygonContact8EvaluateEP10b2ManifoldRK11b2TransformS4_,__ZN25b2PolygonAndCircleContact8EvaluateEP10b2ManifoldRK11b2TransformS4_,__ZN15b2CircleContact8EvaluateEP10b2ManifoldRK11b2TransformS4_,__ZN22b2EdgeAndCircleContact8EvaluateEP10b2ManifoldRK11b2TransformS4_,__ZN23b2ChainAndCircleContact8EvaluateEP10b2ManifoldRK11b2TransformS4_,__ZN23b2EdgeAndPolygonContact8EvaluateEP10b2ManifoldRK11b2TransformS4_,__ZN16b2PolygonContact8EvaluateEP10b2ManifoldRK11b2TransformS4_,__ZZN16b2ParticleSystem14SolveCollisionERK10b2TimeStepEN22SolveCollisionCallback24ReportFixtureAndParticleEP9b2Fixtureii,__ZZN16b2ParticleSystem18UpdateBodyContactsEvEN26UpdateBodyContactsCallback24ReportFixtureAndParticleEP9b2Fixtureii,__ZZN16b2ParticleSystem20UpdatePairsAndTriadsEiiRKNS_16ConnectionFilterEEN20UpdateTriadsCallbackclEiii,__ZZN16b2ParticleSystem33CreateParticlesWithShapesForGroupEPKPK7b2ShapeiRK18b2ParticleGroupDefRK11b2TransformENK14CompositeShape11ComputeAABBEP6b2AABBSA_i,__ZNK10__cxxabiv117__class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi,__ZNK10__cxxabiv120__si_class_type_info27has_unambiguous_public_baseEPNS_19__dynamic_cast_infoEPvi,b15,b15,b15,b15,b15,b15,b15
  ,b15,b15,b15];

  return { _b2PrismaticJoint_IsMotorEnabled: _b2PrismaticJoint_IsMotorEnabled, _b2Body_GetWorldVector: _b2Body_GetWorldVector, _strlen: _strlen, _b2Body_GetLocalVector: _b2Body_GetLocalVector, _b2PrismaticJoint_GetMotorSpeed: _b2PrismaticJoint_GetMotorSpeed, _b2RopeJointDef_Create: _b2RopeJointDef_Create, _b2World_CreateParticleSystem: _b2World_CreateParticleSystem, _b2ParticleSystem_SetRadius: _b2ParticleSystem_SetRadius, _b2FrictionJointDef_Create: _b2FrictionJointDef_Create, _b2World_RayCast: _b2World_RayCast, _b2MotorJointDef_InitializeAndCreate: _b2MotorJointDef_InitializeAndCreate, _b2GearJoint_GetRatio: _b2GearJoint_GetRatio, _b2Body_GetLocalPoint: _b2Body_GetLocalPoint, _memcpy: _memcpy, _b2RevoluteJoint_EnableLimit: _b2RevoluteJoint_EnableLimit, _b2Body_DestroyFixture: _b2Body_DestroyFixture, _b2World_Create: _b2World_Create, _b2PolygonShape_CreateFixture_3: _b2PolygonShape_CreateFixture_3, _b2PolygonShape_CreateFixture_6: _b2PolygonShape_CreateFixture_6, _b2PolygonShape_CreateFixture_7: _b2PolygonShape_CreateFixture_7, _b2PolygonShape_CreateFixture_4: _b2PolygonShape_CreateFixture_4, _b2PolygonShape_CreateFixture_5: _b2PolygonShape_CreateFixture_5, _b2Body_SetAwake: _b2Body_SetAwake, _b2Body_GetWorldCenter: _b2Body_GetWorldCenter, _b2ParticleGroup_DestroyParticles: _b2ParticleGroup_DestroyParticles, _b2PrismaticJoint_EnableLimit: _b2PrismaticJoint_EnableLimit, _b2ParticleContact_GetNormal: _b2ParticleContact_GetNormal, _b2Fixture_TestPoint: _b2Fixture_TestPoint, _b2MotorJoint_SetLinearOffset: _b2MotorJoint_SetLinearOffset, ___cxa_can_catch: ___cxa_can_catch, _free: _free, _b2ParticleSystem_CreateParticle: _b2ParticleSystem_CreateParticle, _b2Body_SetLinearVelocity: _b2Body_SetLinearVelocity, _b2CircleShape_CreateParticleGroup: _b2CircleShape_CreateParticleGroup, _b2WeldJointDef_Create: _b2WeldJointDef_Create, _b2Body_GetAngularVelocity: _b2Body_GetAngularVelocity, _b2Body_ApplyForceToCenter: _b2Body_ApplyForceToCenter, _b2DistanceJointDef_InitializeAndCreate: _b2DistanceJointDef_InitializeAndCreate, _b2Body_ApplyForce: _b2Body_ApplyForce, _GenerateOffsets: _GenerateOffsets, _b2RevoluteJoint_SetMotorSpeed: _b2RevoluteJoint_SetMotorSpeed, ___cxa_is_pointer_type: ___cxa_is_pointer_type, _b2Body_GetPosition: _b2Body_GetPosition, _b2World_CreateBody: _b2World_CreateBody, _b2Body_GetLinearVelocity: _b2Body_GetLinearVelocity, _b2Body_SetMassData: _b2Body_SetMassData, _b2MouseJointDef_Create: _b2MouseJointDef_Create, _b2ParticleSystem_GetColorBuffer: _b2ParticleSystem_GetColorBuffer, _b2DistanceJointDef_Create: _b2DistanceJointDef_Create, _b2ParticleSystem_GetPositionBuffer: _b2ParticleSystem_GetPositionBuffer, _b2CircleShape_DestroyParticlesInShape: _b2CircleShape_DestroyParticlesInShape, _b2World_QueryAABB: _b2World_QueryAABB, _b2PolygonShape_DestroyParticlesInShape_4: _b2PolygonShape_DestroyParticlesInShape_4, _b2RevoluteJointDef_InitializeAndCreate: _b2RevoluteJointDef_InitializeAndCreate, _b2GearJointDef_Create: _b2GearJointDef_Create, _b2PrismaticJoint_IsLimitEnabled: _b2PrismaticJoint_IsLimitEnabled, _b2Contact_GetWorldManifold: _b2Contact_GetWorldManifold, _b2WheelJoint_SetSpringFrequencyHz: _b2WheelJoint_SetSpringFrequencyHz, _b2Body_ApplyTorque: _b2Body_ApplyTorque, _b2ParticleGroup_ApplyLinearImpulse: _b2ParticleGroup_ApplyLinearImpulse, _b2PrismaticJointDef_InitializeAndCreate: _b2PrismaticJointDef_InitializeAndCreate, _memset: _memset, _b2MotorJointDef_Create: _b2MotorJointDef_Create, _b2World_DestroyBody: _b2World_DestroyBody, _b2RevoluteJointDef_Create: _b2RevoluteJointDef_Create, _b2ParticleGroup_GetParticleCount: _b2ParticleGroup_GetParticleCount, _b2World_SetGravity: _b2World_SetGravity, _b2PrismaticJoint_EnableMotor: _b2PrismaticJoint_EnableMotor, _b2PolygonShape_CreateParticleGroup_4: _b2PolygonShape_CreateParticleGroup_4, _b2PolygonShape_CreateFixture_8: _b2PolygonShape_CreateFixture_8, _b2Body_SetAngularVelocity: _b2Body_SetAngularVelocity, _b2Body_GetWorldPoint: _b2Body_GetWorldPoint, _b2WheelJoint_SetMotorSpeed: _b2WheelJoint_SetMotorSpeed, _b2FrictionJointDef_InitializeAndCreate: _b2FrictionJointDef_InitializeAndCreate, _b2World_SetContactListener: _b2World_SetContactListener, _b2ParticleSystem_SetDamping: _b2ParticleSystem_SetDamping, _b2Body_SetType: _b2Body_SetType, _b2Body_SetTransform: _b2Body_SetTransform, _b2CircleShape_CreateFixture: _b2CircleShape_CreateFixture, _b2RevoluteJoint_GetJointAngle: _b2RevoluteJoint_GetJointAngle, _b2ParticleGroup_ApplyForce: _b2ParticleGroup_ApplyForce, _malloc: _malloc, _b2Contact_GetManifold: _b2Contact_GetManifold, _b2RevoluteJoint_IsMotorEnabled: _b2RevoluteJoint_IsMotorEnabled, _b2ParticleSystem_GetVelocityBuffer: _b2ParticleSystem_GetVelocityBuffer, _b2RevoluteJoint_IsLimitEnabled: _b2RevoluteJoint_IsLimitEnabled, _b2World_DestroyParticleSystem: _b2World_DestroyParticleSystem, _b2RevoluteJoint_EnableMotor: _b2RevoluteJoint_EnableMotor, _b2Body_GetTransform: _b2Body_GetTransform, _b2WeldJointDef_InitializeAndCreate: _b2WeldJointDef_InitializeAndCreate, _b2EdgeShape_CreateFixture: _b2EdgeShape_CreateFixture, _b2Body_GetType: _b2Body_GetType, _b2Manifold_GetPointCount: _b2Manifold_GetPointCount, _b2ParticleSystem_SetDensity: _b2ParticleSystem_SetDensity, _b2PrismaticJoint_GetMotorForce: _b2PrismaticJoint_GetMotorForce, _b2Joint_GetBodyA: _b2Joint_GetBodyA, _b2PulleyJointDef_InitializeAndCreate: _b2PulleyJointDef_InitializeAndCreate, _b2Joint_GetBodyB: _b2Joint_GetBodyB, _b2ParticleBodyContact_GetNormal: _b2ParticleBodyContact_GetNormal, _b2ParticleSystem_GetParticleCount: _b2ParticleSystem_GetParticleCount, _b2MouseJoint_SetTarget: _b2MouseJoint_SetTarget, _b2Body_ApplyAngularImpulse: _b2Body_ApplyAngularImpulse, _b2ChainShape_CreateFixture: _b2ChainShape_CreateFixture, _b2World_DestroyJoint: _b2World_DestroyJoint, _b2MotorJoint_SetAngularOffset: _b2MotorJoint_SetAngularOffset, _b2World_Delete: _b2World_Delete, _b2PrismaticJoint_GetJointTranslation: _b2PrismaticJoint_GetJointTranslation, _i64Add: _i64Add, _b2Body_GetMass: _b2Body_GetMass, _b2Body_GetAngle: _b2Body_GetAngle, _b2ParticleGroup_GetBufferIndex: _b2ParticleGroup_GetBufferIndex, _b2WheelJointDef_InitializeAndCreate: _b2WheelJointDef_InitializeAndCreate, _b2World_Step: _b2World_Step, _b2PrismaticJointDef_Create: _b2PrismaticJointDef_Create, _b2WheelJointDef_Create: _b2WheelJointDef_Create, _b2PulleyJointDef_Create: _b2PulleyJointDef_Create, _b2Body_GetInertia: _b2Body_GetInertia, _memmove: _memmove, _b2PrismaticJoint_SetMotorSpeed: _b2PrismaticJoint_SetMotorSpeed, __GLOBAL__I_a: __GLOBAL__I_a, runPostSets: runPostSets, stackAlloc: stackAlloc, stackSave: stackSave, stackRestore: stackRestore, setThrew: setThrew, setTempRet0: setTempRet0, getTempRet0: getTempRet0, dynCall_diiiiid: dynCall_diiiiid, dynCall_ii: dynCall_ii, dynCall_viiiii: dynCall_viiiii, dynCall_did: dynCall_did, dynCall_vi: dynCall_vi, dynCall_diiiid: dynCall_diiiid, dynCall_vii: dynCall_vii, dynCall_iiii: dynCall_iiii, dynCall_viii: dynCall_viii, dynCall_v: dynCall_v, dynCall_viid: dynCall_viid, dynCall_iiiii: dynCall_iiiii, dynCall_viiiiii: dynCall_viiiiii, dynCall_iii: dynCall_iii, dynCall_iiiiii: dynCall_iiiiii, dynCall_viiii: dynCall_viiii };
})
// EMSCRIPTEN_END_ASM
(Module.asmGlobalArg, Module.asmLibraryArg, buffer);
var _b2PrismaticJoint_IsMotorEnabled = Module["_b2PrismaticJoint_IsMotorEnabled"] = asm["_b2PrismaticJoint_IsMotorEnabled"];
var _b2Body_GetWorldVector = Module["_b2Body_GetWorldVector"] = asm["_b2Body_GetWorldVector"];
var _strlen = Module["_strlen"] = asm["_strlen"];
var _b2Body_GetLocalVector = Module["_b2Body_GetLocalVector"] = asm["_b2Body_GetLocalVector"];
var _b2PrismaticJoint_GetMotorSpeed = Module["_b2PrismaticJoint_GetMotorSpeed"] = asm["_b2PrismaticJoint_GetMotorSpeed"];
var _b2RopeJointDef_Create = Module["_b2RopeJointDef_Create"] = asm["_b2RopeJointDef_Create"];
var _b2World_CreateParticleSystem = Module["_b2World_CreateParticleSystem"] = asm["_b2World_CreateParticleSystem"];
var _b2ParticleSystem_SetRadius = Module["_b2ParticleSystem_SetRadius"] = asm["_b2ParticleSystem_SetRadius"];
var _b2FrictionJointDef_Create = Module["_b2FrictionJointDef_Create"] = asm["_b2FrictionJointDef_Create"];
var _b2World_RayCast = Module["_b2World_RayCast"] = asm["_b2World_RayCast"];
var _b2MotorJointDef_InitializeAndCreate = Module["_b2MotorJointDef_InitializeAndCreate"] = asm["_b2MotorJointDef_InitializeAndCreate"];
var _b2GearJoint_GetRatio = Module["_b2GearJoint_GetRatio"] = asm["_b2GearJoint_GetRatio"];
var _b2Body_GetLocalPoint = Module["_b2Body_GetLocalPoint"] = asm["_b2Body_GetLocalPoint"];
var _memcpy = Module["_memcpy"] = asm["_memcpy"];
var _b2RevoluteJoint_EnableLimit = Module["_b2RevoluteJoint_EnableLimit"] = asm["_b2RevoluteJoint_EnableLimit"];
var _b2Body_DestroyFixture = Module["_b2Body_DestroyFixture"] = asm["_b2Body_DestroyFixture"];
var _b2World_Create = Module["_b2World_Create"] = asm["_b2World_Create"];
var _b2PolygonShape_CreateFixture_3 = Module["_b2PolygonShape_CreateFixture_3"] = asm["_b2PolygonShape_CreateFixture_3"];
var _b2PolygonShape_CreateFixture_6 = Module["_b2PolygonShape_CreateFixture_6"] = asm["_b2PolygonShape_CreateFixture_6"];
var _b2PolygonShape_CreateFixture_7 = Module["_b2PolygonShape_CreateFixture_7"] = asm["_b2PolygonShape_CreateFixture_7"];
var _b2PolygonShape_CreateFixture_4 = Module["_b2PolygonShape_CreateFixture_4"] = asm["_b2PolygonShape_CreateFixture_4"];
var _b2PolygonShape_CreateFixture_5 = Module["_b2PolygonShape_CreateFixture_5"] = asm["_b2PolygonShape_CreateFixture_5"];
var _b2Body_SetAwake = Module["_b2Body_SetAwake"] = asm["_b2Body_SetAwake"];
var _b2Body_GetWorldCenter = Module["_b2Body_GetWorldCenter"] = asm["_b2Body_GetWorldCenter"];
var _b2ParticleGroup_DestroyParticles = Module["_b2ParticleGroup_DestroyParticles"] = asm["_b2ParticleGroup_DestroyParticles"];
var _b2PrismaticJoint_EnableLimit = Module["_b2PrismaticJoint_EnableLimit"] = asm["_b2PrismaticJoint_EnableLimit"];
var _b2ParticleContact_GetNormal = Module["_b2ParticleContact_GetNormal"] = asm["_b2ParticleContact_GetNormal"];
var _b2Fixture_TestPoint = Module["_b2Fixture_TestPoint"] = asm["_b2Fixture_TestPoint"];
var _b2MotorJoint_SetLinearOffset = Module["_b2MotorJoint_SetLinearOffset"] = asm["_b2MotorJoint_SetLinearOffset"];
var ___cxa_can_catch = Module["___cxa_can_catch"] = asm["___cxa_can_catch"];
var _free = Module["_free"] = asm["_free"];
var _b2ParticleSystem_CreateParticle = Module["_b2ParticleSystem_CreateParticle"] = asm["_b2ParticleSystem_CreateParticle"];
var _b2Body_SetLinearVelocity = Module["_b2Body_SetLinearVelocity"] = asm["_b2Body_SetLinearVelocity"];
var _b2CircleShape_CreateParticleGroup = Module["_b2CircleShape_CreateParticleGroup"] = asm["_b2CircleShape_CreateParticleGroup"];
var _b2WeldJointDef_Create = Module["_b2WeldJointDef_Create"] = asm["_b2WeldJointDef_Create"];
var _b2Body_GetAngularVelocity = Module["_b2Body_GetAngularVelocity"] = asm["_b2Body_GetAngularVelocity"];
var _b2Body_ApplyForceToCenter = Module["_b2Body_ApplyForceToCenter"] = asm["_b2Body_ApplyForceToCenter"];
var _b2DistanceJointDef_InitializeAndCreate = Module["_b2DistanceJointDef_InitializeAndCreate"] = asm["_b2DistanceJointDef_InitializeAndCreate"];
var _b2Body_ApplyForce = Module["_b2Body_ApplyForce"] = asm["_b2Body_ApplyForce"];
var _GenerateOffsets = Module["_GenerateOffsets"] = asm["_GenerateOffsets"];
var _b2RevoluteJoint_SetMotorSpeed = Module["_b2RevoluteJoint_SetMotorSpeed"] = asm["_b2RevoluteJoint_SetMotorSpeed"];
var ___cxa_is_pointer_type = Module["___cxa_is_pointer_type"] = asm["___cxa_is_pointer_type"];
var _b2Body_GetPosition = Module["_b2Body_GetPosition"] = asm["_b2Body_GetPosition"];
var _b2World_CreateBody = Module["_b2World_CreateBody"] = asm["_b2World_CreateBody"];
var _b2Body_GetLinearVelocity = Module["_b2Body_GetLinearVelocity"] = asm["_b2Body_GetLinearVelocity"];
var _b2Body_SetMassData = Module["_b2Body_SetMassData"] = asm["_b2Body_SetMassData"];
var _b2MouseJointDef_Create = Module["_b2MouseJointDef_Create"] = asm["_b2MouseJointDef_Create"];
var _b2ParticleSystem_GetColorBuffer = Module["_b2ParticleSystem_GetColorBuffer"] = asm["_b2ParticleSystem_GetColorBuffer"];
var _b2DistanceJointDef_Create = Module["_b2DistanceJointDef_Create"] = asm["_b2DistanceJointDef_Create"];
var _b2ParticleSystem_GetPositionBuffer = Module["_b2ParticleSystem_GetPositionBuffer"] = asm["_b2ParticleSystem_GetPositionBuffer"];
var _b2CircleShape_DestroyParticlesInShape = Module["_b2CircleShape_DestroyParticlesInShape"] = asm["_b2CircleShape_DestroyParticlesInShape"];
var _b2World_QueryAABB = Module["_b2World_QueryAABB"] = asm["_b2World_QueryAABB"];
var _b2PolygonShape_DestroyParticlesInShape_4 = Module["_b2PolygonShape_DestroyParticlesInShape_4"] = asm["_b2PolygonShape_DestroyParticlesInShape_4"];
var _b2RevoluteJointDef_InitializeAndCreate = Module["_b2RevoluteJointDef_InitializeAndCreate"] = asm["_b2RevoluteJointDef_InitializeAndCreate"];
var _b2GearJointDef_Create = Module["_b2GearJointDef_Create"] = asm["_b2GearJointDef_Create"];
var _b2PrismaticJoint_IsLimitEnabled = Module["_b2PrismaticJoint_IsLimitEnabled"] = asm["_b2PrismaticJoint_IsLimitEnabled"];
var _b2Contact_GetWorldManifold = Module["_b2Contact_GetWorldManifold"] = asm["_b2Contact_GetWorldManifold"];
var _b2WheelJoint_SetSpringFrequencyHz = Module["_b2WheelJoint_SetSpringFrequencyHz"] = asm["_b2WheelJoint_SetSpringFrequencyHz"];
var _b2Body_ApplyTorque = Module["_b2Body_ApplyTorque"] = asm["_b2Body_ApplyTorque"];
var _b2ParticleGroup_ApplyLinearImpulse = Module["_b2ParticleGroup_ApplyLinearImpulse"] = asm["_b2ParticleGroup_ApplyLinearImpulse"];
var _b2PrismaticJointDef_InitializeAndCreate = Module["_b2PrismaticJointDef_InitializeAndCreate"] = asm["_b2PrismaticJointDef_InitializeAndCreate"];
var _memset = Module["_memset"] = asm["_memset"];
var _b2MotorJointDef_Create = Module["_b2MotorJointDef_Create"] = asm["_b2MotorJointDef_Create"];
var _b2World_DestroyBody = Module["_b2World_DestroyBody"] = asm["_b2World_DestroyBody"];
var _b2RevoluteJointDef_Create = Module["_b2RevoluteJointDef_Create"] = asm["_b2RevoluteJointDef_Create"];
var _b2ParticleGroup_GetParticleCount = Module["_b2ParticleGroup_GetParticleCount"] = asm["_b2ParticleGroup_GetParticleCount"];
var _b2World_SetGravity = Module["_b2World_SetGravity"] = asm["_b2World_SetGravity"];
var _b2PrismaticJoint_EnableMotor = Module["_b2PrismaticJoint_EnableMotor"] = asm["_b2PrismaticJoint_EnableMotor"];
var _b2PolygonShape_CreateParticleGroup_4 = Module["_b2PolygonShape_CreateParticleGroup_4"] = asm["_b2PolygonShape_CreateParticleGroup_4"];
var _b2PolygonShape_CreateFixture_8 = Module["_b2PolygonShape_CreateFixture_8"] = asm["_b2PolygonShape_CreateFixture_8"];
var _b2Body_SetAngularVelocity = Module["_b2Body_SetAngularVelocity"] = asm["_b2Body_SetAngularVelocity"];
var _b2Body_GetWorldPoint = Module["_b2Body_GetWorldPoint"] = asm["_b2Body_GetWorldPoint"];
var _b2WheelJoint_SetMotorSpeed = Module["_b2WheelJoint_SetMotorSpeed"] = asm["_b2WheelJoint_SetMotorSpeed"];
var _b2FrictionJointDef_InitializeAndCreate = Module["_b2FrictionJointDef_InitializeAndCreate"] = asm["_b2FrictionJointDef_InitializeAndCreate"];
var _b2World_SetContactListener = Module["_b2World_SetContactListener"] = asm["_b2World_SetContactListener"];
var _b2ParticleSystem_SetDamping = Module["_b2ParticleSystem_SetDamping"] = asm["_b2ParticleSystem_SetDamping"];
var _b2Body_SetType = Module["_b2Body_SetType"] = asm["_b2Body_SetType"];
var _b2Body_SetTransform = Module["_b2Body_SetTransform"] = asm["_b2Body_SetTransform"];
var _b2CircleShape_CreateFixture = Module["_b2CircleShape_CreateFixture"] = asm["_b2CircleShape_CreateFixture"];
var _b2RevoluteJoint_GetJointAngle = Module["_b2RevoluteJoint_GetJointAngle"] = asm["_b2RevoluteJoint_GetJointAngle"];
var _b2ParticleGroup_ApplyForce = Module["_b2ParticleGroup_ApplyForce"] = asm["_b2ParticleGroup_ApplyForce"];
var _malloc = Module["_malloc"] = asm["_malloc"];
var _b2Contact_GetManifold = Module["_b2Contact_GetManifold"] = asm["_b2Contact_GetManifold"];
var _b2RevoluteJoint_IsMotorEnabled = Module["_b2RevoluteJoint_IsMotorEnabled"] = asm["_b2RevoluteJoint_IsMotorEnabled"];
var _b2ParticleSystem_GetVelocityBuffer = Module["_b2ParticleSystem_GetVelocityBuffer"] = asm["_b2ParticleSystem_GetVelocityBuffer"];
var _b2RevoluteJoint_IsLimitEnabled = Module["_b2RevoluteJoint_IsLimitEnabled"] = asm["_b2RevoluteJoint_IsLimitEnabled"];
var _b2World_DestroyParticleSystem = Module["_b2World_DestroyParticleSystem"] = asm["_b2World_DestroyParticleSystem"];
var _b2RevoluteJoint_EnableMotor = Module["_b2RevoluteJoint_EnableMotor"] = asm["_b2RevoluteJoint_EnableMotor"];
var _b2Body_GetTransform = Module["_b2Body_GetTransform"] = asm["_b2Body_GetTransform"];
var _b2WeldJointDef_InitializeAndCreate = Module["_b2WeldJointDef_InitializeAndCreate"] = asm["_b2WeldJointDef_InitializeAndCreate"];
var _b2EdgeShape_CreateFixture = Module["_b2EdgeShape_CreateFixture"] = asm["_b2EdgeShape_CreateFixture"];
var _b2Body_GetType = Module["_b2Body_GetType"] = asm["_b2Body_GetType"];
var _b2Manifold_GetPointCount = Module["_b2Manifold_GetPointCount"] = asm["_b2Manifold_GetPointCount"];
var _b2ParticleSystem_SetDensity = Module["_b2ParticleSystem_SetDensity"] = asm["_b2ParticleSystem_SetDensity"];
var _b2PrismaticJoint_GetMotorForce = Module["_b2PrismaticJoint_GetMotorForce"] = asm["_b2PrismaticJoint_GetMotorForce"];
var _b2Joint_GetBodyA = Module["_b2Joint_GetBodyA"] = asm["_b2Joint_GetBodyA"];
var _b2PulleyJointDef_InitializeAndCreate = Module["_b2PulleyJointDef_InitializeAndCreate"] = asm["_b2PulleyJointDef_InitializeAndCreate"];
var _b2Joint_GetBodyB = Module["_b2Joint_GetBodyB"] = asm["_b2Joint_GetBodyB"];
var _b2ParticleBodyContact_GetNormal = Module["_b2ParticleBodyContact_GetNormal"] = asm["_b2ParticleBodyContact_GetNormal"];
var _b2ParticleSystem_GetParticleCount = Module["_b2ParticleSystem_GetParticleCount"] = asm["_b2ParticleSystem_GetParticleCount"];
var _b2MouseJoint_SetTarget = Module["_b2MouseJoint_SetTarget"] = asm["_b2MouseJoint_SetTarget"];
var _b2Body_ApplyAngularImpulse = Module["_b2Body_ApplyAngularImpulse"] = asm["_b2Body_ApplyAngularImpulse"];
var _b2ChainShape_CreateFixture = Module["_b2ChainShape_CreateFixture"] = asm["_b2ChainShape_CreateFixture"];
var _b2World_DestroyJoint = Module["_b2World_DestroyJoint"] = asm["_b2World_DestroyJoint"];
var _b2MotorJoint_SetAngularOffset = Module["_b2MotorJoint_SetAngularOffset"] = asm["_b2MotorJoint_SetAngularOffset"];
var _b2World_Delete = Module["_b2World_Delete"] = asm["_b2World_Delete"];
var _b2PrismaticJoint_GetJointTranslation = Module["_b2PrismaticJoint_GetJointTranslation"] = asm["_b2PrismaticJoint_GetJointTranslation"];
var _i64Add = Module["_i64Add"] = asm["_i64Add"];
var _b2Body_GetMass = Module["_b2Body_GetMass"] = asm["_b2Body_GetMass"];
var _b2Body_GetAngle = Module["_b2Body_GetAngle"] = asm["_b2Body_GetAngle"];
var _b2ParticleGroup_GetBufferIndex = Module["_b2ParticleGroup_GetBufferIndex"] = asm["_b2ParticleGroup_GetBufferIndex"];
var _b2WheelJointDef_InitializeAndCreate = Module["_b2WheelJointDef_InitializeAndCreate"] = asm["_b2WheelJointDef_InitializeAndCreate"];
var _b2World_Step = Module["_b2World_Step"] = asm["_b2World_Step"];
var _b2PrismaticJointDef_Create = Module["_b2PrismaticJointDef_Create"] = asm["_b2PrismaticJointDef_Create"];
var _b2WheelJointDef_Create = Module["_b2WheelJointDef_Create"] = asm["_b2WheelJointDef_Create"];
var _b2PulleyJointDef_Create = Module["_b2PulleyJointDef_Create"] = asm["_b2PulleyJointDef_Create"];
var _b2Body_GetInertia = Module["_b2Body_GetInertia"] = asm["_b2Body_GetInertia"];
var _memmove = Module["_memmove"] = asm["_memmove"];
var _b2PrismaticJoint_SetMotorSpeed = Module["_b2PrismaticJoint_SetMotorSpeed"] = asm["_b2PrismaticJoint_SetMotorSpeed"];
var __GLOBAL__I_a = Module["__GLOBAL__I_a"] = asm["__GLOBAL__I_a"];
var runPostSets = Module["runPostSets"] = asm["runPostSets"];
var dynCall_diiiiid = Module["dynCall_diiiiid"] = asm["dynCall_diiiiid"];
var dynCall_ii = Module["dynCall_ii"] = asm["dynCall_ii"];
var dynCall_viiiii = Module["dynCall_viiiii"] = asm["dynCall_viiiii"];
var dynCall_did = Module["dynCall_did"] = asm["dynCall_did"];
var dynCall_vi = Module["dynCall_vi"] = asm["dynCall_vi"];
var dynCall_diiiid = Module["dynCall_diiiid"] = asm["dynCall_diiiid"];
var dynCall_vii = Module["dynCall_vii"] = asm["dynCall_vii"];
var dynCall_iiii = Module["dynCall_iiii"] = asm["dynCall_iiii"];
var dynCall_viii = Module["dynCall_viii"] = asm["dynCall_viii"];
var dynCall_v = Module["dynCall_v"] = asm["dynCall_v"];
var dynCall_viid = Module["dynCall_viid"] = asm["dynCall_viid"];
var dynCall_iiiii = Module["dynCall_iiiii"] = asm["dynCall_iiiii"];
var dynCall_viiiiii = Module["dynCall_viiiiii"] = asm["dynCall_viiiiii"];
var dynCall_iii = Module["dynCall_iii"] = asm["dynCall_iii"];
var dynCall_iiiiii = Module["dynCall_iiiiii"] = asm["dynCall_iiiiii"];
var dynCall_viiii = Module["dynCall_viiii"] = asm["dynCall_viiii"];

Runtime.stackAlloc = asm['stackAlloc'];
Runtime.stackSave = asm['stackSave'];
Runtime.stackRestore = asm['stackRestore'];
Runtime.setTempRet0 = asm['setTempRet0'];
Runtime.getTempRet0 = asm['getTempRet0'];


// TODO: strip out parts of this we do not need

//======= begin closure i64 code =======

// Copyright 2009 The Closure Library Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS-IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

/**
 * @fileoverview Defines a Long class for representing a 64-bit two's-complement
 * integer value, which faithfully simulates the behavior of a Java "long". This
 * implementation is derived from LongLib in GWT.
 *
 */

var i64Math = (function() { // Emscripten wrapper
  var goog = { math: {} };


  /**
   * Constructs a 64-bit two's-complement integer, given its low and high 32-bit
   * values as *signed* integers.  See the from* functions below for more
   * convenient ways of constructing Longs.
   *
   * The internal representation of a long is the two given signed, 32-bit values.
   * We use 32-bit pieces because these are the size of integers on which
   * Javascript performs bit-operations.  For operations like addition and
   * multiplication, we split each number into 16-bit pieces, which can easily be
   * multiplied within Javascript's floating-point representation without overflow
   * or change in sign.
   *
   * In the algorithms below, we frequently reduce the negative case to the
   * positive case by negating the input(s) and then post-processing the result.
   * Note that we must ALWAYS check specially whether those values are MIN_VALUE
   * (-2^63) because -MIN_VALUE == MIN_VALUE (since 2^63 cannot be represented as
   * a positive number, it overflows back into a negative).  Not handling this
   * case would often result in infinite recursion.
   *
   * @param {number} low  The low (signed) 32 bits of the long.
   * @param {number} high  The high (signed) 32 bits of the long.
   * @constructor
   */
  goog.math.Long = function(low, high) {
    /**
     * @type {number}
     * @private
     */
    this.low_ = low | 0;  // force into 32 signed bits.

    /**
     * @type {number}
     * @private
     */
    this.high_ = high | 0;  // force into 32 signed bits.
  };


  // NOTE: Common constant values ZERO, ONE, NEG_ONE, etc. are defined below the
  // from* methods on which they depend.


  /**
   * A cache of the Long representations of small integer values.
   * @type {!Object}
   * @private
   */
  goog.math.Long.IntCache_ = {};


  /**
   * Returns a Long representing the given (32-bit) integer value.
   * @param {number} value The 32-bit integer in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromInt = function(value) {
    if (-128 <= value && value < 128) {
      var cachedObj = goog.math.Long.IntCache_[value];
      if (cachedObj) {
        return cachedObj;
      }
    }

    var obj = new goog.math.Long(value | 0, value < 0 ? -1 : 0);
    if (-128 <= value && value < 128) {
      goog.math.Long.IntCache_[value] = obj;
    }
    return obj;
  };


  /**
   * Returns a Long representing the given value, provided that it is a finite
   * number.  Otherwise, zero is returned.
   * @param {number} value The number in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromNumber = function(value) {
    if (isNaN(value) || !isFinite(value)) {
      return goog.math.Long.ZERO;
    } else if (value <= -goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MIN_VALUE;
    } else if (value + 1 >= goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MAX_VALUE;
    } else if (value < 0) {
      return goog.math.Long.fromNumber(-value).negate();
    } else {
      return new goog.math.Long(
          (value % goog.math.Long.TWO_PWR_32_DBL_) | 0,
          (value / goog.math.Long.TWO_PWR_32_DBL_) | 0);
    }
  };


  /**
   * Returns a Long representing the 64-bit integer that comes by concatenating
   * the given high and low bits.  Each is assumed to use 32 bits.
   * @param {number} lowBits The low 32-bits.
   * @param {number} highBits The high 32-bits.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromBits = function(lowBits, highBits) {
    return new goog.math.Long(lowBits, highBits);
  };


  /**
   * Returns a Long representation of the given string, written using the given
   * radix.
   * @param {string} str The textual representation of the Long.
   * @param {number=} opt_radix The radix in which the text is written.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromString = function(str, opt_radix) {
    if (str.length == 0) {
      throw Error('number format error: empty string');
    }

    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }

    if (str.charAt(0) == '-') {
      return goog.math.Long.fromString(str.substring(1), radix).negate();
    } else if (str.indexOf('-') >= 0) {
      throw Error('number format error: interior "-" character: ' + str);
    }

    // Do several (8) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 8));

    var result = goog.math.Long.ZERO;
    for (var i = 0; i < str.length; i += 8) {
      var size = Math.min(8, str.length - i);
      var value = parseInt(str.substring(i, i + size), radix);
      if (size < 8) {
        var power = goog.math.Long.fromNumber(Math.pow(radix, size));
        result = result.multiply(power).add(goog.math.Long.fromNumber(value));
      } else {
        result = result.multiply(radixToPower);
        result = result.add(goog.math.Long.fromNumber(value));
      }
    }
    return result;
  };


  // NOTE: the compiler should inline these constant values below and then remove
  // these variables, so there should be no runtime penalty for these.


  /**
   * Number used repeated below in calculations.  This must appear before the
   * first call to any from* function below.
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_16_DBL_ = 1 << 16;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_24_DBL_ = 1 << 24;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_32_DBL_ =
      goog.math.Long.TWO_PWR_16_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_31_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ / 2;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_48_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_64_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_32_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_63_DBL_ =
      goog.math.Long.TWO_PWR_64_DBL_ / 2;


  /** @type {!goog.math.Long} */
  goog.math.Long.ZERO = goog.math.Long.fromInt(0);


  /** @type {!goog.math.Long} */
  goog.math.Long.ONE = goog.math.Long.fromInt(1);


  /** @type {!goog.math.Long} */
  goog.math.Long.NEG_ONE = goog.math.Long.fromInt(-1);


  /** @type {!goog.math.Long} */
  goog.math.Long.MAX_VALUE =
      goog.math.Long.fromBits(0xFFFFFFFF | 0, 0x7FFFFFFF | 0);


  /** @type {!goog.math.Long} */
  goog.math.Long.MIN_VALUE = goog.math.Long.fromBits(0, 0x80000000 | 0);


  /**
   * @type {!goog.math.Long}
   * @private
   */
  goog.math.Long.TWO_PWR_24_ = goog.math.Long.fromInt(1 << 24);


  /** @return {number} The value, assuming it is a 32-bit integer. */
  goog.math.Long.prototype.toInt = function() {
    return this.low_;
  };


  /** @return {number} The closest floating-point representation to this value. */
  goog.math.Long.prototype.toNumber = function() {
    return this.high_ * goog.math.Long.TWO_PWR_32_DBL_ +
           this.getLowBitsUnsigned();
  };


  /**
   * @param {number=} opt_radix The radix in which the text should be written.
   * @return {string} The textual representation of this value.
   */
  goog.math.Long.prototype.toString = function(opt_radix) {
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }

    if (this.isZero()) {
      return '0';
    }

    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        // We need to change the Long value before it can be negated, so we remove
        // the bottom-most digit in this base and then recurse to do the rest.
        var radixLong = goog.math.Long.fromNumber(radix);
        var div = this.div(radixLong);
        var rem = div.multiply(radixLong).subtract(this);
        return div.toString(radix) + rem.toInt().toString(radix);
      } else {
        return '-' + this.negate().toString(radix);
      }
    }

    // Do several (6) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 6));

    var rem = this;
    var result = '';
    while (true) {
      var remDiv = rem.div(radixToPower);
      var intval = rem.subtract(remDiv.multiply(radixToPower)).toInt();
      var digits = intval.toString(radix);

      rem = remDiv;
      if (rem.isZero()) {
        return digits + result;
      } else {
        while (digits.length < 6) {
          digits = '0' + digits;
        }
        result = '' + digits + result;
      }
    }
  };


  /** @return {number} The high 32-bits as a signed value. */
  goog.math.Long.prototype.getHighBits = function() {
    return this.high_;
  };


  /** @return {number} The low 32-bits as a signed value. */
  goog.math.Long.prototype.getLowBits = function() {
    return this.low_;
  };


  /** @return {number} The low 32-bits as an unsigned value. */
  goog.math.Long.prototype.getLowBitsUnsigned = function() {
    return (this.low_ >= 0) ?
        this.low_ : goog.math.Long.TWO_PWR_32_DBL_ + this.low_;
  };


  /**
   * @return {number} Returns the number of bits needed to represent the absolute
   *     value of this Long.
   */
  goog.math.Long.prototype.getNumBitsAbs = function() {
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        return 64;
      } else {
        return this.negate().getNumBitsAbs();
      }
    } else {
      var val = this.high_ != 0 ? this.high_ : this.low_;
      for (var bit = 31; bit > 0; bit--) {
        if ((val & (1 << bit)) != 0) {
          break;
        }
      }
      return this.high_ != 0 ? bit + 33 : bit + 1;
    }
  };


  /** @return {boolean} Whether this value is zero. */
  goog.math.Long.prototype.isZero = function() {
    return this.high_ == 0 && this.low_ == 0;
  };


  /** @return {boolean} Whether this value is negative. */
  goog.math.Long.prototype.isNegative = function() {
    return this.high_ < 0;
  };


  /** @return {boolean} Whether this value is odd. */
  goog.math.Long.prototype.isOdd = function() {
    return (this.low_ & 1) == 1;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long equals the other.
   */
  goog.math.Long.prototype.equals = function(other) {
    return (this.high_ == other.high_) && (this.low_ == other.low_);
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long does not equal the other.
   */
  goog.math.Long.prototype.notEquals = function(other) {
    return (this.high_ != other.high_) || (this.low_ != other.low_);
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than the other.
   */
  goog.math.Long.prototype.lessThan = function(other) {
    return this.compare(other) < 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than or equal to the other.
   */
  goog.math.Long.prototype.lessThanOrEqual = function(other) {
    return this.compare(other) <= 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than the other.
   */
  goog.math.Long.prototype.greaterThan = function(other) {
    return this.compare(other) > 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than or equal to the other.
   */
  goog.math.Long.prototype.greaterThanOrEqual = function(other) {
    return this.compare(other) >= 0;
  };


  /**
   * Compares this Long with the given one.
   * @param {goog.math.Long} other Long to compare against.
   * @return {number} 0 if they are the same, 1 if the this is greater, and -1
   *     if the given one is greater.
   */
  goog.math.Long.prototype.compare = function(other) {
    if (this.equals(other)) {
      return 0;
    }

    var thisNeg = this.isNegative();
    var otherNeg = other.isNegative();
    if (thisNeg && !otherNeg) {
      return -1;
    }
    if (!thisNeg && otherNeg) {
      return 1;
    }

    // at this point, the signs are the same, so subtraction will not overflow
    if (this.subtract(other).isNegative()) {
      return -1;
    } else {
      return 1;
    }
  };


  /** @return {!goog.math.Long} The negation of this value. */
  goog.math.Long.prototype.negate = function() {
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.MIN_VALUE;
    } else {
      return this.not().add(goog.math.Long.ONE);
    }
  };


  /**
   * Returns the sum of this and the given Long.
   * @param {goog.math.Long} other Long to add to this one.
   * @return {!goog.math.Long} The sum of this and the given Long.
   */
  goog.math.Long.prototype.add = function(other) {
    // Divide each number into 4 chunks of 16 bits, and then sum the chunks.

    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;

    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;

    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 + b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 + b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 + b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 + b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };


  /**
   * Returns the difference of this and the given Long.
   * @param {goog.math.Long} other Long to subtract from this.
   * @return {!goog.math.Long} The difference of this and the given Long.
   */
  goog.math.Long.prototype.subtract = function(other) {
    return this.add(other.negate());
  };


  /**
   * Returns the product of this and the given long.
   * @param {goog.math.Long} other Long to multiply with this.
   * @return {!goog.math.Long} The product of this and the other.
   */
  goog.math.Long.prototype.multiply = function(other) {
    if (this.isZero()) {
      return goog.math.Long.ZERO;
    } else if (other.isZero()) {
      return goog.math.Long.ZERO;
    }

    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return other.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return this.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    }

    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().multiply(other.negate());
      } else {
        return this.negate().multiply(other).negate();
      }
    } else if (other.isNegative()) {
      return this.multiply(other.negate()).negate();
    }

    // If both longs are small, use float multiplication
    if (this.lessThan(goog.math.Long.TWO_PWR_24_) &&
        other.lessThan(goog.math.Long.TWO_PWR_24_)) {
      return goog.math.Long.fromNumber(this.toNumber() * other.toNumber());
    }

    // Divide each long into 4 chunks of 16 bits, and then add up 4x4 products.
    // We can skip products that would overflow.

    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;

    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;

    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 * b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 * b00;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c16 += a00 * b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 * b00;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a16 * b16;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a00 * b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 * b00 + a32 * b16 + a16 * b32 + a00 * b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };


  /**
   * Returns this Long divided by the given one.
   * @param {goog.math.Long} other Long by which to divide.
   * @return {!goog.math.Long} This Long divided by the given one.
   */
  goog.math.Long.prototype.div = function(other) {
    if (other.isZero()) {
      throw Error('division by zero');
    } else if (this.isZero()) {
      return goog.math.Long.ZERO;
    }

    if (this.equals(goog.math.Long.MIN_VALUE)) {
      if (other.equals(goog.math.Long.ONE) ||
          other.equals(goog.math.Long.NEG_ONE)) {
        return goog.math.Long.MIN_VALUE;  // recall that -MIN_VALUE == MIN_VALUE
      } else if (other.equals(goog.math.Long.MIN_VALUE)) {
        return goog.math.Long.ONE;
      } else {
        // At this point, we have |other| >= 2, so |this/other| < |MIN_VALUE|.
        var halfThis = this.shiftRight(1);
        var approx = halfThis.div(other).shiftLeft(1);
        if (approx.equals(goog.math.Long.ZERO)) {
          return other.isNegative() ? goog.math.Long.ONE : goog.math.Long.NEG_ONE;
        } else {
          var rem = this.subtract(other.multiply(approx));
          var result = approx.add(rem.div(other));
          return result;
        }
      }
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.ZERO;
    }

    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().div(other.negate());
      } else {
        return this.negate().div(other).negate();
      }
    } else if (other.isNegative()) {
      return this.div(other.negate()).negate();
    }

    // Repeat the following until the remainder is less than other:  find a
    // floating-point that approximates remainder / other *from below*, add this
    // into the result, and subtract it from the remainder.  It is critical that
    // the approximate value is less than or equal to the real value so that the
    // remainder never becomes negative.
    var res = goog.math.Long.ZERO;
    var rem = this;
    while (rem.greaterThanOrEqual(other)) {
      // Approximate the result of division. This may be a little greater or
      // smaller than the actual value.
      var approx = Math.max(1, Math.floor(rem.toNumber() / other.toNumber()));

      // We will tweak the approximate result by changing it in the 48-th digit or
      // the smallest non-fractional digit, whichever is larger.
      var log2 = Math.ceil(Math.log(approx) / Math.LN2);
      var delta = (log2 <= 48) ? 1 : Math.pow(2, log2 - 48);

      // Decrease the approximation until it is smaller than the remainder.  Note
      // that if it is too large, the product overflows and is negative.
      var approxRes = goog.math.Long.fromNumber(approx);
      var approxRem = approxRes.multiply(other);
      while (approxRem.isNegative() || approxRem.greaterThan(rem)) {
        approx -= delta;
        approxRes = goog.math.Long.fromNumber(approx);
        approxRem = approxRes.multiply(other);
      }

      // We know the answer can't be zero... and actually, zero would cause
      // infinite recursion since we would make no progress.
      if (approxRes.isZero()) {
        approxRes = goog.math.Long.ONE;
      }

      res = res.add(approxRes);
      rem = rem.subtract(approxRem);
    }
    return res;
  };


  /**
   * Returns this Long modulo the given one.
   * @param {goog.math.Long} other Long by which to mod.
   * @return {!goog.math.Long} This Long modulo the given one.
   */
  goog.math.Long.prototype.modulo = function(other) {
    return this.subtract(this.div(other).multiply(other));
  };


  /** @return {!goog.math.Long} The bitwise-NOT of this value. */
  goog.math.Long.prototype.not = function() {
    return goog.math.Long.fromBits(~this.low_, ~this.high_);
  };


  /**
   * Returns the bitwise-AND of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to AND.
   * @return {!goog.math.Long} The bitwise-AND of this and the other.
   */
  goog.math.Long.prototype.and = function(other) {
    return goog.math.Long.fromBits(this.low_ & other.low_,
                                   this.high_ & other.high_);
  };


  /**
   * Returns the bitwise-OR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to OR.
   * @return {!goog.math.Long} The bitwise-OR of this and the other.
   */
  goog.math.Long.prototype.or = function(other) {
    return goog.math.Long.fromBits(this.low_ | other.low_,
                                   this.high_ | other.high_);
  };


  /**
   * Returns the bitwise-XOR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to XOR.
   * @return {!goog.math.Long} The bitwise-XOR of this and the other.
   */
  goog.math.Long.prototype.xor = function(other) {
    return goog.math.Long.fromBits(this.low_ ^ other.low_,
                                   this.high_ ^ other.high_);
  };


  /**
   * Returns this Long with bits shifted to the left by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the left by the given amount.
   */
  goog.math.Long.prototype.shiftLeft = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var low = this.low_;
      if (numBits < 32) {
        var high = this.high_;
        return goog.math.Long.fromBits(
            low << numBits,
            (high << numBits) | (low >>> (32 - numBits)));
      } else {
        return goog.math.Long.fromBits(0, low << (numBits - 32));
      }
    }
  };


  /**
   * Returns this Long with bits shifted to the right by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount.
   */
  goog.math.Long.prototype.shiftRight = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >> numBits);
      } else {
        return goog.math.Long.fromBits(
            high >> (numBits - 32),
            high >= 0 ? 0 : -1);
      }
    }
  };


  /**
   * Returns this Long with bits shifted to the right by the given amount, with
   * the new top bits matching the current sign bit.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount, with
   *     zeros placed into the new leading bits.
   */
  goog.math.Long.prototype.shiftRightUnsigned = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >>> numBits);
      } else if (numBits == 32) {
        return goog.math.Long.fromBits(high, 0);
      } else {
        return goog.math.Long.fromBits(high >>> (numBits - 32), 0);
      }
    }
  };

  //======= begin jsbn =======

  var navigator = { appName: 'Modern Browser' }; // polyfill a little

  // Copyright (c) 2005  Tom Wu
  // All Rights Reserved.
  // http://www-cs-students.stanford.edu/~tjw/jsbn/

  /*
   * Copyright (c) 2003-2005  Tom Wu
   * All Rights Reserved.
   *
   * Permission is hereby granted, free of charge, to any person obtaining
   * a copy of this software and associated documentation files (the
   * "Software"), to deal in the Software without restriction, including
   * without limitation the rights to use, copy, modify, merge, publish,
   * distribute, sublicense, and/or sell copies of the Software, and to
   * permit persons to whom the Software is furnished to do so, subject to
   * the following conditions:
   *
   * The above copyright notice and this permission notice shall be
   * included in all copies or substantial portions of the Software.
   *
   * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
   * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
   * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
   *
   * IN NO EVENT SHALL TOM WU BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
   * INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES WHATSOEVER
   * RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER OR NOT ADVISED OF
   * THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT
   * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   *
   * In addition, the following condition applies:
   *
   * All redistributions must retain an intact copy of this copyright notice
   * and disclaimer.
   */

  // Basic JavaScript BN library - subset useful for RSA encryption.

  // Bits per digit
  var dbits;

  // JavaScript engine analysis
  var canary = 0xdeadbeefcafe;
  var j_lm = ((canary&0xffffff)==0xefcafe);

  // (public) Constructor
  function BigInteger(a,b,c) {
    if(a != null)
      if("number" == typeof a) this.fromNumber(a,b,c);
      else if(b == null && "string" != typeof a) this.fromString(a,256);
      else this.fromString(a,b);
  }

  // return new, unset BigInteger
  function nbi() { return new BigInteger(null); }

  // am: Compute w_j += (x*this_i), propagate carries,
  // c is initial carry, returns final carry.
  // c < 3*dvalue, x < 2*dvalue, this_i < dvalue
  // We need to select the fastest one that works in this environment.

  // am1: use a single mult and divide to get the high bits,
  // max digit bits should be 26 because
  // max internal value = 2*dvalue^2-2*dvalue (< 2^53)
  function am1(i,x,w,j,c,n) {
    while(--n >= 0) {
      var v = x*this[i++]+w[j]+c;
      c = Math.floor(v/0x4000000);
      w[j++] = v&0x3ffffff;
    }
    return c;
  }
  // am2 avoids a big mult-and-extract completely.
  // Max digit bits should be <= 30 because we do bitwise ops
  // on values up to 2*hdvalue^2-hdvalue-1 (< 2^31)
  function am2(i,x,w,j,c,n) {
    var xl = x&0x7fff, xh = x>>15;
    while(--n >= 0) {
      var l = this[i]&0x7fff;
      var h = this[i++]>>15;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x7fff)<<15)+w[j]+(c&0x3fffffff);
      c = (l>>>30)+(m>>>15)+xh*h+(c>>>30);
      w[j++] = l&0x3fffffff;
    }
    return c;
  }
  // Alternately, set max digit bits to 28 since some
  // browsers slow down when dealing with 32-bit numbers.
  function am3(i,x,w,j,c,n) {
    var xl = x&0x3fff, xh = x>>14;
    while(--n >= 0) {
      var l = this[i]&0x3fff;
      var h = this[i++]>>14;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x3fff)<<14)+w[j]+c;
      c = (l>>28)+(m>>14)+xh*h;
      w[j++] = l&0xfffffff;
    }
    return c;
  }
  if(j_lm && (navigator.appName == "Microsoft Internet Explorer")) {
    BigInteger.prototype.am = am2;
    dbits = 30;
  }
  else if(j_lm && (navigator.appName != "Netscape")) {
    BigInteger.prototype.am = am1;
    dbits = 26;
  }
  else { // Mozilla/Netscape seems to prefer am3
    BigInteger.prototype.am = am3;
    dbits = 28;
  }

  BigInteger.prototype.DB = dbits;
  BigInteger.prototype.DM = ((1<<dbits)-1);
  BigInteger.prototype.DV = (1<<dbits);

  var BI_FP = 52;
  BigInteger.prototype.FV = Math.pow(2,BI_FP);
  BigInteger.prototype.F1 = BI_FP-dbits;
  BigInteger.prototype.F2 = 2*dbits-BI_FP;

  // Digit conversions
  var BI_RM = "0123456789abcdefghijklmnopqrstuvwxyz";
  var BI_RC = new Array();
  var rr,vv;
  rr = "0".charCodeAt(0);
  for(vv = 0; vv <= 9; ++vv) BI_RC[rr++] = vv;
  rr = "a".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  rr = "A".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;

  function int2char(n) { return BI_RM.charAt(n); }
  function intAt(s,i) {
    var c = BI_RC[s.charCodeAt(i)];
    return (c==null)?-1:c;
  }

  // (protected) copy this to r
  function bnpCopyTo(r) {
    for(var i = this.t-1; i >= 0; --i) r[i] = this[i];
    r.t = this.t;
    r.s = this.s;
  }

  // (protected) set from integer value x, -DV <= x < DV
  function bnpFromInt(x) {
    this.t = 1;
    this.s = (x<0)?-1:0;
    if(x > 0) this[0] = x;
    else if(x < -1) this[0] = x+DV;
    else this.t = 0;
  }

  // return bigint initialized to value
  function nbv(i) { var r = nbi(); r.fromInt(i); return r; }

  // (protected) set from string and radix
  function bnpFromString(s,b) {
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 256) k = 8; // byte array
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else { this.fromRadix(s,b); return; }
    this.t = 0;
    this.s = 0;
    var i = s.length, mi = false, sh = 0;
    while(--i >= 0) {
      var x = (k==8)?s[i]&0xff:intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-") mi = true;
        continue;
      }
      mi = false;
      if(sh == 0)
        this[this.t++] = x;
      else if(sh+k > this.DB) {
        this[this.t-1] |= (x&((1<<(this.DB-sh))-1))<<sh;
        this[this.t++] = (x>>(this.DB-sh));
      }
      else
        this[this.t-1] |= x<<sh;
      sh += k;
      if(sh >= this.DB) sh -= this.DB;
    }
    if(k == 8 && (s[0]&0x80) != 0) {
      this.s = -1;
      if(sh > 0) this[this.t-1] |= ((1<<(this.DB-sh))-1)<<sh;
    }
    this.clamp();
    if(mi) BigInteger.ZERO.subTo(this,this);
  }

  // (protected) clamp off excess high words
  function bnpClamp() {
    var c = this.s&this.DM;
    while(this.t > 0 && this[this.t-1] == c) --this.t;
  }

  // (public) return string representation in given radix
  function bnToString(b) {
    if(this.s < 0) return "-"+this.negate().toString(b);
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else return this.toRadix(b);
    var km = (1<<k)-1, d, m = false, r = "", i = this.t;
    var p = this.DB-(i*this.DB)%k;
    if(i-- > 0) {
      if(p < this.DB && (d = this[i]>>p) > 0) { m = true; r = int2char(d); }
      while(i >= 0) {
        if(p < k) {
          d = (this[i]&((1<<p)-1))<<(k-p);
          d |= this[--i]>>(p+=this.DB-k);
        }
        else {
          d = (this[i]>>(p-=k))&km;
          if(p <= 0) { p += this.DB; --i; }
        }
        if(d > 0) m = true;
        if(m) r += int2char(d);
      }
    }
    return m?r:"0";
  }

  // (public) -this
  function bnNegate() { var r = nbi(); BigInteger.ZERO.subTo(this,r); return r; }

  // (public) |this|
  function bnAbs() { return (this.s<0)?this.negate():this; }

  // (public) return + if this > a, - if this < a, 0 if equal
  function bnCompareTo(a) {
    var r = this.s-a.s;
    if(r != 0) return r;
    var i = this.t;
    r = i-a.t;
    if(r != 0) return (this.s<0)?-r:r;
    while(--i >= 0) if((r=this[i]-a[i]) != 0) return r;
    return 0;
  }

  // returns bit length of the integer x
  function nbits(x) {
    var r = 1, t;
    if((t=x>>>16) != 0) { x = t; r += 16; }
    if((t=x>>8) != 0) { x = t; r += 8; }
    if((t=x>>4) != 0) { x = t; r += 4; }
    if((t=x>>2) != 0) { x = t; r += 2; }
    if((t=x>>1) != 0) { x = t; r += 1; }
    return r;
  }

  // (public) return the number of bits in "this"
  function bnBitLength() {
    if(this.t <= 0) return 0;
    return this.DB*(this.t-1)+nbits(this[this.t-1]^(this.s&this.DM));
  }

  // (protected) r = this << n*DB
  function bnpDLShiftTo(n,r) {
    var i;
    for(i = this.t-1; i >= 0; --i) r[i+n] = this[i];
    for(i = n-1; i >= 0; --i) r[i] = 0;
    r.t = this.t+n;
    r.s = this.s;
  }

  // (protected) r = this >> n*DB
  function bnpDRShiftTo(n,r) {
    for(var i = n; i < this.t; ++i) r[i-n] = this[i];
    r.t = Math.max(this.t-n,0);
    r.s = this.s;
  }

  // (protected) r = this << n
  function bnpLShiftTo(n,r) {
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<cbs)-1;
    var ds = Math.floor(n/this.DB), c = (this.s<<bs)&this.DM, i;
    for(i = this.t-1; i >= 0; --i) {
      r[i+ds+1] = (this[i]>>cbs)|c;
      c = (this[i]&bm)<<bs;
    }
    for(i = ds-1; i >= 0; --i) r[i] = 0;
    r[ds] = c;
    r.t = this.t+ds+1;
    r.s = this.s;
    r.clamp();
  }

  // (protected) r = this >> n
  function bnpRShiftTo(n,r) {
    r.s = this.s;
    var ds = Math.floor(n/this.DB);
    if(ds >= this.t) { r.t = 0; return; }
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<bs)-1;
    r[0] = this[ds]>>bs;
    for(var i = ds+1; i < this.t; ++i) {
      r[i-ds-1] |= (this[i]&bm)<<cbs;
      r[i-ds] = this[i]>>bs;
    }
    if(bs > 0) r[this.t-ds-1] |= (this.s&bm)<<cbs;
    r.t = this.t-ds;
    r.clamp();
  }

  // (protected) r = this - a
  function bnpSubTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]-a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c -= a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c -= a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c -= a.s;
    }
    r.s = (c<0)?-1:0;
    if(c < -1) r[i++] = this.DV+c;
    else if(c > 0) r[i++] = c;
    r.t = i;
    r.clamp();
  }

  // (protected) r = this * a, r != this,a (HAC 14.12)
  // "this" should be the larger one if appropriate.
  function bnpMultiplyTo(a,r) {
    var x = this.abs(), y = a.abs();
    var i = x.t;
    r.t = i+y.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < y.t; ++i) r[i+x.t] = x.am(0,y[i],r,i,0,x.t);
    r.s = 0;
    r.clamp();
    if(this.s != a.s) BigInteger.ZERO.subTo(r,r);
  }

  // (protected) r = this^2, r != this (HAC 14.16)
  function bnpSquareTo(r) {
    var x = this.abs();
    var i = r.t = 2*x.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < x.t-1; ++i) {
      var c = x.am(i,x[i],r,2*i,0,1);
      if((r[i+x.t]+=x.am(i+1,2*x[i],r,2*i+1,c,x.t-i-1)) >= x.DV) {
        r[i+x.t] -= x.DV;
        r[i+x.t+1] = 1;
      }
    }
    if(r.t > 0) r[r.t-1] += x.am(i,x[i],r,2*i,0,1);
    r.s = 0;
    r.clamp();
  }

  // (protected) divide this by m, quotient and remainder to q, r (HAC 14.20)
  // r != q, this != m.  q or r may be null.
  function bnpDivRemTo(m,q,r) {
    var pm = m.abs();
    if(pm.t <= 0) return;
    var pt = this.abs();
    if(pt.t < pm.t) {
      if(q != null) q.fromInt(0);
      if(r != null) this.copyTo(r);
      return;
    }
    if(r == null) r = nbi();
    var y = nbi(), ts = this.s, ms = m.s;
    var nsh = this.DB-nbits(pm[pm.t-1]);	// normalize modulus
    if(nsh > 0) { pm.lShiftTo(nsh,y); pt.lShiftTo(nsh,r); }
    else { pm.copyTo(y); pt.copyTo(r); }
    var ys = y.t;
    var y0 = y[ys-1];
    if(y0 == 0) return;
    var yt = y0*(1<<this.F1)+((ys>1)?y[ys-2]>>this.F2:0);
    var d1 = this.FV/yt, d2 = (1<<this.F1)/yt, e = 1<<this.F2;
    var i = r.t, j = i-ys, t = (q==null)?nbi():q;
    y.dlShiftTo(j,t);
    if(r.compareTo(t) >= 0) {
      r[r.t++] = 1;
      r.subTo(t,r);
    }
    BigInteger.ONE.dlShiftTo(ys,t);
    t.subTo(y,y);	// "negative" y so we can replace sub with am later
    while(y.t < ys) y[y.t++] = 0;
    while(--j >= 0) {
      // Estimate quotient digit
      var qd = (r[--i]==y0)?this.DM:Math.floor(r[i]*d1+(r[i-1]+e)*d2);
      if((r[i]+=y.am(0,qd,r,j,0,ys)) < qd) {	// Try it out
        y.dlShiftTo(j,t);
        r.subTo(t,r);
        while(r[i] < --qd) r.subTo(t,r);
      }
    }
    if(q != null) {
      r.drShiftTo(ys,q);
      if(ts != ms) BigInteger.ZERO.subTo(q,q);
    }
    r.t = ys;
    r.clamp();
    if(nsh > 0) r.rShiftTo(nsh,r);	// Denormalize remainder
    if(ts < 0) BigInteger.ZERO.subTo(r,r);
  }

  // (public) this mod a
  function bnMod(a) {
    var r = nbi();
    this.abs().divRemTo(a,null,r);
    if(this.s < 0 && r.compareTo(BigInteger.ZERO) > 0) a.subTo(r,r);
    return r;
  }

  // Modular reduction using "classic" algorithm
  function Classic(m) { this.m = m; }
  function cConvert(x) {
    if(x.s < 0 || x.compareTo(this.m) >= 0) return x.mod(this.m);
    else return x;
  }
  function cRevert(x) { return x; }
  function cReduce(x) { x.divRemTo(this.m,null,x); }
  function cMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  function cSqrTo(x,r) { x.squareTo(r); this.reduce(r); }

  Classic.prototype.convert = cConvert;
  Classic.prototype.revert = cRevert;
  Classic.prototype.reduce = cReduce;
  Classic.prototype.mulTo = cMulTo;
  Classic.prototype.sqrTo = cSqrTo;

  // (protected) return "-1/this % 2^DB"; useful for Mont. reduction
  // justification:
  //         xy == 1 (mod m)
  //         xy =  1+km
  //   xy(2-xy) = (1+km)(1-km)
  // x[y(2-xy)] = 1-k^2m^2
  // x[y(2-xy)] == 1 (mod m^2)
  // if y is 1/x mod m, then y(2-xy) is 1/x mod m^2
  // should reduce x and y(2-xy) by m^2 at each step to keep size bounded.
  // JS multiply "overflows" differently from C/C++, so care is needed here.
  function bnpInvDigit() {
    if(this.t < 1) return 0;
    var x = this[0];
    if((x&1) == 0) return 0;
    var y = x&3;		// y == 1/x mod 2^2
    y = (y*(2-(x&0xf)*y))&0xf;	// y == 1/x mod 2^4
    y = (y*(2-(x&0xff)*y))&0xff;	// y == 1/x mod 2^8
    y = (y*(2-(((x&0xffff)*y)&0xffff)))&0xffff;	// y == 1/x mod 2^16
    // last step - calculate inverse mod DV directly;
    // assumes 16 < DB <= 32 and assumes ability to handle 48-bit ints
    y = (y*(2-x*y%this.DV))%this.DV;		// y == 1/x mod 2^dbits
    // we really want the negative inverse, and -DV < y < DV
    return (y>0)?this.DV-y:-y;
  }

  // Montgomery reduction
  function Montgomery(m) {
    this.m = m;
    this.mp = m.invDigit();
    this.mpl = this.mp&0x7fff;
    this.mph = this.mp>>15;
    this.um = (1<<(m.DB-15))-1;
    this.mt2 = 2*m.t;
  }

  // xR mod m
  function montConvert(x) {
    var r = nbi();
    x.abs().dlShiftTo(this.m.t,r);
    r.divRemTo(this.m,null,r);
    if(x.s < 0 && r.compareTo(BigInteger.ZERO) > 0) this.m.subTo(r,r);
    return r;
  }

  // x/R mod m
  function montRevert(x) {
    var r = nbi();
    x.copyTo(r);
    this.reduce(r);
    return r;
  }

  // x = x/R mod m (HAC 14.32)
  function montReduce(x) {
    while(x.t <= this.mt2)	// pad x so am has enough room later
      x[x.t++] = 0;
    for(var i = 0; i < this.m.t; ++i) {
      // faster way of calculating u0 = x[i]*mp mod DV
      var j = x[i]&0x7fff;
      var u0 = (j*this.mpl+(((j*this.mph+(x[i]>>15)*this.mpl)&this.um)<<15))&x.DM;
      // use am to combine the multiply-shift-add into one call
      j = i+this.m.t;
      x[j] += this.m.am(0,u0,x,i,0,this.m.t);
      // propagate carry
      while(x[j] >= x.DV) { x[j] -= x.DV; x[++j]++; }
    }
    x.clamp();
    x.drShiftTo(this.m.t,x);
    if(x.compareTo(this.m) >= 0) x.subTo(this.m,x);
  }

  // r = "x^2/R mod m"; x != r
  function montSqrTo(x,r) { x.squareTo(r); this.reduce(r); }

  // r = "xy/R mod m"; x,y != r
  function montMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }

  Montgomery.prototype.convert = montConvert;
  Montgomery.prototype.revert = montRevert;
  Montgomery.prototype.reduce = montReduce;
  Montgomery.prototype.mulTo = montMulTo;
  Montgomery.prototype.sqrTo = montSqrTo;

  // (protected) true iff this is even
  function bnpIsEven() { return ((this.t>0)?(this[0]&1):this.s) == 0; }

  // (protected) this^e, e < 2^32, doing sqr and mul with "r" (HAC 14.79)
  function bnpExp(e,z) {
    if(e > 0xffffffff || e < 1) return BigInteger.ONE;
    var r = nbi(), r2 = nbi(), g = z.convert(this), i = nbits(e)-1;
    g.copyTo(r);
    while(--i >= 0) {
      z.sqrTo(r,r2);
      if((e&(1<<i)) > 0) z.mulTo(r2,g,r);
      else { var t = r; r = r2; r2 = t; }
    }
    return z.revert(r);
  }

  // (public) this^e % m, 0 <= e < 2^32
  function bnModPowInt(e,m) {
    var z;
    if(e < 256 || m.isEven()) z = new Classic(m); else z = new Montgomery(m);
    return this.exp(e,z);
  }

  // protected
  BigInteger.prototype.copyTo = bnpCopyTo;
  BigInteger.prototype.fromInt = bnpFromInt;
  BigInteger.prototype.fromString = bnpFromString;
  BigInteger.prototype.clamp = bnpClamp;
  BigInteger.prototype.dlShiftTo = bnpDLShiftTo;
  BigInteger.prototype.drShiftTo = bnpDRShiftTo;
  BigInteger.prototype.lShiftTo = bnpLShiftTo;
  BigInteger.prototype.rShiftTo = bnpRShiftTo;
  BigInteger.prototype.subTo = bnpSubTo;
  BigInteger.prototype.multiplyTo = bnpMultiplyTo;
  BigInteger.prototype.squareTo = bnpSquareTo;
  BigInteger.prototype.divRemTo = bnpDivRemTo;
  BigInteger.prototype.invDigit = bnpInvDigit;
  BigInteger.prototype.isEven = bnpIsEven;
  BigInteger.prototype.exp = bnpExp;

  // public
  BigInteger.prototype.toString = bnToString;
  BigInteger.prototype.negate = bnNegate;
  BigInteger.prototype.abs = bnAbs;
  BigInteger.prototype.compareTo = bnCompareTo;
  BigInteger.prototype.bitLength = bnBitLength;
  BigInteger.prototype.mod = bnMod;
  BigInteger.prototype.modPowInt = bnModPowInt;

  // "constants"
  BigInteger.ZERO = nbv(0);
  BigInteger.ONE = nbv(1);

  // jsbn2 stuff

  // (protected) convert from radix string
  function bnpFromRadix(s,b) {
    this.fromInt(0);
    if(b == null) b = 10;
    var cs = this.chunkSize(b);
    var d = Math.pow(b,cs), mi = false, j = 0, w = 0;
    for(var i = 0; i < s.length; ++i) {
      var x = intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-" && this.signum() == 0) mi = true;
        continue;
      }
      w = b*w+x;
      if(++j >= cs) {
        this.dMultiply(d);
        this.dAddOffset(w,0);
        j = 0;
        w = 0;
      }
    }
    if(j > 0) {
      this.dMultiply(Math.pow(b,j));
      this.dAddOffset(w,0);
    }
    if(mi) BigInteger.ZERO.subTo(this,this);
  }

  // (protected) return x s.t. r^x < DV
  function bnpChunkSize(r) { return Math.floor(Math.LN2*this.DB/Math.log(r)); }

  // (public) 0 if this == 0, 1 if this > 0
  function bnSigNum() {
    if(this.s < 0) return -1;
    else if(this.t <= 0 || (this.t == 1 && this[0] <= 0)) return 0;
    else return 1;
  }

  // (protected) this *= n, this >= 0, 1 < n < DV
  function bnpDMultiply(n) {
    this[this.t] = this.am(0,n-1,this,0,0,this.t);
    ++this.t;
    this.clamp();
  }

  // (protected) this += n << w words, this >= 0
  function bnpDAddOffset(n,w) {
    if(n == 0) return;
    while(this.t <= w) this[this.t++] = 0;
    this[w] += n;
    while(this[w] >= this.DV) {
      this[w] -= this.DV;
      if(++w >= this.t) this[this.t++] = 0;
      ++this[w];
    }
  }

  // (protected) convert to radix string
  function bnpToRadix(b) {
    if(b == null) b = 10;
    if(this.signum() == 0 || b < 2 || b > 36) return "0";
    var cs = this.chunkSize(b);
    var a = Math.pow(b,cs);
    var d = nbv(a), y = nbi(), z = nbi(), r = "";
    this.divRemTo(d,y,z);
    while(y.signum() > 0) {
      r = (a+z.intValue()).toString(b).substr(1) + r;
      y.divRemTo(d,y,z);
    }
    return z.intValue().toString(b) + r;
  }

  // (public) return value as integer
  function bnIntValue() {
    if(this.s < 0) {
      if(this.t == 1) return this[0]-this.DV;
      else if(this.t == 0) return -1;
    }
    else if(this.t == 1) return this[0];
    else if(this.t == 0) return 0;
    // assumes 16 < DB < 32
    return ((this[1]&((1<<(32-this.DB))-1))<<this.DB)|this[0];
  }

  // (protected) r = this + a
  function bnpAddTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]+a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c += a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c += a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += a.s;
    }
    r.s = (c<0)?-1:0;
    if(c > 0) r[i++] = c;
    else if(c < -1) r[i++] = this.DV+c;
    r.t = i;
    r.clamp();
  }

  BigInteger.prototype.fromRadix = bnpFromRadix;
  BigInteger.prototype.chunkSize = bnpChunkSize;
  BigInteger.prototype.signum = bnSigNum;
  BigInteger.prototype.dMultiply = bnpDMultiply;
  BigInteger.prototype.dAddOffset = bnpDAddOffset;
  BigInteger.prototype.toRadix = bnpToRadix;
  BigInteger.prototype.intValue = bnIntValue;
  BigInteger.prototype.addTo = bnpAddTo;

  //======= end jsbn =======

  // Emscripten wrapper
  var Wrapper = {
    abs: function(l, h) {
      var x = new goog.math.Long(l, h);
      var ret;
      if (x.isNegative()) {
        ret = x.negate();
      } else {
        ret = x;
      }
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
    },
    ensureTemps: function() {
      if (Wrapper.ensuredTemps) return;
      Wrapper.ensuredTemps = true;
      Wrapper.two32 = new BigInteger();
      Wrapper.two32.fromString('4294967296', 10);
      Wrapper.two64 = new BigInteger();
      Wrapper.two64.fromString('18446744073709551616', 10);
      Wrapper.temp1 = new BigInteger();
      Wrapper.temp2 = new BigInteger();
    },
    lh2bignum: function(l, h) {
      var a = new BigInteger();
      a.fromString(h.toString(), 10);
      var b = new BigInteger();
      a.multiplyTo(Wrapper.two32, b);
      var c = new BigInteger();
      c.fromString(l.toString(), 10);
      var d = new BigInteger();
      c.addTo(b, d);
      return d;
    },
    stringify: function(l, h, unsigned) {
      var ret = new goog.math.Long(l, h).toString();
      if (unsigned && ret[0] == '-') {
        // unsign slowly using jsbn bignums
        Wrapper.ensureTemps();
        var bignum = new BigInteger();
        bignum.fromString(ret, 10);
        ret = new BigInteger();
        Wrapper.two64.addTo(bignum, ret);
        ret = ret.toString(10);
      }
      return ret;
    },
    fromString: function(str, base, min, max, unsigned) {
      Wrapper.ensureTemps();
      var bignum = new BigInteger();
      bignum.fromString(str, base);
      var bigmin = new BigInteger();
      bigmin.fromString(min, 10);
      var bigmax = new BigInteger();
      bigmax.fromString(max, 10);
      if (unsigned && bignum.compareTo(BigInteger.ZERO) < 0) {
        var temp = new BigInteger();
        bignum.addTo(Wrapper.two64, temp);
        bignum = temp;
      }
      var error = false;
      if (bignum.compareTo(bigmin) < 0) {
        bignum = bigmin;
        error = true;
      } else if (bignum.compareTo(bigmax) > 0) {
        bignum = bigmax;
        error = true;
      }
      var ret = goog.math.Long.fromString(bignum.toString()); // min-max checks should have clamped this to a range goog.math.Long can handle well
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
      if (error) throw 'range error';
    }
  };
  return Wrapper;
})();

//======= end closure i64 code =======



// === Auto-generated postamble setup entry stuff ===

if (memoryInitializer) {
  if (typeof Module['locateFile'] === 'function') {
    memoryInitializer = Module['locateFile'](memoryInitializer);
  } else if (Module['memoryInitializerPrefixURL']) {
    memoryInitializer = Module['memoryInitializerPrefixURL'] + memoryInitializer;
  }
  if (ENVIRONMENT_IS_NODE || ENVIRONMENT_IS_SHELL) {
    var data = Module['readBinary'](memoryInitializer);
    HEAPU8.set(data, STATIC_BASE);
  } else {
    addRunDependency('memory initializer');
    Browser.asyncLoad(memoryInitializer, function(data) {
      HEAPU8.set(data, STATIC_BASE);
      removeRunDependency('memory initializer');
    }, function(data) {
      throw 'could not load memory initializer ' + memoryInitializer;
    });
  }
}

function ExitStatus(status) {
  this.name = "ExitStatus";
  this.message = "Program terminated with exit(" + status + ")";
  this.status = status;
};
ExitStatus.prototype = new Error();
ExitStatus.prototype.constructor = ExitStatus;

var initialStackTop;
var preloadStartTime = null;
var calledMain = false;

dependenciesFulfilled = function runCaller() {
  // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
  if (!Module['calledRun'] && shouldRunNow) run();
  if (!Module['calledRun']) dependenciesFulfilled = runCaller; // try this again later, after new deps are fulfilled
}

Module['callMain'] = Module.callMain = function callMain(args) {
  assert(runDependencies == 0, 'cannot call main when async dependencies remain! (listen on __ATMAIN__)');
  assert(__ATPRERUN__.length == 0, 'cannot call main when preRun functions remain to be called');

  args = args || [];

  ensureInitRuntime();

  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString(Module['thisProgram']), 'i8', ALLOC_NORMAL) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_NORMAL));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_NORMAL);

  initialStackTop = STACKTOP;

  try {

    var ret = Module['_main'](argc, argv, 0);


    // if we're not running an evented main loop, it's time to exit
    exit(ret);
  }
  catch(e) {
    if (e instanceof ExitStatus) {
      // exit() throws this once it's done to make sure execution
      // has been stopped completely
      return;
    } else if (e == 'SimulateInfiniteLoop') {
      // running an evented main loop, don't immediately exit
      Module['noExitRuntime'] = true;
      return;
    } else {
      if (e && typeof e === 'object' && e.stack) Module.printErr('exception thrown: ' + [e, e.stack]);
      throw e;
    }
  } finally {
    calledMain = true;
  }
}




function run(args) {
  args = args || Module['arguments'];

  if (preloadStartTime === null) preloadStartTime = Date.now();

  if (runDependencies > 0) {
    return;
  }

  preRun();

  if (runDependencies > 0) return; // a preRun added a dependency, run will be called later
  if (Module['calledRun']) return; // run may have just been called through dependencies being fulfilled just in this very frame

  function doRun() {
    if (Module['calledRun']) return; // run may have just been called while the async setStatus time below was happening
    Module['calledRun'] = true;

    if (ABORT) return; 

    ensureInitRuntime();

    preMain();

    if (ENVIRONMENT_IS_WEB && preloadStartTime !== null) {
      Module.printErr('pre-main prep time: ' + (Date.now() - preloadStartTime) + ' ms');
    }

    if (Module['onRuntimeInitialized']) Module['onRuntimeInitialized']();

    if (Module['_main'] && shouldRunNow) Module['callMain'](args);

    postRun();
  }

  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      doRun();
    }, 1);
  } else {
    doRun();
  }
}
Module['run'] = Module.run = run;

function exit(status) {
  if (Module['noExitRuntime']) {
    return;
  }

  ABORT = true;
  EXITSTATUS = status;
  STACKTOP = initialStackTop;

  // exit the runtime
  exitRuntime();

  if (ENVIRONMENT_IS_NODE) {
    // Work around a node.js bug where stdout buffer is not flushed at process exit:
    // Instead of process.exit() directly, wait for stdout flush event.
    // See https://github.com/joyent/node/issues/1669 and https://github.com/kripken/emscripten/issues/2582
    // Workaround is based on https://github.com/RReverser/acorn/commit/50ab143cecc9ed71a2d66f78b4aec3bb2e9844f6
    process['stdout']['once']('drain', function () {
      process['exit'](status);
    });
    console.log(' '); // Make sure to print something to force the drain event to occur, in case the stdout buffer was empty.
    // Work around another node bug where sometimes 'drain' is never fired - make another effort
    // to emit the exit status, after a significant delay (if node hasn't fired drain by then, give up)
    setTimeout(function() {
      process['exit'](status);
    }, 500);
  } else
  if (ENVIRONMENT_IS_SHELL && typeof quit === 'function') {
    quit(status);
  }
  // if we reach here, we must throw an exception to halt the current execution
  throw new ExitStatus(status);
}
Module['exit'] = Module.exit = exit;

function abort(text) {
  if (text) {
    Module.print(text);
    Module.printErr(text);
  }

  ABORT = true;
  EXITSTATUS = 1;

  var extra = '\nIf this abort() is unexpected, build with -s ASSERTIONS=1 which can give more information.';

  throw 'abort() at ' + stackTrace() + extra;
}
Module['abort'] = Module.abort = abort;

// {{PRE_RUN_ADDITIONS}}

if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}

// shouldRunNow refers to calling main(), not run().
var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}


run();

// {{POST_RUN_ADDITIONS}}






// {{MODULE_ADDITIONS}}



